import mockjs from 'mockjs';
import { getRule, postRule } from './mock/rule';
import {
  getActivities,
  getNotice,
  getFakeList,
  getNormalUserList,
  getUser,
  getAccumulationList,
  getAccumulation,
  getPayList,
  getVipCodeList,
  getSystemList,
  getUserPhotoList,
  getComsumerList,
  getAuthorityList,
  getRoleList,
  getDitchList,
  getDitch,
  getAuthorityPageList,
  getAllAuthorityList,
} from './mock/api';
import { getFakeChartData } from './mock/chart';
import { getProfileBasicData } from './mock/profile';
import { getProfileAdvancedData } from './mock/profile';
import { getNotices } from './mock/notices';
import { format, delay } from 'roadhog-api-doc';

// 是否禁用代理
const noProxy = process.env.NO_PROXY === 'true';

// 代码中会兼容本地 service mock 以及部署站点的静态数据
const proxy = {
  // 支持值为 Object 和 Array
  'GET /api/currentUser': {
    $desc: '获取当前用户接口',
    $params: {
      pageSize: {
        desc: '分页',
        exp: 2,
      },
    },
    $body: {
      c: 200,
      m: '',
      d: {
  "createDate":"2018-03-19",
    "createDateList":"2018-03-19",
    "userName":"export493143",
    "password":"F379EAF3C831B04DE153469D1BEC345E",
    "email":null,
    "roles": [{
    "roleName": "机构班主任",
    "actions": [{
      "actionName": "首页",
      "action": "/home",
      "type": "PAGE",
      "id": 1
    },{
      "actionName": "班级信息-添加",
      "action": "/class/add",
      "type": "FUNCTION",
      "id": 123
    }, {
      "actionName": "班级列表数据导出",
      "action": "/class/export",
      "type": "FUNCTION",
      "id": 6311
    }, {
      "actionName": "班级首页-机构班主任",
      "action": "/class/indexForAuthorizedAgencyTeacher",
      "type": "PAGE",
      "id": 6328
    }, {
      "actionName": "班级信息-详情",
      "action": "/class/get",
      "type": "FUNCTION",
      "id": 126
    }, {
      "actionName": "报名信息-添加",
      "action": "/enrol/add",
      "type": "FUNCTION",
      "id": 148
    }, {
      "actionName": "后台改密",
      "action": "/account/changePwd",
      "type": "FUNCTION",
      "id": 104
    }, {
      "actionName": "班级信息-所有开课中班级",
      "action": "/class/findAll",
      "type": "FUNCTION",
      "id": 127
    }, {
      "actionName": "授权机构管理-全部未禁用机构",
      "action": "/authorizedAgency/findAllActiveTrue",
      "type": "FUNCTION",
      "id": 5883
    }, { "actionName": "首页", "action": "/", "type": "PAGE", "id": 101 }, {
      "actionName": "报名信息-列表",
      "action": "/enrol/list",
      "type": "FUNCTION",
      "id": 147
    }, {
      "actionName": "报名信息-详情",
      "action": "/enrol/get",
      "type": "FUNCTION",
      "id": 149
    }, {
      "actionName": "课程问题-列表",
      "action": "/putQuestionOnWite/list",
      "type": "FUNCTION",
      "id": 164
    }, {
      "actionName": "班级信息-开课",
      "action": "/class/startCourse/.*",
      "type": "FUNCTION",
      "id": 128
    }, {
      "actionName": "课程已回答问题页",
      "action": "/putQuestionOnWite/indexOnSuccessful",
      "type": "PAGE",
      "id": 163
    }, {
      "actionName": "课程问题-回答",
      "action": "/putQuestionOnWite/update",
      "type": "FUNCTION",
      "id": 166
    }, {
      "actionName": "班级信息-列表",
      "action": "/class/list",
      "type": "FUNCTION",
      "id": 122
    }, {
      "actionName": "课程问题-详情",
      "action": "/putQuestionOnWite/get",
      "type": "FUNCTION",
      "id": 165
    }, {
      "actionName": "报名信息-删除",
      "action": "/enrol/delete",
      "type": "FUNCTION",
      "id": 151
    }, {
      "actionName": "报名信息-机构班主任",
      "action": "/enrol/indexForAuthorizedAgencyTeacher",
      "type": "PAGE",
      "id": 6351
    }, {
      "actionName": "后台登出",
      "action": "/account/quit",
      "type": "PAGE",
      "id": 103
    }, {
      "actionName": "报名信息-修改",
      "action": "/enrol/update",
      "type": "FUNCTION",
      "id": 150
    }, {
      "actionName": "平台班主任管理-所有平台班主任",
      "action": "/teacher/findAll",
      "type": "FUNCTION",
      "id": 214
    }, {
      "actionName": "班级信息-删除",
      "action": "/class/delete",
      "type": "FUNCTION",
      "id": 125
    }, {
      "actionName": "班级信息-所有班级",
      "action": "/class/findAllClass",
      "type": "FUNCTION",
      "id": 129
    }, {
      "actionName": "课程待回答问题页",
      "action": "/putQuestionOnWite/index",
      "type": "PAGE",
      "id": 162
    }, {
      "actionName": "报名信息列表数据导出",
      "action": "/enrol/export",
      "type": "FUNCTION",
      "id": 6312
    }, {
      "actionName": "报名信息-重发开班码",
      "action": "/enrol/reSendCode/.*",
      "type": "FUNCTION",
      "id": 153
    }, {
      "actionName": "课程问题-删除",
      "action": "/putQuestionOnWite/delete",
      "type": "FUNCTION",
      "id": 167
    }, {
      "actionName": "班主任问题列表数据导出",
      "action": "/putQuestionOnWite/export",
      "type": "FUNCTION",
      "id": 6325
    }, {
      "actionName": "班级信息-修改",
      "action": "/class/update",
      "type": "FUNCTION",
      "id": 124
    }, {
      "actionName": "课程问题-所有班级",
      "action": "/class/findAllClassByOtherId",
      "type": "FUNCTION",
      "id": 6301
    }, {
      "actionName": "后台登录",
      "action": "/account/login",
      "type": "PAGE",
      "id": 102
    }, {
      "actionName": "机构班主任管理-所有机构班主任",
      "action": "/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*",
      "type": "FUNCTION",
      "id": 5877
    }],}],
    "id": 4,
    "avatar": 'https://gw.alipayobjects.com/zos/rmsportal/BiazfanxmamNRoxxVxka.png',
    }
    },
  },
  // GET POST 可省略
  'GET /api/users': [
    {
      key: '1',
      name: 'John Brown',
      age: 32,
      address: 'New York No. 1 Lake Park',
    },
    {
      key: '2',
      name: 'Jim Green',
      age: 42,
      address: 'London No. 1 Lake Park',
    },
    {
      key: '3',
      name: 'Joe Black',
      age: 32,
      address: 'Sidney No. 1 Lake Park',
    },
  ],
  'GET /api/project/notice': getNotice,
  'GET /api/activities': getActivities,
  'GET /api/rule': getRule,
  'POST /api/rule': {
    $params: {
      pageSize: {
        desc: '分页',
        exp: 2,
      },
    },
    $body: postRule,
  },
  'POST /api/forms': (req, res) => {
    res.send({ message: 'Ok' });
  },
  'GET /api/tags': mockjs.mock({
    'list|100': [{ name: '@city', 'value|1-100': 150, 'type|0-2': 1 }],
  }),
  'GET /api/fake_list': getFakeList,
  'GET /api/fake_normal_user_list': getNormalUserList,
  'GET /api/v1/consumer/get': getUser,
  'POST /api/pass_user_list': (req, res) => {
    res.send({ status: 'ok' });
  },
  'GET /api/pass_user': (req, res) => {
    res.send({ status: 'ok' });
  },
  'GET /api/fail_user': (req, res) => {
    res.send({ status: 'ok' });
  },
  'GET /api/delete_photo': (req, res) => {
    res.status(403).send({
      c: 200,
      m: '',
      d: {},
    });
  },
  'POST /api/upload': (req, res) => {
    res.send({ status: 'done' });
  },
  'GET /api/fake_chart_data': getFakeChartData,
  'POST /api/v1/gathering/list': getAccumulationList,
  'GET /api/v1/gathering/gathering': getAccumulation,
  'POST /api/fake_accumulation_submit': (req, res) => {
    res.send({
      c: 200,
       m: '',
      d: {
        id: 12,
      },
    });
  },
  'GET /api/accumulation_delete': (req, res) => {
    res.send({
      status: 'ok',
    });
  },
  'POST /api/fake_accumulation_edit': (req, res) => {
    res.send({
      status: 'error',
    });
  },
  'GET /api/fake_pay_list': getPayList,
  'GET /api/fake_suspend': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {}
    });
  },
  'GET /api/fake_vipCode_list': getVipCodeList,
  'GET /api/v1/log/list': getSystemList,
  'POST /api/album/list': getUserPhotoList,
  'GET /api/fake_comsumer_list': getComsumerList,
  'GET /api/profile/basic': getProfileBasicData,
  'GET /api/profile/advanced': getProfileAdvancedData,
  'POST /api/auth/login': (req, res) => {
    const { password, username, type } = req.body;
    if (password === '888888' && username === 'admin') {
      res.send({
        c: 200,
        m: '',
        d:  [{
              "name": "首页",
              "url": "/home",
              "type": "PAGE",
              "id": 163
            }, {
              "name": "聚点管理",
              "url": "/accumulationList",
              "type": "PAGE",
              "id": 6351
            },],
      });
      return;
    }
    if (password === '123456' && username === 'user') {
      res.send({
        c: 200,
        m: '',
        d: [{
              "name": "首页",
              "url": "/home",
              "type": "PAGE",
              "id": 163
            },],
      });
      return;
    }
    res.send({
      c: 200,
      m: 'error',
      d: '',
    });
  },
  'POST /api/fake_personal_submit': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {}
    });
  },
  'POST /api/v1/sysTag/list': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {
        data: [{
        name: '标签1',
        used: 200,
        createdDate: '2018-12-09',
        state: '删除',
      },{
        name: '标签2',
        used: 10,
        createdDate: '2018-01-09',
        state: '正常',
      }],
      total: 2,
      pageSize: 30,
      page: 1,
      },
    });
  },
  'GET /api/v1/sysTag/sysTag': (req, res) => {
    res.send({
      c: 200,
      m: null,
      d: {
        name: '标签1',
      },
    });
  },
  'GET /api/500': (req, res) => {
    res.status(500).send({
      timestamp: 1513932555104,
      status: 500,
      error: 'error',
      message: 'error',
      path: '/base/category/list',
    });
  },
  'GET /api/404': (req, res) => {
    res.status(404).send({
      timestamp: 1513932643431,
      status: 404,
      error: 'Not Found',
      message: 'No message available',
      path: '/base/category/list/2121212',
    });
  },
  'GET /api/403': (req, res) => {
    res.status(403).send({
      timestamp: 1513932555104,
      status: 403,
      error: 'Unauthorized',
      message: 'Unauthorized',
      path: '/base/category/list',
    });
  },
  'GET /api/401': (req, res) => {
    res.status(401).send({
      timestamp: 1513932555104,
      status: 401,
      error: 'Unauthorized',
      message: 'Unauthorized',
      path: '/base/category/list',
    });
  },
  'GET /api/fake_ditch_list': getDitchList,
  'GET /api/fake_ditch': getDitch,
  'POST /api/v1/sysAuthority/list': getAuthorityList,
  'POST /api/v1/sysAuthority/all': getAllAuthorityList,
  'GET /api/fake_authority': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {
        id: 1321,
        type: 1,
        createDate: '2018-01-12',
        name: '权限管理-修改',
      }
    });
  },
  'GET /api/fake_delete_authority': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {
        id: 1321,
        type: 1,
        createDate: '2018-01-12',
        name: '权限管理-修改',
      }
    });
  },
  'GET /api/fake_all_role': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: [{"roleName":"专家","actions":[{"actionName":"班主任问题列表数据导出","action":"/putQuestionOnWite/export","type":"FUNCTION","id":6325},{"actionName":"课程待回答问题页","action":"/putQuestionOnWite/index","type":"PAGE","id":162},{"actionName":"课程问题-所有班级","action":"/class/findAllClassByOtherId","type":"FUNCTION","id":6301},{"actionName":"课程已回答问题页","action":"/putQuestionOnWite/indexOnSuccessful","type":"PAGE","id":163},{"actionName":"课程问题-回答","action":"/putQuestionOnWite/update","type":"FUNCTION","id":166},{"actionName":"课程问题-详情","action":"/putQuestionOnWite/get","type":"FUNCTION","id":165},{"actionName":"后台登出","action":"/account/quit","type":"PAGE","id":103},{"actionName":"首页","action":"/","type":"PAGE","id":101},{"actionName":"后台登录","action":"/account/login","type":"PAGE","id":102},{"actionName":"课程问题-删除","action":"/putQuestionOnWite/delete","type":"FUNCTION","id":167},{"actionName":"课程问题-列表","action":"/putQuestionOnWite/list","type":"FUNCTION","id":164}],"createDate":"2011-11-11","createDateList":"2011-11-11","id":1},{"roleName":"平台班主任","actions":[{"actionName":"班级首页-平台班主任","action":"/class/indexForTeacher","type":"PAGE","id":6329},{"actionName":"班级信息-添加","action":"/class/add","type":"FUNCTION","id":123},{"actionName":"班级列表数据导出","action":"/class/export","type":"FUNCTION","id":6311},{"actionName":"报名信息-平台班主任","action":"/enrol/indexForTeacher","type":"PAGE","id":6352},{"actionName":"班级信息-详情","action":"/class/get","type":"FUNCTION","id":126},{"actionName":"报名信息-添加","action":"/enrol/add","type":"FUNCTION","id":148},{"actionName":"后台改密","action":"/account/changePwd","type":"FUNCTION","id":104},{"actionName":"班级信息-所有开课中班级","action":"/class/findAll","type":"FUNCTION","id":127},{"actionName":"授权机构管理-全部未禁用机构","action":"/authorizedAgency/findAllActiveTrue","type":"FUNCTION","id":5883},{"actionName":"首页","action":"/","type":"PAGE","id":101},{"actionName":"报名信息-列表","action":"/enrol/list","type":"FUNCTION","id":147},{"actionName":"报名信息-详情","action":"/enrol/get","type":"FUNCTION","id":149},{"actionName":"课程问题-列表","action":"/putQuestionOnWite/list","type":"FUNCTION","id":164},{"actionName":"班级信息-开课","action":"/class/startCourse/.*","type":"FUNCTION","id":128},{"actionName":"课程已回答问题页","action":"/putQuestionOnWite/indexOnSuccessful","type":"PAGE","id":163},{"actionName":"课程问题-回答","action":"/putQuestionOnWite/update","type":"FUNCTION","id":166},{"actionName":"班级信息-列表","action":"/class/list","type":"FUNCTION","id":122},{"actionName":"课程问题-详情","action":"/putQuestionOnWite/get","type":"FUNCTION","id":165},{"actionName":"报名信息-删除","action":"/enrol/delete","type":"FUNCTION","id":151},{"actionName":"后台登出","action":"/account/quit","type":"PAGE","id":103},{"actionName":"报名信息-修改","action":"/enrol/update","type":"FUNCTION","id":150},{"actionName":"平台班主任管理-所有平台班主任","action":"/teacher/findAll","type":"FUNCTION","id":214},{"actionName":"班级信息-删除","action":"/class/delete","type":"FUNCTION","id":125},{"actionName":"班级信息-所有班级","action":"/class/findAllClass","type":"FUNCTION","id":129},{"actionName":"课程待回答问题页","action":"/putQuestionOnWite/index","type":"PAGE","id":162},{"actionName":"报名信息列表数据导出","action":"/enrol/export","type":"FUNCTION","id":6312},{"actionName":"报名信息-重发开班码","action":"/enrol/reSendCode/.*","type":"FUNCTION","id":153},{"actionName":"课程问题-删除","action":"/putQuestionOnWite/delete","type":"FUNCTION","id":167},{"actionName":"班主任问题列表数据导出","action":"/putQuestionOnWite/export","type":"FUNCTION","id":6325},{"actionName":"班级信息-修改","action":"/class/update","type":"FUNCTION","id":124},{"actionName":"课程问题-所有班级","action":"/class/findAllClassByOtherId","type":"FUNCTION","id":6301},{"actionName":"后台登录","action":"/account/login","type":"PAGE","id":102},{"actionName":"机构班主任管理-所有机构班主任","action":"/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*","type":"FUNCTION","id":5877}],"createDate":"2011-11-11","createDateList":"2011-11-11","id":2},{"roleName":"机构管理员","actions":[{"actionName":"机构班主任问题页","action":"/authorizedAgencyTeacher/show","type":"PAGE","id":6392},{"actionName":"班级信息-添加","action":"/class/add","type":"FUNCTION","id":123},{"actionName":"机构班主任管理-详情","action":"/authorizedAgencyTeacher/get","type":"FUNCTION","id":5874},{"actionName":"机构班主任管理-删除","action":"/authorizedAgencyTeacher/delete","type":"FUNCTION","id":5876},{"actionName":"班级列表数据导出","action":"/class/export","type":"FUNCTION","id":6311},{"actionName":"班级信息-详情","action":"/class/get","type":"FUNCTION","id":126},{"actionName":"报名信息-添加","action":"/enrol/add","type":"FUNCTION","id":148},{"actionName":"后台改密","action":"/account/changePwd","type":"FUNCTION","id":104},{"actionName":"班级信息-所有开课中班级","action":"/class/findAll","type":"FUNCTION","id":127},{"actionName":"授权机构管理-全部未禁用机构","action":"/authorizedAgency/findAllActiveTrue","type":"FUNCTION","id":5883},{"actionName":"首页","action":"/","type":"PAGE","id":101},{"actionName":"报名信息-列表","action":"/enrol/list","type":"FUNCTION","id":147},{"actionName":"报名信息-详情","action":"/enrol/get","type":"FUNCTION","id":149},{"actionName":"课程问题-列表","action":"/putQuestionOnWite/list","type":"FUNCTION","id":164},{"actionName":"机构班主任列表数据导出","action":"/authorizedAgencyTeacher/export","type":"FUNCTION","id":6306},{"actionName":"班级首页-授权机构","action":"/class/indexForAuthorizedAgency","type":"PAGE","id":6327},{"actionName":"机构班主任管理-列表","action":"/authorizedAgencyTeacher/list","type":"FUNCTION","id":5872},{"actionName":"班级信息-开课","action":"/class/startCourse/.*","type":"FUNCTION","id":128},{"actionName":"机构班主任管理-修改","action":"/authorizedAgencyTeacher/update","type":"FUNCTION","id":5875},{"actionName":"课程问题-回答","action":"/putQuestionOnWite/update","type":"FUNCTION","id":166},{"actionName":"班级信息-列表","action":"/class/list","type":"FUNCTION","id":122},{"actionName":"课程问题-详情","action":"/putQuestionOnWite/get","type":"FUNCTION","id":165},{"actionName":"报名信息-删除","action":"/enrol/delete","type":"FUNCTION","id":151},{"actionName":"后台登出","action":"/account/quit","type":"PAGE","id":103},{"actionName":"报名信息-修改","action":"/enrol/update","type":"FUNCTION","id":150},{"actionName":"平台班主任管理-所有平台班主任","action":"/teacher/findAll","type":"FUNCTION","id":214},{"actionName":"报名信息-授权机构","action":"/enrol/indexForAuthorizedAgency","type":"PAGE","id":6330},{"actionName":"班级信息-删除","action":"/class/delete","type":"FUNCTION","id":125},{"actionName":"班级信息-所有班级","action":"/class/findAllClass","type":"FUNCTION","id":129},{"actionName":"机构班主任管理-添加","action":"/authorizedAgencyTeacher/add","type":"FUNCTION","id":5873},{"actionName":"机构班主任管理页","action":"/authorizedAgencyTeacher/index","type":"PAGE","id":5871},{"actionName":"报名信息列表数据导出","action":"/enrol/export","type":"FUNCTION","id":6312},{"actionName":"报名信息-重发开班码","action":"/enrol/reSendCode/.*","type":"FUNCTION","id":153},{"actionName":"课程问题-删除","action":"/putQuestionOnWite/delete","type":"FUNCTION","id":167},{"actionName":"班主任问题列表数据导出","action":"/putQuestionOnWite/export","type":"FUNCTION","id":6325},{"actionName":"班级信息-修改","action":"/class/update","type":"FUNCTION","id":124},{"actionName":"课程问题-所有班级","action":"/class/findAllClassByOtherId","type":"FUNCTION","id":6301},{"actionName":"后台登录","action":"/account/login","type":"PAGE","id":102},{"actionName":"机构班主任管理-所有机构班主任","action":"/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*","type":"FUNCTION","id":5877}],"createDate":"2011-11-11","createDateList":"2011-11-11","id":3},{"roleName":"机构班主任","actions":[{"actionName":"班级信息-添加","action":"/class/add","type":"FUNCTION","id":123},{"actionName":"班级列表数据导出","action":"/class/export","type":"FUNCTION","id":6311},{"actionName":"班级首页-机构班主任","action":"/class/indexForAuthorizedAgencyTeacher","type":"PAGE","id":6328},{"actionName":"班级信息-详情","action":"/class/get","type":"FUNCTION","id":126},{"actionName":"报名信息-添加","action":"/enrol/add","type":"FUNCTION","id":148},{"actionName":"后台改密","action":"/account/changePwd","type":"FUNCTION","id":104},{"actionName":"班级信息-所有开课中班级","action":"/class/findAll","type":"FUNCTION","id":127},{"actionName":"授权机构管理-全部未禁用机构","action":"/authorizedAgency/findAllActiveTrue","type":"FUNCTION","id":5883},{"actionName":"首页","action":"/","type":"PAGE","id":101},{"actionName":"报名信息-列表","action":"/enrol/list","type":"FUNCTION","id":147},{"actionName":"报名信息-详情","action":"/enrol/get","type":"FUNCTION","id":149},{"actionName":"课程问题-列表","action":"/putQuestionOnWite/list","type":"FUNCTION","id":164},{"actionName":"班级信息-开课","action":"/class/startCourse/.*","type":"FUNCTION","id":128},{"actionName":"课程已回答问题页","action":"/putQuestionOnWite/indexOnSuccessful","type":"PAGE","id":163},{"actionName":"课程问题-回答","action":"/putQuestionOnWite/update","type":"FUNCTION","id":166},{"actionName":"班级信息-列表","action":"/class/list","type":"FUNCTION","id":122},{"actionName":"课程问题-详情","action":"/putQuestionOnWite/get","type":"FUNCTION","id":165},{"actionName":"报名信息-删除","action":"/enrol/delete","type":"FUNCTION","id":151},{"actionName":"报名信息-机构班主任","action":"/enrol/indexForAuthorizedAgencyTeacher","type":"PAGE","id":6351},{"actionName":"后台登出","action":"/account/quit","type":"PAGE","id":103},{"actionName":"报名信息-修改","action":"/enrol/update","type":"FUNCTION","id":150},{"actionName":"平台班主任管理-所有平台班主任","action":"/teacher/findAll","type":"FUNCTION","id":214},{"actionName":"班级信息-删除","action":"/class/delete","type":"FUNCTION","id":125},{"actionName":"班级信息-所有班级","action":"/class/findAllClass","type":"FUNCTION","id":129},{"actionName":"课程待回答问题页","action":"/putQuestionOnWite/index","type":"PAGE","id":162},{"actionName":"报名信息列表数据导出","action":"/enrol/export","type":"FUNCTION","id":6312},{"actionName":"报名信息-重发开班码","action":"/enrol/reSendCode/.*","type":"FUNCTION","id":153},{"actionName":"课程问题-删除","action":"/putQuestionOnWite/delete","type":"FUNCTION","id":167},{"actionName":"班主任问题列表数据导出","action":"/putQuestionOnWite/export","type":"FUNCTION","id":6325},{"actionName":"班级信息-修改","action":"/class/update","type":"FUNCTION","id":124},{"actionName":"课程问题-所有班级","action":"/class/findAllClassByOtherId","type":"FUNCTION","id":6301},{"actionName":"后台登录","action":"/account/login","type":"PAGE","id":102},{"actionName":"机构班主任管理-所有机构班主任","action":"/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*","type":"FUNCTION","id":5877}],"createDate":"2011-11-11","createDateList":"2011-11-11","id":4},{"roleName":"班级管理员","actions":[{"actionName":"机构班主任问题页","action":"/authorizedAgencyTeacher/show","type":"PAGE","id":6392},{"actionName":"机构班主任管理-删除","action":"/authorizedAgencyTeacher/delete","type":"FUNCTION","id":5876},{"actionName":"平台班主任管理-添加","action":"/teacher/add","type":"FUNCTION","id":210},{"actionName":"报名信息-添加","action":"/enrol/add","type":"FUNCTION","id":148},{"actionName":"后台改密","action":"/account/changePwd","type":"FUNCTION","id":104},{"actionName":"班级信息-所有开课中班级","action":"/class/findAll","type":"FUNCTION","id":127},{"actionName":"首页","action":"/","type":"PAGE","id":101},{"actionName":"课程问题-列表","action":"/putQuestionOnWite/list","type":"FUNCTION","id":164},{"actionName":"机构班主任管理-列表","action":"/authorizedAgencyTeacher/list","type":"FUNCTION","id":5872},{"actionName":"班级信息-开课","action":"/class/startCourse/.*","type":"FUNCTION","id":128},{"actionName":"授权机构列表数据导出","action":"/authorizedAgency/export","type":"FUNCTION","id":6303},{"actionName":"课程问题-回答","action":"/putQuestionOnWite/update","type":"FUNCTION","id":166},{"actionName":"平台班主任管理-列表","action":"/teacher/list","type":"FUNCTION","id":209},{"actionName":"报名信息页","action":"/enrol/index","type":"PAGE","id":146},{"actionName":"平台班主任管理页","action":"/teacher/index","type":"PAGE","id":208},{"actionName":"后台登出","action":"/account/quit","type":"PAGE","id":103},{"actionName":"平台班主任管理-所有平台班主任","action":"/teacher/findAll","type":"FUNCTION","id":214},{"actionName":"机构班主任管理-添加","action":"/authorizedAgencyTeacher/add","type":"FUNCTION","id":5873},{"actionName":"平台班主任管理-删除","action":"/teacher/delete","type":"FUNCTION","id":213},{"actionName":"授权机构管理-添加","action":"/authorizedAgency/add","type":"FUNCTION","id":5880},{"actionName":"报名信息列表数据导出","action":"/enrol/export","type":"FUNCTION","id":6312},{"actionName":"平台班主任问题页","action":"/teacher/show","type":"PAGE","id":6391},{"actionName":"课程问题-删除","action":"/putQuestionOnWite/delete","type":"FUNCTION","id":167},{"actionName":"授权机构管理-删除","action":"/authorizedAgency/delete","type":"FUNCTION","id":5882},{"actionName":"平台班主任管理-修改","action":"/teacher/update","type":"FUNCTION","id":212},{"actionName":"班主任问题列表数据导出","action":"/putQuestionOnWite/export","type":"FUNCTION","id":6325},{"actionName":"课程问题-所有班级","action":"/class/findAllClassByOtherId","type":"FUNCTION","id":6301},{"actionName":"机构班主任管理-所有机构班主任","action":"/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*","type":"FUNCTION","id":5877},{"actionName":"系统配置-详情","action":"/configuration/get","type":"FUNCTION","id":131},{"actionName":"班级信息-添加","action":"/class/add","type":"FUNCTION","id":123},{"actionName":"机构班主任管理-详情","action":"/authorizedAgencyTeacher/get","type":"FUNCTION","id":5874},{"actionName":"班级列表数据导出","action":"/class/export","type":"FUNCTION","id":6311},{"actionName":"班级信息-详情","action":"/class/get","type":"FUNCTION","id":126},{"actionName":"授权机构管理-修改","action":"/authorizedAgency/update","type":"FUNCTION","id":5881},{"actionName":"授权机构管理-全部未禁用机构","action":"/authorizedAgency/findAllActiveTrue","type":"FUNCTION","id":5883},{"actionName":"报名信息-列表","action":"/enrol/list","type":"FUNCTION","id":147},{"actionName":"报名信息-详情","action":"/enrol/get","type":"FUNCTION","id":149},{"actionName":"机构班主任列表数据导出","action":"/authorizedAgencyTeacher/export","type":"FUNCTION","id":6306},{"actionName":"主页","action":"/index","type":"PAGE","id":180},{"actionName":"机构班主任管理-修改","action":"/authorizedAgencyTeacher/update","type":"FUNCTION","id":5875},{"actionName":"班级信息-列表","action":"/class/list","type":"FUNCTION","id":122},{"actionName":"课程问题-详情","action":"/putQuestionOnWite/get","type":"FUNCTION","id":165},{"actionName":"报名信息-删除","action":"/enrol/delete","type":"FUNCTION","id":151},{"actionName":"报名信息-修改","action":"/enrol/update","type":"FUNCTION","id":150},{"actionName":"班级信息-删除","action":"/class/delete","type":"FUNCTION","id":125},{"actionName":"班级信息-所有班级","action":"/class/findAllClass","type":"FUNCTION","id":129},{"actionName":"平台班主任管理-详情","action":"/teacher/get","type":"FUNCTION","id":211},{"actionName":"机构班主任管理页","action":"/authorizedAgencyTeacher/index","type":"PAGE","id":5871},{"actionName":"报名信息-重发开班码","action":"/enrol/reSendCode/.*","type":"FUNCTION","id":153},{"actionName":"班级信息页","action":"/class/index","type":"PAGE","id":121},{"actionName":"班级信息-修改","action":"/class/update","type":"FUNCTION","id":124},{"actionName":"授权机构管理页","action":"/authorizedAgency/index","type":"PAGE","id":5878},{"actionName":"授权机构管理-列表","action":"/authorizedAgency/list","type":"FUNCTION","id":5879},{"actionName":"平台班主任列表数据导出","action":"/teacher/export","type":"FUNCTION","id":6305},{"actionName":"后台登录","action":"/account/login","type":"PAGE","id":102},{"actionName":"授权机构管理-详情","action":"/authorizedAgency/get","type":"FUNCTION","id":25461}],"createDate":"2011-11-11","createDateList":"2011-11-11","id":5},{"roleName":"考试管理员","actions":[{"actionName":"申请管理-有效期单元","action":"/examinee/validUnit.*","type":"FUNCTION","id":277},{"actionName":"订单管理页","action":"/orderRecord/index","type":"PAGE","id":174},{"actionName":"考试管理-详情","action":"/examination/get","type":"FUNCTION","id":259},{"actionName":"考试管理-单元信息页","action":"/examination/show","type":"PAGE","id":262},{"actionName":"城市列表","action":"/city/cityList/.*","type":"FUNCTION","id":255},{"actionName":"考试单元页","action":"/examinationUnit/index","type":"PAGE","id":265},{"actionName":"申请管理-延考","action":"/examinee/delay","type":"FUNCTION","id":279},{"actionName":"后台改密","action":"/account/changePwd","type":"FUNCTION","id":104},{"actionName":"考试单元列表数据导出","action":"/examination/exportUnit","type":"FUNCTION","id":6318},{"actionName":"首页","action":"/","type":"PAGE","id":101},{"actionName":"订单管理-列表","action":"/orderRecord/list","type":"FUNCTION","id":175},{"actionName":"考试列表数据导出","action":"/examination/export","type":"FUNCTION","id":6317},{"actionName":"订单列表数据导出","action":"/orderRecord/export","type":"FUNCTION","id":6307},{"actionName":"考试单元-详情","action":"/examinationUnit/get","type":"FUNCTION","id":268},{"actionName":"认证申请管理页","action":"/certification/index","type":"PAGE","id":251},{"actionName":"考试申请列表数据导出","action":"/examinee/export","type":"FUNCTION","id":6319},{"actionName":"测评认证-单元报名人数","action":"/examinationRoom/get","type":"FUNCTION","id":264},{"actionName":"申请管理-对应考试下所有单元","action":"/examinee/unitList/.*","type":"FUNCTION","id":276},{"actionName":"订单管理-删除","action":"/orderRecord/delete","type":"FUNCTION","id":179},{"actionName":"后台登出","action":"/account/quit","type":"PAGE","id":103},{"actionName":"申请管理-审核","action":"/examinee/update","type":"FUNCTION","id":274},{"actionName":"认证申请管理-列表","action":"/certification/list","type":"FUNCTION","id":252},{"actionName":"考试单元-添加","action":"/examinationUnit/add","type":"FUNCTION","id":267},{"actionName":"考试单元-删除","action":"/examinationUnit/delete","type":"FUNCTION","id":269},{"actionName":"考试管理页","action":"/examination/index","type":"PAGE","id":256},{"actionName":"申请管理-详情","action":"/examinee/get","type":"FUNCTION","id":273},{"actionName":"认证申请管理-通过","action":"/certification/pass","type":"FUNCTION","id":253},{"actionName":"考试管理-修改","action":"/examination/update","type":"FUNCTION","id":261},{"actionName":"考试管理-添加","action":"/examination/add","type":"FUNCTION","id":258},{"actionName":"申请管理-切换城市","action":"/examinee/changeCity","type":"FUNCTION","id":278},{"actionName":"考试单元-修改","action":"/examinationUnit/update","type":"FUNCTION","id":270},{"actionName":"订单管理-处理","action":"/orderRecord/update","type":"FUNCTION","id":177},{"actionName":"考试单元-列表","action":"/examinationUnit/list","type":"FUNCTION","id":266},{"actionName":"考试管理-删除","action":"/examination/delete","type":"FUNCTION","id":260},{"actionName":"申请管理-列表","action":"/examinee/list","type":"FUNCTION","id":272},{"actionName":"订单管理-详情","action":"/orderRecord/get","type":"FUNCTION","id":176},{"actionName":"订单管理-追加订单","action":"/orderRecord/add","type":"FUNCTION","id":178},{"actionName":"考试管理-列表","action":"/examination/list","type":"FUNCTION","id":257},{"actionName":"证书申请列表数据导出","action":"/certification/export","type":"FUNCTION","id":6320},{"actionName":"申请管理-对应城市下所有考试","action":"/examinee/examinationList/.*","type":"FUNCTION","id":275},{"actionName":"认证申请管理-拒绝","action":"/certification/refuse","type":"FUNCTION","id":254},{"actionName":"申请管理页","action":"/examinee/index","type":"PAGE","id":271},{"actionName":"后台登录","action":"/account/login","type":"PAGE","id":102},{"actionName":"测评认证-添加考场","action":"/examinationRoom/addRoom","type":"FUNCTION","id":263}],"createDate":"2011-11-11","createDateList":"2011-11-11","id":6},{"roleName":"平台管理员","actions":[{"actionName":"考试管理-单元信息页","action":"/examination/show","type":"PAGE","id":262},{"actionName":"报名信息-添加","action":"/enrol/add","type":"FUNCTION","id":148},{"actionName":"后台改密","action":"/account/changePwd","type":"FUNCTION","id":104},{"actionName":"班级信息-所有开课中班级","action":"/class/findAll","type":"FUNCTION","id":127},{"actionName":"会员积分明细列表数据导出","action":"/sendIntegral/export","type":"FUNCTION","id":6326},{"actionName":"订单列表数据导出","action":"/orderRecord/export","type":"FUNCTION","id":6307},{"actionName":"课程问题-回答","action":"/putQuestionOnWite/update","type":"FUNCTION","id":166},{"actionName":"报名信息页","action":"/enrol/index","type":"PAGE","id":146},{"actionName":"专家管理-添加","action":"/expert/add","type":"FUNCTION","id":156},{"actionName":"平台班主任管理-所有平台班主任","action":"/teacher/findAll","type":"FUNCTION","id":214},{"actionName":"用户列表数据导出","action":"/account/export","type":"FUNCTION","id":6322},{"actionName":"机构班主任管理-添加","action":"/authorizedAgencyTeacher/add","type":"FUNCTION","id":5873},{"actionName":"认证申请管理-通过","action":"/certification/pass","type":"FUNCTION","id":253},{"actionName":"授权机构管理-添加","action":"/authorizedAgency/add","type":"FUNCTION","id":5880},{"actionName":"报名信息列表数据导出","action":"/enrol/export","type":"FUNCTION","id":6312},{"actionName":"考试管理-添加","action":"/examination/add","type":"FUNCTION","id":258},{"actionName":"课程问题-删除","action":"/putQuestionOnWite/delete","type":"FUNCTION","id":167},{"actionName":"授权机构管理-删除","action":"/authorizedAgency/delete","type":"FUNCTION","id":5882},{"actionName":"平台班主任管理-修改","action":"/teacher/update","type":"FUNCTION","id":212},{"actionName":"考试单元-列表","action":"/examinationUnit/list","type":"FUNCTION","id":266},{"actionName":"申请管理-列表","action":"/examinee/list","type":"FUNCTION","id":272},{"actionName":"考试管理-列表","action":"/examination/list","type":"FUNCTION","id":257},{"actionName":"机构班主任管理-所有机构班主任","action":"/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*","type":"FUNCTION","id":5877},{"actionName":"积分列表-列表","action":"/sendIntegral/list","type":"FUNCTION","id":207},{"actionName":"订单管理页","action":"/orderRecord/index","type":"PAGE","id":174},{"actionName":"机构班主任管理-详情","action":"/authorizedAgencyTeacher/get","type":"FUNCTION","id":5874},{"actionName":"城市列表","action":"/city/cityList/.*","type":"FUNCTION","id":255},{"actionName":"授权机构管理-修改","action":"/authorizedAgency/update","type":"FUNCTION","id":5881},{"actionName":"会员管理列表数据导出","action":"/user/export","type":"FUNCTION","id":6302},{"actionName":"登录页","action":"/login","type":"PAGE","id":181},{"actionName":"会员管理-考试信息","action":"/user/exam","type":"FUNCTION","id":227},{"actionName":"考试单元列表数据导出","action":"/examination/exportUnit","type":"FUNCTION","id":6318},{"actionName":"专家列表数据导出","action":"/expert/export","type":"FUNCTION","id":6304},{"actionName":"机构班主任列表数据导出","action":"/authorizedAgencyTeacher/export","type":"FUNCTION","id":6306},{"actionName":"主页","action":"/index","type":"PAGE","id":180},{"actionName":"认证申请管理页","action":"/certification/index","type":"PAGE","id":251},{"actionName":"机构班主任管理-修改","action":"/authorizedAgencyTeacher/update","type":"FUNCTION","id":5875},{"actionName":"专家管理-列表","action":"/expert/list","type":"FUNCTION","id":155},{"actionName":"测评认证-单元报名人数","action":"/examinationRoom/get","type":"FUNCTION","id":264},{"actionName":"班级信息-列表","action":"/class/list","type":"FUNCTION","id":122},{"actionName":"课程问题-详情","action":"/putQuestionOnWite/get","type":"FUNCTION","id":165},{"actionName":"报名信息-删除","action":"/enrol/delete","type":"FUNCTION","id":151},{"actionName":"订单管理-删除","action":"/orderRecord/delete","type":"FUNCTION","id":179},{"actionName":"申请管理-审核","action":"/examinee/update","type":"FUNCTION","id":274},{"actionName":"考试单元-删除","action":"/examinationUnit/delete","type":"FUNCTION","id":269},{"actionName":"班级信息-删除","action":"/class/delete","type":"FUNCTION","id":125},{"actionName":"报名信息-重发开班码","action":"/enrol/reSendCode/.*","type":"FUNCTION","id":153},{"actionName":"专家管理-删除","action":"/expert/delete","type":"FUNCTION","id":159},{"actionName":"专家管理页","action":"/expert/index","type":"PAGE","id":154},{"actionName":"申请管理-切换城市","action":"/examinee/changeCity","type":"FUNCTION","id":278},{"actionName":"考试单元-修改","action":"/examinationUnit/update","type":"FUNCTION","id":270},{"actionName":"班级信息-修改","action":"/class/update","type":"FUNCTION","id":124},{"actionName":"考试管理-删除","action":"/examination/delete","type":"FUNCTION","id":260},{"actionName":"授权机构管理页","action":"/authorizedAgency/index","type":"PAGE","id":5878},{"actionName":"用户管理-列表","action":"/account/list","type":"FUNCTION","id":106},{"actionName":"证书申请列表数据导出","action":"/certification/export","type":"FUNCTION","id":6320},{"actionName":"平台班主任列表数据导出","action":"/teacher/export","type":"FUNCTION","id":6305},{"actionName":"后台登录","action":"/account/login","type":"PAGE","id":102},{"actionName":"专家管理-修改","action":"/expert/update","type":"FUNCTION","id":158},{"actionName":"授权机构管理-详情","action":"/authorizedAgency/get","type":"FUNCTION","id":25461},{"actionName":"申请管理-有效期单元","action":"/examinee/validUnit.*","type":"FUNCTION","id":277},{"actionName":"机构班主任问题页","action":"/authorizedAgencyTeacher/show","type":"PAGE","id":6392},{"actionName":"机构班主任管理-删除","action":"/authorizedAgencyTeacher/delete","type":"FUNCTION","id":5876},{"actionName":"平台班主任管理-添加","action":"/teacher/add","type":"FUNCTION","id":210},{"actionName":"积分列表页","action":"/sendIntegral/index","type":"PAGE","id":206},{"actionName":"首页","action":"/","type":"PAGE","id":101},{"actionName":"课程问题-列表","action":"/putQuestionOnWite/list","type":"FUNCTION","id":164},{"actionName":"机构班主任管理-列表","action":"/authorizedAgencyTeacher/list","type":"FUNCTION","id":5872},{"actionName":"班级信息-开课","action":"/class/startCourse/.*","type":"FUNCTION","id":128},{"actionName":"授权机构列表数据导出","action":"/authorizedAgency/export","type":"FUNCTION","id":6303},{"actionName":"平台班主任管理-列表","action":"/teacher/list","type":"FUNCTION","id":209},{"actionName":"会员管理页","action":"/user/index","type":"PAGE","id":223},{"actionName":"平台班主任管理页","action":"/teacher/index","type":"PAGE","id":208},{"actionName":"后台登出","action":"/account/quit","type":"PAGE","id":103},{"actionName":"专家管理-详情","action":"/expert/get","type":"FUNCTION","id":157},{"actionName":"考试单元-添加","action":"/examinationUnit/add","type":"FUNCTION","id":267},{"actionName":"考试管理页","action":"/examination/index","type":"PAGE","id":256},{"actionName":"会员管理-列表","action":"/user/list","type":"FUNCTION","id":224},{"actionName":"平台班主任管理-删除","action":"/teacher/delete","type":"FUNCTION","id":213},{"actionName":"会员管理-备注","action":"/user/getRemark","type":"FUNCTION","id":228},{"actionName":"考试管理-修改","action":"/examination/update","type":"FUNCTION","id":261},{"actionName":"平台班主任问题页","action":"/teacher/show","type":"PAGE","id":6391},{"actionName":"班主任问题列表数据导出","action":"/putQuestionOnWite/export","type":"FUNCTION","id":6325},{"actionName":"订单管理-处理","action":"/orderRecord/update","type":"FUNCTION","id":177},{"actionName":"课程问题-所有班级","action":"/class/findAllClassByOtherId","type":"FUNCTION","id":6301},{"actionName":"订单管理-详情","action":"/orderRecord/get","type":"FUNCTION","id":176},{"actionName":"认证申请管理-拒绝","action":"/certification/refuse","type":"FUNCTION","id":254},{"actionName":"申请管理页","action":"/examinee/index","type":"PAGE","id":271},{"actionName":"专家管理-所有专家","action":"/expert/findAll","type":"FUNCTION","id":160},{"actionName":"会员管理-详情","action":"/user/get","type":"FUNCTION","id":225},{"actionName":"测评认证-添加考场","action":"/examinationRoom/addRoom","type":"FUNCTION","id":263},{"actionName":"会员管理-积分调整","action":"/user/update","type":"FUNCTION","id":226},{"actionName":"班级信息-添加","action":"/class/add","type":"FUNCTION","id":123},{"actionName":"考试管理-详情","action":"/examination/get","type":"FUNCTION","id":259},{"actionName":"班级列表数据导出","action":"/class/export","type":"FUNCTION","id":6311},{"actionName":"班级信息-详情","action":"/class/get","type":"FUNCTION","id":126},{"actionName":"考试单元页","action":"/examinationUnit/index","type":"PAGE","id":265},{"actionName":"申请管理-延考","action":"/examinee/delay","type":"FUNCTION","id":279},{"actionName":"授权机构管理-全部未禁用机构","action":"/authorizedAgency/findAllActiveTrue","type":"FUNCTION","id":5883},{"actionName":"订单管理-列表","action":"/orderRecord/list","type":"FUNCTION","id":175},{"actionName":"报名信息-列表","action":"/enrol/list","type":"FUNCTION","id":147},{"actionName":"考试列表数据导出","action":"/examination/export","type":"FUNCTION","id":6317},{"actionName":"报名信息-详情","action":"/enrol/get","type":"FUNCTION","id":149},{"actionName":"考试单元-详情","action":"/examinationUnit/get","type":"FUNCTION","id":268},{"actionName":"考试申请列表数据导出","action":"/examinee/export","type":"FUNCTION","id":6319},{"actionName":"申请管理-对应考试下所有单元","action":"/examinee/unitList/.*","type":"FUNCTION","id":276},{"actionName":"用户管理-添加","action":"/account/add","type":"FUNCTION","id":107},{"actionName":"证件类型","action":"/idtype/findAll","type":"FUNCTION","id":173},{"actionName":"报名信息-修改","action":"/enrol/update","type":"FUNCTION","id":150},{"actionName":"认证申请管理-列表","action":"/certification/list","type":"FUNCTION","id":252},{"actionName":"专家管理-专家相关问题页","action":"/expert/show","type":"PAGE","id":161},{"actionName":"平台班主任管理-详情","action":"/teacher/get","type":"FUNCTION","id":211},{"actionName":"申请管理-详情","action":"/examinee/get","type":"FUNCTION","id":273},{"actionName":"机构班主任管理页","action":"/authorizedAgencyTeacher/index","type":"PAGE","id":5871},{"actionName":"班级信息页","action":"/class/index","type":"PAGE","id":121},{"actionName":"用户管理-修改","action":"/account/update","type":"FUNCTION","id":108},{"actionName":"订单管理-追加订单","action":"/orderRecord/add","type":"FUNCTION","id":178},{"actionName":"授权机构管理-列表","action":"/authorizedAgency/list","type":"FUNCTION","id":5879},{"actionName":"申请管理-对应城市下所有考试","action":"/examinee/examinationList/.*","type":"FUNCTION","id":275}],"createDate":"2011-11-11","createDateList":"2011-11-11","id":7},{"roleName":"班级管理员（旧）","actions":[{"actionName":"班级信息-删除","action":"/class/delete","type":"FUNCTION","id":125},{"actionName":"班级信息-所有班级","action":"/class/findAllClass","type":"FUNCTION","id":129},{"actionName":"班级信息-添加","action":"/class/add","type":"FUNCTION","id":123},{"actionName":"班级信息-详情","action":"/class/get","type":"FUNCTION","id":126},{"actionName":"报名信息-添加","action":"/enrol/add","type":"FUNCTION","id":148},{"actionName":"报名信息-重发开班码","action":"/enrol/reSendCode/.*","type":"FUNCTION","id":153},{"actionName":"班级信息页","action":"/class/index","type":"PAGE","id":121},{"actionName":"班级信息-所有开课中班级","action":"/class/findAll","type":"FUNCTION","id":127},{"actionName":"首页","action":"/","type":"PAGE","id":101},{"actionName":"报名信息-列表","action":"/enrol/list","type":"FUNCTION","id":147},{"actionName":"报名信息-详情","action":"/enrol/get","type":"FUNCTION","id":149},{"actionName":"班级信息-修改","action":"/class/update","type":"FUNCTION","id":124},{"actionName":"班级信息-开课","action":"/class/startCourse/.*","type":"FUNCTION","id":128},{"actionName":"班级信息-列表","action":"/class/list","type":"FUNCTION","id":122},{"actionName":"报名信息-删除","action":"/enrol/delete","type":"FUNCTION","id":151},{"actionName":"报名信息页","action":"/enrol/index","type":"PAGE","id":146},{"actionName":"后台登出","action":"/account/quit","type":"PAGE","id":103},{"actionName":"后台登录","action":"/account/login","type":"PAGE","id":102},{"actionName":"报名信息-修改","action":"/enrol/update","type":"FUNCTION","id":150},{"actionName":"平台班主任管理-所有平台班主任","action":"/teacher/findAll","type":"FUNCTION","id":214}],"createDate":"2018-03-28","createDateList":"2018-03-28","id":10211},{"roleName":"测评认证管理员","actions":[{"actionName":"申请管理-有效期单元","action":"/examinee/validUnit.*","type":"FUNCTION","id":277},{"actionName":"考试管理-详情","action":"/examination/get","type":"FUNCTION","id":259},{"actionName":"考试管理-单元信息页","action":"/examination/show","type":"PAGE","id":262},{"actionName":"城市列表","action":"/city/cityList/.*","type":"FUNCTION","id":255},{"actionName":"考试单元页","action":"/examinationUnit/index","type":"PAGE","id":265},{"actionName":"申请管理-延考","action":"/examinee/delay","type":"FUNCTION","id":279},{"actionName":"首页","action":"/","type":"PAGE","id":101},{"actionName":"考试单元-详情","action":"/examinationUnit/get","type":"FUNCTION","id":268},{"actionName":"认证申请管理页","action":"/certification/index","type":"PAGE","id":251},{"actionName":"测评认证-单元报名人数","action":"/examinationRoom/get","type":"FUNCTION","id":264},{"actionName":"申请管理-对应考试下所有单元","action":"/examinee/unitList/.*","type":"FUNCTION","id":276},{"actionName":"后台登出","action":"/account/quit","type":"PAGE","id":103},{"actionName":"申请管理-审核","action":"/examinee/update","type":"FUNCTION","id":274},{"actionName":"认证申请管理-列表","action":"/certification/list","type":"FUNCTION","id":252},{"actionName":"考试单元-添加","action":"/examinationUnit/add","type":"FUNCTION","id":267},{"actionName":"考试单元-删除","action":"/examinationUnit/delete","type":"FUNCTION","id":269},{"actionName":"考试管理页","action":"/examination/index","type":"PAGE","id":256},{"actionName":"申请管理-详情","action":"/examinee/get","type":"FUNCTION","id":273},{"actionName":"认证申请管理-通过","action":"/certification/pass","type":"FUNCTION","id":253},{"actionName":"考试管理-修改","action":"/examination/update","type":"FUNCTION","id":261},{"actionName":"考试管理-添加","action":"/examination/add","type":"FUNCTION","id":258},{"actionName":"申请管理-切换城市","action":"/examinee/changeCity","type":"FUNCTION","id":278},{"actionName":"考试单元-修改","action":"/examinationUnit/update","type":"FUNCTION","id":270},{"actionName":"考试单元-列表","action":"/examinationUnit/list","type":"FUNCTION","id":266},{"actionName":"考试管理-删除","action":"/examination/delete","type":"FUNCTION","id":260},{"actionName":"申请管理-列表","action":"/examinee/list","type":"FUNCTION","id":272},{"actionName":"考试管理-列表","action":"/examination/list","type":"FUNCTION","id":257},{"actionName":"申请管理-对应城市下所有考试","action":"/examinee/examinationList/.*","type":"FUNCTION","id":275},{"actionName":"认证申请管理-拒绝","action":"/certification/refuse","type":"FUNCTION","id":254},{"actionName":"申请管理页","action":"/examinee/index","type":"PAGE","id":271},{"actionName":"后台登录","action":"/account/login","type":"PAGE","id":102},{"actionName":"测评认证-添加考场","action":"/examinationRoom/addRoom","type":"FUNCTION","id":263}],"createDate":"2018-03-28","createDateList":"2018-03-28","id":10212}],
    });
  },
  'GET /api/fake_role_list': getRoleList,
  'GET /api/fake_administrator': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {
        "createDate":"2018-03-19",
        "createDateList":"2018-03-19",
        "userName":"export493143",
        "password":"F379EAF3C831B04DE153469D1BEC345E",
        "email":null,
        "roles": [{
        "roleName": "机构班主任",
        "actions": [{
          "actionName": "班级信息-添加",
          "action": "/class/add",
          "type": "FUNCTION",
          "id": 123
        }, {
          "actionName": "班级列表数据导出",
          "action": "/class/export",
          "type": "FUNCTION",
          "id": 6311
        }, {
          "actionName": "班级首页-机构班主任",
          "action": "/class/indexForAuthorizedAgencyTeacher",
          "type": "PAGE",
          "id": 6328
        }, {
          "actionName": "班级信息-详情",
          "action": "/class/get",
          "type": "FUNCTION",
          "id": 126
        }, {
          "actionName": "报名信息-添加",
          "action": "/enrol/add",
          "type": "FUNCTION",
          "id": 148
        }, {
          "actionName": "后台改密",
          "action": "/account/changePwd",
          "type": "FUNCTION",
          "id": 104
        }, {
          "actionName": "班级信息-所有开课中班级",
          "action": "/class/findAll",
          "type": "FUNCTION",
          "id": 127
        }, {
          "actionName": "授权机构管理-全部未禁用机构",
          "action": "/authorizedAgency/findAllActiveTrue",
          "type": "FUNCTION",
          "id": 5883
        }, { "actionName": "首页", "action": "/", "type": "PAGE", "id": 101 }, {
          "actionName": "报名信息-列表",
          "action": "/enrol/list",
          "type": "FUNCTION",
          "id": 147
        }, {
          "actionName": "报名信息-详情",
          "action": "/enrol/get",
          "type": "FUNCTION",
          "id": 149
        }, {
          "actionName": "课程问题-列表",
          "action": "/putQuestionOnWite/list",
          "type": "FUNCTION",
          "id": 164
        }, {
          "actionName": "班级信息-开课",
          "action": "/class/startCourse/.*",
          "type": "FUNCTION",
          "id": 128
        }, {
          "actionName": "课程已回答问题页",
          "action": "/putQuestionOnWite/indexOnSuccessful",
          "type": "PAGE",
          "id": 163
        }, {
          "actionName": "课程问题-回答",
          "action": "/putQuestionOnWite/update",
          "type": "FUNCTION",
          "id": 166
        }, {
          "actionName": "班级信息-列表",
          "action": "/class/list",
          "type": "FUNCTION",
          "id": 122
        }, {
          "actionName": "课程问题-详情",
          "action": "/putQuestionOnWite/get",
          "type": "FUNCTION",
          "id": 165
        }, {
          "actionName": "报名信息-删除",
          "action": "/enrol/delete",
          "type": "FUNCTION",
          "id": 151
        }, {
          "actionName": "报名信息-机构班主任",
          "action": "/enrol/indexForAuthorizedAgencyTeacher",
          "type": "PAGE",
          "id": 6351
        }, {
          "actionName": "后台登出",
          "action": "/account/quit",
          "type": "PAGE",
          "id": 103
        }, {
          "actionName": "报名信息-修改",
          "action": "/enrol/update",
          "type": "FUNCTION",
          "id": 150
        }, {
          "actionName": "平台班主任管理-所有平台班主任",
          "action": "/teacher/findAll",
          "type": "FUNCTION",
          "id": 214
        }, {
          "actionName": "班级信息-删除",
          "action": "/class/delete",
          "type": "FUNCTION",
          "id": 125
        }, {
          "actionName": "班级信息-所有班级",
          "action": "/class/findAllClass",
          "type": "FUNCTION",
          "id": 129
        }, {
          "actionName": "课程待回答问题页",
          "action": "/putQuestionOnWite/index",
          "type": "PAGE",
          "id": 162
        }, {
          "actionName": "报名信息列表数据导出",
          "action": "/enrol/export",
          "type": "FUNCTION",
          "id": 6312
        }, {
          "actionName": "报名信息-重发开班码",
          "action": "/enrol/reSendCode/.*",
          "type": "FUNCTION",
          "id": 153
        }, {
          "actionName": "课程问题-删除",
          "action": "/putQuestionOnWite/delete",
          "type": "FUNCTION",
          "id": 167
        }, {
          "actionName": "班主任问题列表数据导出",
          "action": "/putQuestionOnWite/export",
          "type": "FUNCTION",
          "id": 6325
        }, {
          "actionName": "班级信息-修改",
          "action": "/class/update",
          "type": "FUNCTION",
          "id": 124
        }, {
          "actionName": "课程问题-所有班级",
          "action": "/class/findAllClassByOtherId",
          "type": "FUNCTION",
          "id": 6301
        }, {
          "actionName": "后台登录",
          "action": "/account/login",
          "type": "PAGE",
          "id": 102
        }, {
          "actionName": "机构班主任管理-所有机构班主任",
          "action": "/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*",
          "type": "FUNCTION",
          "id": 5877
        }],}],
        "id": 4
      },
    });
  },
  'GET /api/fake_administrator_list': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {
        list: [{
          "createDate": "2018-05-07",
          "createDateList": "2018-05-07",
          "id": 25429,
          "userName": "teacher781501",
          "password": "F379EAF3C831B04DE153469D1BEC345E",
          "email": null,
          "roles": [{
            "roleName": "机构班主任",
            "actions": [{
              "actionName": "班级信息-添加",
              "action": "/class/add",
              "type": "FUNCTION",
              "id": 123
            }, {
              "actionName": "班级列表数据导出",
              "action": "/class/export",
              "type": "FUNCTION",
              "id": 6311
            }, {
              "actionName": "班级首页-机构班主任",
              "action": "/class/indexForAuthorizedAgencyTeacher",
              "type": "PAGE",
              "id": 6328
            }, {
              "actionName": "班级信息-详情",
              "action": "/class/get",
              "type": "FUNCTION",
              "id": 126
            }, {
              "actionName": "报名信息-添加",
              "action": "/enrol/add",
              "type": "FUNCTION",
              "id": 148
            }, {
              "actionName": "后台改密",
              "action": "/account/changePwd",
              "type": "FUNCTION",
              "id": 104
            }, {
              "actionName": "班级信息-所有开课中班级",
              "action": "/class/findAll",
              "type": "FUNCTION",
              "id": 127
            }, {
              "actionName": "授权机构管理-全部未禁用机构",
              "action": "/authorizedAgency/findAllActiveTrue",
              "type": "FUNCTION",
              "id": 5883
            }, { "actionName": "首页", "action": "/", "type": "PAGE", "id": 101 }, {
              "actionName": "报名信息-列表",
              "action": "/enrol/list",
              "type": "FUNCTION",
              "id": 147
            }, {
              "actionName": "报名信息-详情",
              "action": "/enrol/get",
              "type": "FUNCTION",
              "id": 149
            }, {
              "actionName": "课程问题-列表",
              "action": "/putQuestionOnWite/list",
              "type": "FUNCTION",
              "id": 164
            }, {
              "actionName": "班级信息-开课",
              "action": "/class/startCourse/.*",
              "type": "FUNCTION",
              "id": 128
            }, {
              "actionName": "课程已回答问题页",
              "action": "/putQuestionOnWite/indexOnSuccessful",
              "type": "PAGE",
              "id": 163
            }, {
              "actionName": "课程问题-回答",
              "action": "/putQuestionOnWite/update",
              "type": "FUNCTION",
              "id": 166
            }, {
              "actionName": "班级信息-列表",
              "action": "/class/list",
              "type": "FUNCTION",
              "id": 122
            }, {
              "actionName": "课程问题-详情",
              "action": "/putQuestionOnWite/get",
              "type": "FUNCTION",
              "id": 165
            }, {
              "actionName": "报名信息-删除",
              "action": "/enrol/delete",
              "type": "FUNCTION",
              "id": 151
            }, {
              "actionName": "报名信息-机构班主任",
              "action": "/enrol/indexForAuthorizedAgencyTeacher",
              "type": "PAGE",
              "id": 6351
            }, {
              "actionName": "后台登出",
              "action": "/account/quit",
              "type": "PAGE",
              "id": 103
            }, {
              "actionName": "报名信息-修改",
              "action": "/enrol/update",
              "type": "FUNCTION",
              "id": 150
            }, {
              "actionName": "平台班主任管理-所有平台班主任",
              "action": "/teacher/findAll",
              "type": "FUNCTION",
              "id": 214
            }, {
              "actionName": "班级信息-删除",
              "action": "/class/delete",
              "type": "FUNCTION",
              "id": 125
            }, {
              "actionName": "班级信息-所有班级",
              "action": "/class/findAllClass",
              "type": "FUNCTION",
              "id": 129
            }, {
              "actionName": "课程待回答问题页",
              "action": "/putQuestionOnWite/index",
              "type": "PAGE",
              "id": 162
            }, {
              "actionName": "报名信息列表数据导出",
              "action": "/enrol/export",
              "type": "FUNCTION",
              "id": 6312
            }, {
              "actionName": "报名信息-重发开班码",
              "action": "/enrol/reSendCode/.*",
              "type": "FUNCTION",
              "id": 153
            }, {
              "actionName": "课程问题-删除",
              "action": "/putQuestionOnWite/delete",
              "type": "FUNCTION",
              "id": 167
            }, {
              "actionName": "班主任问题列表数据导出",
              "action": "/putQuestionOnWite/export",
              "type": "FUNCTION",
              "id": 6325
            }, {
              "actionName": "班级信息-修改",
              "action": "/class/update",
              "type": "FUNCTION",
              "id": 124
            }, {
              "actionName": "课程问题-所有班级",
              "action": "/class/findAllClassByOtherId",
              "type": "FUNCTION",
              "id": 6301
            }, {
              "actionName": "后台登录",
              "action": "/account/login",
              "type": "PAGE",
              "id": 102
            }, {
              "actionName": "机构班主任管理-所有机构班主任",
              "action": "/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*",
              "type": "FUNCTION",
              "id": 5877
            }],
            "id": 4
          }]
        }, {
          "createDate": "2018-05-07",
          "createDateList": "2018-05-07",
          "id": 25428,
          "userName": "teacher290341",
          "password": "E1AFDC3949BA59ABBE56E057F2FF883E",
          "email": null,
          "roles": [{
            "roleName": "机构班主任",
            "actions": [{
              "actionName": "班级信息-添加",
              "action": "/class/add",
              "type": "FUNCTION",
              "id": 123
            }, {
              "actionName": "班级列表数据导出",
              "action": "/class/export",
              "type": "FUNCTION",
              "id": 6311
            }, {
              "actionName": "班级首页-机构班主任",
              "action": "/class/indexForAuthorizedAgencyTeacher",
              "type": "PAGE",
              "id": 6328
            }, {
              "actionName": "班级信息-详情",
              "action": "/class/get",
              "type": "FUNCTION",
              "id": 126
            }, {
              "actionName": "报名信息-添加",
              "action": "/enrol/add",
              "type": "FUNCTION",
              "id": 148
            }, {
              "actionName": "后台改密",
              "action": "/account/changePwd",
              "type": "FUNCTION",
              "id": 104
            }, {
              "actionName": "班级信息-所有开课中班级",
              "action": "/class/findAll",
              "type": "FUNCTION",
              "id": 127
            }, {
              "actionName": "授权机构管理-全部未禁用机构",
              "action": "/authorizedAgency/findAllActiveTrue",
              "type": "FUNCTION",
              "id": 5883
            }, { "actionName": "首页", "action": "/", "type": "PAGE", "id": 101 }, {
              "actionName": "报名信息-列表",
              "action": "/enrol/list",
              "type": "FUNCTION",
              "id": 147
            }, {
              "actionName": "报名信息-详情",
              "action": "/enrol/get",
              "type": "FUNCTION",
              "id": 149
            }, {
              "actionName": "课程问题-列表",
              "action": "/putQuestionOnWite/list",
              "type": "FUNCTION",
              "id": 164
            }, {
              "actionName": "班级信息-开课",
              "action": "/class/startCourse/.*",
              "type": "FUNCTION",
              "id": 128
            }, {
              "actionName": "课程已回答问题页",
              "action": "/putQuestionOnWite/indexOnSuccessful",
              "type": "PAGE",
              "id": 163
            }, {
              "actionName": "课程问题-回答",
              "action": "/putQuestionOnWite/update",
              "type": "FUNCTION",
              "id": 166
            }, {
              "actionName": "班级信息-列表",
              "action": "/class/list",
              "type": "FUNCTION",
              "id": 122
            }, {
              "actionName": "课程问题-详情",
              "action": "/putQuestionOnWite/get",
              "type": "FUNCTION",
              "id": 165
            }, {
              "actionName": "报名信息-删除",
              "action": "/enrol/delete",
              "type": "FUNCTION",
              "id": 151
            }, {
              "actionName": "报名信息-机构班主任",
              "action": "/enrol/indexForAuthorizedAgencyTeacher",
              "type": "PAGE",
              "id": 6351
            }, {
              "actionName": "后台登出",
              "action": "/account/quit",
              "type": "PAGE",
              "id": 103
            }, {
              "actionName": "报名信息-修改",
              "action": "/enrol/update",
              "type": "FUNCTION",
              "id": 150
            }, {
              "actionName": "平台班主任管理-所有平台班主任",
              "action": "/teacher/findAll",
              "type": "FUNCTION",
              "id": 214
            }, {
              "actionName": "班级信息-删除",
              "action": "/class/delete",
              "type": "FUNCTION",
              "id": 125
            }, {
              "actionName": "班级信息-所有班级",
              "action": "/class/findAllClass",
              "type": "FUNCTION",
              "id": 129
            }, {
              "actionName": "课程待回答问题页",
              "action": "/putQuestionOnWite/index",
              "type": "PAGE",
              "id": 162
            }, {
              "actionName": "报名信息列表数据导出",
              "action": "/enrol/export",
              "type": "FUNCTION",
              "id": 6312
            }, {
              "actionName": "报名信息-重发开班码",
              "action": "/enrol/reSendCode/.*",
              "type": "FUNCTION",
              "id": 153
            }, {
              "actionName": "课程问题-删除",
              "action": "/putQuestionOnWite/delete",
              "type": "FUNCTION",
              "id": 167
            }, {
              "actionName": "班主任问题列表数据导出",
              "action": "/putQuestionOnWite/export",
              "type": "FUNCTION",
              "id": 6325
            }, {
              "actionName": "班级信息-修改",
              "action": "/class/update",
              "type": "FUNCTION",
              "id": 124
            }, {
              "actionName": "课程问题-所有班级",
              "action": "/class/findAllClassByOtherId",
              "type": "FUNCTION",
              "id": 6301
            }, {
              "actionName": "后台登录",
              "action": "/account/login",
              "type": "PAGE",
              "id": 102
            }, {
              "actionName": "机构班主任管理-所有机构班主任",
              "action": "/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*",
              "type": "FUNCTION",
              "id": 5877
            }],
            "id": 4
          }]
        }, {
          "createDate": "2018-05-07",
          "createDateList": "2018-05-07",
          "id": 25427,
          "userName": "YDZX",
          "password": "F379EAF3C831B04DE153469D1BEC345E",
          "email": null,
          "roles": [{
            "roleName": "机构管理员",
            "actions": [{
              "actionName": "机构班主任问题页",
              "action": "/authorizedAgencyTeacher/show",
              "type": "PAGE",
              "id": 6392
            }, {
              "actionName": "班级信息-添加",
              "action": "/class/add",
              "type": "FUNCTION",
              "id": 123
            }, {
              "actionName": "机构班主任管理-详情",
              "action": "/authorizedAgencyTeacher/get",
              "type": "FUNCTION",
              "id": 5874
            }, {
              "actionName": "机构班主任管理-删除",
              "action": "/authorizedAgencyTeacher/delete",
              "type": "FUNCTION",
              "id": 5876
            }, {
              "actionName": "班级列表数据导出",
              "action": "/class/export",
              "type": "FUNCTION",
              "id": 6311
            }, {
              "actionName": "班级信息-详情",
              "action": "/class/get",
              "type": "FUNCTION",
              "id": 126
            }, {
              "actionName": "报名信息-添加",
              "action": "/enrol/add",
              "type": "FUNCTION",
              "id": 148
            }, {
              "actionName": "后台改密",
              "action": "/account/changePwd",
              "type": "FUNCTION",
              "id": 104
            }, {
              "actionName": "班级信息-所有开课中班级",
              "action": "/class/findAll",
              "type": "FUNCTION",
              "id": 127
            }, {
              "actionName": "授权机构管理-全部未禁用机构",
              "action": "/authorizedAgency/findAllActiveTrue",
              "type": "FUNCTION",
              "id": 5883
            }, { "actionName": "首页", "action": "/", "type": "PAGE", "id": 101 }, {
              "actionName": "报名信息-列表",
              "action": "/enrol/list",
              "type": "FUNCTION",
              "id": 147
            }, {
              "actionName": "报名信息-详情",
              "action": "/enrol/get",
              "type": "FUNCTION",
              "id": 149
            }, {
              "actionName": "课程问题-列表",
              "action": "/putQuestionOnWite/list",
              "type": "FUNCTION",
              "id": 164
            }, {
              "actionName": "机构班主任列表数据导出",
              "action": "/authorizedAgencyTeacher/export",
              "type": "FUNCTION",
              "id": 6306
            }, {
              "actionName": "班级首页-授权机构",
              "action": "/class/indexForAuthorizedAgency",
              "type": "PAGE",
              "id": 6327
            }, {
              "actionName": "机构班主任管理-列表",
              "action": "/authorizedAgencyTeacher/list",
              "type": "FUNCTION",
              "id": 5872
            }, {
              "actionName": "班级信息-开课",
              "action": "/class/startCourse/.*",
              "type": "FUNCTION",
              "id": 128
            }, {
              "actionName": "机构班主任管理-修改",
              "action": "/authorizedAgencyTeacher/update",
              "type": "FUNCTION",
              "id": 5875
            }, {
              "actionName": "课程问题-回答",
              "action": "/putQuestionOnWite/update",
              "type": "FUNCTION",
              "id": 166
            }, {
              "actionName": "班级信息-列表",
              "action": "/class/list",
              "type": "FUNCTION",
              "id": 122
            }, {
              "actionName": "课程问题-详情",
              "action": "/putQuestionOnWite/get",
              "type": "FUNCTION",
              "id": 165
            }, {
              "actionName": "报名信息-删除",
              "action": "/enrol/delete",
              "type": "FUNCTION",
              "id": 151
            }, {
              "actionName": "后台登出",
              "action": "/account/quit",
              "type": "PAGE",
              "id": 103
            }, {
              "actionName": "报名信息-修改",
              "action": "/enrol/update",
              "type": "FUNCTION",
              "id": 150
            }, {
              "actionName": "平台班主任管理-所有平台班主任",
              "action": "/teacher/findAll",
              "type": "FUNCTION",
              "id": 214
            }, {
              "actionName": "报名信息-授权机构",
              "action": "/enrol/indexForAuthorizedAgency",
              "type": "PAGE",
              "id": 6330
            }, {
              "actionName": "班级信息-删除",
              "action": "/class/delete",
              "type": "FUNCTION",
              "id": 125
            }, {
              "actionName": "班级信息-所有班级",
              "action": "/class/findAllClass",
              "type": "FUNCTION",
              "id": 129
            }, {
              "actionName": "机构班主任管理-添加",
              "action": "/authorizedAgencyTeacher/add",
              "type": "FUNCTION",
              "id": 5873
            }, {
              "actionName": "机构班主任管理页",
              "action": "/authorizedAgencyTeacher/index",
              "type": "PAGE",
              "id": 5871
            }, {
              "actionName": "报名信息列表数据导出",
              "action": "/enrol/export",
              "type": "FUNCTION",
              "id": 6312
            }, {
              "actionName": "报名信息-重发开班码",
              "action": "/enrol/reSendCode/.*",
              "type": "FUNCTION",
              "id": 153
            }, {
              "actionName": "课程问题-删除",
              "action": "/putQuestionOnWite/delete",
              "type": "FUNCTION",
              "id": 167
            }, {
              "actionName": "班主任问题列表数据导出",
              "action": "/putQuestionOnWite/export",
              "type": "FUNCTION",
              "id": 6325
            }, {
              "actionName": "班级信息-修改",
              "action": "/class/update",
              "type": "FUNCTION",
              "id": 124
            }, {
              "actionName": "课程问题-所有班级",
              "action": "/class/findAllClassByOtherId",
              "type": "FUNCTION",
              "id": 6301
            }, {
              "actionName": "后台登录",
              "action": "/account/login",
              "type": "PAGE",
              "id": 102
            }, {
              "actionName": "机构班主任管理-所有机构班主任",
              "action": "/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*",
              "type": "FUNCTION",
              "id": 5877
            }],
            "id": 3
          }]
        }, {
          "createDate": "2018-05-07",
          "createDateList": "2018-05-07",
          "id": 25426,
          "userName": "export667585",
          "password": "F379EAF3C831B04DE153469D1BEC345E",
          "email": null,
          "roles": [{
            "roleName": "专家",
            "actions": [{
              "actionName": "班主任问题列表数据导出",
              "action": "/putQuestionOnWite/export",
              "type": "FUNCTION",
              "id": 6325
            }, {
              "actionName": "课程待回答问题页",
              "action": "/putQuestionOnWite/index",
              "type": "PAGE",
              "id": 162
            }, {
              "actionName": "课程问题-所有班级",
              "action": "/class/findAllClassByOtherId",
              "type": "FUNCTION",
              "id": 6301
            }, {
              "actionName": "课程已回答问题页",
              "action": "/putQuestionOnWite/indexOnSuccessful",
              "type": "PAGE",
              "id": 163
            }, {
              "actionName": "课程问题-回答",
              "action": "/putQuestionOnWite/update",
              "type": "FUNCTION",
              "id": 166
            }, {
              "actionName": "课程问题-详情",
              "action": "/putQuestionOnWite/get",
              "type": "FUNCTION",
              "id": 165
            }, { "actionName": "后台登出", "action": "/account/quit", "type": "PAGE", "id": 103 }, {
              "actionName": "首页",
              "action": "/",
              "type": "PAGE",
              "id": 101
            }, {
              "actionName": "后台登录",
              "action": "/account/login",
              "type": "PAGE",
              "id": 102
            }, {
              "actionName": "课程问题-删除",
              "action": "/putQuestionOnWite/delete",
              "type": "FUNCTION",
              "id": 167
            }, { "actionName": "课程问题-列表", "action": "/putQuestionOnWite/list", "type": "FUNCTION", "id": 164 }],
            "id": 1
          }]
        }, {
          "createDate": "2018-05-07",
          "createDateList": "2018-05-07",
          "id": 25425,
          "userName": "admin",
          "password": "21232F297A57A5A743894AEF4A801FC3",
          "email": "",
          "roles": [{
            "roleName": "平台管理员",
            "actions": [{
              "actionName": "考试管理-单元信息页",
              "action": "/examination/show",
              "type": "PAGE",
              "id": 262
            }, {
              "actionName": "报名信息-添加",
              "action": "/enrol/add",
              "type": "FUNCTION",
              "id": 148
            }, {
              "actionName": "后台改密",
              "action": "/account/changePwd",
              "type": "FUNCTION",
              "id": 104
            }, {
              "actionName": "班级信息-所有开课中班级",
              "action": "/class/findAll",
              "type": "FUNCTION",
              "id": 127
            }, {
              "actionName": "会员积分明细列表数据导出",
              "action": "/sendIntegral/export",
              "type": "FUNCTION",
              "id": 6326
            }, {
              "actionName": "订单列表数据导出",
              "action": "/orderRecord/export",
              "type": "FUNCTION",
              "id": 6307
            }, {
              "actionName": "课程问题-回答",
              "action": "/putQuestionOnWite/update",
              "type": "FUNCTION",
              "id": 166
            }, {
              "actionName": "报名信息页",
              "action": "/enrol/index",
              "type": "PAGE",
              "id": 146
            }, {
              "actionName": "专家管理-添加",
              "action": "/expert/add",
              "type": "FUNCTION",
              "id": 156
            }, {
              "actionName": "平台班主任管理-所有平台班主任",
              "action": "/teacher/findAll",
              "type": "FUNCTION",
              "id": 214
            }, {
              "actionName": "用户列表数据导出",
              "action": "/account/export",
              "type": "FUNCTION",
              "id": 6322
            }, {
              "actionName": "机构班主任管理-添加",
              "action": "/authorizedAgencyTeacher/add",
              "type": "FUNCTION",
              "id": 5873
            }, {
              "actionName": "认证申请管理-通过",
              "action": "/certification/pass",
              "type": "FUNCTION",
              "id": 253
            }, {
              "actionName": "授权机构管理-添加",
              "action": "/authorizedAgency/add",
              "type": "FUNCTION",
              "id": 5880
            }, {
              "actionName": "报名信息列表数据导出",
              "action": "/enrol/export",
              "type": "FUNCTION",
              "id": 6312
            }, {
              "actionName": "考试管理-添加",
              "action": "/examination/add",
              "type": "FUNCTION",
              "id": 258
            }, {
              "actionName": "课程问题-删除",
              "action": "/putQuestionOnWite/delete",
              "type": "FUNCTION",
              "id": 167
            }, {
              "actionName": "授权机构管理-删除",
              "action": "/authorizedAgency/delete",
              "type": "FUNCTION",
              "id": 5882
            }, {
              "actionName": "平台班主任管理-修改",
              "action": "/teacher/update",
              "type": "FUNCTION",
              "id": 212
            }, {
              "actionName": "考试单元-列表",
              "action": "/examinationUnit/list",
              "type": "FUNCTION",
              "id": 266
            }, {
              "actionName": "申请管理-列表",
              "action": "/examinee/list",
              "type": "FUNCTION",
              "id": 272
            }, {
              "actionName": "考试管理-列表",
              "action": "/examination/list",
              "type": "FUNCTION",
              "id": 257
            }, {
              "actionName": "机构班主任管理-所有机构班主任",
              "action": "/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*",
              "type": "FUNCTION",
              "id": 5877
            }, {
              "actionName": "积分列表-列表",
              "action": "/sendIntegral/list",
              "type": "FUNCTION",
              "id": 207
            }, {
              "actionName": "订单管理页",
              "action": "/orderRecord/index",
              "type": "PAGE",
              "id": 174
            }, {
              "actionName": "机构班主任管理-详情",
              "action": "/authorizedAgencyTeacher/get",
              "type": "FUNCTION",
              "id": 5874
            }, {
              "actionName": "城市列表",
              "action": "/city/cityList/.*",
              "type": "FUNCTION",
              "id": 255
            }, {
              "actionName": "授权机构管理-修改",
              "action": "/authorizedAgency/update",
              "type": "FUNCTION",
              "id": 5881
            }, {
              "actionName": "会员管理列表数据导出",
              "action": "/user/export",
              "type": "FUNCTION",
              "id": 6302
            }, { "actionName": "登录页", "action": "/login", "type": "PAGE", "id": 181 }, {
              "actionName": "会员管理-考试信息",
              "action": "/user/exam",
              "type": "FUNCTION",
              "id": 227
            }, {
              "actionName": "考试单元列表数据导出",
              "action": "/examination/exportUnit",
              "type": "FUNCTION",
              "id": 6318
            }, {
              "actionName": "专家列表数据导出",
              "action": "/expert/export",
              "type": "FUNCTION",
              "id": 6304
            }, {
              "actionName": "机构班主任列表数据导出",
              "action": "/authorizedAgencyTeacher/export",
              "type": "FUNCTION",
              "id": 6306
            }, { "actionName": "主页", "action": "/index", "type": "PAGE", "id": 180 }, {
              "actionName": "认证申请管理页",
              "action": "/certification/index",
              "type": "PAGE",
              "id": 251
            }, {
              "actionName": "机构班主任管理-修改",
              "action": "/authorizedAgencyTeacher/update",
              "type": "FUNCTION",
              "id": 5875
            }, {
              "actionName": "专家管理-列表",
              "action": "/expert/list",
              "type": "FUNCTION",
              "id": 155
            }, {
              "actionName": "测评认证-单元报名人数",
              "action": "/examinationRoom/get",
              "type": "FUNCTION",
              "id": 264
            }, {
              "actionName": "班级信息-列表",
              "action": "/class/list",
              "type": "FUNCTION",
              "id": 122
            }, {
              "actionName": "课程问题-详情",
              "action": "/putQuestionOnWite/get",
              "type": "FUNCTION",
              "id": 165
            }, {
              "actionName": "报名信息-删除",
              "action": "/enrol/delete",
              "type": "FUNCTION",
              "id": 151
            }, {
              "actionName": "订单管理-删除",
              "action": "/orderRecord/delete",
              "type": "FUNCTION",
              "id": 179
            }, {
              "actionName": "申请管理-审核",
              "action": "/examinee/update",
              "type": "FUNCTION",
              "id": 274
            }, {
              "actionName": "考试单元-删除",
              "action": "/examinationUnit/delete",
              "type": "FUNCTION",
              "id": 269
            }, {
              "actionName": "班级信息-删除",
              "action": "/class/delete",
              "type": "FUNCTION",
              "id": 125
            }, {
              "actionName": "报名信息-重发开班码",
              "action": "/enrol/reSendCode/.*",
              "type": "FUNCTION",
              "id": 153
            }, {
              "actionName": "专家管理-删除",
              "action": "/expert/delete",
              "type": "FUNCTION",
              "id": 159
            }, {
              "actionName": "专家管理页",
              "action": "/expert/index",
              "type": "PAGE",
              "id": 154
            }, {
              "actionName": "申请管理-切换城市",
              "action": "/examinee/changeCity",
              "type": "FUNCTION",
              "id": 278
            }, {
              "actionName": "考试单元-修改",
              "action": "/examinationUnit/update",
              "type": "FUNCTION",
              "id": 270
            }, {
              "actionName": "班级信息-修改",
              "action": "/class/update",
              "type": "FUNCTION",
              "id": 124
            }, {
              "actionName": "考试管理-删除",
              "action": "/examination/delete",
              "type": "FUNCTION",
              "id": 260
            }, {
              "actionName": "授权机构管理页",
              "action": "/authorizedAgency/index",
              "type": "PAGE",
              "id": 5878
            }, {
              "actionName": "用户管理-列表",
              "action": "/account/list",
              "type": "FUNCTION",
              "id": 106
            }, {
              "actionName": "证书申请列表数据导出",
              "action": "/certification/export",
              "type": "FUNCTION",
              "id": 6320
            }, {
              "actionName": "平台班主任列表数据导出",
              "action": "/teacher/export",
              "type": "FUNCTION",
              "id": 6305
            }, {
              "actionName": "后台登录",
              "action": "/account/login",
              "type": "PAGE",
              "id": 102
            }, {
              "actionName": "专家管理-修改",
              "action": "/expert/update",
              "type": "FUNCTION",
              "id": 158
            }, {
              "actionName": "授权机构管理-详情",
              "action": "/authorizedAgency/get",
              "type": "FUNCTION",
              "id": 25461
            }, {
              "actionName": "申请管理-有效期单元",
              "action": "/examinee/validUnit.*",
              "type": "FUNCTION",
              "id": 277
            }, {
              "actionName": "机构班主任问题页",
              "action": "/authorizedAgencyTeacher/show",
              "type": "PAGE",
              "id": 6392
            }, {
              "actionName": "机构班主任管理-删除",
              "action": "/authorizedAgencyTeacher/delete",
              "type": "FUNCTION",
              "id": 5876
            }, {
              "actionName": "平台班主任管理-添加",
              "action": "/teacher/add",
              "type": "FUNCTION",
              "id": 210
            }, {
              "actionName": "积分列表页",
              "action": "/sendIntegral/index",
              "type": "PAGE",
              "id": 206
            }, { "actionName": "首页", "action": "/", "type": "PAGE", "id": 101 }, {
              "actionName": "课程问题-列表",
              "action": "/putQuestionOnWite/list",
              "type": "FUNCTION",
              "id": 164
            }, {
              "actionName": "机构班主任管理-列表",
              "action": "/authorizedAgencyTeacher/list",
              "type": "FUNCTION",
              "id": 5872
            }, {
              "actionName": "班级信息-开课",
              "action": "/class/startCourse/.*",
              "type": "FUNCTION",
              "id": 128
            }, {
              "actionName": "授权机构列表数据导出",
              "action": "/authorizedAgency/export",
              "type": "FUNCTION",
              "id": 6303
            }, {
              "actionName": "平台班主任管理-列表",
              "action": "/teacher/list",
              "type": "FUNCTION",
              "id": 209
            }, {
              "actionName": "会员管理页",
              "action": "/user/index",
              "type": "PAGE",
              "id": 223
            }, {
              "actionName": "平台班主任管理页",
              "action": "/teacher/index",
              "type": "PAGE",
              "id": 208
            }, {
              "actionName": "后台登出",
              "action": "/account/quit",
              "type": "PAGE",
              "id": 103
            }, {
              "actionName": "专家管理-详情",
              "action": "/expert/get",
              "type": "FUNCTION",
              "id": 157
            }, {
              "actionName": "考试单元-添加",
              "action": "/examinationUnit/add",
              "type": "FUNCTION",
              "id": 267
            }, {
              "actionName": "考试管理页",
              "action": "/examination/index",
              "type": "PAGE",
              "id": 256
            }, {
              "actionName": "会员管理-列表",
              "action": "/user/list",
              "type": "FUNCTION",
              "id": 224
            }, {
              "actionName": "平台班主任管理-删除",
              "action": "/teacher/delete",
              "type": "FUNCTION",
              "id": 213
            }, {
              "actionName": "会员管理-备注",
              "action": "/user/getRemark",
              "type": "FUNCTION",
              "id": 228
            }, {
              "actionName": "考试管理-修改",
              "action": "/examination/update",
              "type": "FUNCTION",
              "id": 261
            }, {
              "actionName": "平台班主任问题页",
              "action": "/teacher/show",
              "type": "PAGE",
              "id": 6391
            }, {
              "actionName": "班主任问题列表数据导出",
              "action": "/putQuestionOnWite/export",
              "type": "FUNCTION",
              "id": 6325
            }, {
              "actionName": "订单管理-处理",
              "action": "/orderRecord/update",
              "type": "FUNCTION",
              "id": 177
            }, {
              "actionName": "课程问题-所有班级",
              "action": "/class/findAllClassByOtherId",
              "type": "FUNCTION",
              "id": 6301
            }, {
              "actionName": "订单管理-详情",
              "action": "/orderRecord/get",
              "type": "FUNCTION",
              "id": 176
            }, {
              "actionName": "认证申请管理-拒绝",
              "action": "/certification/refuse",
              "type": "FUNCTION",
              "id": 254
            }, {
              "actionName": "申请管理页",
              "action": "/examinee/index",
              "type": "PAGE",
              "id": 271
            }, {
              "actionName": "专家管理-所有专家",
              "action": "/expert/findAll",
              "type": "FUNCTION",
              "id": 160
            }, {
              "actionName": "会员管理-详情",
              "action": "/user/get",
              "type": "FUNCTION",
              "id": 225
            }, {
              "actionName": "测评认证-添加考场",
              "action": "/examinationRoom/addRoom",
              "type": "FUNCTION",
              "id": 263
            }, {
              "actionName": "会员管理-积分调整",
              "action": "/user/update",
              "type": "FUNCTION",
              "id": 226
            }, {
              "actionName": "班级信息-添加",
              "action": "/class/add",
              "type": "FUNCTION",
              "id": 123
            }, {
              "actionName": "考试管理-详情",
              "action": "/examination/get",
              "type": "FUNCTION",
              "id": 259
            }, {
              "actionName": "班级列表数据导出",
              "action": "/class/export",
              "type": "FUNCTION",
              "id": 6311
            }, {
              "actionName": "班级信息-详情",
              "action": "/class/get",
              "type": "FUNCTION",
              "id": 126
            }, {
              "actionName": "考试单元页",
              "action": "/examinationUnit/index",
              "type": "PAGE",
              "id": 265
            }, {
              "actionName": "申请管理-延考",
              "action": "/examinee/delay",
              "type": "FUNCTION",
              "id": 279
            }, {
              "actionName": "授权机构管理-全部未禁用机构",
              "action": "/authorizedAgency/findAllActiveTrue",
              "type": "FUNCTION",
              "id": 5883
            }, {
              "actionName": "订单管理-列表",
              "action": "/orderRecord/list",
              "type": "FUNCTION",
              "id": 175
            }, {
              "actionName": "报名信息-列表",
              "action": "/enrol/list",
              "type": "FUNCTION",
              "id": 147
            }, {
              "actionName": "考试列表数据导出",
              "action": "/examination/export",
              "type": "FUNCTION",
              "id": 6317
            }, {
              "actionName": "报名信息-详情",
              "action": "/enrol/get",
              "type": "FUNCTION",
              "id": 149
            }, {
              "actionName": "考试单元-详情",
              "action": "/examinationUnit/get",
              "type": "FUNCTION",
              "id": 268
            }, {
              "actionName": "考试申请列表数据导出",
              "action": "/examinee/export",
              "type": "FUNCTION",
              "id": 6319
            }, {
              "actionName": "申请管理-对应考试下所有单元",
              "action": "/examinee/unitList/.*",
              "type": "FUNCTION",
              "id": 276
            }, {
              "actionName": "用户管理-添加",
              "action": "/account/add",
              "type": "FUNCTION",
              "id": 107
            }, {
              "actionName": "证件类型",
              "action": "/idtype/findAll",
              "type": "FUNCTION",
              "id": 173
            }, {
              "actionName": "报名信息-修改",
              "action": "/enrol/update",
              "type": "FUNCTION",
              "id": 150
            }, {
              "actionName": "认证申请管理-列表",
              "action": "/certification/list",
              "type": "FUNCTION",
              "id": 252
            }, {
              "actionName": "专家管理-专家相关问题页",
              "action": "/expert/show",
              "type": "PAGE",
              "id": 161
            }, {
              "actionName": "平台班主任管理-详情",
              "action": "/teacher/get",
              "type": "FUNCTION",
              "id": 211
            }, {
              "actionName": "申请管理-详情",
              "action": "/examinee/get",
              "type": "FUNCTION",
              "id": 273
            }, {
              "actionName": "机构班主任管理页",
              "action": "/authorizedAgencyTeacher/index",
              "type": "PAGE",
              "id": 5871
            }, {
              "actionName": "班级信息页",
              "action": "/class/index",
              "type": "PAGE",
              "id": 121
            }, {
              "actionName": "用户管理-修改",
              "action": "/account/update",
              "type": "FUNCTION",
              "id": 108
            }, {
              "actionName": "订单管理-追加订单",
              "action": "/orderRecord/add",
              "type": "FUNCTION",
              "id": 178
            }, {
              "actionName": "授权机构管理-列表",
              "action": "/authorizedAgency/list",
              "type": "FUNCTION",
              "id": 5879
            }, {
              "actionName": "申请管理-对应城市下所有考试",
              "action": "/examinee/examinationList/.*",
              "type": "FUNCTION",
              "id": 275
            }],
            "id": 7
          }]
        }, {
          "createDate": "2018-05-07",
          "createDateList": "2018-05-07",
          "id": 25423,
          "userName": "jigou001",
          "password": "F379EAF3C831B04DE153469D1BEC345E",
          "email": null,
          "roles": [{
            "roleName": "机构管理员",
            "actions": [{
              "actionName": "机构班主任问题页",
              "action": "/authorizedAgencyTeacher/show",
              "type": "PAGE",
              "id": 6392
            }, {
              "actionName": "班级信息-添加",
              "action": "/class/add",
              "type": "FUNCTION",
              "id": 123
            }, {
              "actionName": "机构班主任管理-详情",
              "action": "/authorizedAgencyTeacher/get",
              "type": "FUNCTION",
              "id": 5874
            }, {
              "actionName": "机构班主任管理-删除",
              "action": "/authorizedAgencyTeacher/delete",
              "type": "FUNCTION",
              "id": 5876
            }, {
              "actionName": "班级列表数据导出",
              "action": "/class/export",
              "type": "FUNCTION",
              "id": 6311
            }, {
              "actionName": "班级信息-详情",
              "action": "/class/get",
              "type": "FUNCTION",
              "id": 126
            }, {
              "actionName": "报名信息-添加",
              "action": "/enrol/add",
              "type": "FUNCTION",
              "id": 148
            }, {
              "actionName": "后台改密",
              "action": "/account/changePwd",
              "type": "FUNCTION",
              "id": 104
            }, {
              "actionName": "班级信息-所有开课中班级",
              "action": "/class/findAll",
              "type": "FUNCTION",
              "id": 127
            }, {
              "actionName": "授权机构管理-全部未禁用机构",
              "action": "/authorizedAgency/findAllActiveTrue",
              "type": "FUNCTION",
              "id": 5883
            }, { "actionName": "首页", "action": "/", "type": "PAGE", "id": 101 }, {
              "actionName": "报名信息-列表",
              "action": "/enrol/list",
              "type": "FUNCTION",
              "id": 147
            }, {
              "actionName": "报名信息-详情",
              "action": "/enrol/get",
              "type": "FUNCTION",
              "id": 149
            }, {
              "actionName": "课程问题-列表",
              "action": "/putQuestionOnWite/list",
              "type": "FUNCTION",
              "id": 164
            }, {
              "actionName": "机构班主任列表数据导出",
              "action": "/authorizedAgencyTeacher/export",
              "type": "FUNCTION",
              "id": 6306
            }, {
              "actionName": "班级首页-授权机构",
              "action": "/class/indexForAuthorizedAgency",
              "type": "PAGE",
              "id": 6327
            }, {
              "actionName": "机构班主任管理-列表",
              "action": "/authorizedAgencyTeacher/list",
              "type": "FUNCTION",
              "id": 5872
            }, {
              "actionName": "班级信息-开课",
              "action": "/class/startCourse/.*",
              "type": "FUNCTION",
              "id": 128
            }, {
              "actionName": "机构班主任管理-修改",
              "action": "/authorizedAgencyTeacher/update",
              "type": "FUNCTION",
              "id": 5875
            }, {
              "actionName": "课程问题-回答",
              "action": "/putQuestionOnWite/update",
              "type": "FUNCTION",
              "id": 166
            }, {
              "actionName": "班级信息-列表",
              "action": "/class/list",
              "type": "FUNCTION",
              "id": 122
            }, {
              "actionName": "课程问题-详情",
              "action": "/putQuestionOnWite/get",
              "type": "FUNCTION",
              "id": 165
            }, {
              "actionName": "报名信息-删除",
              "action": "/enrol/delete",
              "type": "FUNCTION",
              "id": 151
            }, {
              "actionName": "后台登出",
              "action": "/account/quit",
              "type": "PAGE",
              "id": 103
            }, {
              "actionName": "报名信息-修改",
              "action": "/enrol/update",
              "type": "FUNCTION",
              "id": 150
            }, {
              "actionName": "平台班主任管理-所有平台班主任",
              "action": "/teacher/findAll",
              "type": "FUNCTION",
              "id": 214
            }, {
              "actionName": "报名信息-授权机构",
              "action": "/enrol/indexForAuthorizedAgency",
              "type": "PAGE",
              "id": 6330
            }, {
              "actionName": "班级信息-删除",
              "action": "/class/delete",
              "type": "FUNCTION",
              "id": 125
            }, {
              "actionName": "班级信息-所有班级",
              "action": "/class/findAllClass",
              "type": "FUNCTION",
              "id": 129
            }, {
              "actionName": "机构班主任管理-添加",
              "action": "/authorizedAgencyTeacher/add",
              "type": "FUNCTION",
              "id": 5873
            }, {
              "actionName": "机构班主任管理页",
              "action": "/authorizedAgencyTeacher/index",
              "type": "PAGE",
              "id": 5871
            }, {
              "actionName": "报名信息列表数据导出",
              "action": "/enrol/export",
              "type": "FUNCTION",
              "id": 6312
            }, {
              "actionName": "报名信息-重发开班码",
              "action": "/enrol/reSendCode/.*",
              "type": "FUNCTION",
              "id": 153
            }, {
              "actionName": "课程问题-删除",
              "action": "/putQuestionOnWite/delete",
              "type": "FUNCTION",
              "id": 167
            }, {
              "actionName": "班主任问题列表数据导出",
              "action": "/putQuestionOnWite/export",
              "type": "FUNCTION",
              "id": 6325
            }, {
              "actionName": "班级信息-修改",
              "action": "/class/update",
              "type": "FUNCTION",
              "id": 124
            }, {
              "actionName": "课程问题-所有班级",
              "action": "/class/findAllClassByOtherId",
              "type": "FUNCTION",
              "id": 6301
            }, {
              "actionName": "后台登录",
              "action": "/account/login",
              "type": "PAGE",
              "id": 102
            }, {
              "actionName": "机构班主任管理-所有机构班主任",
              "action": "/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*",
              "type": "FUNCTION",
              "id": 5877
            }],
            "id": 3
          }]
        }, {
          "createDate": "2018-03-28",
          "createDateList": "2018-03-28",
          "id": 10222,
          "userName": "ceping",
          "password": "F379EAF3C831B04DE153469D1BEC345E",
          "email": "",
          "roles": [{
            "roleName": "考试管理员",
            "actions": [{
              "actionName": "申请管理-有效期单元",
              "action": "/examinee/validUnit.*",
              "type": "FUNCTION",
              "id": 277
            }, {
              "actionName": "订单管理页",
              "action": "/orderRecord/index",
              "type": "PAGE",
              "id": 174
            }, {
              "actionName": "考试管理-详情",
              "action": "/examination/get",
              "type": "FUNCTION",
              "id": 259
            }, {
              "actionName": "考试管理-单元信息页",
              "action": "/examination/show",
              "type": "PAGE",
              "id": 262
            }, {
              "actionName": "城市列表",
              "action": "/city/cityList/.*",
              "type": "FUNCTION",
              "id": 255
            }, {
              "actionName": "考试单元页",
              "action": "/examinationUnit/index",
              "type": "PAGE",
              "id": 265
            }, {
              "actionName": "申请管理-延考",
              "action": "/examinee/delay",
              "type": "FUNCTION",
              "id": 279
            }, {
              "actionName": "后台改密",
              "action": "/account/changePwd",
              "type": "FUNCTION",
              "id": 104
            }, {
              "actionName": "考试单元列表数据导出",
              "action": "/examination/exportUnit",
              "type": "FUNCTION",
              "id": 6318
            }, { "actionName": "首页", "action": "/", "type": "PAGE", "id": 101 }, {
              "actionName": "订单管理-列表",
              "action": "/orderRecord/list",
              "type": "FUNCTION",
              "id": 175
            }, {
              "actionName": "考试列表数据导出",
              "action": "/examination/export",
              "type": "FUNCTION",
              "id": 6317
            }, {
              "actionName": "订单列表数据导出",
              "action": "/orderRecord/export",
              "type": "FUNCTION",
              "id": 6307
            }, {
              "actionName": "考试单元-详情",
              "action": "/examinationUnit/get",
              "type": "FUNCTION",
              "id": 268
            }, {
              "actionName": "认证申请管理页",
              "action": "/certification/index",
              "type": "PAGE",
              "id": 251
            }, {
              "actionName": "考试申请列表数据导出",
              "action": "/examinee/export",
              "type": "FUNCTION",
              "id": 6319
            }, {
              "actionName": "测评认证-单元报名人数",
              "action": "/examinationRoom/get",
              "type": "FUNCTION",
              "id": 264
            }, {
              "actionName": "申请管理-对应考试下所有单元",
              "action": "/examinee/unitList/.*",
              "type": "FUNCTION",
              "id": 276
            }, {
              "actionName": "订单管理-删除",
              "action": "/orderRecord/delete",
              "type": "FUNCTION",
              "id": 179
            }, {
              "actionName": "后台登出",
              "action": "/account/quit",
              "type": "PAGE",
              "id": 103
            }, {
              "actionName": "申请管理-审核",
              "action": "/examinee/update",
              "type": "FUNCTION",
              "id": 274
            }, {
              "actionName": "认证申请管理-列表",
              "action": "/certification/list",
              "type": "FUNCTION",
              "id": 252
            }, {
              "actionName": "考试单元-添加",
              "action": "/examinationUnit/add",
              "type": "FUNCTION",
              "id": 267
            }, {
              "actionName": "考试单元-删除",
              "action": "/examinationUnit/delete",
              "type": "FUNCTION",
              "id": 269
            }, {
              "actionName": "考试管理页",
              "action": "/examination/index",
              "type": "PAGE",
              "id": 256
            }, {
              "actionName": "申请管理-详情",
              "action": "/examinee/get",
              "type": "FUNCTION",
              "id": 273
            }, {
              "actionName": "认证申请管理-通过",
              "action": "/certification/pass",
              "type": "FUNCTION",
              "id": 253
            }, {
              "actionName": "考试管理-修改",
              "action": "/examination/update",
              "type": "FUNCTION",
              "id": 261
            }, {
              "actionName": "考试管理-添加",
              "action": "/examination/add",
              "type": "FUNCTION",
              "id": 258
            }, {
              "actionName": "申请管理-切换城市",
              "action": "/examinee/changeCity",
              "type": "FUNCTION",
              "id": 278
            }, {
              "actionName": "考试单元-修改",
              "action": "/examinationUnit/update",
              "type": "FUNCTION",
              "id": 270
            }, {
              "actionName": "订单管理-处理",
              "action": "/orderRecord/update",
              "type": "FUNCTION",
              "id": 177
            }, {
              "actionName": "考试单元-列表",
              "action": "/examinationUnit/list",
              "type": "FUNCTION",
              "id": 266
            }, {
              "actionName": "考试管理-删除",
              "action": "/examination/delete",
              "type": "FUNCTION",
              "id": 260
            }, {
              "actionName": "申请管理-列表",
              "action": "/examinee/list",
              "type": "FUNCTION",
              "id": 272
            }, {
              "actionName": "订单管理-详情",
              "action": "/orderRecord/get",
              "type": "FUNCTION",
              "id": 176
            }, {
              "actionName": "订单管理-追加订单",
              "action": "/orderRecord/add",
              "type": "FUNCTION",
              "id": 178
            }, {
              "actionName": "考试管理-列表",
              "action": "/examination/list",
              "type": "FUNCTION",
              "id": 257
            }, {
              "actionName": "证书申请列表数据导出",
              "action": "/certification/export",
              "type": "FUNCTION",
              "id": 6320
            }, {
              "actionName": "申请管理-对应城市下所有考试",
              "action": "/examinee/examinationList/.*",
              "type": "FUNCTION",
              "id": 275
            }, {
              "actionName": "认证申请管理-拒绝",
              "action": "/certification/refuse",
              "type": "FUNCTION",
              "id": 254
            }, {
              "actionName": "申请管理页",
              "action": "/examinee/index",
              "type": "PAGE",
              "id": 271
            }, {
              "actionName": "后台登录",
              "action": "/account/login",
              "type": "PAGE",
              "id": 102
            }, { "actionName": "测评认证-添加考场", "action": "/examinationRoom/addRoom", "type": "FUNCTION", "id": 263 }],
            "id": 6
          }]
        }, {
          "createDate": "2018-03-28",
          "createDateList": "2018-03-28",
          "id": 10221,
          "userName": "banji",
          "password": "F379EAF3C831B04DE153469D1BEC345E",
          "email": "",
          "roles": [{
            "roleName": "班级管理员",
            "actions": [{
              "actionName": "机构班主任问题页",
              "action": "/authorizedAgencyTeacher/show",
              "type": "PAGE",
              "id": 6392
            }, {
              "actionName": "机构班主任管理-删除",
              "action": "/authorizedAgencyTeacher/delete",
              "type": "FUNCTION",
              "id": 5876
            }, {
              "actionName": "平台班主任管理-添加",
              "action": "/teacher/add",
              "type": "FUNCTION",
              "id": 210
            }, {
              "actionName": "报名信息-添加",
              "action": "/enrol/add",
              "type": "FUNCTION",
              "id": 148
            }, {
              "actionName": "后台改密",
              "action": "/account/changePwd",
              "type": "FUNCTION",
              "id": 104
            }, {
              "actionName": "班级信息-所有开课中班级",
              "action": "/class/findAll",
              "type": "FUNCTION",
              "id": 127
            }, { "actionName": "首页", "action": "/", "type": "PAGE", "id": 101 }, {
              "actionName": "课程问题-列表",
              "action": "/putQuestionOnWite/list",
              "type": "FUNCTION",
              "id": 164
            }, {
              "actionName": "机构班主任管理-列表",
              "action": "/authorizedAgencyTeacher/list",
              "type": "FUNCTION",
              "id": 5872
            }, {
              "actionName": "班级信息-开课",
              "action": "/class/startCourse/.*",
              "type": "FUNCTION",
              "id": 128
            }, {
              "actionName": "授权机构列表数据导出",
              "action": "/authorizedAgency/export",
              "type": "FUNCTION",
              "id": 6303
            }, {
              "actionName": "课程问题-回答",
              "action": "/putQuestionOnWite/update",
              "type": "FUNCTION",
              "id": 166
            }, {
              "actionName": "平台班主任管理-列表",
              "action": "/teacher/list",
              "type": "FUNCTION",
              "id": 209
            }, {
              "actionName": "报名信息页",
              "action": "/enrol/index",
              "type": "PAGE",
              "id": 146
            }, {
              "actionName": "平台班主任管理页",
              "action": "/teacher/index",
              "type": "PAGE",
              "id": 208
            }, {
              "actionName": "后台登出",
              "action": "/account/quit",
              "type": "PAGE",
              "id": 103
            }, {
              "actionName": "平台班主任管理-所有平台班主任",
              "action": "/teacher/findAll",
              "type": "FUNCTION",
              "id": 214
            }, {
              "actionName": "机构班主任管理-添加",
              "action": "/authorizedAgencyTeacher/add",
              "type": "FUNCTION",
              "id": 5873
            }, {
              "actionName": "平台班主任管理-删除",
              "action": "/teacher/delete",
              "type": "FUNCTION",
              "id": 213
            }, {
              "actionName": "授权机构管理-添加",
              "action": "/authorizedAgency/add",
              "type": "FUNCTION",
              "id": 5880
            }, {
              "actionName": "报名信息列表数据导出",
              "action": "/enrol/export",
              "type": "FUNCTION",
              "id": 6312
            }, {
              "actionName": "平台班主任问题页",
              "action": "/teacher/show",
              "type": "PAGE",
              "id": 6391
            }, {
              "actionName": "课程问题-删除",
              "action": "/putQuestionOnWite/delete",
              "type": "FUNCTION",
              "id": 167
            }, {
              "actionName": "授权机构管理-删除",
              "action": "/authorizedAgency/delete",
              "type": "FUNCTION",
              "id": 5882
            }, {
              "actionName": "平台班主任管理-修改",
              "action": "/teacher/update",
              "type": "FUNCTION",
              "id": 212
            }, {
              "actionName": "班主任问题列表数据导出",
              "action": "/putQuestionOnWite/export",
              "type": "FUNCTION",
              "id": 6325
            }, {
              "actionName": "课程问题-所有班级",
              "action": "/class/findAllClassByOtherId",
              "type": "FUNCTION",
              "id": 6301
            }, {
              "actionName": "机构班主任管理-所有机构班主任",
              "action": "/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*",
              "type": "FUNCTION",
              "id": 5877
            }, {
              "actionName": "系统配置-详情",
              "action": "/configuration/get",
              "type": "FUNCTION",
              "id": 131
            }, {
              "actionName": "班级信息-添加",
              "action": "/class/add",
              "type": "FUNCTION",
              "id": 123
            }, {
              "actionName": "机构班主任管理-详情",
              "action": "/authorizedAgencyTeacher/get",
              "type": "FUNCTION",
              "id": 5874
            }, {
              "actionName": "班级列表数据导出",
              "action": "/class/export",
              "type": "FUNCTION",
              "id": 6311
            }, {
              "actionName": "班级信息-详情",
              "action": "/class/get",
              "type": "FUNCTION",
              "id": 126
            }, {
              "actionName": "授权机构管理-修改",
              "action": "/authorizedAgency/update",
              "type": "FUNCTION",
              "id": 5881
            }, {
              "actionName": "授权机构管理-全部未禁用机构",
              "action": "/authorizedAgency/findAllActiveTrue",
              "type": "FUNCTION",
              "id": 5883
            }, {
              "actionName": "报名信息-列表",
              "action": "/enrol/list",
              "type": "FUNCTION",
              "id": 147
            }, {
              "actionName": "报名信息-详情",
              "action": "/enrol/get",
              "type": "FUNCTION",
              "id": 149
            }, {
              "actionName": "机构班主任列表数据导出",
              "action": "/authorizedAgencyTeacher/export",
              "type": "FUNCTION",
              "id": 6306
            }, { "actionName": "主页", "action": "/index", "type": "PAGE", "id": 180 }, {
              "actionName": "机构班主任管理-修改",
              "action": "/authorizedAgencyTeacher/update",
              "type": "FUNCTION",
              "id": 5875
            }, {
              "actionName": "班级信息-列表",
              "action": "/class/list",
              "type": "FUNCTION",
              "id": 122
            }, {
              "actionName": "课程问题-详情",
              "action": "/putQuestionOnWite/get",
              "type": "FUNCTION",
              "id": 165
            }, {
              "actionName": "报名信息-删除",
              "action": "/enrol/delete",
              "type": "FUNCTION",
              "id": 151
            }, {
              "actionName": "报名信息-修改",
              "action": "/enrol/update",
              "type": "FUNCTION",
              "id": 150
            }, {
              "actionName": "班级信息-删除",
              "action": "/class/delete",
              "type": "FUNCTION",
              "id": 125
            }, {
              "actionName": "班级信息-所有班级",
              "action": "/class/findAllClass",
              "type": "FUNCTION",
              "id": 129
            }, {
              "actionName": "平台班主任管理-详情",
              "action": "/teacher/get",
              "type": "FUNCTION",
              "id": 211
            }, {
              "actionName": "机构班主任管理页",
              "action": "/authorizedAgencyTeacher/index",
              "type": "PAGE",
              "id": 5871
            }, {
              "actionName": "报名信息-重发开班码",
              "action": "/enrol/reSendCode/.*",
              "type": "FUNCTION",
              "id": 153
            }, {
              "actionName": "班级信息页",
              "action": "/class/index",
              "type": "PAGE",
              "id": 121
            }, {
              "actionName": "班级信息-修改",
              "action": "/class/update",
              "type": "FUNCTION",
              "id": 124
            }, {
              "actionName": "授权机构管理页",
              "action": "/authorizedAgency/index",
              "type": "PAGE",
              "id": 5878
            }, {
              "actionName": "授权机构管理-列表",
              "action": "/authorizedAgency/list",
              "type": "FUNCTION",
              "id": 5879
            }, {
              "actionName": "平台班主任列表数据导出",
              "action": "/teacher/export",
              "type": "FUNCTION",
              "id": 6305
            }, {
              "actionName": "后台登录",
              "action": "/account/login",
              "type": "PAGE",
              "id": 102
            }, { "actionName": "授权机构管理-详情", "action": "/authorizedAgency/get", "type": "FUNCTION", "id": 25461 }],
            "id": 5
          }]
        }, {
          "createDate": "2018-03-23",
          "createDateList": "2018-03-23",
          "id": 9771,
          "userName": "teacher685966",
          "password": "F379EAF3C831B04DE153469D1BEC345E",
          "email": null,
          "roles": [{
            "roleName": "平台班主任",
            "actions": [{
              "actionName": "班级首页-平台班主任",
              "action": "/class/indexForTeacher",
              "type": "PAGE",
              "id": 6329
            }, {
              "actionName": "班级信息-添加",
              "action": "/class/add",
              "type": "FUNCTION",
              "id": 123
            }, {
              "actionName": "班级列表数据导出",
              "action": "/class/export",
              "type": "FUNCTION",
              "id": 6311
            }, {
              "actionName": "报名信息-平台班主任",
              "action": "/enrol/indexForTeacher",
              "type": "PAGE",
              "id": 6352
            }, {
              "actionName": "班级信息-详情",
              "action": "/class/get",
              "type": "FUNCTION",
              "id": 126
            }, {
              "actionName": "报名信息-添加",
              "action": "/enrol/add",
              "type": "FUNCTION",
              "id": 148
            }, {
              "actionName": "后台改密",
              "action": "/account/changePwd",
              "type": "FUNCTION",
              "id": 104
            }, {
              "actionName": "班级信息-所有开课中班级",
              "action": "/class/findAll",
              "type": "FUNCTION",
              "id": 127
            }, {
              "actionName": "授权机构管理-全部未禁用机构",
              "action": "/authorizedAgency/findAllActiveTrue",
              "type": "FUNCTION",
              "id": 5883
            }, { "actionName": "首页", "action": "/", "type": "PAGE", "id": 101 }, {
              "actionName": "报名信息-列表",
              "action": "/enrol/list",
              "type": "FUNCTION",
              "id": 147
            }, {
              "actionName": "报名信息-详情",
              "action": "/enrol/get",
              "type": "FUNCTION",
              "id": 149
            }, {
              "actionName": "课程问题-列表",
              "action": "/putQuestionOnWite/list",
              "type": "FUNCTION",
              "id": 164
            }, {
              "actionName": "班级信息-开课",
              "action": "/class/startCourse/.*",
              "type": "FUNCTION",
              "id": 128
            }, {
              "actionName": "课程已回答问题页",
              "action": "/putQuestionOnWite/indexOnSuccessful",
              "type": "PAGE",
              "id": 163
            }, {
              "actionName": "课程问题-回答",
              "action": "/putQuestionOnWite/update",
              "type": "FUNCTION",
              "id": 166
            }, {
              "actionName": "班级信息-列表",
              "action": "/class/list",
              "type": "FUNCTION",
              "id": 122
            }, {
              "actionName": "课程问题-详情",
              "action": "/putQuestionOnWite/get",
              "type": "FUNCTION",
              "id": 165
            }, {
              "actionName": "报名信息-删除",
              "action": "/enrol/delete",
              "type": "FUNCTION",
              "id": 151
            }, {
              "actionName": "后台登出",
              "action": "/account/quit",
              "type": "PAGE",
              "id": 103
            }, {
              "actionName": "报名信息-修改",
              "action": "/enrol/update",
              "type": "FUNCTION",
              "id": 150
            }, {
              "actionName": "平台班主任管理-所有平台班主任",
              "action": "/teacher/findAll",
              "type": "FUNCTION",
              "id": 214
            }, {
              "actionName": "班级信息-删除",
              "action": "/class/delete",
              "type": "FUNCTION",
              "id": 125
            }, {
              "actionName": "班级信息-所有班级",
              "action": "/class/findAllClass",
              "type": "FUNCTION",
              "id": 129
            }, {
              "actionName": "课程待回答问题页",
              "action": "/putQuestionOnWite/index",
              "type": "PAGE",
              "id": 162
            }, {
              "actionName": "报名信息列表数据导出",
              "action": "/enrol/export",
              "type": "FUNCTION",
              "id": 6312
            }, {
              "actionName": "报名信息-重发开班码",
              "action": "/enrol/reSendCode/.*",
              "type": "FUNCTION",
              "id": 153
            }, {
              "actionName": "课程问题-删除",
              "action": "/putQuestionOnWite/delete",
              "type": "FUNCTION",
              "id": 167
            }, {
              "actionName": "班主任问题列表数据导出",
              "action": "/putQuestionOnWite/export",
              "type": "FUNCTION",
              "id": 6325
            }, {
              "actionName": "班级信息-修改",
              "action": "/class/update",
              "type": "FUNCTION",
              "id": 124
            }, {
              "actionName": "课程问题-所有班级",
              "action": "/class/findAllClassByOtherId",
              "type": "FUNCTION",
              "id": 6301
            }, {
              "actionName": "后台登录",
              "action": "/account/login",
              "type": "PAGE",
              "id": 102
            }, {
              "actionName": "机构班主任管理-所有机构班主任",
              "action": "/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*",
              "type": "FUNCTION",
              "id": 5877
            }],
            "id": 2
          }]
        }, {
          "createDate": "2018-03-19",
          "createDateList": "2018-03-19",
          "id": 103,
          "userName": "export849925",
          "password": "F379EAF3C831B04DE153469D1BEC345E",
          "email": null,
          "roles": [{
            "roleName": "专家",
            "actions": [{
              "actionName": "班主任问题列表数据导出",
              "action": "/putQuestionOnWite/export",
              "type": "FUNCTION",
              "id": 6325
            }, {
              "actionName": "课程待回答问题页",
              "action": "/putQuestionOnWite/index",
              "type": "PAGE",
              "id": 162
            }, {
              "actionName": "课程问题-所有班级",
              "action": "/class/findAllClassByOtherId",
              "type": "FUNCTION",
              "id": 6301
            }, {
              "actionName": "课程已回答问题页",
              "action": "/putQuestionOnWite/indexOnSuccessful",
              "type": "PAGE",
              "id": 163
            }, {
              "actionName": "课程问题-回答",
              "action": "/putQuestionOnWite/update",
              "type": "FUNCTION",
              "id": 166
            }, {
              "actionName": "课程问题-详情",
              "action": "/putQuestionOnWite/get",
              "type": "FUNCTION",
              "id": 165
            }, { "actionName": "后台登出", "action": "/account/quit", "type": "PAGE", "id": 103 }, {
              "actionName": "首页",
              "action": "/",
              "type": "PAGE",
              "id": 101
            }, {
              "actionName": "后台登录",
              "action": "/account/login",
              "type": "PAGE",
              "id": 102
            }, {
              "actionName": "课程问题-删除",
              "action": "/putQuestionOnWite/delete",
              "type": "FUNCTION",
              "id": 167
            }, { "actionName": "课程问题-列表", "action": "/putQuestionOnWite/list", "type": "FUNCTION", "id": 164 }],
            "id": 1
          }]
        }],
      },});
  },
  'GET /api/fake_all_authority_list': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {
        list: [{"createDate":"2018-01-15","createDateList":"2018-01-15","id":101,"actionName":"首页","action":"/home","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":102,"actionName":"后台登录","action":"/account/login","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":103,"actionName":"后台登出","action":"/account/quit","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":104,"actionName":"后台改密","action":"/account/changePwd","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":105,"actionName":"用户管理页","action":"/account/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":106,"actionName":"用户管理-列表","action":"/account/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":107,"actionName":"用户管理-添加","action":"/account/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":108,"actionName":"用户管理-修改","action":"/account/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":109,"actionName":"用户管理-删除","action":"/account/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":110,"actionName":"用户管理-详情","action":"/account/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":111,"actionName":"用户管理-重置密码","action":"/account/rest","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":112,"actionName":"权限管理页","action":"/action/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":113,"actionName":"权限管理-列表","action":"/action/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":114,"actionName":"权限管理-添加","action":"/action/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":115,"actionName":"权限管理-详情","action":"/action/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":116,"actionName":"权限管理-修改","action":"/action/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":117,"actionName":"权限管理-删除","action":"/action/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":118,"actionName":"权限管理-所有权限","action":"/action/findAll","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":119,"actionName":"日志管理页","action":"/log/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":120,"actionName":"日志管理-列表","action":"/log/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":121,"actionName":"班级信息页","action":"/class/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":122,"actionName":"班级信息-列表","action":"/class/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":123,"actionName":"班级信息-添加","action":"/class/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":124,"actionName":"班级信息-修改","action":"/class/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":125,"actionName":"班级信息-删除","action":"/class/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":126,"actionName":"班级信息-详情","action":"/class/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":127,"actionName":"班级信息-所有开课中班级","action":"/class/findAll","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":128,"actionName":"班级信息-开课","action":"/class/startCourse/.*","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":129,"actionName":"班级信息-所有班级","action":"/class/findAllClass","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":130,"actionName":"系统配置页","action":"/configuration/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":131,"actionName":"系统配置-详情","action":"/configuration/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":132,"actionName":"系统配置-修改","action":"/system/configuration","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":133,"actionName":"课程列表页","action":"/course/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":134,"actionName":"课程列表-列表","action":"/course/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":135,"actionName":"课程列表-添加","action":"/course/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":136,"actionName":"课程列表-详情","action":"/course/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":137,"actionName":"课程列表-修改","action":"/course/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":138,"actionName":"课程列表-删除","action":"/course/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":139,"actionName":"课程列表-全部课程","action":"/course/findAll","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":140,"actionName":"课程结构页","action":"/comsumerList","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":141,"actionName":"课程结构-列表","action":"/courseStructure/structure/all","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":142,"actionName":"课程结构-添加","action":"/courseStructure/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":143,"actionName":"课程结构-修改","action":"/courseStructure/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":144,"actionName":"课程结构-删除","action":"/courseStructure/del","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":145,"actionName":"课程结构-详情","action":"/courseStructure/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":146,"actionName":"报名信息页","action":"/system/authority","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":147,"actionName":"报名信息-列表","action":"/enrol/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":148,"actionName":"报名信息-添加","action":"/enrol/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":149,"actionName":"报名信息-详情","action":"/enrol/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":150,"actionName":"报名信息-修改","action":"/enrol/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":151,"actionName":"报名信息-删除","action":"/enrol/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":153,"actionName":"报名信息-重发开班码","action":"/enrol/reSendCode/.*","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":154,"actionName":"专家管理页","action":"/expert/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":155,"actionName":"专家管理-列表","action":"/expert/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":156,"actionName":"专家管理-添加","action":"/expert/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":157,"actionName":"专家管理-详情","action":"/expert/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":158,"actionName":"专家管理-修改","action":"/expert/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":159,"actionName":"专家管理-删除","action":"/expert/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":160,"actionName":"专家管理-所有专家","action":"/expert/findAll","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":161,"actionName":"专家管理-专家相关问题页","action":"/expert/show","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":162,"actionName":"课程待回答问题页","action":"/putQuestionOnWite/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":163,"actionName":"课程已回答问题页","action":"/putQuestionOnWite/indexOnSuccessful","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":164,"actionName":"课程问题-列表","action":"/putQuestionOnWite/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":165,"actionName":"课程问题-详情","action":"/putQuestionOnWite/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":166,"actionName":"课程问题-回答","action":"/putQuestionOnWite/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":167,"actionName":"课程问题-删除","action":"/putQuestionOnWite/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":168,"actionName":"基金申请管理页","action":"/fundApplication/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":169,"actionName":"基金申请管理-列表","action":"/fundApplication/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":170,"actionName":"基金申请管理-详情","action":"/fundApplication/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":171,"actionName":"基金申请管理-审核框","action":"/fundApplication/find","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":172,"actionName":"基金申请管理-审核","action":"/fundApplication/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":173,"actionName":"证件类型","action":"/idtype/findAll","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":174,"actionName":"订单管理页","action":"/orderRecord/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":175,"actionName":"订单管理-列表","action":"/orderRecord/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":176,"actionName":"订单管理-详情","action":"/orderRecord/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":177,"actionName":"订单管理-处理","action":"/orderRecord/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":178,"actionName":"订单管理-追加订单","action":"/orderRecord/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":179,"actionName":"订单管理-删除","action":"/orderRecord/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":180,"actionName":"主页","action":"/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":181,"actionName":"登录页","action":"/login","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":182,"actionName":"知识列表页","action":"/repositories/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":183,"actionName":"知识列表-列表","action":"/repositories/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":184,"actionName":"知识列表-添加","action":"/repositories/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":185,"actionName":"知识列表-详情","action":"/repositories/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":186,"actionName":"知识列表-修改","action":"/repositories/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":187,"actionName":"知识列表-删除","action":"/repositories/delete","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":188,"actionName":"知识库结构页","action":"/repositoryStructure/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":189,"actionName":"知识库结构-列表","action":"/repositoryStructure/structure/all","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":190,"actionName":"知识库结构-添加","action":"/repositoryStructure/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":191,"actionName":"知识库结构-修改","action":"/repositoryStructure/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":192,"actionName":"知识库结构-删除","action":"/repositoryStructure/del","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":193,"actionName":"知识库结构-详情","action":"/repositoryStructure/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":194,"actionName":"成果列表页","action":"/research/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":195,"actionName":"成果列表-列表","action":"/research/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":196,"actionName":"成果列表-添加","action":"/research/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":197,"actionName":"成果列表-详情","action":"/research/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":198,"actionName":"成果列表-修改","action":"/research/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":199,"actionName":"成果列表-删除","action":"/research/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":200,"actionName":"角色管理页","action":"/role/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":201,"actionName":"角色管理-列表","action":"/role/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":202,"actionName":"角色管理-添加","action":"/role/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":203,"actionName":"角色管理-修改","action":"/role/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":204,"actionName":"角色管理-删除","action":"/role/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":205,"actionName":"角色管理-所有角色","action":"/role/findAll","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":206,"actionName":"积分列表页","action":"/sendIntegral/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":207,"actionName":"积分列表-列表","action":"/sendIntegral/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":208,"actionName":"平台班主任管理页","action":"/teacher/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":209,"actionName":"平台班主任管理-列表","action":"/teacher/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":210,"actionName":"平台班主任管理-添加","action":"/teacher/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":211,"actionName":"平台班主任管理-详情","action":"/teacher/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":212,"actionName":"平台班主任管理-修改","action":"/teacher/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":213,"actionName":"平台班主任管理-删除","action":"/teacher/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":214,"actionName":"平台班主任管理-所有平台班主任","action":"/teacher/findAll","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":215,"actionName":"教材组管理页","action":"/teachingMaterial/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":216,"actionName":"教材主管理-列表","action":"/teachingMaterial/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":217,"actionName":"教材主管理-所有教材组","action":"/teachingMaterial/findAll","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":218,"actionName":"教材组管理-详情","action":"/teachingMaterial/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":219,"actionName":"教材组管理-详情","action":"/teachingMaterial/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":220,"actionName":"教材组管理-修改","action":"/teachingMaterial/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":221,"actionName":"教材组管理-删除","action":"/teachingMaterial/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":222,"actionName":"研究领域-列表","action":"/territory/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":223,"actionName":"会员管理页","action":"/user/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":224,"actionName":"会员管理-列表","action":"/user/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":225,"actionName":"会员管理-详情","action":"/user/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":226,"actionName":"会员管理-积分调整","action":"/user/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":227,"actionName":"会员管理-考试信息","action":"/user/exam","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":228,"actionName":"会员管理-备注","action":"/user/getRemark","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":229,"actionName":"慧文列表页","action":"/wisdomArticles/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":230,"actionName":"慧文列表-列表","action":"/wisdomArticles/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":231,"actionName":"慧文列表-添加","action":"/wisdomArticles/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":232,"actionName":"慧文列表-详情","action":"/wisdomArticles/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":233,"actionName":"慧文列表-修改","action":"/wisdomArticles/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":234,"actionName":"慧文列表-删除","action":"/wisdomArticles/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":235,"actionName":"首页轮播页","action":"/carousel/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":236,"actionName":"首页轮播-列表","action":"/carousel/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":237,"actionName":"首页轮播-添加","action":"/carousel/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":238,"actionName":"首页轮播-详情","action":"/carousel/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":239,"actionName":"首页轮播-修改","action":"/carousel/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":240,"actionName":"首页轮播-删除","action":"/carousel/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":241,"actionName":"商品分类页","action":"/commodityCategories/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":242,"actionName":"商品分类-列表","action":"/commodityCategories/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":243,"actionName":"商品分类-详情","action":"/commodityCategories/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":244,"actionName":"商品分类-修改","action":"/commodityCategories/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":245,"actionName":"商品列表页","action":"/commodities/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":246,"actionName":"商品列表-列表","action":"/commodities/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":247,"actionName":"商品分类-添加","action":"/commodities/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":248,"actionName":"商品分类-详情","action":"/commodities/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":249,"actionName":"商品分类-修改","action":"/commodities/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":250,"actionName":"商品分类-删除","action":"/commodities/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":251,"actionName":"认证申请管理页","action":"/certification/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":252,"actionName":"认证申请管理-列表","action":"/certification/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":253,"actionName":"认证申请管理-通过","action":"/certification/pass","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":254,"actionName":"认证申请管理-拒绝","action":"/certification/refuse","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":255,"actionName":"城市列表","action":"/city/cityList/.*","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":256,"actionName":"考试管理页","action":"/examination/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":257,"actionName":"考试管理-列表","action":"/examination/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":258,"actionName":"考试管理-添加","action":"/examination/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":259,"actionName":"考试管理-详情","action":"/examination/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":260,"actionName":"考试管理-删除","action":"/examination/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":261,"actionName":"考试管理-修改","action":"/examination/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":262,"actionName":"考试管理-单元信息页","action":"/examination/show","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":263,"actionName":"测评认证-添加考场","action":"/examinationRoom/addRoom","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":264,"actionName":"测评认证-单元报名人数","action":"/examinationRoom/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":265,"actionName":"考试单元页","action":"/examinationUnit/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":266,"actionName":"考试单元-列表","action":"/examinationUnit/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":267,"actionName":"考试单元-添加","action":"/examinationUnit/add","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":268,"actionName":"考试单元-详情","action":"/examinationUnit/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":269,"actionName":"考试单元-删除","action":"/examinationUnit/delete","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":270,"actionName":"考试单元-修改","action":"/examinationUnit/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":271,"actionName":"申请管理页","action":"/examinee/index","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":272,"actionName":"申请管理-列表","action":"/examinee/list","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":273,"actionName":"申请管理-详情","action":"/examinee/get","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":274,"actionName":"申请管理-审核","action":"/examinee/update","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":275,"actionName":"申请管理-对应城市下所有考试","action":"/examinee/examinationList/.*","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":276,"actionName":"申请管理-对应考试下所有单元","action":"/examinee/unitList/.*","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":277,"actionName":"申请管理-有效期单元","action":"/examinee/validUnit.*","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":278,"actionName":"申请管理-切换城市","action":"/examinee/changeCity","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":279,"actionName":"申请管理-延考","action":"/examinee/delay","type":1},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5871,"actionName":"机构班主任管理页","action":"/authorizedAgencyTeacher/index","type":0},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5872,"actionName":"机构班主任管理-列表","action":"/authorizedAgencyTeacher/list","type":1},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5873,"actionName":"机构班主任管理-添加","action":"/authorizedAgencyTeacher/add","type":1},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5874,"actionName":"机构班主任管理-详情","action":"/authorizedAgencyTeacher/get","type":1},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5875,"actionName":"机构班主任管理-修改","action":"/authorizedAgencyTeacher/update","type":1},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5876,"actionName":"机构班主任管理-删除","action":"/authorizedAgencyTeacher/delete","type":1},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5877,"actionName":"机构班主任管理-所有机构班主任","action":"/authorizedAgencyTeacher/findAllAuthorizedAgencyTeacher/.*","type":1},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5878,"actionName":"授权机构管理页","action":"/authorizedAgency/index","type":0},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5879,"actionName":"授权机构管理-列表","action":"/authorizedAgency/list","type":1},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5880,"actionName":"授权机构管理-添加","action":"/authorizedAgency/add","type":1},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5881,"actionName":"授权机构管理-修改","action":"/authorizedAgency/update","type":1},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5882,"actionName":"授权机构管理-删除","action":"/authorizedAgency/delete","type":1},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":5883,"actionName":"授权机构管理-全部未禁用机构","action":"/authorizedAgency/findAllActiveTrue","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":6301,"actionName":"课程问题-所有班级","action":"/class/findAllClassByOtherId","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6302,"actionName":"会员管理列表数据导出","action":"/user/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6303,"actionName":"授权机构列表数据导出","action":"/authorizedAgency/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6304,"actionName":"专家列表数据导出","action":"/expert/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6305,"actionName":"平台班主任列表数据导出","action":"/teacher/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6306,"actionName":"机构班主任列表数据导出","action":"/authorizedAgencyTeacher/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6307,"actionName":"订单列表数据导出","action":"/orderRecord/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6308,"actionName":"基金申请列表数据导出","action":"/fundApplication/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6309,"actionName":"课程列表数据导出","action":"/course/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6310,"actionName":"教材组列表数据导出","action":"/teachingMaterial/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6311,"actionName":"班级列表数据导出","action":"/class/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6312,"actionName":"报名信息列表数据导出","action":"/enrol/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6313,"actionName":"知识列表数据导出","action":"/repositories/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6314,"actionName":"成果列表数据导出","action":"/research/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6315,"actionName":"慧文列表数据导出","action":"/wisdomArticles/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6316,"actionName":"商品列表数据导出","action":"/commodities/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6317,"actionName":"考试列表数据导出","action":"/examination/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6318,"actionName":"考试单元列表数据导出","action":"/examination/exportUnit","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6319,"actionName":"考试申请列表数据导出","action":"/examinee/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6320,"actionName":"证书申请列表数据导出","action":"/certification/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6321,"actionName":"日志列表数据导出","action":"/log/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6322,"actionName":"用户列表数据导出","action":"/account/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6323,"actionName":"后台角色列表数据导出","action":"/role/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6324,"actionName":"权限列表数据导出","action":"/action/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6325,"actionName":"班主任问题列表数据导出","action":"/putQuestionOnWite/export","type":1},{"createDate":"2018-05-02","createDateList":"2018-05-02","id":6326,"actionName":"会员积分明细列表数据导出","action":"/sendIntegral/export","type":1},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":6327,"actionName":"班级首页-授权机构","action":"/class/indexForAuthorizedAgency","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":6328,"actionName":"班级首页-机构班主任","action":"/class/indexForAuthorizedAgencyTeacher","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":6329,"actionName":"班级首页-平台班主任","action":"/class/indexForTeacher","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":6330,"actionName":"报名信息-授权机构","action":"/enrol/indexForAuthorizedAgency","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":6351,"actionName":"报名信息-机构班主任","action":"/enrol/indexForAuthorizedAgencyTeacher","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":6352,"actionName":"报名信息-平台班主任","action":"/enrol/indexForTeacher","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":6391,"actionName":"平台班主任问题页","action":"/teacher/show","type":0},{"createDate":"2018-01-15","createDateList":"2018-01-15","id":6392,"actionName":"机构班主任问题页","action":"/authorizedAgencyTeacher/show","type":0},{"createDate":"2018-04-10","createDateList":"2018-04-10","id":25461,"actionName":"授权机构管理-详情","action":"/authorizedAgency/get","type":1}],
      }
    });
  },
  'GET /api/fake_role': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {
        id: 255,
        roleName:"测评认证管理员",
        list: [{"actionName":"申请管理-有效期单元","action":"/examinee/validUnit.*","type":"FUNCTION","id":277},{"actionName":"考试管理-详情","action":"/examination/get","type":"FUNCTION","id":259},{"actionName":"考试管理-单元信息页","action":"/examination/show","type":"PAGE","id":262},{"actionName":"城市列表","action":"/city/cityList/.*","type":"FUNCTION","id":255},{"actionName":"考试单元页","action":"/examinationUnit/index","type":"PAGE","id":265},{"actionName":"申请管理-延考","action":"/examinee/delay","type":"FUNCTION","id":279},{"actionName":"首页","action":"/","type":"PAGE","id":101},{"actionName":"考试单元-详情","action":"/examinationUnit/get","type":"FUNCTION","id":268},{"actionName":"认证申请管理页","action":"/certification/index","type":"PAGE","id":251},{"actionName":"测评认证-单元报名人数","action":"/examinationRoom/get","type":"FUNCTION","id":264},{"actionName":"申请管理-对应考试下所有单元","action":"/examinee/unitList/.*","type":"FUNCTION","id":276},{"actionName":"后台登出","action":"/account/quit","type":"PAGE","id":103},{"actionName":"申请管理-审核","action":"/examinee/update","type":"FUNCTION","id":274},{"actionName":"认证申请管理-列表","action":"/certification/list","type":"FUNCTION","id":252},{"actionName":"考试单元-添加","action":"/examinationUnit/add","type":"FUNCTION","id":267},{"actionName":"考试单元-删除","action":"/examinationUnit/delete","type":"FUNCTION","id":269},{"actionName":"考试管理页","action":"/examination/index","type":"PAGE","id":256},{"actionName":"申请管理-详情","action":"/examinee/get","type":"FUNCTION","id":273},{"actionName":"认证申请管理-通过","action":"/certification/pass","type":"FUNCTION","id":253},{"actionName":"考试管理-修改","action":"/examination/update","type":"FUNCTION","id":261},{"actionName":"考试管理-添加","action":"/examination/add","type":"FUNCTION","id":258},{"actionName":"申请管理-切换城市","action":"/examinee/changeCity","type":"FUNCTION","id":278},{"actionName":"考试单元-修改","action":"/examinationUnit/update","type":"FUNCTION","id":270},{"actionName":"考试单元-列表","action":"/examinationUnit/list","type":"FUNCTION","id":266},{"actionName":"考试管理-删除","action":"/examination/delete","type":"FUNCTION","id":260},{"actionName":"申请管理-列表","action":"/examinee/list","type":"FUNCTION","id":272},{"actionName":"考试管理-列表","action":"/examination/list","type":"FUNCTION","id":257},{"actionName":"申请管理-对应城市下所有考试","action":"/examinee/examinationList/.*","type":"FUNCTION","id":275},{"actionName":"认证申请管理-拒绝","action":"/certification/refuse","type":"FUNCTION","id":254},{"actionName":"申请管理页","action":"/examinee/index","type":"PAGE","id":271},{"actionName":"后台登录","action":"/account/login","type":"PAGE","id":102},{"actionName":"测评认证-添加考场","action":"/examinationRoom/addRoom","type":"FUNCTION","id":263}],
      },});
  },
  'POST /api/fake_role_submit': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {},
    });
  },
  'POST /api/permission/list': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {
        data: [
          {
            id: 1,
            name: '资源1',
            description: 'jieshao',
            createDate: '2018-02-01',
            url: '/jiasjid',
          },
        ],
        recordsTotal: 1,
      },
    });
  },
  'POST /api/permission/info': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: '',
    });
  },
  'POST /api/v1/sysAuthority/info': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: '',
    });
  },
  'GET /api/v1/sysAuthority/info': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {
        name: '权限1',
        description: '描述',
        id: 1,
        authorityList: [{
          name: '权限2',
          description: '页面资源1',
          id: 1,
          type: 'PAGE',
        },{
          name: '权限6',
          description: '页面资源2',
          id: 2,
          type: 'PAGE',
        },{
          name: '权限10',
          description: '页面资源3',
          id: 3,
          type: 'PAGE',
        },{
          name: '权限3',
          description: '方法资源8',
          id: 8,
          type: 'FUNCTION',
        },{
          name: '权限7',
          description: '方法资源7',
          id: 7,
          type: 'FUNCTION',
        },{
          name: '权限13',
          description: '方法资源6',
          id: 6,
          type: 'FUNCTION',
        }],
      },
    });
  },
  'POST /api/v1/role/list': getRoleList,
  'POST /api/v1/role/all': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {
        data: [
          {
            id: 1,
            name: '资源1',
            description: 'jieshao',
            createDate: '2018-02-01',
            url: '/jiasjid',
          },
          {
            id: 2,
            name: '资源2',
            description: 'jieshao',
            createDate: '2018-02-01',
            url: '/jiasjid',
          },
          {
            id: 3,
            name: '资源3',
            description: 'jieshao',
            createDate: '2018-02-01',
            url: '/jiasjid',
          },
          {
            id: 4,
            name: '资源4',
            description: 'jieshao',
            createDate: '2018-02-01',
            url: '/jiasjid',
          },
          {
            id: 5,
            name: '资源5',
            description: 'jieshao',
            createDate: '2018-02-01',
            url: '/jiasjid',
          },
          {
            id: 6,
            name: '资源6',
            description: 'jieshao',
            createDate: '2018-02-01',
            url: '/jiasjid',
          },
        ],
      },
    });
  },
  'POST /api/v1/role/info': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: '',
    });
  },
  'DELETE /api/v1/role/info': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: '',
    });
  },
  'GET /api/v1/role/info': (req, res) => {
    res.send({
      c: 200,
      m: '',
      d: {
        name: '角色1',
        id: 1,
        description: '描述',
        authorityList: [{
          id: 1,
          name: '权限1',
          description: '描述',
        },{
          id: 2,
          name: '权限2',
          description: '描述',
        },{
          id: 3,
          name: '权限3',
          description: '描述',
        },{
          id: 4,
          name: '权限4',
          description: '描述',
        },{
          id: 5,
          name: '权限5',
          description: '描述',
        }],
      },
    });
  },
};


export default (noProxy ? {} : delay(proxy, 1000));
