import {createElement} from 'react';
import dynamic from 'dva/dynamic';
import pathToRegexp from 'path-to-regexp';
import {getMenuData} from './menu';

let routerDataCache;

const modelNotExisted = (app, model) =>
  // eslint-disable-next-line
  !app._models.some(({namespace}) => {
    return namespace === model.substring(model.lastIndexOf('/') + 1);
  });

// wrapper of dynamic
const dynamicWrapper = (app, models, component) => {
  // () => require('module')
  // transformed by babel-plugin-dynamic-import-node-sync
  if (component.toString().indexOf('.then(') < 0) {
    models.forEach(model => {
      if (modelNotExisted(app, model)) {
        // eslint-disable-next-line
        app.model(require(`../models/${model}`).default);
      }
    });
    return props => {
      if (!routerDataCache) {
        routerDataCache = getRouterData(app);
      }
      return createElement(component().default, {
        ...props,
        routerData: routerDataCache,
      });
    };
  }
  // () => import('module')
  return dynamic({
    app,
    models: () =>
      models.filter(model => modelNotExisted(app, model)).map(m => import(`../models/${m}.js`)),
    // add routerData prop
    component: () => {
      if (!routerDataCache) {
        routerDataCache = getRouterData(app);
      }
      return component().then(raw => {
        const Component = raw.default || raw;
        return props =>
          createElement(Component, {
            ...props,
            routerData: routerDataCache,
          });
      });
    },
  });
};

function getFlatMenuData(menus) {
  let keys = {};
  menus.forEach(item => {
    if (item.children) {
      keys[item.path] = {...item};
      keys = {...keys, ...getFlatMenuData(item.children)};
    } else {
      keys[item.path] = {...item};
    }
  });
  return keys;
}

export const getRouterData = app => {
  let routerConfig = {
    '/': {
      component: dynamicWrapper(app, ['user', 'login'], () => import('../layouts/BasicLayout')),
    },
    '/home': {
      component: dynamicWrapper(app, [], () => import('../routes/Dashboard/Analysis')),
      // authority: '/home',
      name: '首页'
    },
    '/comsumer/list': {
      component: dynamicWrapper(app, ['comsumer'], () => import('../routes/List/Comsumer')),
      authority: '/comsumer/list',
      name: '用户管理'
    },
    '/comsumer/comsumerProfile': {
      component: dynamicWrapper(app, ['comsumer'], () => import('../routes/Profile/Comsumer')),
      authority: '/comsumer/comsumerProfile',
      name: '用户详情'
    },
    '/comsumer/realPerson': {
      component: dynamicWrapper(app, ['comsumer'], () => import('../routes/List/RealPerson')),
      authority: '/comsumer/realPerson',
      name: '真人认证'
    },
    // '/analysis': {
    //   component: dynamicWrapper(app, ['chart'], () => import('../routes/Dashboard/Analysis')),
    //   authority: '/analysis',
    //   name: '数据统计',
    // },
    '/review/nickName': {
      component: dynamicWrapper(app, ['review'], () => import('../routes/List/NormalUser')),
      authority: '/review/nickName',
      name: '头像昵称审核'
    },
    '/review/user': {
      component: dynamicWrapper(app, ['review'], () => import('../routes/List/NormalUsers')),
      authority: '/review/user',
      name: '修改后待审核'
    },
    '/review/photo': {
      component: dynamicWrapper(app, ['review'], () => import('../routes/List/NormalPhoto')),
      authority: '/review/photo',
      name: '相册审核'
    },
    '/question': {
      component: dynamicWrapper(app, [], () => import('../routes/List/Question')),
      authority: '/question',
      name: '问题管理'
    },
    
    '/presetPhraese': {
      component: dynamicWrapper(app, ['presetPhraese'], () => import('../routes/List/PresetPhraese')),
      authority: '/presetPhraese',
      name: '预置短语管理'
    },
    '/label': {
      component: dynamicWrapper(app, ['label'], () => import('../routes/List/Label')),
      authority: '/label',
      name: '标签管理'
    },
    '/accumulation/list': {
      component: dynamicWrapper(app, ['accumulation'], () =>
        import('../routes/List/Accumulation')
      ),
      authority: '/accumulation/list',
      name: '聚点管理'
    },
    '/site/list': {
      component: dynamicWrapper(app, ['site'], () =>
        import('../routes/List/Site')
      ),
      authority: '/site/list',
      name: '商户管理'
    },
    '/accumulation/accumulationAdd': {
      component: dynamicWrapper(app, ['accumulation'], () => import('../routes/Profile/AccumulationAdd'),
      ),
      // authority: '/accumulation/accumulationAdd',
      name: '创建聚点'
    },
    '/accumulation/accumulationEdit': {
      component: dynamicWrapper(app, ['accumulation', 'site'], () => import('../routes/Profile/Accumulation'),
      ),
      // authority: '/accumulation/accumulationEdit',
      name: '聚点详情'
    },
    '/accumulation/site/list': {
      component: dynamicWrapper(app, ['site'], () => import('../routes/List/Site')),
      // authority: '/accumulation/site/list',
      name: '商户管理'
    },
    '/accumulation/site/siteEdit': {
      component: dynamicWrapper(app, ['site'], () => import('../routes/Profile/Site')),
      // authority: '/accumulation/site/siteEdit',
      name: '商户详情'
    },
    '/accumulation/site/siteAdd': {
      component: dynamicWrapper(app, ['site'], () => import('../routes/Profile/SiteAdd')),
      // authority: '/accumulation/site/siteAdd',
      name: '创建商户'
    },
    '/accumulation/site/gift/list': {
      component: dynamicWrapper(app, ['gift'], () => import('../routes/List/Gift')),
      // authority: '/accumulation/site/gift/list',
      name: '礼品管理'
    },
    '/accumulation/site/giftAdd': {
      component: dynamicWrapper(app, ['gift'], () => import('../routes/Profile/GiftAdd')),
      // authority: '/accumulation/site/giftAdd',
      name: '创建礼品'
    },
    '/accumulation/site/gift/giftEdit': {
      component: dynamicWrapper(app, ['gift'], () => import('../routes/Profile/Gift')),
      // authority: '/accumulation/site/gift/giftEdit',
      name: '礼品详情'
    },
    '/accumulation/site/gift/sale': {
      component: dynamicWrapper(app, ['sale'], () => import('../routes/List/Sale')),
      // authority: '/accumulation/site/gift/sale',
      name: '礼品销售'
    },
    '/superLike/list': {
      component: dynamicWrapper(app, ['superLike'], () => import('../routes/List/SuperLike')),
      // authority: '/accumulation/site/gift/giftEdit',
      name: '抱礼管理',
    },
    '/superLike/superLikeAdd': {
      component: dynamicWrapper(app, ['superLike'], () => import('../routes/Profile/SuperLikeAdd')),
      name: '创建抱礼'
    },
    '/superLike/superLikeEdit': {
      component: dynamicWrapper(app, ['superLike'], () => import('../routes/Profile/SuperLike')),
      name: '修改抱礼'
    },
    '/pay': {
      component: dynamicWrapper(app, ['pay'], () => import('../routes/List/Pay')),
      authority: '/pay',
      name: '平台流水管理'
    },
    '/authority/administrator/list': {
      component: dynamicWrapper(app, ['administrator'], () => import('../routes/List/Administrator')),
      // authority: '/authority/administrator/list',
      name: '管理员列表'
    },
    '/vip/rechargeCode/list': {
      component: dynamicWrapper(app, ['vip'], () => import('../routes/List/Vip')),
      authority: '/vip/rechargeCode/list',
      name: 'VIP充值码管理'
    },
    // '/vipRecharge/vipRecharge/list': {
    //   component: dynamicWrapper(app, ['vip'], () => import('../routes/List/VipRecharge')),
    //   authority: '/vipRecharge/vipRecharge/list',
    //   name: 'VIP时长列表',
    // },
    '/vip/vipRecharge/list': {
      component: dynamicWrapper(app, ['vip'], () => import('../routes/List/VipRecharge')),
      authority: '/vip/vipRecharge/list',
      name: 'VIP时长列表'
    },
    '/vip/vipRecharge/detail': {
      component: dynamicWrapper(app, ['vip'], () => import('../routes/Profile/VipRecharge')),
      // authority: '/vip/vipRecharge/detail',
      name: 'VIP时长详情'
    },
    '/svip/list': {
      component: dynamicWrapper(app, ['svip'], () => import('../routes/List/Svip')),
      authority: '/svip/list',
      name: '钻石伙伴管理'
    },
    '/svip/svipIntegral': {
      component: dynamicWrapper(app, ['svip'], () => import('../routes/Profile/SvipIntegral')),
      // authority: '/svip/svipIntegral',
      name: '钻石伙伴积分详情'
    },
    '/svip/integrAlapply': {
      component: dynamicWrapper(app, ['svip'], () => import('../routes/List/IntegralApply')),
      authority: '/svip/integrAlapply',
      name: '积分兑现'
    },
    '/svip/diamond': {
      component: dynamicWrapper(app, ['diamond'], () => import('../routes/List/Diamond')),
      authority: '/svip/diamond',
      name: '钻石伙伴激活码管理'
    },
    '/authority/administrator/administratorEdit': {
      component: dynamicWrapper(app, ['administrator'], () => import('../routes/Profile/Administrator')),
      // authority: '/authority/administrator/administratorEdit',
      name: '管理员详情'
    },
    '/authority/administrator/administratorAdd': {
      component: dynamicWrapper(app, ['administrator'], () => import('../routes/Profile/AdministratorAdd')),
      // authority: '/authority/administrator/administratorAdd',
      name: '创建管理员'
    },
    '/authority/role/list': {
      component: dynamicWrapper(app, ['role'], () => import('../routes/List/Role')),
      // authority: '/authority/role/list',
      name: '角色列表'
    },
    '/authority/role/roleEdit': {
      component: dynamicWrapper(app, ['role'], () => import('../routes/Profile/Role')),
      // authority: '/authority/role/roleEdit',
      name: '角色详情'
    },
    '/authority/role/roleAdd': {
      component: dynamicWrapper(app, ['role'], () => import('../routes/Profile/RoleAdd')),
      // authority: '/authority/role/roleAdd',
      name: '创建角色'
    },
    '/authority/permission': {
      component: dynamicWrapper(app, ['permission'], () => import('../routes/List/Permission')),
      authority: '/authority/permission',
      name: '资源管理'
    },
    '/authority/authority/list': {
      component: dynamicWrapper(app, ['authority'], () => import('../routes/List/Authority')),
      authority: '/authority/authority/list',
      name: '权限管理'
    },
    '/authority/authority/authorityEdit': {
      component: dynamicWrapper(app, ['authority'], () => import('../routes/Profile/Authority')),
      // authority: '/authority/authority/authorityEdit',
      name: '权限详情'
    },
    '/authority/authority/authorityAdd': {
      component: dynamicWrapper(app, ['authority'], () => import('../routes/Profile/AuthorityAdd')),
      // authority: '/authority/authority/authorityAdd',
      name: '创建权限'
    },
    '/setting/log': {
      component: dynamicWrapper(app, ['log'], () => import('../routes/List/Log')),
      authority: '/setting/log',
      name: '系统日志'
    },
    '/setting/config': {
      component: dynamicWrapper(app, ['config'], () => import('../routes/List/SystemConfig')),
      authority: '/setting/config',
      name: '全局配置'
    },
    '/contact': {
      component: dynamicWrapper(app, ['contact'], () => import('../routes/List/Contact')),
      authority: '/contact',
      name: '联系我们'
    },
    '/version': {
      component: dynamicWrapper(app, ['version'], () => import('../routes/List/Version')),
      authority: '/version',
      name: '版本管理'
    },
    '/report': {
      component: dynamicWrapper(app, ['report'], () => import('../routes/List/Report')),
      authority: '/report',
      name: '举报管理'
    },
    '/result/success': {
      component: dynamicWrapper(app, [], () => import('../routes/Result/Success')),
    },
    '/result/fail': {
      component: dynamicWrapper(app, [], () => import('../routes/Result/Error')),
    },
    '/exception/403': {
      component: dynamicWrapper(app, [], () => import('../routes/Exception/403')),
    },
    '/exception/404': {
      component: dynamicWrapper(app, [], () => import('../routes/Exception/404')),
    },
    '/exception/500': {
      component: dynamicWrapper(app, [], () => import('../routes/Exception/500')),
    },
    '/exception/trigger': {
      component: dynamicWrapper(app, ['error'], () =>
        import('../routes/Exception/triggerException')
      ),
    },
    '/user': {
      component: dynamicWrapper(app, [], () => import('../layouts/UserLayout')),
    },
    '/user/login': {
      component: dynamicWrapper(app, ['login'], () => import('../routes/User/Login')),
    },
    '/userProfile:id': {
      component: dynamicWrapper(app, ['personal'], () => import('../routes/User/Personal')),
      name: '个人中心',
    },
    '/editPassword:id': {
      component: dynamicWrapper(app, ['personal', 'user'], () => import('../routes/User/EditPassword')),
      name: '修改密码',
    },
  };

  function getActionPath(arr, path) {
    let arrId = [];
    arr.map((item, index) => {
      arrId.push(item.url);
    });
    if (arrId.indexOf(path) > -1) {
      return arr[arrId.indexOf(path)]['path'].toString();
    }
  }

  // Get name from ./menu.js or just set it in the router data.
  const menuData = getFlatMenuData(getMenuData());
  // Route configuration data
  // eg. {name,authority ...routerConfig }
  const routerData = {};
  // The route matches the menu
  Object.keys(routerConfig).forEach(path => {
    // Regular match item name
    // eg.  router /user/:id === /user/chen
    const pathRegexp = pathToRegexp(path);
    const menuKey = Object.keys(menuData).find(key => pathRegexp.test(`${key}`));
    let menuItem = {};
    if (menuKey) {
      menuItem = menuData[menuKey];
    }
    let router = routerConfig[path];
    router = {
      ...router,
      name: router.name || menuItem.name,
      authority: router.authority,
      hideInBreadcrumb: router.hideInBreadcrumb || menuItem.hideInBreadcrumb,
    };
    routerData[path] = router;
  });
  return routerData;
};
