import {Table, Input, Button, Popconfirm, Form} from 'antd';
import styles from './index.less';
const {TextArea} = Input;
const FormItem = Form.Item;
const EditableContext = React.createContext();

const EditableRow = ({form, index, ...props}) => (
  <EditableContext.Provider value={form}>
    <tr {...props} />
  </EditableContext.Provider>
);

const EditableFormRow = Form.create()(EditableRow);
@Form.create()
export default class EditableCell extends React.Component {
  state = {
    editing: false,
  }

  componentDidMount() {
    if (this.props.editable) {
      document.addEventListener('click', this.handleClickOutside, true);
    }
  }

  componentWillUnmount() {
    if (this.props.editable) {
      document.removeEventListener('click', this.handleClickOutside, true);
    }
  }

  toggleEdit = () => {
    const editing = !this.state.editing;
    this.setState({editing}, () => {
      if (editing) {
        this.input.focus();
      }
    });
  }

  handleClickOutside = (e) => {
    const {editing} = this.state;
    if (editing && this.cell !== e.target && !this.cell.contains(e.target)) {
      this.save();
    }
  }

  save = () => {
    const {record, handleSave} = this.props;
    this.props.form.validateFields((error, values) => {
      if (error) {
        return;
      }
      this.toggleEdit();
      handleSave({...record, ...values});
    });
  }

  render() {
    const {editing} = this.state;
    const {getFieldDecorator} = this.props.form;
    const {
      editable,
      dataIndex,
      title,
      record,
      index,
      handleSave,
      ...restProps
    } = this.props;
    return (
      <td ref={node => (this.cell = node)} {...restProps}>
        {editable ? (
          <EditableContext.Consumer>
            {(form) => {
              this.form = form;
              // console.log(record[dataIndex]);
              return (
                editing ? (
                  <FormItem style={{margin: 0}}>
                    {getFieldDecorator(dataIndex, {
                      rules: [{
                        required: true,
                        message: `请输入修改参数`,
                      }],
                      initialValue: record[dataIndex],
                    })
                    (
                      <TextArea ref={node => (this.input = node)} onPressEnter={this.save} autosize={{minRows: 4}}/>
                      // <Input
                      //   ref={node => (this.input = node)}
                      //   onPressEnter={this.save}
                      // />
                    )
                    }
                  </FormItem>
                ) : (
                  <div
                    className={styles["editable-cell-value-wrap"]}
                    style={{paddingRight: 24}}
                    onClick={this.toggleEdit}
                  >
                    {restProps.children}
                  </div>
                )
              );
            }}
          </EditableContext.Consumer>
        ) : restProps.children}
      </td>
    );
  }
}
