import {
  queryAccumulationList,
  queryAccumulation,
  queryAccumulationEdit,
  deleteAccumulation,
  lockAccumulation,
  queryAccumulationAdd,
  queryAccumulationSite,
  queryCity,
  queryWhisperSwitch,
  queryAdoreSwitch
} from '../services/api';
import {message} from 'antd';
import {routerRedux} from 'dva/router';

export default {
  namespace: 'accumulation',

  state: {
    list: [],
    accumulationMsg: null,
    pageSize: 30,
    page: 1,
    total: 0,
    point: '',
    siteTotal: 0,
    sitePageSize: 30,
    siteCurrent: 1,
    siteList: [],
    city: [],
    type: '1',
    // status: true
  },

  effects: {
    * fetch({payload}, {call, put}) {
      const response = yield call(queryAccumulationList, payload);
      if (response && response.c === 200) {
        const {data, pageNo, recordsTotal, pageSize} = response.d;
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(data) ? data : [],
            total: recordsTotal,
            page: pageNo,
            pageSize,
          },
        });
      } else {
        message.error("加载聚点列表失败，请刷新重新加载");
      }
    },
    * add({payload}, {put}) {
      yield put(
        routerRedux.push(`/accumulation/accumulationAdd`));
    },
    * addSubmit({payload}, {call, put}) {
      const response = yield call(queryAccumulationAdd, payload);
      if (response && response.c === 200) {
        message.success('创建聚点成功');
        yield put(
          routerRedux.push(`/accumulation/list`));
      } else {
        message.error('创建聚点失败，请重新提交');
      }
    },
    * redirectDetail({payload}, {call, put}) {
      yield put(
        routerRedux.push(`/accumulation/accumulationEdit?id=${payload.id}`));
    },
    * redirectSite({payload}, {call, put}) {
      yield put(
        routerRedux.push(`/accumulation/site/list`));
    },
    * delete({payload}, {call, put}) {
      const response = yield call(deleteAccumulation, {
        id: payload.id,
      });
      if (response && response.c === 200) {
        message.success('操作成功');
      } else {
        message.error('操作失败，请重新提交');
      }
    },
    * lock({payload}, {call, put}) {
      const response = yield call(lockAccumulation, {
        id: payload.id,
      });
      if (response && response.c === 200) {
        message.success('操作成功');
        if (payload.pageNo && payload.pageSize) {
          yield put({
            type: 'fetch',
            payload: {
              page: payload.page,
              pageSize: payload.pageSize,
            },
          });
        } else {
          const response = yield call(queryAccumulation, {id: payload.id});
          if (response && response.c === 200) {
            const res = response.d;
            let city = [];
            let cityList = [];
            if (res.provinceResponse) {
              city.push(res.provinceResponse.id);
              city.push(res.cityResponse.id);
              city.push(res.countyResponse.id);
              let cityListItem = {
                value: 0,
                label: 1,
                children: [
                  {
                    value: 0,
                    label: 0,
                    children: [{
                      value: 0,
                      label: 0,
                    }],
                  },
                ],
              };
              cityListItem.value = res.provinceResponse.id;
              cityListItem.label = res.provinceResponse.name;
              cityListItem.children[0].value = res.cityResponse.id;
              cityListItem.children[0].label = res.cityResponse.name;
              cityListItem.children[0].children[0].value = res.countyResponse.id;
              cityListItem.children[0].children[0].label = res.countyResponse.name;
              cityList.push(cityListItem);
            }
            let coordinates = [];
            res.coordinates.map((item) => {
              coordinates.push({
                lng: item.lng,
                lat: item.lat,
              });
            });
            let quitCoordinates = [];
            res.quitCoordinates.map((item) => {
              quitCoordinates.push({
                lng: item.lng,
                lat: item.lat,
              });
            });
            yield put({
              type: 'saveDetail',
              payload: {
                ...res,
                city,
                cityList,
                quitCoordinates,
                coordinates,
              },
            });
          } else {
            message.error('数据加载出错，请刷新重新加载')
          }
        }
      } else {
        message.error('操作失败，请重新提交');
      }
    },
    * whisperSwitch({payload}, {call, put}) {
      console.log({payload});
      const response = yield call(queryWhisperSwitch, payload);
      if (response && response.c === 200) {
        message.success('操作成功');
        const res = yield call(queryAccumulationList, payload);
        if (res && res.c === 200) {
          const {data, pageNo, recordsTotal, pageSize} = res.d;
          yield put({
            type: 'queryList',
            payload: {
              list: Array.isArray(data) ? data : [],
              total: recordsTotal,
              page: pageNo,
              pageSize,
            }
          });
        } else {
          message.error("加载聚点列表失败，请刷新重新加载");
        }
      }
    },
    // queryAdoreSwitch
    * adoreSwitch({payload}, {call, put}) {
      console.log({payload});
      const response = yield call(queryAdoreSwitch, payload);
      if (response && response.c === 200) {
        message.success('操作成功');
        const res = yield call(queryAccumulationList, payload);
        if (res && res.c === 200) {
          const {data, pageNo, recordsTotal, pageSize} = res.d;
          yield put({
            type: 'queryList',
            payload: {
              list: Array.isArray(data) ? data : [],
              total: recordsTotal,
              page: pageNo,
              pageSize,
            }
          });
        } else {
          message.error("加载聚点列表失败，请刷新重新加载");
        }
      }
    },
    // * detailLock({payload}, {call, put}) {
    //   const res = yield call(lockAccumulation, {
    //     id: payload.id,
    //   });
    //   if (response && response.c === 200) {
    //     message.success('操作成功');
    //     if (payload.pageNo && payload.pageSize) {
    //       yield put({
    //         type: 'fetch',
    //         payload: {
    //           page: payload.page,
    //           pageSize: payload.pageSize,
    //         },
    //       });
    //     }
    //   } else {
    //     message.error('操作失败，请重新提交');
    //   }
    // },
    * fetchDetail({payload}, {call, put}) {
      const response = yield call(queryAccumulation, payload);
      if (response && response.c === 200) {
        const res = response.d;
        let city = [];
        let cityList = [];
        if (res.provinceResponse) {
          city.push(res.provinceResponse.id);
          city.push(res.cityResponse.id);
          city.push(res.countyResponse.id);
          let cityListItem = {
            value: 0,
            label: 1,
            children: [
              {
                value: 0,
                label: 0,
                children: [{
                  value: 0,
                  label: 0,
                }],
              },
            ],
          };
          cityListItem.value = res.provinceResponse.id;
          cityListItem.label = res.provinceResponse.name;
          cityListItem.children[0].value = res.cityResponse.id;
          cityListItem.children[0].label = res.cityResponse.name;
          cityListItem.children[0].children[0].value = res.countyResponse.id;
          cityListItem.children[0].children[0].label = res.countyResponse.name;
          cityList.push(cityListItem);
        }
        let coordinates = [];
        res.coordinates.map((item) => {
          coordinates.push({
            lng: item.lng,
            lat: item.lat,
          });
        });
        let quitCoordinates = [];
        res.quitCoordinates.map((item) => {
          quitCoordinates.push({
            lng: item.lng,
            lat: item.lat,
          });
        });
        yield put({
          type: 'saveDetail',
          payload: {
            ...res,
            city,
            cityList,
            quitCoordinates,
            coordinates,
          },
        });
      } else {
        message.error('数据加载出错，请刷新重新加载')
      }
    },
    * fetchSite({payload}, {call, put}) {
      const response = yield call(queryAccumulationSite, payload);
      if (response && response.c === 200) {
        const {data, pageNo, pageSize, recordsTotal} = response.d;
        yield put({
          type: 'querySiteList',
          payload: {
            list: Array.isArray(data) ? data : [],
            page: pageNo,
            pageSize,
            total: recordsTotal,
          },
        });
      } else {
        message.error('数据加载出错，请刷新重新加载')
      }
    },
    * editSubmit({payload}, {call, put}) {
      const res1 = yield call(queryAccumulationAdd, payload);
      if (res1 && res1.c === 200) {
        message.success('聚点信息修改成功');
        const response = yield call(queryAccumulation, {id: payload.id});
        if (response && response.c === 200) {
          const res = response.d;
          let city = [];
          let cityList = [];
          if (res.provinceResponse) {
            city.push(res.provinceResponse.id);
            city.push(res.cityResponse.id);
            city.push(res.countyResponse.id);
            let cityListItem = {
              value: 0,
              label: 1,
              children: [
                {
                  value: 0,
                  label: 0,
                  children: [{
                    value: 0,
                    label: 0,
                  }],
                },
              ],
            };
            cityListItem.value = res.provinceResponse.id;
            cityListItem.label = res.provinceResponse.name;
            cityListItem.children[0].value = res.cityResponse.id;
            cityListItem.children[0].label = res.cityResponse.name;
            cityListItem.children[0].children[0].value = res.countyResponse.id;
            cityListItem.children[0].children[0].label = res.countyResponse.name;
            cityList.push(cityListItem);
          }
          let coordinates = [];
          res.coordinates.map((item) => {
            coordinates.push({
              lng: item.lng,
              lat: item.lat,
            });
          });
          let quitCoordinates = [];
          res.quitCoordinates.map((item) => {
            quitCoordinates.push({
              lng: item.lng,
              lat: item.lat,
            });
          });
          yield put({
            type: 'saveDetail',
            payload: {
              ...res,
              city,
              cityList,
              quitCoordinates,
              coordinates,
            },
          });
          console.log('res');
          console.log(res);
        }

        // yield put({
        //   type: 'saveDetail',
        //   payload,
        // });
      } else {
        message.error('聚点信息修改失败，请重新提交');
      }
    },
    * fetchCity({payload}, {select, call, put}) {
      const response = yield call(queryCity, {
        id: payload.id,
      });
      if (response && response.c === 200) {
        let list = [];
        response.d.map((item) => {
          list.push({
            value: item.id,
            label: item.name,
          })
        });
        if (payload && payload.targetOption !== null) {
          const targetOption = payload.targetOption;
          let city = yield select(state => state.accumulation.city);
          city = city ? city : [];
          city.map((item, index) => {
            if (item.value === targetOption.value) {
              city[index]['children'] = list;
            } else {
              if (city[index]['children']) {
                let c = city[index]['children'];
                c.map((item1, index1) => {
                  if (item1.value === targetOption.value) {
                    city[index]['children'][index1]['children'] = list;
                  }
                });
              }
            }
          });
          yield put({
            type: 'saveCity',
            payload: city,
          });
        } else {
          yield put({
            type: 'saveCity',
            payload: list,
          });
        }

      } else {
        message.error('数据加载出错，请刷新重新加载')
      }
    },
  },

  reducers: {
    queryList(state, action) {
      const {list, total, page, pageSize} = action.payload;
      return {
        ...state,
        list,
        total,
        page,
        pageSize,
      };
    },
    querySiteList(state, action) {
      const {list, pageSize, page, total} = action.payload;
      return {
        ...state,
        siteList: list,
        pageSize,
        page,
        siteTotal: total,
      };
    },
    savePoint(state, action) {
      return {
        ...state,
        point: action.payload,
      };
    },
    saveDetail(state, action) {
      // if (action.payload.status){
      //   state.status=action.payload.status;
      // }
      //
      // if (action.payload.status == undefined) {
      //   action.payload.status=state.status;
      // }
      console.log('saveDetail');
      console.log(action);
      return {
        ...state,
        accumulationMsg: action.payload,
      };
    },
    saveCity(state, action) {
      return {
        ...state,
        city: action.payload,
      };
    },
  },
};
