import {
  queryAdministratorList,
  queryAdministratorSubmit,
  queryAdministrator,
  deleteAdministrator,
  queryAdministratorEditSubmit,
  resetPassword,
} from '../services/user';
import { queryRoleAll } from '../services/api';
import { message, } from 'antd';
import { routerRedux } from 'dva/router';
export default {
  namespace: 'administrator',

  state: {
    list: [],
    total: 0,
    pageSize: 30,
    page: 1,
    user: null,
    roleList: [],
  },

  effects: {
    *fetch({ payload }, { call, put }) {
      const response = yield call(queryAdministratorList, payload);
      if(response && response.c === 200){
        const { data, recordsTotal, pageSize, pageNo } = response.d;
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(data) ? data : [],
            total: recordsTotal,
            pageSize,
            page: pageNo,
          },
        });
      }else{
        message.error("加载管理员信息失败，请刷新重新加载");
      }
    },
    *fetchAll({ payload }, { call, put }) {
      const response = yield call(queryRoleAll);
      if(response && response.c === 200){
        let list = [];
        response.d.map((item) => {
          list.push({
            label: item.name,
            value: item.id,
          });
        });
        yield put({
          type: 'queryAllList',
          payload: list,
        });
      }else{
        message.error("加载角色信息失败，请刷新重新加载");
      }
    },
    *edit({ payload }, { call, put }) {
      yield put(routerRedux.push(`/authority/administrator/administratorEdit?id=${payload.id}`));
    },
    *add({ payload }, { call, put }) {
      yield put(routerRedux.push('/authority/administrator/administratorAdd'));
    },
    *fetchProfile({ payload }, { call, put }) {
      const response = yield call(queryAdministrator, payload);
      if(response && response.c === 200){
        let list = [];
        response.d.ids.map((item) => {
          list.push(item.id);
        });
        yield put({
          type: 'queryAdministrator',
          payload: {
            ...response.d,
            roleList: list,
          },
        });
      }else {
        message.error('加载管理员信息失败，请刷新重新加载');
      }
    },
    *delete({ payload }, { call, put }) {
      const { page, pageSize, id } = payload;
      const response = yield call(deleteAdministrator, {id,});
      if (response && response.c === 200) {
        message.success('操作成功');
        yield put({
          type: 'fetch',
          payload: {
            page,
            pageSize,
          }
        });
      }else {
        message.error('操作失败，请重新再试');
      }
    },
    *fetchChange({ payload }, { call, put }) {
      const response = yield call(queryAdministratorList, payload);
      yield put({
        type: 'queryList',
        payload: {
          list: Array.isArray(response.d.list) ? response.d.list : [],
          total: response.d.total,
          pageSize: payload.pageSize,
        },
      });
    },
    *editSubmit({ payload }, { call }) {
        let response = yield call(queryAdministratorSubmit, payload);
      if(response && response.c === 200) {
        message.success('提交成功');
      }else {
        message.error('提交失败，请刷新重试');
      }
    },
    *submit({ payload }, { call }) {
      let response = yield call(queryAdministratorEditSubmit, payload);
      if(response && response.c === 200) {
        message.success('修改成功');
      }else {
        message.error('修改失败，请刷新重试');
      }
    },
    *resetPassword({ payload }, { call, put }) {
      console.log(payload)
      const response = yield call(resetPassword, payload);
      if(response && response.c === 200) {
        message.success('操作成功');
      }else {
        message.error('操作失败，请刷新重试');
      }
    },
  },

  reducers: {
    queryList(state, action) {
      return {
        ...state,
        list: action.payload.list,
        pageSize: action.payload.pageSize,
        total: action.payload.total,
        page: action.payload.page,
      };
    },
    queryAllList(state, action) {
      return {
        ...state,
        roleList: action.payload,
      };
    },
    queryAdministrator(state, action) {
      return {
        ...state,
        user: action.payload,
      };
    },
  },
};
