import {
  queryPermissionAll,
  queryAuthorityList,
  queryAuthoritySubmit,
  queryAuthority,
  deleteAuthority,
} from '../services/api';
import {message,} from 'antd';
import {treeSelect,} from '../utils/utils';
import {routerRedux} from 'dva/router';

export default {
  namespace: 'authority',

  state: {
    list: [],
    total: 0,
    pageSize: 30,
    page: 1,
    authority: null,
    permissionList: [],
    pageList: [],
    funcList: [],
  },

  effects: {
    * fetch({payload}, {call, put}) {
      const response = yield call(queryAuthorityList, payload);
      if (response && response.c === 200) {
        const {data, page, pageSize, recordsTotal} = response.d;
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(data) ? data : [],
            pageSize: pageSize,
            total: recordsTotal,
            page: page,
          },
        });
      } else {
        message.error('数据加载出错，请刷新再试');
      }
    },
    * fetchPageAll({payload}, {call, put}) {
      const response = yield call(queryPermissionAll, payload);
      if (response && response.c === 200) {
        const list = treeSelect(response.d);
        yield put({
          type: 'queryAllPageList',
          payload: list,
        });
      } else {
        message.error('数据加载出错，请刷新再试');
      }
    },
    * fetchFuncAll({payload}, {call, put}) {
      const response = yield call(queryPermissionAll, payload);
      if (response && response.c === 200) {
        let list = [];
        response.d.map((item) => {
          list.push({
            value: item.id,
            label: item.name,
          });
        });
        yield put({
          type: 'queryAllFuncList',
          payload: list,
        });
      } else {
        message.error('数据加载出错，请刷新再试');
      }
    },
    * delete({payload}, {call, put}) {
      const {id, page, pageSize} = payload;
      const response = yield call(deleteAuthority, {id,});
      if (response && response.c === 200) {
        message.success('删除成功');
        yield put({
          type: 'fetch',
          payload: {
            page,
            pageSize,
          },
        });
      } else {
        message.error('删除失败，请重新再试');
      }
    },
    * edit({payload}, {call, put}) {
      yield put(routerRedux.push(`/authority/authority/authorityEdit?id=${payload.id}`));
    },
    * add({payload}, {call, put}) {
      yield put(routerRedux.push(`/authority/authority/authorityAdd`));
    },
    * fetchProfile({payload}, {call, put}) {
      const response = yield call(queryAuthority, payload);
      if (response && response.c === 200) {
        let pageList = [];
        let funcList = [];
        response.d.sysPermissions.map((item) => {
          funcList.push(item.id);
        });

        response.d.sysPermissionsPage.map((item) => {
          pageList.push(item.id.toString());
        });
        yield put({
          type: 'queryAuthority',
          payload: {
            ...response.d,
            sysPermissionsPage: pageList,
            sysPermissions: funcList,
          },
        });
      } else {
        message.error("加载数据失败，请刷新重新加载");
      }
    },
    * addSubmit({payload}, {call, put}) {
      const response = yield call(queryAuthoritySubmit, payload);
      if (response && response.c === 200) {
        message.success('权限提交成功');
      } else {
        message.error('权限提交失败，请重新再试');
      }
    },
  },
  reducers: {
    queryAllFuncList(state, action) {
      return {
        ...state,
        funcList: action.payload,
      };
    },
    queryAllPageList(state, action) {
      return {
        ...state,
        pageList: action.payload,
      };
    },
    queryList(state, action) {
      return {
        ...state,
        list: action.payload.list,
        pageSize: action.payload.pageSize,
        total: action.payload.total,
      };
    },
    queryAuthority(state, action) {
      return {
        ...state,
        authority: action.payload,
      };
    },
  },
};
