import {
  queryUser,
  passUser,
  deletePhoto,
  querySuspend,
  fakeComsumerSubmit,
  queryUserPhotoList,
  queryComsumerList,
  queryPayList,
  passPhotoList,
  queryAlbumPass,
  queryTagsList,
  querySysVocationIdList, queryPhotoRefuse,
  queryConsumerData,
} from '../services/api';
import {message,} from 'antd';
import {routerRedux} from 'dva/router';

export default {
  namespace: 'comsumer',

  state: {
    list: [],
    user: null,
    userData: null,
    comsumer: [],
    photoList: [],
    pageSize: 30,
    page: 1,
    total: 0,
    payList: [],
    payPageSize: 30,
    payPage: 1,
    payTotal: 0,
    passing: false,
    suspending: false,
  },

  effects: {
    * fetch({payload}, {call, put}) {
      const response = yield call(queryComsumerList, payload);
      if (response && response.c === 200) {
        const {data, recordsTotal, pageSize, pageNo} = response.d;
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(data) ? data : [],
            total: recordsTotal,
            pageSize,
            page: pageNo,
          },
        });
      } else {
        message.error("数据加载失败，请刷新重新加载")
      }
    },
    * redirectProfile({payload}, {put}) {
      console.log('jsFunc');
      yield put(
        routerRedux.push(`/comsumerProfile?id=${payload.id}`));
    },
    * fetchProfile({payload}, {call, put}) {
      const response = yield call(queryUser, payload);
      if (response && response.c === 200) {
        // console.log(response.d.latitude);
        const user = response.d;
        let tags = [];
        user.tags.map((item) => {
          tags.push(item.id);
        });
        yield put({
          type: 'queryUser',
          payload: {
            ...user,
            sex: user.sex ? '男' : '女',
            tags,
          },
        });
      } else {
        message.error("数据加载失败，请刷新重新加载")
      }
    },
    * fetchData({payload}, {call, put}) {
      // console.log({payload});
      const response = yield call(queryConsumerData, payload);
      // console.log(response);
      if (response && response.c === 200) {
        const userData = response.d;
        // let tags = [];
        // userData.tags.map((item) => {
        //   tags.push(item.id);
        // });
        // console.log(userData);
        yield put({
          type: 'queryUserData',
          payload: {
            ...userData
            // ...user,
            // sex: user.sex ? '男' : '女',
            // tags,
          },
        });
      } else {
        message.error("数据加载失败，请刷新重新加载")
      }
    },
    * pass({payload}, {call, put}) {
      const response = yield call(passUser, payload);
      if (response && response.c === 200) {
        message.success('操作成功');
        yield put({
          type: 'saveList',
          payload: payload,
        });
      } else {
        message.error('操作失败，请返回重新再试');
      }
    },
    * delete({payload}, {call, put}) {
      // console.log('delete');
      const response = yield call(deletePhoto, {
        id: payload.id,
      });
      if (response && response.c === 200) {
        message.success('删除成功');
        const responseList = yield call(queryUserPhotoList, payload);
        if (responseList && responseList.c === 200) {
          yield put({
            type: 'queryUserPhotoList',
            payload: {
              list: Array.isArray(responseList.d) ? responseList.d : [],
            },
          });
        } else {
          message.error('获取用户相册失败，请刷新重新再试');
        }
      } else {
        message.error('删除失败，请重新再试');
      }
    },
    * suspend({payload}, {call, put, select}) {
      const response = yield call(querySuspend, payload);
      if (response && response.c === 200) {
        message.success('操作成功');
        let user = yield select(state => state.comsumer.user);
        yield put({
          type: 'queryUser',
          payload: {
            ...user,
            lock: !user.lock,
          },
        });
      } else {
        message.error('操作失败，请重新再试');
      }
    },
    * submit({payload}, {call, put}) {
      const response = yield call(fakeComsumerSubmit, payload);
      if (response && response.c === 200) {
        message.success("修改成功");
      } else {
        message.error("修改失败，请重新再试");
      }
    },
    * fetchPhotoList({payload}, {call, put}) {
      // console.log('fetchPhotoList');
      // console.log({payload});
      const response = yield call(queryUserPhotoList, payload);
      if (response && response.c === 200) {
        yield put({
          type: 'queryUserPhotoList',
          payload: {
            photoList: Array.isArray(response.d) ? response.d : [],
          },
        });
      } else {
        message.error('相册加载出错，请刷新再试');
      }
    },
    * fetchPayList({payload}, {call, put}) {
      const response = yield call(queryPayList, payload);
      if (response && response.c === 200) {
        const {data, recordsTotal, pageSize, pageNo} = response.d;
        yield put({
          type: 'queryPayList',
          payload: {
            list: Array.isArray(data) ? data : [],
            pageSize,
            page: pageNo,
            total: recordsTotal,
          },
        });
      } else {
        message.error('相册加载出错，请刷新再试');
      }
    },
    * fetchTags({payload}, {call, put}) {
      const response = yield call(queryTagsList, payload);
      if (response && response.c === 200) {
        let list = response.d;
        let res = [];
        if (Array.isArray(list)) {
          list.map((item) => {
            res.push({
              key: item.id,
              value: item.name,
            });
          });
        }
        ;
        yield put({
          type: 'queryTagsList',
          payload: res,
        });
      } else {
        message.error('系统标签加载出错，请刷新重新加载');
      }
    },
    * fetchSysVocationId({payload}, {call, put}) {
      const response = yield call(querySysVocationIdList, payload);
      if (response && response.c === 200) {
        let list = response.d.data;
        let res = [];
        if (Array.isArray(list)) {
          list.map((item) => {
            res.push({
              key: item.id,
              value: item.name,
            });
          });
        }
        ;
        yield put({
          type: 'querySysVocationIdList',
          payload: res,
        });
      } else {
        message.error('系统行业加载出错，请刷新重新加载');
      }
    },
    * ablumPass({payload}, {call, put, select}) {
      const response = yield call(queryAlbumPass, {id: payload.id});
      if (response && response.c === 200) {
        message.success('操作成功');
        const res = yield call(queryUserPhotoList, payload.uid);
        if (res && res.c === 200) {
          console.log(res.d);
          yield put({
            type: 'queryUserPhotoList',
            payload: {
              photoList: Array.isArray(res.d) ? res.d : [],
            },
          });
        } else {
          message.error('相册加载出错，请刷新再试');
        }
      } else {
        message.error('操作失败，请重新再试');
      }
    },
    * refuse({payload}, {call, put, select}) {
      // console.log('refuse');
      // console.log({payload});
      // console.log(this.state.user);
      const response = yield call(queryPhotoRefuse, {id: payload.id});
      if (response && response.c === 200) {
        message.success('操作成功');
        const res = yield call(queryUserPhotoList, payload.uid);
        if (res && res.c === 200) {
          console.log(res.d);
          yield put({
            type: 'queryUserPhotoList',
            payload: {
              photoList: Array.isArray(res.d) ? res.d : [],
            },
          });
        } else {
          message.error('相册加载出错，请刷新再试');
        }
      } else {
        message.error('操作失败，请重新再试');
      }
    },
  },

  reducers: {
    queryList(state, action) {
      return {
        ...state,
        list: action.payload.list,
        pageSize: action.payload.pageSize,
        total: action.payload.total,
        page: action.payload.page,
      };
    },
    queryUser(state, action) {
      // console.log('queryUser');
      return {
        ...state,
        user: action.payload,
      };
    },
    queryUserData(state, action) {
      // console.log('queryUserData');
      return {
        ...state,
        userData: action.payload,
      };
    },
    changeVisible(state, action) {
      return {
        ...state,
        visible: action.payload,
      };
    },
    queryPayList(state, action) {
      const {list, pageSize, page, total} = action.payload;
      return {
        ...state,
        payList: list,
        payPageSize: pageSize,
        payPage: page,
        payTotal: total,
      };
    },
    queryUserPhotoList(state, action) {
      // console.log('reducersQUP');
      // console.log(action);
      return {
        ...state,
        photoList: action.payload.photoList,
        photoPageSize: action.payload.pageSize,
        photoTotal: action.payload.total,
      };
    },
    querySysVocationIdList(state, action) {
      return {
        ...state,
        sysVocationIdList: action.payload,
      };
    },
    queryTagsList(state, action) {
      return {
        ...state,
        tagsList: action.payload,
      };
    },
  },
};
