import {queryGlobalList, queryGlobalInfo, updateGlobal} from '../services/api';
import {message} from 'antd';

export default {
  namespace: 'config',

  state: {
    list: [],
    config: null,
    total: 0,
    pageSize: 30,
    page: 1,
  },

  effects: {
    * fetch({payload}, {call, put}) {
      const response = yield call(queryGlobalList, payload);
      if (response && response.c === 200) {
        const {data, recordsTotal, pageSize, pageNo} = response.d;
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(data) ? data : [],
            total: recordsTotal,
            pageSize,
            page: pageNo,
          },
        });
      } else {
        message.error("数据加载失败，请刷新重新加载")
      }
    },
    * fetchProfile({payload}, {call, put}) {
      console.log('fetchProfile');
      console.log(payload);
      const response = yield call(queryGlobalInfo, payload);
      if (response && response.c === 200) {
        yield put({
          type: 'queryDetail',
          payload: response.d,
        });
      } else {
        message.error('数据加载出错，请刷新再试。');
      }
    },
    * update({payload}, {call, put}) {
      const res = yield call(updateGlobal, payload);
      if (res && res.c === 200) {
        message.success('修改成功');
        const response = yield call(queryGlobalList, payload);
        if (response && response.c === 200) {
          const {data, recordsTotal, pageSize, pageNo} = response.d;
          yield put({
            type: 'queryList',
            payload: {
              list: Array.isArray(data) ? data : [],
              total: recordsTotal,
              pageSize,
              page: pageNo,
            },
          });
        } else {
          message.error("数据加载失败，请刷新重新加载")
        }
      } else {
        message.error("数据修改失败，请重试")
      }
    }
  },

  reducers: {
    queryList(state, action) {
      const {list, total, pageSize, page} = action.payload;
      return {
        ...state,
        list,
        total,
        pageSize,
        page,
      };
    },
    queryDetail(state, action) {
      return {
        ...state,
        config: action.payload
      };
    }
  },
};
