import {
  queryDiamondCodeList,
  addDiamondCode,
  deleteDiamondCode,
  diamondRemark,
  addChannel,
} from '../services/api';
import { message, } from 'antd';
export default {
  namespace: 'diamond',

  state: {
    list: [],
    visible: false,
    total: 0,
    pageSize: 30,
    page: 1,
    confirmLoading: false,
  },

  effects: {
    *fetch({ payload }, { call, put }) {
      const response = yield call(queryDiamondCodeList, payload);
      if(response && response.c === 200) {
        const { data, pageNo, pageSize, recordsTotal} = response.d;
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(data) ? data : [],
            pageSize,
            total: recordsTotal,
            page: pageNo,
          },
        });
      }else{
        message.error("数据加载失败，请刷新重新加载");
      }
    },
    *addSubmit({ payload }, { call, put }) {
      console.log({ payload });
      const response = yield call(addDiamondCode, {
        size: payload.size,profit:payload.profit
      });
      if(response && response.c === 200) {
        message.success('钻石卡生成成功');
        yield put({
          type: 'fetch',
          payload: {
            page: payload.page,
            pageSize: payload.pageSize,
          }
        });
      }else{
        message.error('钻石卡生成失败，请重新提交');
      }
    },
    *channelSubmit({ payload }, { call, put }) {
      const response = yield call(addChannel, {
        start: payload.start,
        end: payload.end,
        channel: payload.channel,
        activationInstructions: payload.activationInstructions,
      });
      if(response && response.c === 200) {
        message.success('设置渠道成功');
        yield put({
          type: 'fetch',
          payload: {
            page: payload.page,
            pageSize: payload.pageSize,
          }
        });
      }else{
        message.error(response.m);
      }
    },
    *remarkSubmit({ payload }, { call, put }) {
      const response = yield call(diamondRemark, {
        id: payload.id,
        remark: payload.remark,
      });
      if(response && response.c === 200) {
        message.success('备注成功');
        yield put({
          type: 'fetch',
          payload: {
            page: payload.page,
            pageSize: payload.pageSize,
          }
        });

      }else{
        message.error('备注失败，请重新备注');
      }
    },
    *delete({ payload }, { call, put }) {
      const response = yield call(deleteDiamondCode, {
        id: payload.id,
      });
      if(response && response.c === 200) {
        message.success('该卡片已成功作废');
        yield put({
          type: 'fetch',
          payload: {
            page: payload.page,
            pageSize: payload.pageSize,
          }
        });
      }else{
        message.error('操作失败，请重新提交');
      }
    },
    *redirectDetail({ payload }, { call, put }) {
      yield put(
        routerRedux.push(`/comsumerProfile${payload.id}`));
    },
  },

  reducers: {
    queryList(state, action) {
      let list = action.payload.list;
      list.map((item, index) => {
        if(item.channel){
          let channel = item.channel.split("&");
          list[index].channel1 = channel[0] === 'undefined' ? '' : channel[0];
          list[index].channel2 = channel[1] === 'undefined' ? '' : channel[1];
          list[index].channel3 = channel[2] === 'undefined' ? '' : channel[2];
        }
      });
      const { pageSize, total, page } = action.payload;
      return {
        ...state,
        list: list,
        pageSize,
        total,
        page,
      };
    },
    queryChangeList(state, action) {
      return {
        ...state,
        list: action.payload.list,
        total: action.payload.total,
        pageSize: action.payload.pageSize,
        confirmLoading: false,
      };
    },
  },
};
