import {
  queryGiftList,
  queryGift,
  queryGiftEdit,
  deleteGift,
  queryGiftAdd,
  queryRecoveryGift,
  querySiteList,
  queryAllSiteList,
  queryAccumulationList,
  updateGiftStatus
} from '../services/api';
import {message} from 'antd';
import {routerRedux} from 'dva/router';

export default {
  namespace: 'gift',

  state: {
    list: [],
    gift: null,
    pageSize: 30,
    page: 1,
    total: 0,
    sites: [],
    accumulations: []
  },

  effects: {
    * fetch({payload}, {call, put}) {
      const response = yield call(queryGiftList, payload);
      if (response && response.c === 200) {
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(response.d.data) ? response.d.data : [],
            total: response.d.recordsTotal,
            page: response.d.pageNo,
            pageSize: response.d.pageSize
          }
        });
      } else {
        message.error("数据加载失败，请刷新重新加载");
      }
    },
    * addSubmit({payload}, {call, put}) {
      const response = yield call(queryGiftAdd, payload);
      if (response && response.c === 200) {
        message.success('创建礼品成功');
        yield put(routerRedux.push(`/accumulation/site/gift/list`));
        // routerRedux.push(`/accumulation/site/gift/list?siteId=${payload.id}`);
        //  http://localhost:8000/#/accumulation/site/gift/list?id=32060
        //  http://localhost:8000/#/accumulation/site/gift/list?siteId=32060
      } else {
        message.error('数据提交失败，请重新提交');
      }
    },
    * add({payload}, {call, put}) {
      yield put(
        routerRedux.push(`/accumulation/site/giftAdd`));
    },
    * redirectDetail({payload}, {call, put}) {
      yield put(
        routerRedux.push(`/accumulation/site/gift/giftEdit?id=${payload.id}`));
    },
    * delete({payload}, {call, put}) {
      const response = yield call(deleteGift, {
        ids: payload.ids,
      });
      if (response && response.c === 200) {
        message.success('操作成功');
        yield put({
          type: 'fetch',
          payload: {
            columns: payload.columns,
            page: 1,
            pageSize: 30,
          },
        });
      } else {
        message.error('操作失败，请重新再试');
      }
    },
    * fetchDetail({payload}, {call, put}) {
      const response = yield call(queryGift, payload);
      if (response && response.c === 200) {
        yield put({
          type: 'saveDetail',
          payload: response.d,
        });
      } else {
        message.error('数据加载出错，请刷新重新加载')
      }
    },
    * editSubmit({payload}, {call, put}) {
      const response = yield call(queryGiftEdit, payload);
      if (response && response.c === 200) {
        yield put({
          type: 'fetchDetail',
          payload: {
            id: payload.id,
            siteId: payload.siteId
          }
        });
        message.success('修改成功');
        yield put(routerRedux.push(`/accumulation/site/gift/list`));
      } else {
        message.error('修改失败，请重新提交');
      }
    },
    * fetchSites({payload}, {call, put}) {
      const response = yield call(querySiteList, payload);
      if (response && response.c === 200) {
        let sites = response.d.data;
        yield put({
          type: 'querySites',
          payload: sites
        })
      } else {
        message.error('商户列表加载出错，请刷新重新加载')
      }
    },
    * fetchAccumulations({payload}, {call, put}) {
      const response = yield call(queryAccumulationList, payload);
      if (response && response.c === 200) {
        let accumulations = response.d.data;
        yield put({
          type: 'queryAccumulations',
          payload: accumulations
        })
      } else {
        message.error('商户列表加载出错，请刷新重新加载')
      }
    },
    * updateStatus({payload}, {call, put}) {
      const response = yield call(updateGiftStatus, {id: payload.id});
      if (response && response.c === 200) {
        message.success('操作成功');
        const res = yield call(queryGiftList, {page: payload.page, pageSize: payload.pageSize});
        if (res && res.c === 200) {
          yield put({
            type: 'queryList',
            payload: {
              list: Array.isArray(res.d.data) ? res.d.data : [],
              total: res.d.recordsTotal,
              page: res.d.pageNo,
              pageSize: res.d.pageSize
            }
          });
        } else {
          message.error("数据加载失败，请刷新重新加载");
        }
      } else {
        message.error('操作失败，请重新再试');
      }
    }
  },

  reducers: {
    queryList(state, action) {
      return {
        ...state,
        list: action.payload.list,
        total: action.payload.total,
        page: action.payload.page,
        pageSize: action.payload.pageSize
      };
    },
    saveDetail(state, action) {
      return {
        ...state,
        gift: action.payload,
      };
    },
    querySites(state, action) {
      return {
        ...state,
        sites: action.payload
      }
    },
    queryAccumulations(state, action) {
      return {
        ...state,
        accumulations: action.payload
      }
    }
  }
};
