import {
  queryLabelList,
  queryLabel,
  queryLabelSubmit,
  queryDeleteLabel,
  exportTagsList,
} from '../services/api';
import { message } from 'antd';
export default {
  namespace: 'label',

  state: {
    list: [],
    pageSize: 30,
    page: 1,
    label: null,
    total: 0,
  },

  effects: {
    *fetch({ payload }, { call, put }) {
      const response = yield call(queryLabelList, payload);
      if(response && response.c === 200){
        const { data, pageNo, recordsTotal, pageSize } = response.d;
        let all  = 0;
        if(Array.isArray(payload.columns) && payload.columns.length === 0){
          all = recordsTotal;
          // console.log(all)
          yield put({
            type: 'save',
            payload: {
              list: Array.isArray(data) ? data : [],
              total: recordsTotal,
              page: pageNo,
              pageSize,
              all,
            },
          });
        }else{
          yield put({
            type: 'save',
            payload: {
              list: Array.isArray(data) ? data : [],
              total: recordsTotal,
              page: pageNo,
              pageSize,
              all: recordsTotal,
            },
          });
        }


      }else{
        message.error('数据提交出错，请重新再试。')
      }
    },
    *fetchProfile({ payload }, { call, put }) {
      const response = yield call(queryLabel, payload);
      if(response && response.c === 200){
        yield put({
          type: 'saveDetail',
          payload: response.d,
        });
      }else{
        message.error('数据加载出错，请刷新再试。');
      }
    },
    *delete({ payload }, { call, put }) {
      const { id, page, pageSize } = payload;
      const response = yield call(queryDeleteLabel, {
        id,
      });
      if(response && response.c === 200){
        message.success('标签删除成功！')
        yield put({
          type: 'fetch',
          payload: {
            page,
            pageSize,
          },
        });
      }else{
        message.error('标签删除失败，请重新再试。')
      }
    },
    *addSubmit({ payload }, { call, put }) {
      const { name, page, pageSize } = payload;
      const response = yield call(queryLabelSubmit, {
        name,
      });
      if(response && response.c === 200){
        message.success('标签添加成功。');
        yield put({
          type: 'fetch',
          payload: {
            page,
            pageSize,
          },
        });
      }else{
        if(response && response.m === '标签名已存在'){
          message.error('标签名已存在')
        }else{
          message.error('标签添加失败，请重新再试。')
        }
      }
    },
    *submit({ payload }, { call, put }) {
      const { id, name, page, pageSize } = payload;
      const response = yield call(queryLabelSubmit, {
        id,
        name,
      });
      if(response && response.c === 200){
        message.success('标签修改成功。');
        yield put({
          type: 'fetch',
          payload: {
            page,
            pageSize,
          },
        });
      }else{
        message.error('标签修改出错，请重新再试。')
      }
    },
    *exportTags({ payload }, { call, put }) {
      const response = yield call(exportTagsList, payload);
      if(response && response.c === 200){
        message.success('标签导出成功。');
      }else{
        message.error('标签导出失败，请重新再试。')
      }
    },
  },

  reducers: {
    save(state, action) {
      const { list, page, total, pageSize, all } = action.payload;
      return {
        ...state,
        list,
        total,
        page,
        pageSize,
        all,
      };
    },
    saveDetail(state, action) {
      return {
        ...state,
        label: action.payload,
      };
    },
  },
};
