import {
  queryPermissionList,
  queryPermissionPageSubmit,
  queryPermissionFuncSubmit,
  queryPermission,
  deletePermission,
} from '../services/api';
import {message} from 'antd';

export default {
  namespace: 'permission',

  state: {
    pageList: [],
    pageTotal: 0,
    pagePageSize: 30,
    pageCurrent: 1,
    funcList: [],
    funcTotal: 0,
    funcPageSize: 30,
    funcCurrent: 1,
    pagePermission: null,
    funcPermission: null,
    permission: null,
    type: 'PAGE',
  },

  effects: {
    * fetchPage({payload}, {call, put}) {
      const response = yield call(queryPermissionList, payload);
      if (response && response.c === 200) {
        const {data, recordsTotal, pageNo, pageSize} = response.d;
        data.map(item => {
          // console.log(item);
          if (item.children) {
            item.children.map(child => {
              if (JSON.stringify(child.children) === '[]') {
                child.children = null;
              }
            })
          }
        });
        yield put({
          type: 'queryPageList',
          payload: {
            list: Array.isArray(data) ? data : [],
            total: recordsTotal,
            page: pageNo,
            pageSize,
          },
        });
      } else {
        message.error("加载页面资源失败，请刷新重新加载");
      }
    },
    * fetchFunc({payload}, {call, put}) {
      const response = yield call(queryPermissionList, payload);
      if (response && response.c === 200) {
        const {data, recordsTotal, pageNo, pageSize} = response.d;
        yield put({
          type: 'queryFuncList',
          payload: {
            list: Array.isArray(data) ? data : [],
            total: recordsTotal,
            page: pageNo,
            pageSize,
          },
        });
      } else {
        message.error("加载方法资源失败，请刷新重新加载");
      }
    },
    * delete({payload}, {call, put}) {
      const response = yield call(deletePermission, {id: payload.id});
      if (response && response.c === 200) {
        message.success('删除成功');
        const responseList = yield call(queryPermissionList, {
          ...payload.pagination,
        });
        if (responseList && responseList.c === 200) {
          const res = responseList.d;
          yield put({
            type: payload.pagination.type === 'PAGE' ? 'queryPageList' : 'queryFuncList',
            payload: {
              list: Array.isArray(res.data) ? res.data : [],
              page: res.pageNo,
              pageSize: res.pageSize,
              total: res.recordsTotal,
            },
          });
        } else {
          message.error("加载资源失败，请刷新重新加载");
        }
      } else {
        message.error('删除失败，请重新再试');
      }
    },
    * pageSubmit({payload}, {call, put}) {
      let response = {};
      if (payload.type === 'PAGE') {
        response = yield call(queryPermissionPageSubmit, {
          ...payload.value,
        });
      } else {
        response = yield call(queryPermissionFuncSubmit, {
          ...payload.value,
        });
      }
      if (response && response.c === 200) {
        message.success('提交成功');
        if (payload.type === 'PAGE') {
          yield put({
            type: 'fetchPage',
            payload: {
              ...payload.pagination
            },
          });
        } else {
          yield put({
            type: 'fetchFunc',
            payload: {
              ...payload.pagination
            },
          });
        }
      } else {
        message.error('提交失败，请刷新重试');
      }
    },
    * fetchDetail({payload}, {call, put}) {
      const response = yield call(queryPermission, payload);
      if (response && response.c === 200) {
        yield put({
          type: 'savePermission',
          payload: response.d,
        });
      } else {
        message.error('加载资源失败，请刷新重试');
      }
    },
  },

  reducers: {
    queryPageList(state, action) {
      const {list, total, pageSize, page} = action.payload;
      return {
        ...state,
        pageList: list,
        pageTotal: total,
        pagePageSize: pageSize,
        pageCurrent: page,
      };
    },
    queryFuncList(state, action) {
      const {list, total, pageSize, page} = action.payload;
      return {
        ...state,
        funcList: list,
        funcTotal: total,
        funcPageSize: pageSize,
        funcCurrent: page,
      };
    },
    savePermission(state, action) {
      return {
        ...state,
        permission: action.payload,
      };
    },
  },
};
