import {
  queryRoleList,
  queryRoleSubmit,
  queryRole,
  deleteRole,
  queryAuthorityAll,
} from '../services/api';
import { message, } from 'antd';
import { deleteItemArr, } from '../utils/utils';
import { routerRedux } from 'dva/router';
export default {
  namespace: 'role',

  state: {
    list: [],
    total: 0,
    pageSize: 30,
    page: 1,
    role: null,
    authorityList: [],
  },

  effects: {
    *edit({ payload }, { call, put }) {
      yield put(routerRedux.push(`/authority/role/roleEdit?id=${payload.id}`));
    },
    *fetchRole({ payload }, { call, put }) {
      const response = yield call(queryRole, payload);
      if(response && response.c === 200){
        yield put({
          type: 'queryRole',
          payload: {
            roleFuncAuthority: roleFuncAuthority,
            rolePageAuthority: rolePageAuthority,
          },
        });
      }else {
        message.error('加载角色信息失败，请刷新重新加载');
      }
    },
    *fetch({ payload }, { call, put }) {
      const response = yield call(queryRoleList, payload);
      if(response && response.c === 200) {
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(response.d.data) ? response.d.data : [],
            total: response.d.recordsTotal,
            pageSize: response.d.pageSize,
            page: response.d.page,
          },
        });
      }else {
        message.error('加载角色信息失败，请刷新重新加载');
      }
    },
    *fetchAll({ payload }, { call, put }) {
      const response = yield call(queryAuthorityAll);
      if(response && response.c === 200) {
        let list = [];
        response.d.map((item, index) => {
          list.push({
            value: item.id,
            label: item.name,
          });
        });
        yield put({
          type: 'queryAllList',
          payload: list,
        });
      }else {
        message.error('加载权限信息失败，请刷新重新加载');
      }
    },
    *delete({ payload }, { call, put }) {
      const response = yield call(deleteRole, {id: payload.id});
      if(response && response.c === 200){
        message.success('删除成功');
        yield put({
          type: 'fetch',
          payload: {
            page: payload.page,
            pageSize: payload.pageSize,
          },
        });
      }else {
        message.error('删除失败，请重新再试');
      }
    },
    *add({ payload }, { call, put }) {
      yield put(routerRedux.push('/authority/role/roleAdd'));
    },
    *fetchProfile({ payload }, { call, put }) {
      const response = yield call(queryRole, payload);
      if(response && response.c === 200) {
        let list = [];
        response.d.authorities.map((item) => {
          list.push(item.id);
        });
        yield put({
          type: 'queryRole',
          payload: {
            ...response.d,
            authorityList: list,
          },
        });
      }else {
        message.error('加载角色信息失败，请刷新重新加载');
      }
    },
    *fetchAuthorityList({ payload }, { call, put }) {
      const response = yield call(queryAllAuthorityList, payload);
      if(response && response.c === 200){
        const authorityList = Array.isArray(response.d.data) ? response.d.data : [];
      }else {
        message.error('获取权限失败，请刷新重试');
      }
    },
    *submit({ payload }, { call, put }) {
      const response = yield call(queryRoleSubmit, payload);
      if(response && response.c === 200){
        message.success('提交成功');
      }else {
        message.error('提交失败，请刷新重试');
      }
    },
  },

  reducers: {
    queryList(state, action) {
      return {
        ...state,
        list: action.payload.list,
        pageSize: action.payload.pageSize,
        total: action.payload.total,
        page: action.payload.page,
      };
    },
    queryAllList(state, action) {
      return {
        ...state,
        authorityList: action.payload,
      };
    },
    queryChangeList(state, action) {
      return {
        ...state,
        list: action.payload.list,
        total: action.payload.total,
        pageSize: action.payload.pageSize,
      };
    },
    queryRole(state, action) {
      return {
        ...state,
        role: action.payload,
      };
    },
    queryAuthority(state, action) {
      return {
        ...state,
        authority: action.payload,
      };
    },
  },
};
