import {
  querySiteList,
  querySite,
  querySiteEdit,
  deleteSite,
  querySiteAdd,
  lockSite,
  querySiteSubmit,
  resetSitePassword,
  queryAllGatheringList
} from '../services/api';
import {message} from 'antd';
import {routerRedux} from 'dva/router';
import {resetPassword} from '../services/user';

export default {
  namespace: 'site',

  state: {
    list: [],
    site: null,
    pageSize: 30,
    page: 1,
    total: 0,
    point: '',
    accumulation: [
      {
        value: 1,
        name: '2312',
      },
    ],
    gatheringList: []
  },

  effects: {
    * fetch({payload}, {call, put}) {
      const response = yield call(querySiteList, payload);
      if (response && response.c === 200) {
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(response.d.data) ? response.d.data : [],
            total: response.d.recordsTotal,
            page: response.d.pageNo,
          },
        });
      } else {
        message.error("数据加载失败，请刷新重新加载");
      }
    },
    * add({payload}, {put}) {
      // yield put(
      //   routerRedux.push(`/accumulation/site/siteAdd?gatheringId=${payload.id}`));
      yield put(
        routerRedux.push(`/accumulation/site/siteAdd`));
    },
    * addSubmit({payload}, {call, put}) {
      // console.log({payload});
      const response = yield call(querySiteAdd, payload);
      if (response && response.c === 200) {
        message.success('创建商户成功');
        // console.log(response);
        yield put(
          // /accumulation/accumulationEdit?id=322591
          // routerRedux.push(`/accumulation/accumulationEdit?id=${payload.gatheringId}`)
          routerRedux.push(`/site/list`)
        )
      } else {
        message.error('数据提交失败，请重新提交');
      }
    },
    * redirectDetail({payload}, {call, put}) {
      yield put(
        routerRedux.push(`/accumulation/site/siteEdit?id=${payload.id}`));
    },
    * redirectGift({payload}, {call, put}) {
      console.log(payload);
      yield put(
        routerRedux.push(`/accumulation/site/gift/list`));
    },
    * redirectGiftSale({payload}, {call, put}) {
      yield put(
        routerRedux.push(`/accumulation/site/gift/sale?id=${payload.id}`));
    },
    * lock({payload}, {call, put}) {
      const response = yield call(lockSite, payload);
      if (response && response.c === 200) {
        message.success('操作成功');
        yield put({
          type: 'fetchDetail',
          payload: {
            ...payload
          }
        })
      } else {
        message.error('操作失败，请重新再试')
      }
    },
    * fetchDetail({payload}, {call, put}) {
      const response = yield call(querySite, payload);
      if (response && response.c === 200) {
        yield put({
          type: 'saveDetail',
          payload: response.d,
        });
      } else {
        message.error('数据加载出错，请刷新重新加载')
      }
    },
    * editSubmit({payload}, {call, put}) {
      const response = yield call(querySiteSubmit, payload);
      if (response && response.c === 200) {
        message.success('修改成功');
        yield put({
          type: 'fetchDetail',
          payload: {
            id: payload.id,
          }
        })
      } else {
        message.error('修改失败，请重新提交');
      }
    },
    * resetPassword({payload}, {call, put}) {
      console.log(payload)
      const response = yield call(resetSitePassword, payload);
      if (response && response.c === 200) {
        message.success('操作成功');
      } else {
        message.error('操作失败，请刷新重试');
      }
    },
    * fetchAllGatheringList({payload}, {call, put}) {
      const response = yield call(queryAllGatheringList, payload);
      if (response && response.c === 200) {
        yield put({
          type: 'queryGatheringList',
          payload: {
            gatheringList: Array.isArray(response.d) ? response.d : [],
            // total: response.d.recordsTotal,
            // page: response.d.pageNo,
          }
        })
      } else {
        message.error("数据加载失败，请刷新重新加载");
      }
    }
  },

  reducers: {
    queryList(state, action) {
      return {
        ...state,
        list: action.payload.list,
        total: action.payload.total,
        page: action.payload.page,
      };
    },
    queryGatheringList(state, action) {
      return {
        ...state,
        gatheringList: action.payload.gatheringList
      }
    },
    saveDetail(state, action) {
      return {
        ...state,
        site: action.payload,
      };
    },
  },
};
