import {
  querySvipList,
  querySvipIntegral,
  addSvipIntegral,
  cancelSvip,
  queryIntegralApply,
  queryIntegralApplyStatus
} from '../services/api';
import {message} from 'antd';

export default {
  namespace: 'svip',

  state: {
    list: [],
    pageSize: 30,
    page: 1,
    label: null,
    total: 0,
    detailPageSize: 30,
    detailPage: 1
  },

  effects: {
    * fetch({payload}, {call, put}) {
      const response = yield call(querySvipList, payload);
      if (response && response.c === 200) {
        const {data, pageNo, recordsTotal, pageSize} = response.d;
        let all = 0;
        if (Array.isArray(payload.columns) && payload.columns.length === 0) {
          all = recordsTotal;
          yield put({
            type: 'save',
            payload: {
              list: Array.isArray(data) ? data : [],
              total: recordsTotal,
              page: pageNo,
              pageSize,
              all,
            },
          });
        } else {
          yield put({
            type: 'save',
            payload: {
              list: Array.isArray(data) ? data : [],
              total: recordsTotal,
              page: pageNo,
              pageSize,
              all: recordsTotal,
            },
          });
        }
      } else {
        message.error('数据提交出错，请重新再试。')
      }
    },
    * fetchProfile({payload}, {call, put}) {
      const response = yield call(querySvipIntegral, payload);
      const {data, pageNo, recordsTotal, pageSize} = response.d;
      if (response && response.c === 200) {
        yield put({
          type: 'save',
          payload: {
            list: Array.isArray(data) ? data : [],
            total: recordsTotal,
            page: pageNo,
            pageSize,
            all: recordsTotal,
            detailPage: pageNo,
            detailPageSize: pageSize
          }
        });
      } else {
        message.error('数据加载出错，请刷新再试。');
      }
    },
    * delete({payload}, {call, put}) {
      const {id, page, pageSize} = payload;
      const response = yield call(cancelSvip, {
        id,
      });
      if (response && response.c === 200) {
        message.success('取消身份成功！')
        yield put({
          type: 'fetch',
          payload: {
            page,
            pageSize,
          },
        });
      } else {
        message.error('取消身份失败，请重新再试。')
      }
    },
    * addSubmit({payload}, {call, put}) {
      const { page, pageSize } = payload;
      // console.log(payload);
      const response = yield call(addSvipIntegral, payload);
      if (response && response.c === 200) {
        message.success('积分详情修改成功。');
        yield put({
          type: 'fetch',
          payload: {
            page,
            pageSize,
          },
        });
      } else {
        message.error('积分详情修改失败，请重新再试。')
      }
    },
    * fetchIntegralApply({payload}, {call, put}) {
      const response = yield call(queryIntegralApply, payload);
      if (response && response.c === 200) {
        const {data, page, recordsTotal, pageSize} = response.d;
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(data) ? data : [],
            page,
            pageSize
          }
        })
      } else {
        message.error('数据提交出错，请重新再试。')
      }
    },
    * confirm({payload}, {call, put}) {
      const response = yield call(queryIntegralApplyStatus, payload);
      if (response && response.c === 200) {
        const res = yield call(queryIntegralApply, payload);
        if (res && res.c === 200) {
          const {data, page, recordsTotal, pageSize} = res.d;
          yield put({
            type: 'queryList',
            payload: {
              list: Array.isArray(data) ? data : [],
              page,
              pageSize
            }
          })
        } else {
          message.error('数据提交出错，请重新再试。')
        }
      } else {
        message.error('数据提交出错，请重新再试。')
      }
    }
    // *submit({ payload }, { call, put }) {
    //   const { id, name, page, pageSize } = payload;
    //   const response = yield call(queryLabelSubmit, {
    //     id,
    //     name,
    //   });
    //   if(response && response.c === 200){
    //     message.success('标签修改成功。');
    //     yield put({
    //       type: 'fetch',
    //       payload: {
    //         page,
    //         pageSize,
    //       },
    //     });
    //   }else{
    //     message.error('标签修改出错，请重新再试。')
    //   }
    // },
    // *exportTags({ payload }, { call, put }) {
    //   const response = yield call(exportTagsList, payload);
    //   if(response && response.c === 200){
    //     message.success('标签导出成功。');
    //   }else{
    //     message.error('标签导出失败，请重新再试。')
    //   }
    // },
  },

  reducers: {
    save(state, action) {
      const {list, page, total, pageSize, all, detailPage, detailPageSize} = action.payload;
      return {
        ...state,
        list,
        total,
        page,
        pageSize,
        all,
        detailPage,
        detailPageSize
      };
    },
    saveDetail(state, action) {
      return {
        ...state,
        label: action.payload,
      };
    },
    queryList(state, action) {
      const {list, page, pageSize} = action.payload;
      return {
        list,
        page,
        pageSize
      }
    }
  }
};
