import {
  queryVipCodeList,
  vipCreateList,
  vipCreateCard,
  vipActivate,
  deleteVipCode,
  vipRemark,
  queryVip,
  queryRechargeList,
  vipRechargeStatus,
  vipRechargeDetail,
  vipRechargeGathering
} from '../services/api';
import {message,} from 'antd';
import {routerRedux} from 'dva/router';
import {getSessionStorage} from "../utils/utils";

export default {
  namespace: 'vip',

  state: {
    list: [],
    visible: false,
    total: 0,
    pageSize: 30,
    confirmLoading: false,
    page: 1,
    vip: {},
    recharge: {}
  },

  effects: {
    * fetch({payload}, {call, put}) {
      const response = yield call(queryVipCodeList, payload);
      if (response && response.c === 200) {
        const {data, pageSize, recordsTotal, pageNo} = response.d;
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(data) ? data : [],
            pageSize,
            total: recordsTotal,
            page: pageNo,
          },
        });
      } else {
        message.error("数据加载失败，请刷新重新加载")
      }
    },
    * queryVip({payload}, {call, put}) {
      const response = yield call(queryVip, payload);
      if (response && response.c === 200) {
        yield put({
          type: 'saveVip',
          payload: response.d,
        });
      } else {
        message.error("数据加载失败，请刷新重新加载")
      }
    },
    * addSubmit({payload}, {call, put}) {
      const response = yield call(vipCreateList, {
        size: payload.size,
      });
      if (response && response.c === 200) {
        message.success('VIP卡生成成功');
        yield put({
          type: 'fetch',
          payload: {
            order: [{direction: "DESC", property: "id"}],
            pageSize: payload.pageSize,
            pageNo: payload.pageNo,
          },
        });
      } else {
        message.error('VIP卡生成失败，请重新提交');
      }
    },
    * remarkSubmit({payload}, {call, put}) {
      const response = yield call(vipRemark, {
        id: payload.id,
        remark: payload.remark,
      });
      if (response && response.c === 200) {
        message.success('备注成功');
        yield put({
          type: 'fetch',
          payload: {
            pageSize: payload.pageSize,
            pageNo: payload.pageNo,
          },
        });
      } else {
        message.error('备注失败，请重新提交');
      }
    },
    * createCardSubmit({payload}, {call, put}) {
      const response = yield call(vipCreateCard, {
        start: payload.start,
        end: payload.end,
      });
      if (response && response.c === 200) {
        message.success('制卡成功');
        yield put({
          type: 'fetch',
          payload: {
            pageSize: payload.pageSize,
            pageNo: payload.pageNo,
          },
        });

      } else {
        message.error('制卡失败，请重新提交');
      }
    },
    * activateSubmit({payload}, {call, put}) {
      const response = yield call(vipActivate, {
        start: payload.start,
        end: payload.end,
        activationInstructions: payload.activationInstructions,
        channel: payload.channel,
        dayNum: payload.dayNum,
        discount: payload.discount,
      });
      if (response && response.c === 200) {
        message.success('激活成功');
        yield put({
          type: 'fetch',
          payload: {
            pageSize: payload.pageSize,
            pageNo: payload.pageNo,
          },
        });

      } else {
        message.error(response.m);
      }
    },
    * delete({payload}, {call, put}) {
      const response = yield call(deleteVipCode, {
        id: payload.id,
      });
      if (response && response.c === 200) {
        message.success('该卡片已成功作废');
        yield put({
          type: 'fetch',
          payload: {
            pageSize: payload.pageSize,
            pageNo: payload.pageNo,
          },
        });
      } else {
        message.error('提交失败，请重新提交');
      }
    },
    * redirectDetail({payload}, {call, put}) {
      yield put(
        routerRedux.push(`/comsumerProfile${payload.id}`));
    },
    * rechargeList({payload}, {call, put}) {
      // console.log('fetch');
      const response = yield call(queryRechargeList, payload);

      if (response && response.c === 200) {
        const {data, pageSize, recordsTotal, pageNo} = response.d;
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(data) ? data : [],
            pageSize,
            total: recordsTotal,
            page: pageNo,
          },
        });
      } else {
        message.error('提交失败，请重新提交');
      }
    },
    // vipRechargeDetail
    * rechargeDetail({payload}, {call, put}) {
      const response = yield call(vipRechargeDetail, payload);

      if (response && response.c === 200) {
        yield put({
          type: 'queryDetail',
          payload: {
            recharge: response.d
          },
        });
      } else {
        message.error('获取数据失败，请稍后重试');
      }
    },
    //修改VIP时长
    * editRecharge({payload}, {call, put}) {
      const response = yield call(vipRechargeGathering, payload);
      const {page, pageSize} = payload;
      if (response && response.c === 200) {
        const res = yield call(queryRechargeList, {page,pageSize});

        if (res && res.c === 200) {
          const {data, pageSize, recordsTotal, pageNo} = res.d;
          yield put({
            type: 'queryList',
            payload: {
              list: Array.isArray(data) ? data : [],
              pageSize,
              total: recordsTotal,
              page: pageNo,
            },
          });
        } else {
          message.error('获取数据失败，请稍后重试');
        }
      } else {
        message.error('获取数据失败，请稍后重试');
      }
    },
    * addRecharge({payload}, {call, put}) {
      const response = yield call(vipRechargeGathering, payload);
      if (response && response.c === 200) {
        const res = yield call(queryRechargeList, payload);

        if (res && res.c === 200) {
          const {data, pageSize, recordsTotal, pageNo} = res.d;
          yield put({
            type: 'queryList',
            payload: {
              list: Array.isArray(data) ? data : [],
              pageSize,
              total: recordsTotal,
              page: pageNo,
            },
          });
        } else {
          message.error(res.m);
        }
      } else {
        message.error('获取数据失败，请稍后重试');
      }
    },

    * redirectProfile({payload}, {call, put}) {
      yield put(
        routerRedux.push(`/vipRecharge/vipRecharge/detail?id=${payload.id}`));
    },

    * vipRechargeStatus({payload}, {call, put}) {
      const response = yield call(vipRechargeStatus, payload);
      if (response && response.c === 200) {
        const res = yield call(queryRechargeList, payload);
        const {data, pageSize, recordsTotal, pageNo} = res.d;
        yield put({
          type: 'queryList',
          payload: {
            list: Array.isArray(data) ? data : [],
            pageSize,
            total: recordsTotal,
            page: pageNo,
          },
        });
        message.success('操作成功');
      } else {
        message.error('提交失败，请重新提交');
      }
    }
  },

  reducers: {
    queryList(state, action) {
      const {list, pageSize, total, page} = action.payload;
      return {
        ...state,
        list,
        pageSize,
        total,
        page
      };
    },
    queryDetail(state, action) {
      const {recharge} = action.payload;
      return {
        ...state,
        recharge
      };
    },
    saveVip(state, action) {
      return {
        ...state,
        vip: action.payload
      };
    }
  }
};
