import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {
  Table,
  Form,
  Card,
  Row,
  Col,
  Radio,
  Input,
  Button,
  Divider,
  Popconfirm,
} from 'antd';
import {
  setSessionStorage,
  getSessionStorage,
  removeSessionStorage,
  sortTable,
  searchTable,
} from '../../utils/utils';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import styles from './SystemList.less';

const FormItem = Form.Item;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const {Search} = Input;
@connect(({accumulation, loading}) => ({
  list: accumulation.list,
  loading: loading.models.accumulation,
  pageSize: accumulation.pageSize,
  page: accumulation.page,
  total: accumulation.total,
}))
@Form.create()
export default class AccumulationList extends PureComponent {

  state = {
    expandForm: false,
    formValues: {},
    filters: {},
  };

  componentDidMount() {
    const {pageSize, page} = this.props;
    this.fetch({
      pageSize: getSessionStorage("accumulationListPageSize") * 1 || pageSize,
      page: getSessionStorage("accumulationListCurrent") * 1 || page,
    });
  }

  fetch = (payload) => {
    this.props.dispatch({
      type: 'accumulation/fetch',
      payload: {
        ...payload
      }
    })
  };

  componentWillUnmount() {
    removeSessionStorage('accumulationListCurrent');
    removeSessionStorage('accumulationListPageSize');
  }

  handleFormReset = () => {
    const {form} = this.props;
    form.resetFields();
    this.setState({
      formValues: {},
    });
  };

  handleSearch = e => {
    e.preventDefault();
    const {form} = this.props;
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };
      const columns = searchTable(values);
      if (this.state.filters && this.state.filters.columns) {
        this.state.filters.columns.map((item) => {
          columns.push({
            ...item,
          });
        });
      }
      this.fetch({
        columns,
        order: this.state.filters.order,
        pageNo: 1,
        pageSize: getSessionStorage("accumulationListPageSize") * 1 || this.props.pageSize,
      });
    });
  };

  toggleForm = () => {
    this.setState({
      expandForm: !this.state.expandForm,
    });
  };

  handleChange = current => {
    setSessionStorage("accumulationListCurrent", current);
    this.props.dispatch({
      type: 'accumulation/fetchChange',
      payload: {
        pageSize: getSessionStorage("accumulationListPageSize") * 1 || this.props.pageSize,
        pageNo: current,
      },
    });
  };

  handleSizeChange = (current, size) => {
    setSessionStorage("accumulationListCurrent", current);
    setSessionStorage("accumulationListPageSize", size);
    this.props.dispatch({
      type: 'accumulation/fetchChange',
      payload: {
        pageSize: size,
        pageNo: current,
      },
    });
  };

  handleDetail = id => {
    this.props.dispatch({
      type: 'accumulation/redirectDetail',
      payload: {
        id
      }
    })
  };
  handleSiteList = record => {
    this.props.dispatch({
      type:'accumulation/redirectSite',
      payload:{
        id:record.id
      }
    });
    setSessionStorage('siteListFilterName',record.name)
  };

  handleDelete = id => {
    const {dispatch, pageSize, page} = this.props;
    dispatch({
      type: 'accumulation/delete',
      payload: {
        id,
        pageSize: getSessionStorage("accumulationListPageSize") * 1 || pageSize,
        pageNo: getSessionStorage("accumulationListCurrent") * 1 || page,
      },
    });
  };

  handleLock = id => {
    const {dispatch, pageSize, page} = this.props;
    dispatch({
      type: 'accumulation/lock',
      payload: {
        id,
        pageSize: getSessionStorage("accumulationListPageSize") * 1 || pageSize,
        pageNo: getSessionStorage("accumulationListCurrent") * 1 || page,
      },
    });
  };

  handleCreate = () => {
    this.props.dispatch({
      type: 'accumulation/add',
    });
  };

  handleSite = (id) => {
    this.props.dispatch({
      type: 'accumulation/redirectSite',
      payload: {
        id,
      }
    });
  };

  renderForm() {
    return this.renderSimpleForm();
  }

  handleTableChange = (pagination, filters, sorter) => {
    const {form} = this.props;
    let values = null;
    form.validateFields((err, fieldsValue) => {
      if (err) return;

      values = {
        ...fieldsValue,
      };
    });
    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;
    this.setState({
      filters: {
        columns,
        order,
      }
    });
    Object.keys(values).map((item) => {
      if (values[item]) {
        columns.push({
          name: item,
          relation: "LIKE",
          search: values[item],
        })
      }
    });

    setSessionStorage("accumulationListCurrent", current);
    setSessionStorage("accumulationListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order,
    });
  };

  swiperChange = id => {
    // this.setState({
    //   whisperSwitch: {
    //     change: !this.state.whisperSwitch.change,
    //     value: !this.props.accumulationMsg.whisperSwitch,
    //   }
    // });
    this.props.dispatch({
      type: 'accumulation/whisperSwitch',
      payload: {
        id
      }
    });
  };

  likeChange = id => {
    // this.setState({
    //   adoreSwitch: {
    //     change: !this.state.adoreSwitch.change,
    //     value: !this.props.accumulationMsg.adoreSwitch,
    //   }
    // });
    this.props.dispatch({
      type: 'accumulation/adoreSwitch',
      payload: {
        id
      }
    });
  };

  renderSimpleForm() {
    const {getFieldDecorator} = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col md={8} sm={24}>
            <FormItem label="聚点名称">
              {getFieldDecorator('name')(<Input placeholder="请输入聚点名称"/>)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="所在地区">
              {getFieldDecorator('cityName')(<Input placeholder="请输入所在地区"/>)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  render() {
    const {list, loading, pageSize, page, total} = this.props;

    const extraContent = (
      <div className={styles.extraContent}>
        <Button icon="plus" type="primary" onClick={this.handleCreate}>
          新建聚点
        </Button>
      </div>
    );

    const pagination = {
      pageSize: getSessionStorage('accumulationListPageSize') * 1 || pageSize,
      current: getSessionStorage('accumulationListCurrent') * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const columns = [
      {
        title: '序号',
        dataIndex: 'id',
        render: (text, record, index) => (
          <span>
            {index + 1 + (page - 1) * pageSize}
          </span>
        ),
      },
      {
        title: '聚点名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '创建时间',
        dataIndex: 'createDate',
        render: (text, record) => (
          <span>
            {moment(record.createDate).format('YYYY-MM-DD HH:mm:ss')}
          </span>
        ),
        sorter: true,
      },
      {
        title: '所在地区',
        dataIndex: 'cityName',
      },
      // {
      //   title: '封面1',
      //   key: 'pic',
      //   render: (text, record) => (
      //     <img src={record.pic} alt={record.name} style={{ width: '40px', height: '40px' }} />
      //   ),
      // },
      {
        title: '场所数量',
        dataIndex: 'siteNum',
      },
      {
        title: '当前人数',
        dataIndex: 'currentHeadcount',
      },
      {
        title: '上一周期真实配对成功数',
        dataIndex: 'matching',
      },
      {
        title: '状态',
        dataIndex: 'status',
        filters: [
          {
            text: '正常',
            value: true,
          },
          {
            text: '已关闭',
            value: false,
          },
        ],
        filterMultiple: false,
        render: (text, record) => (
          <span>
            {record.status ? '正常' : '已关闭'}
          </span>
        ),
      },
      {
        title: '聚点介绍',
        dataIndex: 'introduce',
        key: 'introduce',
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            <a onClick={this.handleDetail.bind(null, record.id)}>查看详情</a>
            <Divider type="vertical"/>
            <a onClick={this.handleSiteList.bind(null, record)}>查看聚点商户</a>
            <Divider type="vertical"/>
            <a onClick={this.handleLock.bind(null, record.id)}>
              {record.status ? '关闭聚点' : '恢复聚点'}
            </a>
          </span>
        ),
      },
      {
        title: '无限私语（开启/关闭）',
        render: (text, record) => (
          <span>
            <a onClick={this.swiperChange.bind(null, record.id)}>
              {record.whisperSwitch ? '关闭' : '开启'}
            </a>
          </span>
        )
      },
      {
        title: '无限喜欢（开启/关闭）',
        render: (text, record) => (
          <span>
            <a onClick={this.likeChange.bind(null, record.id)}>
              {record.adoreSwitch ? '关闭' : '开启'}
            </a>
          </span>
        )
      }
    ];


    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Card
            className={styles.listCard}
            bordered={false}
            title="聚点列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 32px 40px 32px'}}
            extra={extraContent}
          >
            <Table
              bordered
              loading={loading}
              rowKey={record => record.id}
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
