import React, { PureComponent } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import {
  Table,
  Card,
  Button,
  Form,
  Row,
  Col,
  Input,
  Icon,
  Select,
  DatePicker,
  Divider,
  Popconfirm,
  Modal,
} from 'antd';
import styles from './SystemList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import { setSessionStorage, getSessionStorage, removeSessionStorage, sortTable, searchTable } from '../../utils/utils';
const FormItem = Form.Item;
const { RangePicker } = DatePicker;
const Option = Select.Option;
@connect(({ administrator, loading }) => ({
  submitting: loading.effects['administrator/submit'],
  list: administrator.list,
  total: administrator.total,
  loading: loading.models.administrator,
  pageSize: administrator.pageSize,
  page: administrator.page,
  roleList: administrator.roleList,
}))
@Form.create()
export default class RoleList extends PureComponent {

  state = {
    modal: false,
    id: 0,
    formValues: {},
    filters: {},
  }

  componentDidMount() {
    this.fetch({
      "pageSize": getSessionStorage("administratorListPageSize") * 1 || this.props.pageSize,
      "page": getSessionStorage("administratorListCurrent") * 1 || this.props.page,
    });
  }

  componentWillUnmount() {
    removeSessionStorage("administratorListPageSize");
    removeSessionStorage("administratorListCurrent");
  }

  fetch = (payload) => {
    this.props.dispatch({
      type: 'administrator/fetch',
      payload,
    });
  };

  handleExport() {
    console.log('点击了导出文件表格按钮');
  }

  handleEdit = (record) => {
    this.props.dispatch({
      type: 'administrator/edit',
      payload: {
        id: record.id,
      },
    });
  };

  handlerResetPassword = (record) => {
    this.setState({
      modal: true,
      id: record.id,
    });
  };

  handlerResetPasswordCancel = (record) => {
    this.setState({
      modal: false,
    });
    this.handleFormReset();
  };

  handlerResetPasswordSubmit = (record) => {
    const { dispatch, form } = this.props;
    form.validateFields(['password', 'confirmPassword'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        modal: false,
      });
      this.handleFormReset();
      dispatch({
        type: 'administrator/resetPassword',
        payload: {
          id: this.state.id,
          ...fieldsValue,
        },
      });
    });
  };

  handleDelete = (record) => {
    this.props.dispatch({
      type: 'administrator/delete',
      payload: {
        id: record.id,
        page: getSessionStorage("administratorListCurrent") || this.props.page,
        pageSize: getSessionStorage("administratorListPageSize") || this.props.pageSize,
      },
    });
  };

  handleSizeChange = (current, size) => {
    setSessionStorage("administratorListCurrent", current);
    setSessionStorage("administratorListPageSize", size);
    this.props.dispatch({
      type: 'administrator/fetchChange',
      payload: {
        pageSize: size,
        page: current,
      },
    });
  };

  handleSearch = e => {
    e.preventDefault();
    const { dispatch, form, pageSize } = this.props;

    form.validateFields(['name'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };
      const columns = searchTable(values);
      if(this.state.filters && this.state.filters.columns){
        this.state.filters.columns.map((item) => {
          columns.push({
            ...item,
          });
        });
      };
      dispatch({
        type: 'administrator/fetch',
        payload: {
          columns,
          order: this.state.filters.order,
          pageSize: getSessionStorage('administratorListPageSize') * 1 || pageSize,
          page: 1,
        },
      });
    });
  };

  renderForm() {
    return this.renderSimpleForm();
  }
  renderSimpleForm() {
    const { getFieldDecorator } = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
            <FormItem label="管理员昵称">
              {getFieldDecorator('name')(<Input placeholder="请输入管理员昵称" />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  handleCreate = () => {
    this.props.dispatch({
      type: 'administrator/add',
    });
  };

  handleTableChange = (pagination, filters, sorter) => {
    const { form } = this.props;
    let values = null;
    form.validateFields(['name'],(err, fieldsValue) => {
      if (err) return;

      values = {
        ...fieldsValue,
      };
    });
    const { current, pageSize } = pagination;
    const res = sortTable(pagination, filters, sorter);
    const { columns, order } = res;
    this.setState({
      filters: {
        columns,
        order,
      }
    });
    if(values){
      Object.keys(values).map((item) => {
        if(values[item]){
          columns.push({
            name: item,
            relation: "LIKE",
            search: values[item],
          })
        }
      });
    }

    setSessionStorage("administratorListCurrent", current);
    setSessionStorage("administratorListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order,
    });
  };

  checkPassword = (rule, value, callback) => {
    const form = this.props.form;
    if (value && value !== form.getFieldValue('password')) {
      callback('两次密码输入不一致！');
    } else {
      callback();
    }
  };

  handleFormReset = () => {
    const { form } = this.props;
    form.resetFields();
  };

  renderResetPasswordModal() {
    const { getFieldDecorator } = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
    };

    return (
      <Form>
        <FormItem label="新密码" {...formItemLayout}>
          {getFieldDecorator('password',{
            rules: [{
              required: true,
              message: '请输入新密码',
            }],
          })(<Input type="passsword" placeholder="请输入新密码" style={{width:'100%'}} />)}
        </FormItem>
        <FormItem label="再次输入新密码" {...formItemLayout}>
          {getFieldDecorator('confirmPassword',{
            rules: [{
              required: true,
              message: '请输入新密码',
            }, { validator: this.checkPassword },],
          })(<Input type="passsword" placeholder="请输入新密码" style={{width:'100%'}} />)}
        </FormItem>
      </Form>
    );
  }

  render() {
    const { list, loading, total, pageSize, page, } = this.props;
    const { modal } = this.state;
    const pagination = {
      pageSize: getSessionStorage("administratorListPageSize") * 1 || pageSize,
      current: getSessionStorage("administratorListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const columns = [
      {
        title: '管理员账号',
        dataIndex: 'userName',
        key: 'userName',
      },
      {
        title: '管理员昵称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '邮箱',
        dataIndex: 'email',
        key: 'email',
      },
      {
        title: '状态',
        dataIndex: 'lock',
        render: (text, record) => (
          <span>
          {
            record.lock ? '已封号' : '正常'
          }
          </span>
        ),
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record, index) => (
          <span>
            <a onClick={this.handleEdit.bind(null, record)}>修改</a>
            <Divider type="vertical" />
            {record.lock
              ?
              <Popconfirm placement="leftTop" title='确定要解封吗？' onConfirm={this.handleDelete.bind(null, record, index)} okText="确定" cancelText="取消">
                <a>解封</a>
              </Popconfirm>
              :
              <Popconfirm placement="leftTop" title='确定要封号吗？' onConfirm={this.handleDelete.bind(null, record, index)} okText="确定" cancelText="取消">
                <a>封号</a>
              </Popconfirm>
            }
            <Divider type="vertical" />
            <a onClick={this.handlerResetPassword.bind(null, record)}>重置密码</a>
          </span>
        ),
      },
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Modal title="重置密码"
                 visible={modal}
                 onOk={this.handlerResetPasswordSubmit}
                 onCancel={this.handlerResetPasswordCancel}
          >
            {this.renderResetPasswordModal()}
          </Modal>
          <Card
            className={styles.listCard}
            bordered={false}
            title="管理员列表"
            style={{ marginTop: 24 }}
            bodyStyle={{ padding: '0 32px 40px 32px' }}
          >
            <Button className={styles.btnBt20} icon="download" onClick={this.handleExport}>
              导出表格
            </Button>
            <Button type="primary" icon="plus" style={{marginLeft: 8}} onClick={this.handleCreate}>
                新建管理员
            </Button>
            <Table
              bordered
              loading={loading}
              rowKey={record => record.id}
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
