import React, { PureComponent } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import {
  Table,
  Card,
  Button,
  Form,
  Row,
  Col,
  Input,
  Icon,
  Select,
  DatePicker,
  Divider,
  Modal,
  Popconfirm,
  Checkbox,
} from 'antd';
import styles from './SystemList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import { setSessionStorage, getSessionStorage, removeSessionStorage } from '../../utils/utils';
const FormItem = Form.Item;
const { RangePicker } = DatePicker;
const Option = Select.Option;
const CheckboxGroup = Checkbox.Group;
@connect(({ authority, loading }) => ({
  list: authority.list,
  total: authority.total,
  loading: loading.models.authority,
  loadingAll: loading.effects['models/fetchAll'],
  pageSize: authority.pageSize,
  page : authority.page,
  permissionList: authority.permissionList,
  authority: authority.authority,
  id: 0,
}))
@Form.create()
export default class AuthorityFuncList extends PureComponent {

  state = {
    modal: false,
    startTime: null,
    endTime: null,
    confirmLoading: false,
    modalVisible: false,
    checkedValues: [],
  }

  componentDidMount() {
    // console.log('componentDidMount');
    const { dispatch, page, pageSize } = this.props;
    this.props.dispatch({
      type: 'authority/fetch',
      payload: {
        pageSize: getSessionStorage("authorityListPageSize") * 1 || pageSize,
        page: getSessionStorage("authorityListCurrent") * 1 || page,
      },
    });
  }

  componentWillUnmount() {
    removeSessionStorage("authorityListPageSize");
    removeSessionStorage("authorityListCurrent");
  }

  handleCreateCancel = () => {
    this.setState({
      modalVisible: false,
    })
  };

  handleEditCancel = () => {
    this.setState({
      modal: false,
    })
  };

  handleCreate = () => {
    // console.log('handleCreate');
    this.props.dispatch({
      type: 'authority/add',
    });
  };

  handleExport() {
    // console.log('点击了导出文件表格按钮');
  }

  handleChange = (current) => {
    // console.log('handleChange');
    setSessionStorage("authorityListCurrent", current);
    this.props.dispatch({
      type: 'authority/fetchChange',
      payload: {
        pageSize: this.props.pageSize,
        page: current,
      },
    });
  };

  handleSizeChange = (current, size) => {
    // console.log('handleSizeChange');
    setSessionStorage("authorityListCurrent", current);
    setSessionStorage("authorityListPageSize", size);
    this.props.dispatch({
      type: 'authority/fetchChange',
      payload: {
        pageSize: size,
        page: current,
      },
    });
  };

  handleSearch = e => {
    // console.log('handleSearch');
    e.preventDefault();
    const { dispatch, form, pageSize } = this.props;

    form.validateFields((err, fieldsValue) => {
      if (err) return;

      const values = {
        ...fieldsValue,
        createdAt: {
          startTime: this.state.startTime,
          endTime: this.state.endTime,
        }
      };
      // console.log(values)
      dispatch({
        type: 'authority/fetch',
        payload: {
          ...values,
          pageSize: pageSize,
          current: 1,
        },
      });
    });
  };

  toggleForm = () => {
    this.setState({
      expandForm: !this.state.expandForm,
    });
  };

  handleDateChange = (date, dateString) => {
    this.setState({
      startTime: dateString[0],
      endTime: dateString[1],
    });
  }

  handleDelete = (record) => {
    // console.log('delete');
    this.props.dispatch({
      type: 'authority/delete',
      payload: {
        id: record.id,
        pageSize: getSessionStorage("authorityListPageSize") * 1 || this.props.pageSize,
        page: getSessionStorage("authorityListCurrent") * 1 || this.props.page,
      },
    });
  };

  handleCancel = () => {
    this.setState({
      modal: false,
    });
  };

  handleEdit = (record) => {
    // console.log('handleEdit');
    this.props.dispatch({
      type: 'authority/edit',
      payload: {
        id: record.id,
      },
    });
  };

  handleAddChange = (checkedValues) => {
    // console.log('handleAddChange');
    this.setState({
      checkedValues: checkedValues,
    });
  };

  renderForm() {
    // console.log('renderForm');
    return this.renderSimpleForm();
  }

  renderCreateModal() {
    // console.log('renderCreateModal');
    return this.state.modalVisible ? this.renderCreateModalForm() : '';
  }

  renderCreateModalForm() {
    // console.log('renderCreateModalForm');
    const { getFieldDecorator } = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
    };
    return (
      <Form>
        <FormItem label="权限名称" {...formItemLayout}>
          {getFieldDecorator('name',{
            rules: [{
              required: true,
              message: '权限名称不能为空',
            },],
          })(<Input placeholder="请输入权限名称" />)}
        </FormItem>
        <FormItem label="权限描述" {...formItemLayout}>
          {getFieldDecorator('description',{
            rules: [{
              required: true,
              message: '权限描述不能为空',
            },],
          })(<Input placeholder="请输入权限描述" />)}
        </FormItem>
        <FormItem label="权限资源" {...formItemLayout}>
          {getFieldDecorator('permission',
            {
              rules: [{
                required: true,
                message: '请输入请求路径',
              },],
            }
          )(
            <CheckboxGroup options={this.props.permissionList} onChange={this.props.handleAddChange} />
          )}
        </FormItem>
      </Form>
    );
  }

  renderEditModal() {
    // console.log('renderEditModal')
    return this.state.modal ? this.renderEditModalForm() : '';
  };

  handleAddSubmit = (e) => {
    // console.log('handleAddSubmit')
    e.preventDefault();
    const { dispatch, form } = this.props;
    form.validateFields(['name', 'description', 'permission'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        modalVisible: false,
      });
      const values = {
        ...fieldsValue,
      };
      dispatch({
        type: 'authority/addSubmit',
        payload: {
          ...values,
          confirmLoading: this.props.confirmLoading,
        },
      });
    });
  };

  handleEditSubmit = (e) => {
    // console.log('handleEditSubmit');
    e.preventDefault();
    const { dispatch, form } = this.props;
    form.validateFields(['name', 'description', 'permission'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        modal: false,
      });
      const values = {
        ...fieldsValue,
      };
      dispatch({
        type: 'authority/addSubmit',
        payload: {
          ...values,
          id: this.state.id,
          confirmLoading: this.props.confirmLoading,
        },
      });
    });
  };

  renderEditModalForm() {
    // console.log('renderEditModalForm')
    const { getFieldDecorator } = this.props.form;
    const authority = this.props.authority;
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
    };
    return (
      <Form>
        <FormItem label="权限名称" {...formItemLayout}>
          {getFieldDecorator('name',{
            initialValue: authority && authority.name,
            rules: [{
              required: true,
              message: '权限名称不能为空',
            },],
          })(<Input placeholder="请输入权限名称" />)}
        </FormItem>
        <FormItem label="权限描述" {...formItemLayout}>
          {getFieldDecorator('description',{
            initialValue: authority && authority.description,
            rules: [{
              required: true,
              message: '权限描述不能为空',
            },],
          })(<Input placeholder="请输入权限描述" />)}
        </FormItem>
        <FormItem label="权限资源" {...formItemLayout}>
          {getFieldDecorator('permission',
            {
              initialValue: authority && authority.permission,
              rules: [{
                required: true,
                message: '请输入请求路径',
              },],
            }
          )(
            <CheckboxGroup options={this.props.permissionList} />
          )}
        </FormItem>
      </Form>
    );
  }

  renderSimpleForm() {
    // console.log('renderSimpleForm')
    const { getFieldDecorator } = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
            <FormItem label="权限名称">
              {getFieldDecorator('name')(<Input placeholder="请输入权限名称" />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  render() {
    const { list,
      loading,
      total,
      pageSize,
      page,
      authority,
    } = this.props;
    const { modal, modalVisible } = this.state;

    const pagination = {
      pageSize: getSessionStorage("authorityListPageSize") * 1 || pageSize,
      current: getSessionStorage("authorityListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onChange: this.handleChange,
      onShowSizeChange: this.handleSizeChange,
    };

    const columns = [
      {
        title: '权限名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '描述',
        dataIndex: 'description',
        key: 'description',
      },
      {
        title: '创建时间',
        dataIndex: 'createDate',
        key: 'createDate',
        render: (text, record) => (
          <span>
            {moment(record.createDate).format('YYYY-MM-DD HH:mm:ss')}
          </span>
        )
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record, index) => (
          <span>
            <a onClick={this.handleEdit.bind(null, record)}>修改</a>
            <Divider type="vertical" />
            <Popconfirm placement="top" title='确定要删除该权限吗？' onConfirm={this.handleDelete.bind(null, record)} okText="确定" cancelText="取消"><a>删除</a></Popconfirm>
          </span>
        ),
      },
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Modal title="权限修改"
                 visible={modal}
                 onOk={this.handleEditSubmit}
                 onCancel={this.handleEditCancel}
          >
            {this.renderEditModal()}
          </Modal>
          <Modal title="新建权限"
                 visible={modalVisible}
                 onOk={this.handleAddSubmit}
                 onCancel={this.handleCreateCancel}
                 loading={this.props.loadingAll}
          >
            {this.renderCreateModal()}
          </Modal>
          <Card
            className={styles.listCard}
            bordered={false}
            title="权限列表"
            style={{ marginTop: 24 }}
            bodyStyle={{ padding: '0 32px 40px 32px' }}
          >
            <Button className={styles.btnBt20} icon="download" style={{marginRight: '8px'}} onClick={this.handleExport}>
              导出表格
            </Button>
            <Button icon="plus" type="primary" onClick={this.handleCreate}>
              新建权限
            </Button>
            <Table
              bordered
              loading={loading}
              rowKey='id'
              columns={columns}
              dataSource={list}
              pagination={pagination}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
