import React, { PureComponent } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import {
  Table,
  Card,
  Row,
  Col,
  Radio,
  Input,
  Button,
  Icon,
  Avatar,
  message,
  Modal,
  Divider,
  Popconfirm,
  Form,
  Select,
  DatePicker,
} from 'antd';

import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {
  setSessionStorage,
  getSessionStorage,
  removeSessionStorage,
  sortTable,
  searchTable,
  searchTableEq,
  ApiPostDownloadFile,
} from '../../utils/utils';

import styles from './SystemList.less';

const FormItem = Form.Item;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const { Search } = Input;
const { RangePicker } = DatePicker;
@connect(({ comsumer, loading }) => ({
  list: comsumer.list,
  loading: loading.models.comsumer,
  user: comsumer.user,
  pageSize: comsumer.pageSize,
  total: comsumer.total,
  page: comsumer.page,
}))
@Form.create()
export default class ComsumerList extends PureComponent {

  state = {
    startTime: null,
    endTime: null,
    panes: '',
    formValues: {},
    filters: {},
    searchType: 'NICKNAME',
    searchVal: null,
  };

  componentDidMount() {
    setSessionStorage('comsumerListPageSize', 30);
    setSessionStorage('comsumerListCurrent', 1);
    this.fetch({
      "pageSize": getSessionStorage("comsumerListPageSize") * 1 || this.props.pageSize,
      "page": getSessionStorage("comsumerListCurrent") * 1 || this.props.page
    })
  }

  componentWillUnmount() {
    removeSessionStorage("comsumerListPageSize");
    removeSessionStorage("comsumerListCurrent");
  }

  fetch = (payload) => {
    this.props.dispatch({
      type: 'comsumer/fetch',
      payload
    })
  };

  redirectProfile = (record) => {
    window.open(window.location.origin + '#/comsumer/comsumerProfile?id=' + record.id)
  };

  handleTableChange = (pagination, filters, sorter) => {
    const { form } = this.props;
    let values = null;
    form.validateFields(['nickName'], (err, fieldsValue) => {
      if (err) return;

      values = {
        ...fieldsValue,
      }
    });
    const { current, pageSize } = pagination;
    // const res = sortTable(pagination, filters, sorter);
    // console.log(res)
    // const {columns, order} = res;
    const { columns, order } = this.state.filters;
    this.setState({
      filters: {
        columns,
        order
      }
    });
    if (values) {
      Object.keys(values).map((item) => {
        if (values[item]) {
          columns.push({
            name: item,
            relation: "LIKE",
            search: values[item],
          })
        }
      });
    }

    setSessionStorage("comsumerListCurrent", current);
    setSessionStorage("comsumerListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order
    })
  };

  handleSizeChange = (current, size) => {
    const { columns } = this.state.filters;
    setSessionStorage("comsumerListCurrent", current);
    setSessionStorage("comsumerListPageSize", size);
    this.props.dispatch({
      type: 'comsumer/fetch',
      payload: {
        columns,
        pageSize: size,
        page: current
      }
    })
  };
  dataBind = e => {
    this.setState({
      searchVal: e.target.value
    })
  };


  handleFormReset = () => {
    const { form } = this.props;
    form.resetFields();
  };

  handleChange = (value) => {
    this.setState({
      searchType: value
    });
    // this.setState({
    //   filter:{
    //     searchType:value,
    //   }
    // })
  };

  handleSearch = e => {
    e.preventDefault();

    const { dispatch, form, pageSize } = this.props;

    form.validateFields(['searchType', 'searchVal'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };

      var columns = [];
      if (values.searchType === 'NICKNAME') {
        columns = [{
          "name": 'nickName',
          "relation": 'LIKE',
          "search": values.searchVal || '',
        }]
      }
      else if (values.searchType === 'ID') {
        columns = [{
          "name": 'id',
          "relation": 'EQ',
          "search": values.searchVal || '',
        }]
      } else if (values.searchType === 'TID') {
        columns = [{
          "name": 'translate.id',
          "relation": 'EQ',
          "search": values.searchVal || '',
        }]
      } else if (values.searchType === 'DEFAULTNICKNAME') {
        columns = [{
          "name": 'defaultNickName',
          "relation": 'LIKE',
          "search": values.searchVal || '',
        }]
      } else if (values.searchType === 'PHONE') {
        columns = [{
          "name": 'account.username',
          "relation": 'LIKE',
          "search": values.searchVal || '',
        }]
      }
      this.setState({
        filters: {
          columns
        }
      });
      console.log(this.state.filters)
      dispatch({
        type: 'comsumer/fetch',
        payload: {
          columns,
          order: this.state.filters.order,
          pageSize: getSessionStorage('comsumerListPageSize') * 1 || pageSize,
          page: 1,
        },
      });
    }
    )
      ;
  };

  renderForm() {
    return this.renderSimpleForm();
  }

  renderSimpleForm() {
    const { getFieldDecorator } = this.props.form;
    const Option = Select.Option;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={3} sm={24}>
            <FormItem>
              {getFieldDecorator('searchType', {
                initialValue: 'NICKNAME'
              })(
                <Select
                  // style={{width: '100px', float: 'left', marginRight: '10px'}}
                  // defaultValue="NICKNAME"
                  onChange={this.handleChange}
                >
                  <Option value="NICKNAME" type='option'>真实昵称</Option>
                  {/*<Option value="DEFAULTNICKNAME" type='option'>匿名昵称</Option>*/}
                  <Option value="PHONE" type='option'>手机号码</Option>
                  <Option value="ID" type='option'>用户ID</Option>
                  <Option value="TID" type='option'>邀请人ID</Option>
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <FormItem>
              {getFieldDecorator('searchVal',)(
                <Input placeholder="请输入查询内容" onKeyUp={this.dataBind} />
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }
  ;

  handleExport = (e) => {
    e.preventDefault();
    const columns = this.state.filters.columns;
    const { pageSize, page } = this.props;
    //API
    // ApiPostDownloadFile('/api/v1/export/consumer', {
    ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/consumer', {
      columns,
      page: getSessionStorage('comsumerListCurrent') * 1 || page,
      pageSize: getSessionStorage('comsumerListPageSize') * 1 || pageSize,
    });
  };

  render() {
    const {
      list,
      loading,
      pageSize,
      total,
      page,
    } = this.props;

    const pagination = {
      pageSize: getSessionStorage("comsumerListPageSize") * 1 || pageSize,
      current: getSessionStorage("comsumerListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const columns = [
      // {
      //   title: '序号',
      //   dataIndex: 'no',
      //   // key:'id',
      //   render: (text, record, index) => (index + 1 + (page - 1) * pageSize),
      // },
      {
        title: '用户ID',
        dataIndex: 'id',
        // key:'id'
      },
      {
        title: '真实昵称',
        dataIndex: 'nickName',
        key: 'nickName',
      },
      // {
      //   title: '匿名昵称',
      //   dataIndex: 'defaultNickName',
      //   key: 'defaultNickName'
      // },
      {
        title: '手机号码',
        dataIndex: 'phone',
        key: 'phone',
      },
      {
        title: '用户性别',
        dataIndex: 'sex',
        // filters: [
        //   {
        //     text: '男',
        //     value: 1,
        //   },
        //   {
        //     text: '女',
        //     value: 0,
        //   },
        // ],
        // filterMultiple: false,
        render: (text, record) => (
          <span>
            {record.sex === 1 ? '男' : '女'}
          </span>

        ),
      },
      {
        title: '真人认证',
        dataIndex: 'isRealPerson',
        render: (text, record) => (
          <span>{record.isRealPerson ? '已认证' : '未认证'}</span>
        )
      },
      {
        title: 'VIP',
        dataIndex: 'vipGrade',
        render: (text, record) => (
          <span>
            {record.vipGrade === 1 ? 'VIP' : '普通'}
          </span>

        ),
      },
      {
        title: 'VIP到期日期',
        dataIndex: 'vipExpirationTime',
        key: 'vipExpirationTime'
        // render: (text, record) => (
        //   record.vipTime && moment(record.vipTime).format('YYYY/MM/DD HH:mm:ss')
        // ),
      },
      {
        title: '邀请人ID',
        dataIndex: 'translateId',
        key: 'translateId'
      },
      // {
      //   title: '当前（最后一次）用户位置',
      //   dataIndex: 'site',
      //   key: 'site',
      // },
      // {
      //   title: '注册时间',
      //   dataIndex: 'createDate',
      //   render: (text, record) => (
      //     record.createDate && moment(record.createDate).format('YYYY/MM/DD HH:mm:ss')
      //   ),
      //   // sorter: true,
      // },
      {
        title: '最后登录时间',
        dataIndex: 'lastSigned',
        render: (text, record) => (
          record.lastSigned && moment(record.lastSigned).format('YYYY-MM-DD HH:mm:ss')
        ),
        // sorter: true,
      },
      {
        title: '手机系统版本',
        dataIndex: 'phoneSysVersion',
        key: 'phoneSysVersion',
      },
      {
        title: '私慕APP版本',
        dataIndex: 'appVersion',
        key: 'appVersion',
      },
      {
        title: '审核状态',
        dataIndex: 'status',
        key: 'status',
        render: (text, record) => (
          <span>
            {
              record.status && record.status === 'NORMAL' ? '正常状态' : record.status === 'PASS' ? '审核通过' : record.status === 'DEFEATED' ? '审核失败' : record.status === 'WAIT' ? '修改后待审核' : ''
            }
          </span>
        )
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            <a
              onClick={this.redirectProfile.bind(null, record)}
            >
              查看详情
            </a>
          </span>
        ),
      },
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Card
            className={styles.listCard}
            bordered={false}
            title="用户列表"
            style={{ marginTop: 24 }}
            bodyStyle={{ padding: '0 40px 32px' }}
          >
            <div style={{ marginBottom: '20px' }}>
              <Button icon="download" onClick={this.handleExport}>
                导出表格
              </Button>
            </div>
            <Table
              bordered
              loading={loading}
              rowKey='id'
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
