import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {
  Table,
  Form,
  Card,
  Row,
  Col,
  Input,
  Button,
  message,
  Modal,
  Divider,
  Popconfirm,
  Select,
  InputNumber,
} from 'antd';
import styles from './PayList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {
  setSessionStorage,
  getSessionStorage,
  sortTable,
  searchTable,
  removeSessionStorage,
  ApiPostDownloadFile,
} from '../../utils/utils';

const FormItem = Form.Item;
const {Option} = Select;
const {TextArea} = Input;
@connect(({diamond, loading}) => ({
  list: diamond.list,
  loading: loading.models.diamond,
  submitting: loading.effects['diamond/addSubmit'],
  total: diamond.total,
  pageSize: diamond.pageSize,
  confirmLoading: diamond.confirmLoading,
  page: diamond.page,
}))
@Form.create()
export default class DiamondList extends PureComponent {
  state = {
    modalVisible: false,
    expandForm: false,
    useAt: null,
    endAt: null,
    createdAt: null,
    modal: false,
    remarkModal: false,
    id: 0,
    remark: '',
    filters: {},
    order: [
      {
        "direction": "DESC",
        "property": "createDate"
      }
    ],
    formValues: {},
  };

  fetch = (payload) => {
    this.props.dispatch({
      type: 'diamond/fetch',
      payload: {
        ...payload,
      },
    });
  };

  componentDidMount() {
    this.fetch({
      pageSize: getSessionStorage('diamondListPageSize') * 1 || this.props.pageSize,
      page: getSessionStorage('diamondListCurrent') * 1 || this.props.current,
    });
  }

  componentWillUnmount() {
    removeSessionStorage("diamondListCurrent");
    removeSessionStorage("diamondListPageSize")
  }

  handleCreate = () => {
    this.setState({
      modalVisible: true,
    });
  };

  handleHideModal = () => {
    this.setState({
      modalVisible: false,
    });
    this.handleFormReset();
  };

  handleChange = (current) => {
    // console.log('handleChange');
    setSessionStorage('diamondListCurrent', current);
    this.props.dispatch({
      type: 'diamond/fetch',
      payload: {
        columns: this.state.filters.columns,
        pageSize: getSessionStorage('diamondListPageSize') * 1 || this.props.pageSize,
        page: current,
      },
    });
  };

  handleSizeChange = (current, size) => {
    // console.log('handleSizeChange');
    setSessionStorage('diamondListCurrent', current);
    setSessionStorage('diamondListPageSize', size);
    this.props.dispatch({
      type: 'diamond/fetch',
      payload: {
        columns: this.state.filters.columns,
        pageSize: size,
        page: current,
      },
    });
  };

  handleAddSubmit = (e) => {
    e.preventDefault();
    const {dispatch, form} = this.props;
    form.validateFields(['size','profit'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        modalVisible: false,
      });
      this.handleFormReset();
      const values = {
        ...fieldsValue,
      };
      dispatch({
        type: 'diamond/addSubmit',
        payload: {
          ...values,
          confirmLoading: this.props.confirmLoading,
          pageSize: getSessionStorage('diamondListPageSize') * 1 || this.props.pageSize,
          page: getSessionStorage('diamondListCurrent') * 1 || this.props.page,
        },
      });
    });
  };

  handleChannelSubmit = (e) => {
    e.preventDefault();
    const {dispatch, form} = this.props;
    form.validateFields(['start', 'end', 'channel1', 'channel2', 'channel3', 'activationInstructions'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        modal: false,
      });
      this.handleFormReset();
      const values = {
        ...fieldsValue,
      };
      let channel = '';
      channel = `${values.channel1}&${values.channel2}&${values.channel3}`;
      dispatch({
        type: 'diamond/channelSubmit',
        payload: {
          start: values.start,
          end: values.end,
          activationInstructions: values.activationInstructions,
          channel,
          pageSize: getSessionStorage('diamondListPageSize') * 1 || this.props.pageSize,
          page: getSessionStorage('diamondListCurrent') * 1 || this.props.page,
        },
      });
    });
  };

  handleExport = (e) => {
    e.preventDefault();
    const {columns} = this.state.filters;
    //API
    // ApiPostDownloadFile('/api/v1/export/svip', {
    ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/svip', {
      columns,
      order: this.state.order,
      pageNo: getSessionStorage('diamondListCurrent') * 1 || this.props.page,
      pageSize: getSessionStorage('diamondListPageSize') * 1 || this.props.pageSize,
    });
  };

  handleSearch = e => {
    e.preventDefault();
    const {dispatch, form, pageSize} = this.props;

    form.validateFields(['id', 'creatorPhone', 'phone'], (err, fieldsValue) => {
      if (err) return;

      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };

      let columns = [];
      Object.keys(values).forEach((item) => {
        if (values[item]) {
          // console.log(item);
          if (item === 'id') {
            columns.push({
              "name": item,
              "relation": 'EQ',
              "search": values[item],
            });
          }
          if (item === 'creatorPhone') {
            columns.push({
              "name": 'creator.account.username',
              "relation": 'LIKE',
              "search": values[item],
            });
          }
          if (item === 'phone') {
            columns.push({
              "name": 'consumer.account.username',
              "relation": 'LIKE',
              "search": values[item],
            });
          }
        }
      });

      this.setState({
        filters: {
          columns
        }
      });

      dispatch({
        type: 'diamond/fetch',
        payload: {
          columns,
          order: this.state.filters.order,
          pageSize: getSessionStorage('diamondListPageSize') * 1 || pageSize,
          page: 1,
        },
      });
    });
  };

  toggleForm = () => {
    this.setState({
      expandForm: !this.state.expandForm,
    });
  };

  handleFormReset = () => {
    const {form} = this.props;
    this.setState({
      filters: {
        columns: []
      }
    });
    form.resetFields();
  };

  renderForm() {
    return this.renderSimpleForm();
  }

  renderModal() {
    return this.state.modalVisible ? this.renderModalForm() : '';
  }

  renderModalForm() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="生成数量" {...formItemLayout}>
          {getFieldDecorator('size', {
            rules: [{
              required: true,
              message: '请输入需要生成的卡片数量',
            }],
          })(<InputNumber min={1} placeholder="请输入需要生成的卡片数量。" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="分润额度" {...formItemLayout}>
          {getFieldDecorator('profit', {
            rules: [{
              required: true,
              message: '请输入分润额度',
            }],
          })(<InputNumber min={1} placeholder="请输入分润额度。" style={{width: '100%'}}/>)}
        </FormItem>
      </Form>
    );
  }

  renderChannelModal() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="开始序列号" {...formItemLayout}>
          {getFieldDecorator('start', {
            rules: [{
              required: true,
              message: '请输入开始序列号',
            }],
          })(<InputNumber min={1} placeholder="请输入开始序列号。" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="结束序列号" {...formItemLayout}>
          {getFieldDecorator('end', {
            rules: [{
              required: true,
              message: '请输入结束序列号',
            }],
          })(<InputNumber min={1} placeholder="请输入结束序列号。" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="一级渠道" {...formItemLayout}>
          {getFieldDecorator('channel1', {})(<Input min={1} placeholder="请输入一级渠道。" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="二级渠道" {...formItemLayout}>
          {getFieldDecorator('channel2', {})(<Input min={1} placeholder="请输入二级渠道。" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="三级渠道" {...formItemLayout}>
          {getFieldDecorator('channel3', {})(<Input min={1} placeholder="请输入三级渠道。" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="备注" {...formItemLayout}>
          {getFieldDecorator('activationInstructions', {
            rules: [{
              required: true,
              message: '请输入备注',
            }],
          })(<TextArea placeholder="请输入备注。" style={{width: '100%'}}/>)}
        </FormItem>
      </Form>
    );
  }

  handleShowModal = (record) => {
    // console.log(record.remark);
    this.setState({
      remarkModal: true,
      id: record.id,
      remark: record.remark
    });
  };

  handleRemark = (e) => {
    e.preventDefault();
    const {dispatch, form} = this.props;
    form.validateFields(['remark'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        remarkModal: false,
      });
      this.handleFormReset();
      const values = {
        ...fieldsValue,
      };
      this.props.dispatch({
        type: 'diamond/remarkSubmit',
        payload: {
          id: this.state.id,
          ...values,
          pageSize: getSessionStorage('diamondListPageSize') * 1 || this.props.pageSize,
          page: getSessionStorage('diamondListPage') * 1 || this.props.page,
        },
      });
    });
  };

  handleEditRemarkCancel = () => {
    this.setState({
      remarkModal: false,
    });
    this.handleFormReset();
  }

  renderEditModal() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="备注" {...formItemLayout}>
          {getFieldDecorator('remark', {
            initialValue: this.state.remark || '',
            rules: [{
              max: 60,
              message: '备注信息最多60个字符',
            }, {
              required: true,
              message: '请输入备注内容',
            }],
          })(<TextArea placeholder="请输入备注内容，最多60个字符。" autosize={{minRows: 4}}/>)}
        </FormItem>
      </Form>
    );
  }

  renderDetail(record) {
    return (<span><Divider type="vertical"/><a onClick={this.handleDetail.bind(null, record)}>查看详情</a></span>);
  }

  handleDetail = record => {
    this.props.dispatch({
      type: 'diamond/redirectDetail',
      payload: record,
    });
  };

  renderDelete(record) {
    return (<Popconfirm placement="top" title='是否作废？' onConfirm={this.handleDelete.bind(null, record)} okText="确定"
                        cancelText="取消"><Divider type="vertical"/><a>作废</a></Popconfirm>);
  }

  handleDelete = (record) => {
    this.props.dispatch({
      type: 'diamond/delete',
      payload: {
        id: record.id,
        pageSize: getSessionStorage('diamondListPageSize') * 1 || this.props.pageSize,
        page: getSessionStorage('diamondListPageNo') * 1 || this.props.pageNo,
      },
    });
  };

  renderSimpleForm() {
    const {getFieldDecorator} = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col md={6} sm={24}>
            <FormItem label="序列号">
              {getFieldDecorator('id',)(<Input placeholder="请输入序列号"/>)}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <FormItem label="申请者">
              {getFieldDecorator('creatorPhone')(
                <Input placeholder="请输入申请者手机号"/>)}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <FormItem label="使用者">
              {getFieldDecorator('phone')(
                <Input placeholder="请输入使用者手机号"/>)}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  handleDitch = () => {
    this.setState({
      modal: true,
    });
  };

  handleHideChannelModal = () => {
    this.setState({
      modal: false,
    });
    this.handleFormReset();
  };

  handleTableChange = (pagination, filters, sorter) => {
    // console.log('handleTableChange');
    // const {form} = this.props;
    // let values = null;
    // form.validateFields(['id', 'channel'], (err, fieldsValue) => {
    //   if (err) return;
    //
    //   values = {
    //     ...fieldsValue,
    //   };
    // });
    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;
    // this.setState({
    //   filters: {
    //     columns,
    //     order,
    //   }
    // });
    // if (values) {
    //   Object.keys(values).map((item) => {
    //     if (values[item]) {
    //       columns.push({
    //         name: item,
    //         relation: "LIKE",
    //         search: values[item],
    //       })
    //     }
    //   });
    // }

    setSessionStorage("diamondListCurrent", current);
    setSessionStorage("diamondListPageSize", pageSize);

    this.fetch({
      page: current,
      pageSize,
      columns: this.state.filters.columns || columns,
      order,
    });
  };

  render() {
    const {
      list,
      loading,
      pageSize,
      total,
      page,
      submitting,
    } = this.props;
    const {modalVisible, remarkModal, modal} = this.state;

    const pagination = {
      pageSize: pageSize,
      total: total,
      current: page,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const columns = [
      {
        title: '序列号',
        dataIndex: 'id',
        sorter: true,
      },
      {
        title: '验证码',
        dataIndex: 'code',
        key: 'code',
      },
      {
        title: '分润额度',
        dataIndex: 'profit',
        key: 'profit',
      },
      {
        title: '生成时间',
        dataIndex: 'createDate',
        sorter: true,
        render: (text, record) => (
          moment(record.createDate).format('YYYY-MM-DD HH:mm:ss')
        ),
      },
      {
        title: '申请者手机号',
        dataIndex: 'creatorPhone',
        key: 'creatorPhone',
      },
      // {
      //   title: '一级渠道',
      //   dataIndex: 'channel1',
      //   key: 'channel1',
      // },
      // {
      //   title: '二级渠道',
      //   dataIndex: 'channel2',
      //   key: 'channel2',
      // },
      // {
      //   title: '三级渠道',
      //   dataIndex: 'channel3',
      //   key: 'channel3',
      // },
      {
        title: '使用者手机号',
        dataIndex: 'phone',
        key: 'phone',
      },
      {
        title: '使用时间',
        dataIndex: 'usedDate',
        key: 'usedDate'
        // render: (text, record) => (
        //   record.usedDate ? moment(record.usedDate).format('YYYY/MM/DD HH:mm:ss') : '未激活'
        // ),
      },
      {
        title: '结束日期',
        dataIndex: 'endDate',
        render: (text, record) => (
          <span>
            {record.expireTime && moment(record.expireTime).format('YYYY-MM-DD HH:mm:ss')}
          </span>
        ),
      },
      // {
      //   title: '作废状态',
      //   dataIndex: 'status',
      //   filters: [
      //     {
      //       text: '正常',
      //       value: 1,
      //     },
      //     {
      //       text: '已作废',
      //       value: 0,
      //     },
      //   ],
      //   filterMultiple: false,
      //   render: (text, record) => (
      //     <span>
      //       {record.status === 1 ? '正常' : '已作废'}
      //     </span>
      //   ),
      // },
      {
        title: '使用状态',
        dataIndex: 'used',
        filters: [
          {
            text: '已使用',
            value: true,
          },
          {
            text: '未使用',
            value: false,
          },
        ],
        filterMultiple: false,
        render: (text, record) => (
          <span>
            {record.used ? '已使用' : '未使用'}
          </span>
        ),
      },
      {
        title: '备注',
        dataIndex: 'activationInstructions',
        render: (text, record) => (
          <span>
            {record.remark ? record.remark : record.activationInstructions}
          </span>
        ),
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            <a onClick={this.handleShowModal.bind(null, record)}>备注</a>
            {/*{record.status !== 1 ? '' : this.renderDelete(record)}*/}
          </span>
        ),
      },
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Modal
            title="批量生成钻石激活码"
            visible={modalVisible}
            onOk={this.handleAddSubmit}
            onCancel={this.handleHideModal}
            okText="确认"
            cancelText="取消"
            confirmLoading={submitting}
          >
            {this.renderModal()}
          </Modal>
          <Modal
            title="设置渠道"
            visible={modal}
            onOk={this.handleChannelSubmit}
            onCancel={this.handleHideChannelModal}
            okText="确认"
            cancelText="取消"
            confirmLoading={submitting}
          >
            {this.renderChannelModal()}
          </Modal>
          <Modal title="备注"
                 visible={remarkModal}
                 onOk={this.handleRemark}
                 onCancel={this.handleEditRemarkCancel}
          >
            {this.renderEditModal()}
          </Modal>
          <Card
            className={styles.listCard}
            bordered={false}
            title="已生成的钻石激活码列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 32px 40px 32px'}}
          >
            <div className={styles.tableListOperator}>
              <Button icon="download" onClick={this.handleExport}>
                导出表格
              </Button>
              <Button icon="plus" type="primary" onClick={this.handleCreate}>
                批量生成钻石激活码
              </Button>
              {/*<Button icon="api" type="dashed" onClick={this.handleDitch}>*/}
              {/*设置渠道*/}
              {/*</Button>*/}
            </div>
            <Table
              bordered
              loading={loading}
              rowKey={record => record.id}
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
