import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {parse} from 'qs';
import {
  Table,
  Form,
  Card,
  Row,
  Col,
  Radio,
  Input,
  Progress,
  Button,
  Icon,
  Dropdown,
  Menu,
  Avatar,
  Alert,
  message,
  Modal,
  Divider,
  Popconfirm,
} from 'antd';
import {
  setSessionStorage,
  getSessionStorage,
  removeSessionStorage,
  sortTable,
  searchTable,
  ApiPostDownloadFile
} from '../../utils/utils';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';

import styles from './BasicList.less';
import {updateGiftStatus} from "../../services/api";

const FormItem = Form.Item;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const {Search} = Input;
@connect(({gift, loading}) => ({
  list: gift.list,
  loading: loading.models.gift,
  pageSize: gift.pageSize,
  page: gift.page,
  total: gift.total,
}))
@Form.create()
export default class GiftList extends PureComponent {

  state = {
    expandForm: false,
    formValues: {},
    selectedRowKeys: [],
    options: [
      {
        label: '用户自提',
        value: 'TAKE',
        disabled: false
      },
      {
        label: '场内派送',
        value: 'SEND',
        disabled: false
      },
      {
        label: '快递配送',
        value: 'EXPRESS',
        disabled: false
      },
      {
        label: '电子券码',
        value: 'ELECTRONIC_CODE',
        disabled: false
      }
    ],
    checkMethod: undefined,
    gatheringName: undefined,//聚点名称
    siteName: undefined,//商户名称
    name: undefined, //礼物名称
    order: [
      {
        "direction": "DESC",
        "property": "createDate"
      }
    ]
  };

  fetch = (filter) => {
    const {page, pageSize, dispatch} = this.props;
    const {id} = parse(this.props.location.search.substr(1));
    const siteName = getSessionStorage('giftListFilterSiteName');
    dispatch({
      type: 'gift/fetch',
      payload: {
        page: getSessionStorage('giftListCurrent') * 1 || page,
        pageSize: getSessionStorage('giftListPageSize') * 1 || pageSize,
        siteName: siteName || null,
        ...filter,
        order: this.state.order
        // siteId: id || null,,

      }

    })
    // }

    // if (this.props.location.search.substr(1)) {
    //   var columns = [{
    //     name: 'site.id',
    //     relation: 'EQ',
    //     search: parse(this.props.location.search.substr(1)).id,
    //     type: 'T_STRING'
    //   }]
    // } else {
    //   var columns = null
    // }

    // this.props.dispatch({
    //   type: 'gift/fetch',
    //   payload: {
    //     // siteId,
    //     columns,
    //     // page:this.props.page,
    //     ...payload
    //   }
    // })
  };

  componentDidMount() {
    setSessionStorage('giftListPageSize', 30);
    setSessionStorage('giftListCurrent', 1);
    this.fetch()
  }

  componentWillUnmount() {
    removeSessionStorage('giftListCurrent');
    removeSessionStorage('giftListPageSize');
  }

  handleFormReset = () => {
    const {form} = this.props;
    setSessionStorage('giftListFilterSiteName', '');
    form.resetFields();
    this.setState({
      formValues: {}
    })
  };

  handleSearch = e => {
    e.preventDefault();
    const {dispatch, form} = this.props;
    setSessionStorage('giftListCurrent', 1);
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      console.log(fieldsValue);
      sessionStorage.setItem('giftListFilterSiteName', fieldsValue.siteName);
      this.fetch({
        ...fieldsValue,
        pageNo: getSessionStorage('giftListCurrent') * 1 || this.props.page,
        pageSize: getSessionStorage("giftListPageSize") * 1 || this.props.pageSize,
      });
    });
  };

  toggleForm = () => {
    this.setState({
      expandForm: !this.state.expandForm
    })
  };

  handleChange = current => {
    setSessionStorage("giftListCurrent", current);
    this.props.dispatch({
      type: 'gift/fetch',
      payload: {
        pageSize: getSessionStorage("giftListPageSize") * 1 || this.props.pageSize,
        pageNo: current
      }
    })
  };

  handleSizeChange = (current, size) => {
    setSessionStorage("giftListCurrent", current);
    setSessionStorage("giftListPageSize", size);
    this.props.dispatch({
      type: 'gift/fetch',
      payload: {
        pageSize: size,
        page: current
      }
    })
  };

  handleDetail = id => {
    this.props.dispatch({
      type: 'gift/redirectDetail',
      payload: {
        id: id,
        // siteId: parse(this.props.location.search.substr(1)).id
      }
    })
  };

  handleCreate = () => {
    this.props.dispatch({
      type: 'gift/add',
      payload: {
        id: parse(this.props.location.search.substr(1)).id
      }
    })
  };

  renderForm() {
    return this.state.expandForm ? this.renderAdvancedForm() : this.renderSimpleForm()
  }

  renderSimpleForm() {
    const {getFieldDecorator} = this.props.form;
    const siteName = getSessionStorage('giftListFilterSiteName');
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col md={6} sm={24}>
            <FormItem label="礼品名称">
              {getFieldDecorator('name', {})(
                <Input placeholder="请输入礼品名称"/>
              )}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <FormItem label="所属聚点">
              {getFieldDecorator('gatheringName')(<Input placeholder="请输入聚点名称"/>)}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <FormItem label="所属商户">
              {getFieldDecorator('siteName', {
                initialValue: siteName || ''
              })(<Input placeholder="请输商户名称"/>)}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
              <Button style={{marginLeft: 8}} icon="download" onClick={this.handleExport}>
                导出表格
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    )
  }

  onSelectChange = (selectedRowKeys) => {
    this.setState({selectedRowKeys});
  };

  handleDelete = (id) => {
    const {selectedRowKeys} = this.state;
    let ids = [];
    if (selectedRowKeys.length) {
      ids = selectedRowKeys;
    } else {
      ids.push(id);
    }
    this.props.dispatch({
      type: 'gift/delete',
      payload: {
        ids,
        // siteId: parse(this.props.location.search.substr(1)).id,
        // columns: [{
        //   name: 'site.id',
        //   relation: 'EQ',
        //   search: parse(this.props.location.search.substr(1)).id,
        //   type: 'T_STRING'
        // }]
      }
    })
  };

  handleTableChange = (pagination, filters, sorter) => {
    // e.preventDefault();
    const {form} = this.props;
    // // setSessionStorage('giftListCurrent', 1);
    // form.validateFields((err, fieldsValue) => {
    //   if (err) return;
    //   // sessionStorage.setItem('giftListFilterSiteName',fieldsValue.siteName);
    //   this.fetch({
    //     ...fieldsValue,
    //     pageNo: getSessionStorage('giftListCurrent') * 1 || this.props.page,
    //     pageSize: getSessionStorage("giftListPageSize") * 1 || this.props.pageSize,
    //   });
    // });

    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;
    setSessionStorage("giftListCurrent", current);
    setSessionStorage("giftListPageSize", pageSize);
    form.validateFields((err, fieldsValue) => {
      this.fetch({
        ...fieldsValue,
        page: current,
        pageSize,
        columns,
        order,
        siteId: parse(this.props.location.search.substr(1)).id
      })
    })
  };
  handleStatus = (id) => {
    const {page, pageSize, dispatch} = this.props;
    console.log(this.props);
    this.props.dispatch({
      type: 'gift/updateStatus',
      payload: {
        id,
        page,
        pageSize
      }
    })
  };

  handleExport = (e) => {
    e.preventDefault();
    const {form, page, pageSize} = this.props;
    form.validateFields(['name', 'siteName', 'gatheringName'], (err, fieldsValue) => {
      // if (err) return;
      // this.setState({
      //   formValues: fieldsValue,
      // });
      // const values = {
      //   ...fieldsValue,
      // };
      // const columns = searchTable(values);
      // if (this.state.filters && this.state.filters.columns) {
      //   this.state.filters.columns.map((item) => {
      //     columns.push({
      //       ...item
      //     });
      //   });
      // }
      //http://192.168.10.111:8082
      // http://test.admin.seemore.club/api
      //API
      // ApiPostDownloadFile('/api/v1/export/souvenir', {
      ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/souvenir', {
      // ApiPostDownloadFile('/api/v1/export/souvenir', {
        ...fieldsValue,
        // order: this.state.filters.order,
        pageNo: page,
        pageSize: getSessionStorage('giftListPageSize') * 1 || pageSize,
      })
    })
  };

  render() {
    const {
      list,
      loading,
      handleDetail,
      pageSize,
      current,
      handleSizeChange,
      total,
      handleDelete,
    } = this.props;

    const {selectedRowKeys} = this.state;

    const Info = ({title, value, bordered}) => (
      <div className={styles.headerInfo}>
        <span>{title}</span>
        <p>{value}</p>
        {bordered && <em/>}
      </div>
    );

    const extraContent = (
      <div className={styles.extraContent}>
        <Button icon="plus" type="primary" onClick={this.handleCreate}>
          新建礼品
        </Button>
      </div>
    );

    const pagination = {
      pageSize: getSessionStorage('giftListPageSize') * 1 || pageSize,
      current: getSessionStorage('giftListCurrent') * 1 || current,
      total: total,
      showSizeChanger: true,
    };

    const rowSelection = {
      selectedRowKeys,
      onChange: this.onSelectChange,
    };

    const columns = [
      // {
      //   title:'礼物序号',
      //   dataIndex:'number',
      //   sorter: true
      // },
      {
        title: '礼物编号',
        dataIndex: 'id',
        key: 'id'
      },
      {
        title: '礼物名称',
        dataIndex: 'name',
      },
      {
        title: '礼物单价',
        dataIndex: 'money',
      },
      {
        title: '礼物库存',
        dataIndex: 'number',
      },
      {
        title: '礼物简介',
        dataIndex: 'introduce',
      },
      {
        title: '礼物领取方式',
        dataIndex: 'method',
        // render: (text, record) => (
        //   <span>
        //     {record.method === 'TAKE' ? '用户自提' : record.method === 'SEND' ? '场内派送' : record.method === 'EXPRESS' ? '快递配送' : record.method === 'ELECTRONIC_CODE' ? '电子券码' : null}
        //   </span>
        // )
      },
      {
        title: '所属商户',
        dataIndex: 'siteName',
        key: 'siteName'
      },
      {
        title: '所属聚点',
        dataIndex: 'gatheringName',
        key: 'gatheringName'
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            <a onClick={this.handleDetail.bind(null, record.id)}>详情</a>
            <Divider type="vertical"/>
            <a onClick={this.handleStatus.bind(null, record.id)}>{record.status ? '下架' : '上架'}</a>
            <Divider type="vertical"/>
            <Popconfirm placement="top" onConfirm={this.handleDelete.bind(null, record.id)} title='确定要删除吗？' okText="确定"
                        cancelText="取消"><a>删除</a></Popconfirm>
          </span>
        )
      }
    ];


    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Card
            className={styles.listCard}
            bordered={false}
            title="礼品列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 32px 40px 32px'}}
            extra={extraContent}
          >
            <Table
              bordered
              loading={loading}
              rowKey={record => record.id}
              columns={columns}
              dataSource={list}
              pagination={pagination}
              // rowSelection={rowSelection}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    )
  }
}
