import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {parse} from 'qs';
import {
  Table,
  Form,
  Card,
  Row,
  Col,
  Radio,
  Input,
  Button,
  Icon,
  Select,
  DatePicker,
  Popconfirm,
  Divider
} from 'antd';
import styles from './PayList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {
  setSessionStorage,
  getSessionStorage,
  sortTable,
  searchTable,
  removeSessionStorage,
  ApiPostDownloadFile
} from '../../utils/utils';

const FormItem = Form.Item;
const {Option} = Select;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const {Search} = Input;
const {RangePicker} = DatePicker;

@connect(({svip, loading}) => ({
  list: svip.list,
  loading: loading.models.svip,
  page: svip.page,
  pageSize: svip.pageSize,
  total: svip.total,
}))
@Form.create()
export default class IntegralApply extends PureComponent {

  state = {
    filters: {},
    order: [
      {
        "direction": "DESC",
        "property": "createDate"
      }
    ]
  };

  fetch = (payload) => {
    this.props.dispatch({
      type: 'svip/fetchIntegralApply',
      payload: {
        ...payload,
      },
    });
  };

  componentDidMount() {
    const {page, pageSize} = this.props;
    this.fetch({
      page,
      pageSize: getSessionStorage("cashListPageSize") * 1 || pageSize,
    });
  }

  componentWillUnmount() {
    removeSessionStorage("cashListCurrent");
    removeSessionStorage("cashListPageSize");
  }

  handleDateChange = (date, dateStr) => {
    this.setState({
      filters: {
        startTime: dateStr[0],
        endTime: dateStr[1]
      }
    })
  };

  handleFormReset = () => {
    const {form} = this.props;
    this.state.filters = {};
    form.resetFields();
  };

  renderForm() {
    return this.renderSimpleForm();
  }

  handleSearch = e => {
    e.preventDefault();
    const {form} = this.props;
    form.validateFields(['searchType', 'searchVal'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };
      var columns = [];
      if (values.searchType === 'APPLYUSERNAME' && values.searchVal) {
        columns = [{
          "name": 'consumer.nickName',
          "relation": 'LIKE',
          "search": values.searchVal || '',
        }]
      } else if (values.searchType === 'PHONE') {
        columns = [{
          "name": 'consumer.username',
          "relation": 'LIKE',
          "search": values.searchVal || '',
        }]
      } else if (values.searchType === 'ALIPAY') {
        columns = [{
          "name": 'alipayPhone',
          "relation": 'LIKE',
          "search": values.searchVal || '',
        }]
      }
      this.setState({
        filters: {
          columns
        },
      });
      this.fetch({
        columns,
        order: this.state.filters.order,
        startTime: this.state.filters.startTime,
        endTime: this.state.filters.endTime,
        page: 1,
        pageSize: getSessionStorage("cashListPageSize") * 1 || this.props.pageSize,
      });
    });
  };

  handleTableChange = (pagination, filters, sorter) => {
    const {form} = this.props;
    let values = null;
    form.validateFields(['phone'], (err, fieldsValue) => {
      if (err) return;

      values = {
        ...fieldsValue,
      };
    });
    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;
    this.setState({
      filters: {
        columns,
        // order,
      }
    });
    if (values) {
      Object.keys(values).map((item) => {
        if (values[item]) {
          columns.push({
            name: item,
            relation: "LIKE",
            search: values[item],
          })
        }
      });
    }

    setSessionStorage("cashListCurrent", current);
    setSessionStorage("cashListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order,
    });
  };

  handleExport = (e) => {
    e.preventDefault();
    const {columns} = this.state.filters;
    console.log(columns);
    // console.log(this.props);
    const {pageSize} = this.props;
    //API
    // ApiPostDownloadFile('/api/v1/export/integralApply', {
    ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/integralApply', {
      columns,
      order: this.state.order,
      pageNo: getSessionStorage('cashListCurrent') * 1 || 1,
      pageSize: getSessionStorage('cashListPageSize') * 1 || pageSize,
    });
  }

  handleDetail = (id) => {
    window.open(window.location.origin + '#/comsumerProfile' + id)
  };

  renderForm() {
    return this.renderSimpleForm();
  }

  renderConfirm(record) {
    return (<Popconfirm placement="top" title='确认打款' onConfirm={this.handleConfirm.bind(null, record)} okText="确定"
                        cancelText="取消"><a>确认打款</a></Popconfirm>);
  }

  handleConfirm = record => {
    const {id} = record
    this.props.dispatch({
      type: 'svip/confirm',
      payload: {
        id,
        status: 1,
        pageNo: getSessionStorage('cashListCurrent') * 1 || 1,
        pageSize: getSessionStorage('cashListPageSize') * 1 || this.props.pageSize,
      }
      //  0未处理，1已处理
    })
  };

  renderSimpleForm() {
    const {getFieldDecorator} = this.props.form;
    const Option = Select.Option;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col md={3} sm={24}>
            <FormItem>
              {getFieldDecorator('searchType', {
                initialValue: 'APPLYUSERNAME'
              })(
                <Select
                  onChange={this.handleChange}
                >
                  <Option value="APPLYUSERNAME" type='option'>钻石伙伴名称</Option>
                  <Option value="PHONE" type='option'>注册手机</Option>
                  <Option value="ALIPAY" type='option'>支付宝账号</Option>
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <FormItem>
              {getFieldDecorator('searchVal',)(
                <Input placeholder="请输入查询内容" onKeyUp={this.dataBind}/>
              )}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <FormItem>
              {getFieldDecorator('date',)(
                <RangePicker
                  onChange={this.handleDateChange}
                  showTime={{
                    hideDisabledOptions: true,
                    defaultValue: [moment('06:00:00', 'HH:mm:ss'), moment('06:00:00', 'HH:mm:ss')],
                  }}
                  format="YYYY-MM-DD HH:mm:ss"
                />
              )}
            </FormItem>

          </Col>
          <Col md={8} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  };

  render() {
    const {
      list,
      loading,
      total,
      page,
      pageSize,
    } = this.props;

    const pagination = {
      pageSize: getSessionStorage("cashListPageSize") * 1 || pageSize,
      current: getSessionStorage("cashListPage") * 1 || page,
      total: total,
      showSizeChanger: true,
    };

    const columns = [
      // {
      //   title: '序号',
      //   dataIndex: 'id',
      //   render: (text, record, index) => (
      //     <span>
      //       { index + 1 + (page-1)*pageSize }
      //     </span>
      //   ),
      // },
      {
        title: '钻石伙伴名称',
        dataIndex: 'applyUsername',
        key: 'applyUsername',
      },
      {
        title: '注册手机',
        dataIndex: 'applyPhone',
        key: 'applyPhone',
      },
      {
        title: '兑换积分数量',
        dataIndex: 'num',
        key: 'num',
      },
      {
        title: '支付宝账号',
        dataIndex: 'alipayPhone',
        key: 'alipayPhone',
      },
      {
        title: '支付宝名称',
        dataIndex: 'alipayName',
        key: 'alipayName',
      },
      {
        title: '申请时间',
        dataIndex: 'createDate',
        key: 'createDate',
      },
      {
        title: '状态',
        dataIndex: 'status',
        key: 'status',
        render: (text, record) => (
          <span>
            {record.status ? '已处理' : '未处理'}
          </span>
        )
      },
      {
        title: '打款时间',
        dataIndex: 'lastUpdateDate',
        key: 'lastUpdateDate',
      },
      {
        title: '操作',
        render: (text, record) => (
          <span>
            {
              record.status === 1 ? '' : this.renderConfirm(record)
            }
          </span>
        ),
      },
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Card
            className={styles.listCard}
            bordered={false}
            title="积分兑现列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 32px 40px 32px'}}
          >
            <div className={styles.tableListOperator}>
              <Button icon="download" onClick={this.handleExport}>
                导出表格
              </Button>
            </div>
            <Table
              bordered
              loading={loading}
              rowKey='id'
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
