import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {
  Card,
  Row,
  Col,
  Radio,
  Input,
  Button,
  Icon,
  Modal,
  Divider,
  Popconfirm,
  Upload,
  Table,
  Form,
} from 'antd';

import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {
  setSessionStorage,
  getSessionStorage,
  removeSessionStorage,
  sortTable,
  searchTable,
  getLocalStorage,
  ApiPostDownloadFile,
} from '../../utils/utils';

import styles from './SystemList.less';

const FormItem = Form.Item;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const {Search} = Input;

@connect(({label, loading}) => ({
  loading: loading.models.label,
  submitting: loading.effects['label/submit'],
  list: label.list,
  label: label.label,
  pageSize: label.pageSize,
  page: label.page,
  total: label.total,
  all: label.all,
}))
@Form.create()
export default class LabelList extends PureComponent {

  state = {
    addModal: false,
    editModal: false,
    name: '',
    id: '',
    formValues: {},
    filters: {},
  };

  fetch = (payload) => {
    this.props.dispatch({
      type: 'label/fetch',
      payload: {
        ...payload,
      },
    });
  };

  componentDidMount() {
    this.fetch({
      page: getSessionStorage("labelListCurrent") * 1 || this.props.page,
      pageSize: getSessionStorage("labelListPageSize") * 1 || this.props.pageSize,
    });
  }

  componentWillUnmount() {
    removeSessionStorage("labelListCurrent");
    removeSessionStorage("labelListPageSize");
  }

  handleExport = (e) => {
    e.preventDefault();
    const {form, page, pageSize} = this.props;
    form.validateFields(['name'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };
      const columns = searchTable(values);
      if (this.state.filters && this.state.filters.columns) {
        this.state.filters.columns.map((item) => {
          columns.push({
            ...item,
          });
        });
      }
      //http://192.168.10.111:8082
      //API
      // ApiPostDownloadFile('/api/v1/export/tag', {
      ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/tag', {
        columns,
        order: this.state.filters.order,
        pageNo: page,
        pageSize: getSessionStorage('labelListPageSize') * 1 || pageSize,
      });
    });
  };

  check = (rule, value, callback) => {
    const form = this.props.form;
    if (value && value.indexOf("#") > -1) {
      callback('标签名称不能包含#！');
    } else {
      callback();
    }
  };

  handleAddSubmit = (e) => {
    e.preventDefault();
    const {form} = this.props;
    form.validateFields(['addName'], (err, fieldsValue) => {
      if (err) return;
      const values = {
        ...fieldsValue,
      };
      this.handleFormReset();
      this.setState({
        addModal: false,
      });
      this.props.dispatch({
        type: 'label/addSubmit',
        payload: {
          "name": values.addName,
          page: 1,
          pageSize: getSessionStorage("labelListPageSize") * 1 || this.props.pageSize,
        },
      });
    });
  };

  handleEditSubmit = (e) => {
    e.preventDefault();
    const {form} = this.props;
    form.validateFields(['editName'], (err, fieldsValue) => {
      if (err) return;

      const values = {
        ...fieldsValue,
      };
      this.setState({
        editModal: false,
      });
      this.handleFormReset();
      this.props.dispatch({
        type: 'label/submit',
        payload: {
          "name": values.editName,
          "id": this.state.id,
          "page": getSessionStorage("labelListPageSize") * 1 || this.props.page,
          "pageSize": getSessionStorage("labelListPageSize") * 1 || this.props.pageSize,
        },
      });
    });
  };

  handleAddShow = () => {
    this.setState({
      addModal: true,
    });
  };

  handleAddHideModal = () => {
    this.setState({
      addModal: false,
    });
    this.handleFormReset();
  };

  handleEditShow = (record) => {
    this.setState({
      editModal: true,
      id: record.id,
    });
    this.props.dispatch({
      type: 'label/fetchProfile',
      payload: {
        id: record.id,
      }
    });
  };

  handleEditHideModal = () => {
    this.setState({
      editModal: false,
    });
    this.handleFormReset();
  };

  handleDelete = (record) => {
    this.props.dispatch({
      type: 'label/delete',
      payload: {
        id: record.id,
        page: getSessionStorage("labelListCurrent") || this.props.page,
        pageSize: getSessionStorage("labelListPageSize") || this.props.pageSize,
      },
    });
  };

  handleRecovery = (record) => {
    this.props.dispatch({
      type: 'label/recovery',
      payload: {
        id: record.id,
        "page": getSessionStorage("labelListCurrent") * 1 || this.props.page,
        "pageSize": getSessionStorage("labelListPageSize") * 1 || this.props.pageSize,
      },
    });
  };

  handleChange = (current) => {
    setSessionStorage("labelListCurrent", current);
    this.props.dispatch({
      type: 'label/fetchChange',
      payload: {
        pageSize: getSessionStorage("labelListPageSize") || this.props.pageSize,
        current: current,
      },
    });
  };

  handleSizeChange = (current, size) => {
    setSessionStorage("labelListCurrent", current);
    setSessionStorage("labelListPageSize", size);
    this.props.dispatch({
      type: 'label/fetchChange',
      payload: {
        pageSize: size,
        current: current,
      },
    });
  };

  handleFormReset = () => {
    const {form} = this.props;
    form.resetFields();
  };

  handleSearch = e => {
    e.preventDefault();
    const {form} = this.props;
    form.validateFields(['name'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };
      const columns = searchTable(values);
      if (this.state.filters && this.state.filters.columns) {
        this.state.filters.columns.map((item) => {
          columns.push({
            ...item,
          });
        });
      }
      this.fetch({
        columns,
        order: this.state.filters.order,
        pageNo: 1,
        pageSize: getSessionStorage("labelListPageSize") * 1 || this.props.pageSize,
      });
    });
  };

  renderEditModal() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="标签名称" {...formItemLayout}>
          {getFieldDecorator('editName', {
            initialValue: this.props.label && this.props.label.name,
            rules: [{
              max: 10,
              message: '标签名称最多10个字符',
            }, {
              required: true,
              message: '请输入标签名称',
            }],
          })(<Input placeholder="请输入标签名称，最多10个字符。"/>)}
        </FormItem>
      </Form>
    );
  }

  renderAddModal() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="标签名称" {...formItemLayout}>
          {getFieldDecorator('addName', {
            rules: [{
              max: 10,
              message: '标签名称最多10个字符',
            }, {
              required: true,
              message: '请输入标签名称',
            },
              {validator: this.check},
            ],
          })(<Input placeholder="请输入标签名称，最多10个字符。"/>)}
        </FormItem>
      </Form>
    );
  }

  renderDelete = (record) => {
    return (
      <Popconfirm placement="leftTop" title='确定要删除吗？' onConfirm={this.handleDelete.bind(null, record)} okText="确定"
                  cancelText="取消">
        <a>删除</a>
      </Popconfirm>
    );
  };

  renderRecovery = (record) => {
    return (
      <Popconfirm placement="leftTop" title='确定要恢复吗？' onConfirm={this.handleRecovery.bind(null, record)} okText="确定"
                  cancelText="取消">
        <a>恢复</a>
      </Popconfirm>
    );
  };

  handleTableChange = (pagination, filters, sorter) => {
    const {form} = this.props;
    let values = null;
    form.validateFields(['name'], (err, fieldsValue) => {
      if (err) return;

      values = {
        ...fieldsValue,
      };
    });
    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;
    this.setState({
      filters: {
        columns,
        order,
      }
    });
    if (values) {
      Object.keys(values).map((item) => {
        if (values[item]) {
          columns.push({
            name: item,
            relation: "LIKE",
            search: values[item],
          })
        }
      });
    }

    setSessionStorage("labelListCurrent", current);
    setSessionStorage("labelListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order,
    });
  };

  renderForm() {
    return this.renderSimpleForm();
  }

  renderSimpleForm() {
    const {getFieldDecorator} = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col md={8} sm={24}>
            <FormItem label="标签名称">
              {getFieldDecorator('name')(<Input placeholder="请输入标签名称"/>)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  render() {
    const {
      loading,
      submitting,
      list,
      total,
      pageSize,
      page,
    } = this.props;
    const {addModal, editModal} = this.state;
    const pagination = {
      pageSize: getSessionStorage("labelListPageSize") * 1 || pageSize,
      current: getSessionStorage("labelListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const columns = [
      {
        title: '序号',
        dataIndex: 'id',
        render: (text, record, index) => (
          index + 1 + (page - 1) * pageSize
        ),
      },
      {
        title: '标签名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '创建时间',
        dataIndex: 'createDate',
        render: (text, record) => (
          record.createDate && moment(record.createDate).format('YYYY-MM-DD HH:mm:ss')
        ),
        sorter: true,
      },
      {
        title: '使用次数',
        dataIndex: 'count',
        sorter: true,
      },
      {
        title: '状态',
        dataIndex: 'discard',
        filters: [
          {
            text: '正常',
            value: false,
          },
          {
            text: '已删除',
            value: true,
          },
        ],
        filterMultiple: false,
        render: (text, record) => (
          <span>
          {record.discard ? '已删除' : '正常'}
          </span>
        ),
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            {record.discard ? '' : <a onClick={this.handleEditShow.bind(null, record)}>修改</a>}
            {/*<a onClick={this.handleEditShow.bind(null, record)}>修改</a>*/}
            <Divider type="vertical"/>
            {record.discard ? '' : this.renderDelete(record)}
          </span>
        ),
      },
    ];

    const uploadProps = {
      action: 'http://192.168.10.251:8082/api/upload',
      listType: 'picture',
      name: 'avatar',
    };

    return (
      <PageHeaderLayout>
        <div className={styles.tableListForm}>{this.renderForm()}</div>
        <div className={styles.standardList}>
          <Modal
            title="新建标签"
            visible={addModal}
            onOk={this.handleAddSubmit}
            onCancel={this.handleAddHideModal}
            okText="确认"
            cancelText="取消"
            confirmLoading={submitting}
          >
            {this.renderAddModal()}
          </Modal>
          <Modal
            title="修改标签"
            visible={editModal}
            onOk={this.handleEditSubmit}
            onCancel={this.handleEditHideModal}
            okText="确认"
            cancelText="取消"
            confirmLoading={submitting}
          >
            {this.renderEditModal()}
          </Modal>
          <Card
            className={styles.listCard}
            bordered={false}
            title="标签管理，用EXCEL表格导入和导出标签"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 40px 32px'}}
          >
            <div style={{marginBottom: '20px'}}>
              <Button icon="download" onClick={this.handleExport}>
                导出表格
              </Button>
              <Button icon="plus" style={{marginLeft: '8px'}} type="primary" onClick={this.handleAddShow}>
                新增标签
              </Button>
              {/*<Upload {...uploadProps}>*/}
              {/*<Button style={{marginLeft: '8px'}}>*/}
              {/*<Icon type="upload" /> 导入标签*/}
              {/*</Button>*/}
              {/*</Upload>*/}
            </div>
            <Table
              bordered
              loading={loading}
              rowKey='id'
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
