import React, {PureComponent} from 'react';
import {connect} from 'dva';
import {
  Card,
  Button,
  Icon,
  Divider,
  List,
  Popconfirm,
  Tooltip,
} from 'antd';
import Lightbox from 'react-image-lightbox';
import 'react-image-lightbox/style.css';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';

import styles from './CardList.less';

@connect(({review, loading}) => ({
  list: review.list,
  loading: loading.models.review,
  nexting: loading.effects['review/fetchMore'],
  visible: review.visible,
  user: review.user,
}))

export default class NormalPhotoList extends PureComponent {

  state = {
    formValues: {},
    photoIndex: 0,
    isOpen: false,
  };

  componentDidMount() {
    this.props.dispatch({
      type: 'review/fetch',
      payload: {
        size: 30,
      },
    });
  }

  handleDelete = (record) => {
    this.props.dispatch({
      type: 'review/refuse',
      payload: {
        id: record.id,
      },
    });
  };

  handleFetch = () => {
    let list = [];
    this.props.list.map((item) => {
      list.push(item.id);
    });
    this.props.dispatch({
      type: 'review/fetchMore',
      payload: {
        size: 1,
        ids: list,
      },
    });
  };

  handleDetail = record => {
    window.open(window.location.origin + '#/comsumer/comsumerProfile?id=' + record.consumerId)
  };

  handleSearch = e => {
    e.preventDefault();
    const {dispatch, form} = this.props;

    form.validateFields((err, fieldsValue) => {
      if (err) return;

      const values = {
        ...fieldsValue,
      };

      this.setState({
        formValues: values,
      });
      dispatch({
        type: 'pay/fetch',
        payload: values,
      });
    });
  };

  handleLightBox = (record) => {
    let id = 0;
    this.props.list.map((item, index) => {
      if (item.id === record.id) {
        id = index;
      }
    });
    this.setState({
      isOpen: true,
      photoIndex: id,
    });
  };

  handleClose = () => {
    this.setState({
      isOpen: false,
    });
  };

  fetchImg = (arr) => {
    let res = [];
    arr.map(item => {
      res.push(item.pic);
    });
    return res;
  };

  render() {
    const {
      list,
      loading,
      photoTotal,
      nexting,
    } = this.props;
    const {photoIndex, isOpen} = this.state;
    const imagesList = this.fetchImg(list);
    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <Card
            className={styles.listCard}
            bordered={false}
            title="相册审核"
            style={{marginTop: 24}}
            bodyStyle={{padding: '32px 40px 32px'}}
          >
            <div className={styles.cardList}>
              <List
                rowKey="id"
                loading={loading}
                grid={{gutter: 24, lg: 6, sm: 2, xs: 1}}
                dataSource={list}
                renderItem={(item) =>
                  (
                    <List.Item key={item.id}>
                      <Card style={{width: 180, boxSizing: 'content-box'}}
                            hoverable
                            bodyStyle={{padding: 0}}
                            className={styles.card}
                            actions={[
                              <Tooltip placement="topLeft" title="查看用户详情" arrowPointAtCenter>
                                <a onClick={this.handleDetail.bind(null, item)}>
                                  <Icon style={{fontSize: '20px'}} type="user"/>
                                </a>
                              </Tooltip>,
                              <Tooltip onClick={this.handleDelete.bind(null, item)} placement="topLeft" title="删除该图片"
                                       arrowPointAtCenter>
                                <a style={item.disabled ? {cursor: 'not-allow'} : {cursor: 'pointer'}}>
                                  {/*<Icon style={{fontSize: '20px'}} type="delete"/>*/}
                                  X
                                </a>
                              </Tooltip>
                            ]}
                            cover={
                              <Tooltip placement="topLeft" title="查看高清图片" arrowPointAtCenter>
                                <img onClick={() => this.handleLightBox(item)} alt="用户头像" src={item.pic}
                                     style={{height: '180px', width: '180px'}}/>
                              </Tooltip>}
                      >
                      </Card>
                    </List.Item>
                  )
                }
              />
              <div className={styles.pagination}>
                <Button loading={nexting} type="primary" onClick={this.handleFetch}>
                  下一组<Icon type="right"/>
                </Button>
              </div>
            </div>
          </Card>
          {isOpen && (
            <Lightbox
              mainSrc={imagesList[photoIndex]}
              onCloseRequest={this.handleClose}
            />
          )}
        </div>
      </PageHeaderLayout>
    );
  }
}
