import React, {PureComponent} from 'react';
import {connect} from 'dva';
import {
  Form,
  Card,
  Input,
  Button,
  Icon,
  List,
  Divider,
  Tooltip,
  Popconfirm,
} from 'antd';
import Lightbox from 'react-image-lightbox';
import 'react-image-lightbox/style.css';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import styles from './NormalUserList.less';

const FormItem = Form.Item;
const {Search} = Input;
const {Meta} = Card;
@connect(({review, loading}) => ({
  list: review.list,
  loading: loading.models.review,
  submitting: loading.effects['review/delete'],
  nexting: loading.effects['review/fetchMoreUser'],
  visible: review.visible,
  user: review.user,
}))
@Form.create()
export default class NormalUsers extends PureComponent {

  state = {
    expandForm: false,
    formValues: {},
    isOpen: false,
    photoIndex: 0,
  };

  componentDidMount() {
    this.props.dispatch({
      type: 'review/fetchWaitList',
      payload: {
        columns: [{
          name: 'status',
          relation: 'EQ',
          search: 'WAIT',
          type: "T_STRING",
        }],
        pageSize: 30,
      }
    });
  }

  handleFail = (id) => {
    this.props.dispatch({
      type: 'review/delete',
      payload: {
        id,
      },
    });
  }

  handleFetch = () => {
    let list = [];
    this.props.list.map((item) => {
      list.push(item.id);
    });
    this.props.dispatch({
      type: 'review/fetchWaitList',
      payload: {
        columns: [{
          name: 'status',
          relation: 'EQ',
          search: 'WAIT',
          type: "T_STRING",
        }],
        pageSize: 30,
        ids: list,
        // status: 'WAIT',
      },
    });
  };

  handleDetail = record => {
    window.open(window.location.origin + '#/comsumer/comsumerProfile?id=' + record.id)
  };

  handleSearch = e => {
    e.preventDefault();
    const {dispatch, form} = this.props;

    form.validateFields((err, fieldsValue) => {
      if (err) return;

      const values = {
        ...fieldsValue,
      };

      this.setState({
        formValues: values,
      });
      dispatch({
        type: 'pay/fetch',
        payload: values,
      });
    });
  };

  toggleForm = () => {
    this.setState({
      expandForm: !this.state.expandForm,
    });
  };

  handleClose = () => {
    this.setState({
      isOpen: false,
    });
  };

  fetchImg = (arr) => {
    let res = [];
    arr.map(item => {
      res.push(item.photo);
    });
    return res;
  };

  handleLightBox = (record) => {
    let id = 0;
    this.props.list.map((item, index) => {
      if (item.id === record.id) {
        id = index;
      }
    });
    this.setState({
      isOpen: true,
      photoIndex: id,
    });
  };

  render() {
    const {
      list,
      loading,
      user,
      visible,
      submitting,
      nexting,
    } = this.props;
    const {photoIndex, isOpen} = this.state;

    const images = this.fetchImg(list);

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <Card
            className={styles.listCard}
            bordered={false}
            title="修改后审核"
            style={{marginTop: 24}}
            bodyStyle={{padding: '32px 40px'}}
          >
            <List
              rowKey="id"
              loading={loading}
              grid={{gutter: 24, lg: 6, sm: 2, xs: 1}}
              dataSource={list}
              renderItem={(item) =>
                (
                  <List.Item key={item.id}>
                    <Card
                      hoverable
                      className={styles.card}
                      actions={[<Tooltip placement="topLeft" title="查看用户详情" arrowPointAtCenter><a
                        onClick={this.handleDetail.bind(null, item)}><Icon style={{fontSize: '20px'}} type="user"/></a></Tooltip>,
                          <Tooltip placement="topLeft" title="不通过" arrowPointAtCenter onClick={this.handleFail.bind(null, item.id)}>
                            <a style={item.disabled ? {cursor: 'not-allow'} : {cursor: 'pointer'}}>
                              {/*<Icon style={{fontSize: '20px'}} type="delete"/>*/}
                              X
                            </a>
                          </Tooltip>
                      ]}
                      cover={<Tooltip placement="topLeft" title="查看高清图片" arrowPointAtCenter><img
                        onClick={() => this.handleLightBox(item)} alt="用户头像" src={item.photo}
                        style={{height: '200px', width: '100%'}}/></Tooltip>}
                    >
                      <Meta
                        title={item.nickName ? item.nickName : '用户未设置'}
                      />
                    </Card>
                  </List.Item>
                )
              }
            />
            <div className={styles.pagination}>
              <Button loading={nexting} type="primary" onClick={this.handleFetch}>
                下一组<Icon type="right"/>
              </Button>
            </div>
          </Card>
          {isOpen && (
            <Lightbox
              mainSrc={images[photoIndex]}
              onCloseRequest={this.handleClose}
            />
          )}
        </div>
      </PageHeaderLayout>
    );
  }
}
