import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {
  Table,
  Form,
  Card,
  Row,
  Col,
  Radio,
  Input,
  Button,
  Icon,
  Select,
  DatePicker,
} from 'antd';
import styles from './PayList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {
  setSessionStorage,
  getSessionStorage,
  sortTable,
  searchTable,
  removeSessionStorage,
  ApiPostDownloadFile
} from '../../utils/utils';

const FormItem = Form.Item;
const {Option} = Select;
const {RangePicker} = DatePicker;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const {Search} = Input;

@connect(({pay, loading}) => ({
  list: pay.list,
  loading: loading.models.pay,
  page: pay.page,
  pageSize: pay.pageSize,
  total: pay.total,
}))
@Form.create()
export default class PayList extends PureComponent {

  state = {
    filters: {},
    order: [
      {
        "direction": "DESC",
        "property": "lastUpdateDate"
      }
    ],
  };

  fetch = (payload) => {
    this.props.dispatch({
      type: 'pay/fetch',
      payload: {
        ...payload,
      },
    });
  };

  componentDidMount() {
    this.fetch({
      page: getSessionStorage("payListCurrent") * 1 || this.props.page,
      pageSize: getSessionStorage("payListPageSize") * 1 || this.props.pageSize,
    });
  }

  componentWillUnmount() {
    removeSessionStorage("payListCurrent");
    removeSessionStorage("payListPageSize");
  }

  handleFormReset = () => {
    const {form} = this.props;
    this.setState({
      filters:{}
    });
    form.resetFields();
  };

  renderForm() {
    return this.renderSimpleForm();
  }

  handleSearch = e => {
    e.preventDefault();
    const {form} = this.props;
    form.validateFields(['siteName', 'payType', 'type'], (err, fieldsValue) => {
      if (err) return;

      this.setState({
        formValues: fieldsValue,
      });

      const values = {
        ...fieldsValue,
      };

      let columns = [];
      Object.keys(fieldsValue).forEach((item) => {
        if (item === 'siteName' && values[item]) {
          columns.push({
            "name": 'site.name',
            "relation": 'LIKE',
            "search": fieldsValue[item],
          });
        } else if (values[item]) {
          columns.push({
            "name": item,
            "relation": 'EQ',
            "search": fieldsValue[item],
          });
        }
      });

      this.setState({
        filters: {
          columns,
          startTime: this.state.filters.startTime,
          endTime: this.state.filters.endTime
        }
      });

      // if (this.state.filters && this.state.filters.columns) {
      //   this.state.filters.columns.map((item) => {
      //     columns.push({
      //       ...item,
      //     });
      //   });
      // }
      this.fetch({
        columns,
        order: this.state.order,
        page: 1,
        startTime: this.state.filters.startTime,
        endTime: this.state.filters.endTime,
        pageSize: getSessionStorage("labelListPageSize") * 1 || this.props.pageSize,
      });
    });
  };

  handleTableChange = (pagination, filters, sorter) => {
    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;

    setSessionStorage("payListCurrent", current);
    setSessionStorage("payListPageSize", pageSize);
    this.fetch({
      columns: this.state.filters.columns || columns,
      page: current,
      pageSize,
      order,
    });
  };

  handleExport = (e) => {
    e.preventDefault();
    const {form, pageSize} = this.props;
    form.validateFields(['nickName'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };
      const columns = searchTable(values);
      if (this.state.filters && this.state.filters.columns) {
        this.state.filters.columns.map((item) => {
          columns.push({
            ...item,
          });
        });
      }
      //API
      // ApiPostDownloadFile('/api/v1/export/orderRecord', {
      ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/orderRecord', {
        order: this.state.order,
        columns: this.state.filters.columns,
        page: getSessionStorage('payListCurrent') * 1 || pageSize,
        pageSize: getSessionStorage('payListPageSize') * 1 || pageSize,
        startTime: this.state.filters.startTime,
        endTime: this.state.filters.endTime,
      });
    });
  };

  handleDetail = (id) => {
    window.open(window.location.origin + '#/comsumerProfile' + id)
  };

  renderSimpleForm() {
    const {getFieldDecorator} = this.props.form;
    const Option = Select.Option;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col md={7} sm={24}>
            <FormItem label="场所名称">
              {getFieldDecorator('siteName')(<Input placeholder="请输入场所名称"/>)}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <FormItem label="支付方式">
              {getFieldDecorator('payType')(
                <Select
                  // style={{width: '120px', float: 'left', marginRight: '10px'}}
                  // onChange={this.handleChange}
                  placeholder="请选择支付方式">
                  <Option value="WECHART" type='option'>微信</Option>
                  <Option value="ALIPAY" type='option'>支付宝</Option>
                  <Option value="APPLEPAY" type='option'>苹果</Option>
                  <Option value="DIAMONDS" type='option'>心钻</Option>
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <FormItem label="消费类型">
              {getFieldDecorator('type')(
                <Select
                  // style={{width: '120px', float: 'left', marginRight: '10px'}}
                  // onChange={this.handleChange}
                  placeholder="请选择消费类型">
                  <Option value="SOUVENIR" type='option'>礼物</Option>
                  <Option value="VIP" type='option'>VIP</Option>
                  <Option value="WHISPER" type='option'>私语</Option>
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={5} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

// = (pagination, filters, sorter) =>
  handleDateChange = (date, dateStr) => {
    // console.log(date, dateStr);
    // e.preventDefault();
    const {form} = this.props;
    form.validateFields(['siteName', 'payType', 'type'], (err, fieldsValue) => {
      if (err) return;

      this.setState({
        formValues: fieldsValue,
      });

      this.setState({
        filters: {
          startTime: dateStr[0],
          endTime: dateStr[1]
        }
      })

      const values = {
        ...fieldsValue,
      };
      // console.log(values);
      let columns = [];
      Object.keys(fieldsValue).forEach((item) => {
        // console.log(item);
        if (item === 'siteName' && values[item]) {
          columns.push({
            "name": 'site.name',
            "relation": 'LIKE',
            "search": fieldsValue[item],
          });
        } else if (values[item]) {
          columns.push({
            "name": item,
            "relation": 'EQ',
            "search": fieldsValue[item],
          });
        }
      });

      if (this.state.filters && this.state.filters.columns) {
        this.state.filters.columns.map((item) => {
          columns.push({
            ...item,
          });
        });
      }
      this.fetch({
        columns,
        order: this.state.filters.order,
        page: 1,
        pageSize: getSessionStorage("payListPageSize") * 1 || this.props.pageSize,
        startTime: dateStr[0],
        endTime: dateStr[1]
      });
    });
  };

  render() {
    const {
      list,
      loading,
      total,
      page,
      pageSize,
    } = this.props;
    // console.log({page});
    const pagination = {
      pageSize: getSessionStorage("payListPageSize") * 1 || pageSize,
      total: total,
      current: page,
      showSizeChanger: true,
    };

    const columns = [
      {
        title: '流水号',
        dataIndex: 'id',
        key: 'id'
      },
      {
        title: '礼物商品名称',
        dataIndex: 'souvenirName',
        key: 'souvenirName',
      },
      {
        title: '订单时间',
        dataIndex: 'time',
        // sorter: true,
        render: (text, record) => (
          record.time && moment(record.time).format('YYYY-MM-DD HH:mm:ss')
        ),
      },
      {
        title: '订单号',
        dataIndex: 'orderNo',
        key: 'orderNo'
      },
      {
        title: '消费类型',
        dataIndex: 'type',
        key: 'type',
        // render: (text, record, index) => (
        //   text==='ACCOSTED_SUCCESS'?'购买私语':text==='SOUVENIR_SUCCESS'?'送礼成功':text==='SOUVENIR_FAIL'?'送礼失败':text==='ACCOSTED_FAIL'?'私语退还':text==='VIP_SUCCESS'?'购买会员':text
        // ),
      },
      {
        title: '订单金额',
        dataIndex: 'money',
        key: 'money',
        sorter: true,
      },
      {
        title: '支付方式',
        dataIndex: 'payType',
        key: 'payType',
        render: (text, record, index) => (
          text === 'ALIPAY' ? '支付宝' : text === 'WECHART' ? '微信' : text === 'APPLEPAY' ? '苹果支付' : text === 'DIAMONDS' ? '心钻' : text === 'FREE' ? '免费' : text
        ),
      },
      {
        title: '支付方ID',
        dataIndex: 'consumerId',
        key: 'consumerId'
      },
      {
        title: '场所名称',
        dataIndex: 'siteName',
        key: 'siteName'
      },
      {
        title: '场所ID',
        dataIndex: 'siteId',
        key: 'siteId'
      },
      // {
      //   title: '操作1',
      //   key: 'action',
      //   render: (text, record) => (
      //     <span>
      //       <a onClick={record => this.handleDetail(record.id)}>查看用户详情</a>
      //     </span>
      //   ),
      // },
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <Card
            className={styles.listCard}
            bordered={false}
            title="流水列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 32px 40px 32px'}}
          >
            <div className={styles.tableListForm}>{this.renderForm()}</div>
            <div className={styles.tableListOperator}>
              <Button icon="download" onClick={this.handleExport}>
                导出表格
              </Button>
              <RangePicker
                onChange={this.handleDateChange}
                showTime={{
                  hideDisabledOptions: true,
                  defaultValue: [moment('00:00:00', 'HH:mm:ss'), moment('00:00:00', 'HH:mm:ss')],
                }}
                format="YYYY-MM-DD HH:mm:ss"
              />
            </div>
            <Table
              bordered
              loading={loading}
              rowKey='id'
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
