import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {
  Table,
  Card,
  Button,
  Form,
  Row,
  Col,
  Input,
  Icon,
  Select,
  DatePicker,
  Divider,
  Modal,
  Popconfirm,
  Tabs,
} from 'antd';
import styles from './SystemList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {setSessionStorage, getSessionStorage} from '../../utils/utils';

const FormItem = Form.Item;
const {RangePicker} = DatePicker;
const Option = Select.Option;
const TabPane = Tabs.TabPane;
const {TextArea} = Input;
@connect(({permission, loading}) => ({
  pageList: permission.pageList,
  funcList: permission.funcList,
  loading: loading.models.permission,
  authorityPage: permission.authorityPage,
  funcPageSize: permission.funcPageSize,
  pagePageSize: permission.pagePageSize,
  funcCurrent: permission.funcCurrent,
  pageCurrent: permission.pageCurrent,
  permission: permission.permission,
  type: permission.type,
  pageTotal: permission.pageTotal,
  funcTotal: permission.funcTotal,
}))
@Form.create()
export default class PermissionList extends PureComponent {

  state = {
    expandForm: false,
    modal: false,
    startTime: null,
    endTime: null,
    confirmLoading: false,
    modalVisible: false,
    id: 0,
    addModal: false,
    prantId: 1,
    type: 'PAGE',
  }

  componentDidMount() {
    const {pagePageSize, pageCurrent, funcPageSize, funcCurrent, dispatch} = this.props;
    const type = getSessionStorage("permissionType") || this.props.type;
    let pageSize = 0;
    let page = 0;
    if (type === 'PAGE') {
      // console.log('PAGE');
      pageSize = getSessionStorage("pagePermissionListPageSize") * 1 || pagePageSize;
      page = getSessionStorage("pagePermissionListCurrent") * 1 || pageCurrent;
      dispatch({
        type: 'permission/fetchPage',
        payload: {
          columns: [
            {
              "name": 'type',
              "search": type,
              "relation": "EQ",
            },
            {
              "name": 'parent.id',
              "search": "",
              "relation": "ISNULL",
            }
          ],
          pageSize,
          page,
        },
      });
    } else {
      // console.log('METHOD');
      pageSize = getSessionStorage("funcPermissionListPageSize") * 1 || funcPageSize;
      page = getSessionStorage("funcPermissionListCurrent") * 1 || funcCurrent;
      dispatch({
        type: 'permission/fetchFunc',
        payload: {
          columns: [
            {
              "name": 'type',
              "search": type,
              "relation": "EQ",
            }
          ],
          pageSize,
          page,
        },
      });
    }
  }

  componentWillUnmount() {
    setSessionStorage("pagePermissionListPageSize", 30);
    setSessionStorage("pagePermissionListCurrent", 1);
    setSessionStorage("funcPermissionListPageSize", 30);
    setSessionStorage("funcPermissionListCurrent", 1);
  }

  handleFormReset = () => {
    const {form} = this.props;
    form.resetFields();
  };

  handleCreateChild = (record) => {
    this.setState({
      addModal: true,
      prantId: record.id,
    });
  };

  handleCreateCancel = () => {
    this.setState({
      modalVisible: false,
    })
    this.handleFormReset();
  };

  handleChildCancel = () => {
    this.setState({
      addModal: false,
    })
    this.handleFormReset();
  };

  handleEditCancel = () => {
    this.setState({
      modal: false,
    });
    this.handleFormReset();
  };

  handleCreate = () => {
    this.setState({
      modalVisible: true,
    });
  };

  handleExport() {
    console.log('点击了导出文件表格按钮');
  }

  handleFuncChange = (current) => {
    //页码改变
    //pagePermissionListCurrent
    // setSessionStorage("funcPermissionListFuncCurrent", current);
    setSessionStorage("funcPermissionListCurrent", current);
    this.props.dispatch({
      type: 'permission/fetchFunc',
      payload: {
        "columns": [
          {
            "name": 'type',
            "search": 'METHOD',
            "relation": "EQ",
          }
        ],
        pageSize: this.props.pagePageSize,
        page: current,
      },
    });
  };

  handleFuncSizeChange = (current, size) => {
    setSessionStorage("funcPermissionListCurrent", current);
    setSessionStorage("funcPermissionListPageSize", size);
    this.props.dispatch({
      type: 'permission/fetchFunc',
      payload: {
        "columns": [
          {
            "name": 'type',
            "search": 'METHOD',
            "relation": "EQ",
          }
        ],
        pageSize: size,
        page: current,
      },
    });
  };

  handlePageChange = (current) => {
    setSessionStorage("pagePermissionListCurrent", current);
    this.props.dispatch({
      type: 'permission/fetchPage',
      payload: {
        "columns": [
          {
            "name": 'type',
            "search": 'PAGE',
            "relation": "EQ",
          },
          {
            "name": 'parent.id',
            "search": "",
            "relation": "ISNULL",
          }
        ],
        pageSize: this.props.pagePageSize,
        page: current,
      },
    });
  };

  handlePageSizeChange = (current, size) => {
    setSessionStorage("pagePermissionListCurrent", current);
    setSessionStorage("pagePermissionListPageSize", size);
    const type = this.props.type;
    if (type === 'PAGE') {
      this.props.dispatch({
        type: 'permission/fetchPage',
        payload: {
          pageSize: size,
          page: current,
          columns: [
            {
              "name": 'type',
              "search": type,
              "relation": "EQ",
            },
            {
              "name": 'parent.id',
              "search": "",
              "relation": "ISNULL",
            }
          ],
        },
      });
    } else {
      this.props.dispatch({
        type: 'permission/fetchPage',
        payload: {
          pageSize: size,
          page: current,
          columns: [
            {
              "name": 'type',
              "search": type,
              "relation": "EQ",
            }
          ],
        },
      });
    }
  };

  handleSearch = e => {
    e.preventDefault();
    const {dispatch, form, pageSize} = this.props;

    form.validateFields((err, fieldsValue) => {
      // console.log(fieldsValue);
      if (err) return;

      const values = {
        ...fieldsValue,
        createdAt: {
          startTime: this.state.startTime,
          endTime: this.state.endTime,
        }
      };
      // console.log(values);
      // dispatch({
      //   type: 'authority/fetch',
      //   payload: {
      //     ...values,
      //     pageSize: pageSize,
      //     current: 1,
      //   },
      // });
    });
  };

  toggleForm = () => {
    this.setState({
      expandForm: !this.state.expandForm,
    });
  };

  handleDateChange = (date, dateString) => {
    this.setState({
      startTime: dateString[0],
      endTime: dateString[1],
    });
  }

  handleDelete = (record, type) => {
    let pageSize = 0;
    let page = 0;
    if (type === 'PAGE') {
      this.props.dispatch({
        type: 'permission/delete',
        payload: {
          id: record.id,
          pagination: {
            pageSize: getSessionStorage("pagePermissionListPageSize") * 1 || this.props.pagePageSize,
            page: getSessionStorage("pagePermissionListCurrent") * 1 || this.props.pageCurrent,
            type,
            columns: [
              {
                "name": 'type',
                "search": type,
                "relation": "EQ",
              },
              {
                "name": 'parent.id',
                "search": "",
                "relation": "ISNULL",
              }
            ],
          },
        },
      });
    } else {
      this.props.dispatch({
        type: 'permission/delete',
        payload: {
          id: record.id,
          pagination: {
            pageSize: getSessionStorage("funcPermissionListPageSize") * 1 || this.props.funcPageSize,
            page: getSessionStorage("funcPermissionListCurrent") * 1 || this.props.funcCurrent,
            type,
            columns: [
              {
                "name": 'type',
                "search": type,
                "relation": "EQ",
              }
            ],
          },
        },
      });
    }
  };

  handleCancel = () => {
    this.setState({
      modal: false,
    });
    this.handleFormReset();
  };

  handleShowModal = (record) => {
    const {id, prantId} = record;
    this.setState({
      modal: true,
      id,
      prantId,
    });
    this.props.dispatch({
      type: 'permission/fetchDetail',
      payload: {
        id,
      },
    });
  };

  // renderForm() {
  //   return this.state.expandForm ? this.renderAdvancedForm() : this.renderSimpleForm();
  // }

  renderCreateModal() {
    return this.state.modalVisible ? this.renderCreateModalForm() : '';
  }

  renderChildModal() {
    return this.renderChildModalForm();
  }

  renderIcon() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <FormItem label="资源图标" {...formItemLayout}>
        {getFieldDecorator('icon', {
          initialValue: this.props.permission && this.props.permission.icon,
        })(<Input placeholder="请输入资源图标"/>)}
      </FormItem>
    );
  }

  renderFunc() {
    const {getFieldDecorator} = this.props.form;
    const {permission} = this.props;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <FormItem label="方法类型" {...formItemLayout}>
        {getFieldDecorator('method', {
          initialValue: permission && permission.method,
          rules: [{
            required: true,
            message: '方法类型不能为空',
          },],
        })(
          <Select placeholder="请选择方法类型">
            <Option value='GET'>GET</Option>
            <Option value='POST'>POST</Option>
            <Option value='PUT'>PUT</Option>
            <Option value='DELETE'>DELETE</Option>
            <Option value='ALL'>ALL</Option>
          </Select>
        )}
      </FormItem>
    );
  }

  handlechangeType = (value) => {
    this.setState({
      type: value,
    });
  };

  renderCreateModalForm() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="资源名称" {...formItemLayout}>
          {getFieldDecorator('name', {
            rules: [{
              required: true,
              message: '资源名称不能为空',
            },],
          })(<Input placeholder="请输入权限名称"/>)}
        </FormItem>
        <FormItem label="资源类型" {...formItemLayout}>
          {getFieldDecorator('type', {
            initialValue: 'PAGE',
            rules: [{
              required: true,
              message: '资源类型不能为空',
            },],
          })(
            <Select onChange={this.handlechangeType} placeholder="请选择资源类型">
              <Option value='PAGE'>页面资源</Option>
              <Option value='METHOD'>方法资源</Option>
            </Select>
          )}
        </FormItem>
        {this.state.type === 'PAGE' ? this.renderIcon() : this.renderFunc()}
        <FormItem label="资源请求路径" {...formItemLayout}>
          {getFieldDecorator('url',
            {
              rules: [{
                required: true,
                message: '请输入资源请求路径',
              },],
            }
          )(
            <Input placeholder="请输入资源请求路径"/>
          )}
        </FormItem>
        <FormItem label="菜单序号" {...formItemLayout}>
          {getFieldDecorator('number', {
            rules: [{
              required: true,
              message: '菜单序号不能为空',
            },],
          })(<Input placeholder="请输入菜单序号"/>)}
        </FormItem>
        <FormItem label="资源描述" {...formItemLayout}>
          {getFieldDecorator('description',
            {
              rules: [{
                required: true,
                message: '请输入资源描述',
              },],
            }
          )(
            <TextArea placeholder="请输入资源描述" autosize={{minRows: 4}}/>
          )}
        </FormItem>
      </Form>
    );
  }

  handleAddSubmit = (e) => {
    e.preventDefault();
    const {dispatch, form} = this.props;
    if (this.state.type === 'PAGE') {
      form.validateFields(['name', 'icon', 'url', 'type', 'number', 'description'], (err, fieldsValue) => {
        if (err) return;
        const values = {
          ...fieldsValue,
        };
        dispatch({
          type: 'permission/pageSubmit',
          payload: {
            value: {
              ...values,
            },
            pagination: {
              columns: [
                {
                  "name": 'type',
                  "search": 'PAGE',
                  "relation": "EQ",
                },
                {
                  "name": 'parent.id',
                  "search": "",
                  "relation": "ISNULL",
                }
              ],
              pageSize: getSessionStorage("pagePermissionListPageSize") * 1 || this.props.pagePageSize,
              page: getSessionStorage("pagePermissionListCurrent") * 1 || this.props.pageCurrent,
            },
            type: 'PAGE',
          },
        });
      });
    } else {
      form.validateFields(['name', 'method', 'type', 'url','number', 'description'], (err, fieldsValue) => {
        if (err) return;
        const values = {
          ...fieldsValue,
        };
        dispatch({
          type: 'permission/pageSubmit',
          payload: {
            value: {
              ...values,
            },
            pagination: {
              "columns": [
                {
                  "name": 'type',
                  "search": 'METHOD',
                  "relation": "EQ",
                }
              ],
              pageSize: getSessionStorage("funcPermissionListPageSize") * 1 || this.props.funcPageSize,
              page: getSessionStorage("funcPermissionListCurrent") * 1 || this.props.funcCurrent,
            },
            type: 'FUNC',
          },
        });
      });
    }
    this.setState({
      modalVisible: false,
    });
    this.handleFormReset();
  };

  handleEditSubmit = (e) => {
    e.preventDefault();
    const {dispatch, form, permission} = this.props;
    const {id, prantId} = this.state;
    //页面资源
    if (permission.typeName === 'PAGE') {
      form.validateFields(['name', 'url', 'type', 'description','number', 'icon'], (err, fieldsValue) => {
        if (err) return;
        this.setState({
          type: 'PAGE',
          modal: false,
        });
        const values = {
          ...fieldsValue,
        };
        dispatch({
          type: 'permission/pageSubmit',
          payload: {
            value: {
              ...values,
              id,
              prantId,
            },
            type: permission.typeName,
            pagination: {
              columns: [
                {
                  "name": 'type',
                  "search": 'PAGE',
                  "relation": "EQ",
                },
                {
                  "name": 'parent.id',
                  "search": "",
                  "relation": "ISNULL",
                }
              ],
              pageSize: getSessionStorage("funcPermissionListPageSize") * 1 || this.props.funcPageSize,
              page: getSessionStorage("funcPermissionListCurrent") * 1 || this.props.funcCurrent,
            }
          },
        });
      });
    } else {
      //方法资源
      console.log('方法资源')
      form.validateFields(['name', 'method', 'type', 'url','number', 'description'], (err, fieldsValue) => {
        if (err) return;
        this.setState({
          type: 'METHOD',
          modal: false,
        });
        const values = {
          ...fieldsValue,
        };
        dispatch({
          type: 'permission/pageSubmit',
          payload: {
            value: {
              ...values,
              id,
              prantId,
            },
            type: permission.typeName,
            pagination: {
              columns: [
                {
                  "name": 'type',
                  "search": 'METHOD',
                  "relation": "EQ",
                }
              ],
              pageSize: getSessionStorage("funcPermissionListPageSize") * 1 || this.props.funcPageSize,
              page: getSessionStorage("funcPermissionListCurrent") * 1 || this.props.funcCurrent,
            },
          },
        });
      });
    }
    this.handleFormReset();
  };

  handleChildSubmit = (e) => {
    e.preventDefault();
    const {dispatch, form} = this.props;
    const {prantId} = this.state;
    form.validateFields(['name', 'url', 'description'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        addModal: false,
      });
      const values = {
        ...fieldsValue,
      };
      dispatch({
        type: 'permission/pageSubmit',
        payload: {
          value: {
            ...values,
            type: 'PAGE',
            prantId: prantId,
          },
          pagination: {
            columns: [
              {
                "name": 'type',
                "search": 'PAGE',
                "relation": "EQ",
              },
              {
                "name": 'parent.id',
                "search": "",
                "relation": "ISNULL",
              }
            ],
            pageSize: getSessionStorage("pagePermissionListPageSize") * 1 || this.props.pagePageSize,
            page: getSessionStorage("pagePermissionListCurrent") * 1 || this.props.pageCurrent,
          },
          type: 'PAGE',
        },
      });
    });
    this.handleFormReset();
  };

  handleTabChange = (k) => {
    setSessionStorage("permissionType", k);
    if (k === 'METHOD') {
      this.props.dispatch({
        type: 'permission/fetchFunc',
        payload: {
          "columns": [
            {
              "name": 'type',
              "search": "METHOD",
              "relation": "EQ",
            }
          ],
          pageSize: getSessionStorage("funcPermissionListPageSize") * 1 || this.props.funcPageSize,
          page: getSessionStorage("funcPermissionListCurrent") * 1 || this.props.funcCurrent,
        },
      });
    } else {
      this.props.dispatch({
        type: 'permission/fetchPage',
        payload: {
          "columns": [
            {
              "name": 'type',
              "search": 'PAGE',
              "relation": "EQ",
            },
            {
              "name": 'parent.id',
              "search": "",
              "relation": "ISNULL",
            }
          ],
          pageSize: getSessionStorage("pagePermissionListPageSize") * 1 || this.props.pagePageSize,
          page: getSessionStorage("pagePermissionListCurrent") * 1 || this.props.pageCurrent,
        },
      });
    }
  };

  renderEditModal() {
    return this.state.modal ? this.renderEditModalForm() : '';
  }

  renderEditModalForm() {
    const {getFieldDecorator} = this.props.form;
    const {permission} = this.props;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="权限名称" {...formItemLayout}>
          {getFieldDecorator('name', {
            initialValue: permission && permission.name,
            rules: [{
              required: true,
              message: '权限名称不能为空',
            },],
          })(<Input placeholder="请输入权限名称"/>)}
        </FormItem>
        <FormItem label="权限类别" {...formItemLayout}>
          {getFieldDecorator('type',
            {
              initialValue: permission && permission.typeName,
              rules: [{
                required: true,
                message: '请选择权限类别',
              },],
            }
          )(
            <Select placeholder="请权限类别">
              <Option value='PAGE'>页面</Option>
              <Option value='METHOD'>方法</Option>
            </Select>
          )}
        </FormItem>
        {permission && permission.typeName === 'PAGE' ? this.renderIcon() : this.renderFunc()}
        <FormItem label="请求路径" {...formItemLayout}>
          {getFieldDecorator('url',
            {
              initialValue: permission && permission.url,
              rules: [{
                required: true,
                message: '请输入请求路径',
              },],
            }
          )(
            <Input placeholder="请输入请求路径"/>
          )}
        </FormItem>
        <FormItem label="菜单序号" {...formItemLayout}>
          {getFieldDecorator('number', {
            initialValue: permission && permission.number,
            rules: [{
              required: true,
              message: '菜单序号不能为空',
            },],
          })(<Input placeholder="请输入菜单序号"/>)}
        </FormItem>
        <FormItem label="资源描述" {...formItemLayout}>
          {getFieldDecorator('description',
            {
              initialValue: permission && permission.description,
              rules: [{
                required: true,
                message: '请输入资源描述',
              },],
            }
          )(
            <TextArea placeholder="请输入资源描述" autosize={{minRows: 4}}/>
          )}
        </FormItem>
      </Form>
    );
  }

  renderChildModalForm() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="资源名称" {...formItemLayout}>
          {getFieldDecorator('name', {
            rules: [{
              required: true,
              message: '权限名称不能为空',
            },],
          })(<Input placeholder="请输入权限名称"/>)}
        </FormItem>
        <FormItem label="请求路径" {...formItemLayout}>
          {getFieldDecorator('url',
            {
              rules: [{
                required: true,
                message: '请输入请求路径',
              },],
            }
          )(
            <Input placeholder="请输入请求路径"/>
          )}
        </FormItem>
        <FormItem label="资源描述" {...formItemLayout}>
          {getFieldDecorator('description',
            {
              rules: [{
                required: true,
                message: '请输入资源描述',
              },],
            }
          )(
            <TextArea placeholder="请输入资源描述" autosize={{minRows: 4}}/>
          )}
        </FormItem>
      </Form>
    );
  }

  renderSimpleForm() {
    const {getFieldDecorator} = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col md={8} sm={24}>
            <FormItem label="权限名称">
              {getFieldDecorator('account')(<Input placeholder="请输入权限名称"/>)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="请求路径">
              {getFieldDecorator('content')(<Input placeholder="请输入请求路径"/>)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  render() {
    const {
      loading,
      pageTotal,
      pagePageSize,
      funcTotal,
      funcPageSize,
      pageList,
      funcList,
      type,
    } = this.props;
    const {confirmLoading, modal, modalVisible, addModal} = this.state;
    const paginationPage = {
      pageSize: getSessionStorage("pagePermissionListPageSize") * 1 || this.props.pagePageSize,
      current: getSessionStorage("pagePermissionListCurrent") * 1 || this.props.pageCurrent,
      total: pageTotal,
      showSizeChanger: true,
      onChange: this.handlePageChange,
      onShowSizeChange: this.handlePageSizeChange,
    };
    const paginationFunc = {
      pageSize: getSessionStorage("funcPermissionLisPageSize") * 1 || this.props.funcPageSize,
      current: getSessionStorage("funcPermissionListCurrent") * 1 || this.props.funcCurrent,
      total: funcTotal,
      showSizeChanger: true,
      onChange: this.handleFuncChange,
      onShowSizeChange: this.handleFuncSizeChange,
    };

    const pageColumns = [
      {
        title: '权限名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '请求路径',
        dataIndex: 'url',
        key: 'url',
      },
      {
        title: '资源图标',
        dataIndex: 'icon',
        key: 'icon',
      },
      {
        title: '创建时间',
        dataIndex: 'createDate',
        key: 'createDate',
        render: (text, record) => (
          <span>
            {moment(record.createDate).format('YYYY-MM-DD HH:mm:ss')}
          </span>
        ),
      },
      {
        title: '描述',
        dataIndex: 'description',
        key: 'description',
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            <a onClick={this.handleShowModal.bind(null, record)}>修改</a>
            <Divider type="vertical"/>
            <Popconfirm placement="top" title='确定要删除该权限吗？' onConfirm={this.handleDelete.bind(null, record, 'PAGE')}
                        okText="确定" cancelText="取消"><a>删除</a></Popconfirm>
            <Divider type="vertical"/>
            <a onClick={this.handleCreateChild.bind(null, record)}>增加子级资源</a>
          </span>
        ),
      },
    ];

    const funcColumns = [
      {
        title: '权限名称',
        dataIndex: 'name',
      },
      {
        title: '请求路径',
        dataIndex: 'url',
      },
      {
        title: '创建时间',
        dataIndex: 'createDate',
        sorter: true,
        render: (text, record) => (
          <span>
            {moment(record.createDate).format('YYYY-MM-DD HH:mm:ss')}
          </span>
        )
      },
      {
        title: '操作',
        render: (text, record) => (
          <span>
            <a onClick={this.handleShowModal.bind(null, record)}>修改</a>
            <Divider type="vertical"/>
            <Popconfirm placement="top" title='确定要删除该权限吗？' onConfirm={this.handleDelete.bind(null, record, 'METHOD')}
                        okText="确定" cancelText="取消"><a>删除</a></Popconfirm>
          </span>
        ),
      },
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          {/* <div className={styles.tableListForm}>{this.renderForm()}</div> */}
          <Modal title="资源修改"
                 visible={modal}
                 onOk={this.handleEditSubmit}
                 onCancel={this.handleEditCancel}
          >
            {this.renderEditModal()}
          </Modal>
          <Modal title="新建资源"
                 visible={modalVisible}
                 onOk={this.handleAddSubmit}
                 onCancel={this.handleCreateCancel}
          >
            {this.renderCreateModal()}
          </Modal>
          <Modal title="新建子级资源"
                 visible={addModal}
                 onOk={this.handleChildSubmit}
                 onCancel={this.handleChildCancel}
          >
            {this.renderChildModal()}
          </Modal>
          <Card
            className={styles.listCard}
            bordered={false}
            title="页面资源列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 32px 40px 32px'}}
          >
            <Button className={styles.btnBt20} icon="download" style={{marginRight: '8px'}} onClick={this.handleExport}>
              导出表格
            </Button>
            <Button icon="plus" type="primary" onClick={this.handleCreate}>
              新建资源
            </Button>
            <Tabs onChange={this.handleTabChange} defaultActiveKey={getSessionStorage("permissionType") || type}>
              <TabPane tab="页面资源" key="PAGE">
                <Table
                  bordered
                  loading={loading}
                  rowKey='id'
                  columns={pageColumns}
                  dataSource={pageList}
                  pagination={paginationPage}
                />
              </TabPane>
              <TabPane tab="方法资源" key="METHOD">
                <Table
                  bordered
                  loading={loading}
                  rowKey='id'
                  columns={funcColumns}
                  dataSource={funcList}
                  pagination={paginationFunc}
                />
              </TabPane>
            </Tabs>
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
