import React, { PureComponent } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import {
  Table,
  Card,
  Button,
  Form,
  Row,
  Col,
  Input,
  Icon,
  Select,
  DatePicker,
} from 'antd';
import styles from './SystemList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import { setSessionStorage, getSessionStorage, removeSessionStorage, sortTable, searchTable } from '../../utils/utils';
const FormItem = Form.Item;
const { RangePicker } = DatePicker;
const Option = Select.Option;
@connect(({ report, loading }) => ({
  list: report.list,
  total: report.total,
  loading: loading.models.report,
  pageSize: report.pageSize,
  page: report.page,
}))
@Form.create()
export default class reportList extends PureComponent {

  state = {
    filters: {},
  };

  componentDidMount() {
    this.fetch({
      page: getSessionStorage("reportListCurrent") * 1 || this.props.page,
      pageSize: getSessionStorage("reportListPageSize") * 1 || this.props.pageSize,
    });
  }

  componentWillUnmount() {
    removeSessionStorage("reportListCurrent");
    removeSessionStorage("reportListPageSize")
  }

  fetch = (payload) => {
    this.props.dispatch({
      type: 'report/fetch',
      payload,
    });
  };

  handleExport = (e) => {
    e.preventDefault();
    const { dispatch, form, pageSize } = this.props;

    form.validateFields(['userName', 'operate', 'succeed'], (err, fieldsValue) => {
      if (err) return;

      const values = {
        ...fieldsValue,
        createdAt: {
          startTime: this.state.startTime,
          endTime: this.state.endTime,
        }
      };
      dispatch({
        type: 'report/export',
        payload: {
          "columns": [
            {
              "name": "userName",
              "relation": "LIKE",
              "search": values.userName,
            },
            {
              "name": "operate",
              "relation": "LIKE",
              "search": values.operate,
            },
            {
              "name": "succeed",
              "relation": "LIKE",
              "search": values.succeed,
            },
            {
              "name": "userName",
              "relation": "LIKE",
              "search": "string",
            }
          ],
          "page": 1,
        },
      });
    });
  };

  handleFormReset = () => {
    const { form } = this.props;
    form.resetFields();
  }

  handleTableChange = (pagination, filters, sorter) => {
    const { form } = this.props;
    let values = null;
    form.validateFields(['userName', 'operation'],(err, fieldsValue) => {
      if (err) return;

      values = {
        ...fieldsValue,
      };
    });
    const { current, pageSize } = pagination;
    const res = sortTable(pagination, filters, sorter);
    const { columns, order } = res;
    this.setState({
      filters: {
        columns,
        order,
      }
    });
    if(values){
      Object.keys(values).map((item) => {
        if(values[item]){
          columns.push({
            name: item,
            relation: "LIKE",
            search: values[item],
          })
        }
      });
    }

    setSessionStorage("reportListCurrent", current);
    setSessionStorage("reportListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order,
    });
  };

  handleSizeChange = (current, size) => {
    setSessionStorage("reportListCurrent", current);
    setSessionStorage("reportListPageSize", size);
    this.props.dispatch({
      type: 'report/fetch',
      payload: {
        pageSize: size,
        pageNo: current,
      },
    });
  };

  handleSearch = e => {
    e.preventDefault();
    const { form } = this.props;
    form.validateFields(['username'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };
      const columns = searchTable(values);
      if(this.state.filters && this.state.filters.columns){
        this.state.filters.columns.map((item) => {
          columns.push({
            ...item,
          });
        });
      }
      this.fetch({
        columns,
        order: this.state.filters.order,
        pageNo: 1,
        pageSize: getSessionStorage("reportListPageSize") * 1 || this.props.pageSize,
      });
    });
  };

  renderForm() {
    return  this.renderSimpleForm();
  }
  renderSimpleForm() {
    const { getFieldDecorator } = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
            <FormItem label="操作账号">
              {getFieldDecorator('username')(<Input placeholder="请输入操作用户" />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  redirectProfile = (id) => {
    window.open(window.location.origin+'#/comsumer/comsumerProfile?id='+id)
  };

  render() {
    const {
      list,
      loading,
      total,
      pageSize,
      page,
    } = this.props;
    const columns = [
      {
        title: '序号',
        dataIndex: 'id',
        render: (text, record, index) => (index + 1 + (page-1)*pageSize),
      },
      {
        title: '举报人',
        dataIndex: 'consumerNickName',
        render: (text, record) => (
          <a onClick={() => this.redirectProfile(record.consumerId)}>
            {record.consumerNickName}
          </a>
        ),
      },
      {
        title: '被举报人',
        dataIndex: 'consumerPassivityNickName',
        render: (text, record) => (
          <a onClick={() => this.redirectProfile(record.consumerPassivityId)}>
            {record.consumerPassivityNickName}
          </a>
        ),
      },
      {
        title: '举报理由',
        dataIndex: 'content',
        key: 'content',
      },
      {
        title: '举报时间',
        dataIndex: 'createDate',
        render: (text, record) => (
          <span>
            {moment(record.createDate).format('YYYY-MM-DD HH:mm:ss')}
          </span>
        ),
        sorter: true,
      },
    ];

    const pagination = {
      total,
      showSizeChanger: true,
      pageSize: getSessionStorage("reportListPageSize") * 1 || pageSize,
      current: getSessionStorage("reportListCurrent") * 1 || page,
    };

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <Card
            className={styles.listCard}
            bordered={false}
            title="举报信息列表"
            style={{ marginTop: 24 }}
            bodyStyle={{ padding: '0 32px 40px 32px' }}
          >
            <Table
              bordered
              loading={loading}
              rowKey={record => record.id}
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
