import React, { PureComponent } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import {
  Table,
  Card,
  Button,
  Form,
  Row,
  Col,
  Input,
  Icon,
  Select,
  DatePicker,
  Divider,
  Popconfirm,
} from 'antd';
import styles from './SystemList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import { setSessionStorage, getSessionStorage } from '../../utils/utils';
const FormItem = Form.Item;
const { RangePicker } = DatePicker;
const Option = Select.Option;
@connect(({ role, loading }) => ({
  list: role.list,
  total: role.total,
  loading: loading.models.role,
  pageSize: role.pageSize,
  page: role.page,
}))
@Form.create()
export default class RoleList extends PureComponent {

  state = {
    expandForm: false,
    startTime: null,
    endTime: null,
  }

  fetch = (payload) => {
    this.props.dispatch({
      type: 'role/fetch',
      payload: {
        ...payload,
      },
    });
  };

  componentDidMount() {
    this.fetch({
      pageSize: getSessionStorage("roleListPageSize") * 1 || this.props.pageSize,
      page: getSessionStorage("roleListCurrent") * 1 || this.props.page,
    });
  }

  handleExport() {
    console.log('点击了导出文件表格按钮');
  }

  handleEdit = (record) => {
    this.props.dispatch({
      type: 'role/edit',
      payload: {
        id: record.id,
        pageSize: getSessionStorage("roleListPageSize") * 1 || this.props.pageSize,
        page: getSessionStorage("roleListCurrent") * 1 || this.props.page,
      },
    });
  };

  handleCreate = () => {
    this.props.dispatch({
      type: 'role/add',
      payload: {},
    });
  };

  handleDelete = (record) => {
    this.props.dispatch({
      type: 'role/delete',
      payload: {
        id: record.id,
        pageSize: getSessionStorage("roleListPageSize") * 1 || this.props.pageSize,
        page: getSessionStorage("roleListCurrent") * 1 || this.props.page,
      },
    });
  };

  handleChange = (current) => {
    setSessionStorage("roleListCurrent", current);
    this.props.dispatch({
      type: 'role/fetchChange',
      payload: {
        pageSize: getSessionStorage("roleListPageSize") || this.props.pageSize,
        page: current,
      },
    });
  };

  handleSizeChange = (current, size) => {
    setSessionStorage("roleListCurrent", current);
    setSessionStorage("roleListPageSize", size);
    this.props.dispatch({
      type: 'role/fetchChange',
      payload: {
        pageSize: size,
        page: current,
      },
    });
  };

  handleSearch = e => {
    e.preventDefault();
    const { dispatch, form, pageSize } = this.props;

    form.validateFields((err, fieldsValue) => {
      if (err) return;

      const values = {
        ...fieldsValue,
        createdAt: {
          startTime: this.state.startTime,
          endTime: this.state.endTime,
        }
      };
      dispatch({
        type: 'role/fetch',
        payload: {
          ...values,
          pageSize: pageSize,
          page: 1,
        },
      });
    });
  };

  toggleForm = () => {
    this.setState({
      expandForm: !this.state.expandForm,
    });
  };

  handleDateChange = (date, dateString) => {
    this.setState({
      startTime: dateString[0],
      endTime: dateString[1],
    });
  }

  renderForm() {
    return this.state.expandForm ? this.renderAdvancedForm() : this.renderSimpleForm();
  }
  renderSimpleForm() {
    const { getFieldDecorator } = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
            <FormItem label="操作账号">
              {getFieldDecorator('account')(<Input placeholder="请输入操作用户" />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="操作内容">
              {getFieldDecorator('content')(<Input placeholder="请输入操作内容" />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
                重置
              </Button>
              <a style={{ marginLeft: 8 }} onClick={this.toggleForm}>
                展开 <Icon type="down" />
              </a>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  renderAdvancedForm() {
    const { getFieldDecorator } = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
            <FormItem label="操作账号">
              {getFieldDecorator('account')(<Input placeholder="请输入操作用户" />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="操作内容">
              {getFieldDecorator('content')(<Input placeholder="请输入操作内容" />)}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <Button type="primary" htmlType="submit">
              查询
            </Button>
            <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
              重置
            </Button>
            <a style={{ marginLeft: 8 }} onClick={this.toggleForm}>
              收起 <Icon type="up" />
            </a>
          </Col>
        </Row>
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
            <FormItem label="操作时间">
              {getFieldDecorator('createdAt')(<RangePicker title='请选择操作时间' onChange={this.handleDateChange} />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="是否成功">
              {getFieldDecorator('content')(
                <Select placeholder="请选择操作是否成功" style={{ width: 165 }}>
                  <Option value='操作成功'>操作成功</Option>
                  <Option value='操作失败'>操作失败</Option>
                </Select>
              )}
            </FormItem>
          </Col>
        </Row>
      </Form>
    );
  }

  render() {
    const { list, loading, total, pageSize, page } = this.props;

    const pagination = {
      pageSize: getSessionStorage("roleListPageSize") * 1 || pageSize,
      current: getSessionStorage("roleListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onChange: this.handleChange,
      onShowSizeChange: this.handleSizeChange,
    };

    const columns = [
      {
        title: '角色名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '创建时间',
        dataIndex: 'createDate',
        key: 'createDate',
        render: (text, record) => (
          record.createDate && moment(record.createDate).format('YYYY/MM/DD HH:mm:ss')
        ),
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record, index) => (
          <span>
            <a onClick={this.handleEdit.bind(null, record)}>修改</a>
            <Divider type="vertical" />
            <Popconfirm placement="leftTop" title='确定要删除吗？' onConfirm={this.handleDelete.bind(null, record, index)} okText="确定" cancelText="取消">
              <a>删除</a>
            </Popconfirm>
          </span>
        ),
      },
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Card
            className={styles.listCard}
            bordered={false}
            title="角色列表"
            style={{ marginTop: 24 }}
            bodyStyle={{ padding: '0 32px 40px 32px' }}
          >
            <div className={styles.tableListOperator}>
              <Button className={styles.btnBt20} icon="download" onClick={this.handleExport}>
                导出表格
              </Button>
              <Button type="primary" icon="plus" onClick={this.handleCreate}>
                新建角色
              </Button>
            </div>
            <Table
              bordered
              loading={loading}
              rowKey={record => record.id}
              columns={columns}
              dataSource={list}
              pagination={pagination}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
