import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {parse} from 'qs';
import {
  Table,
  Card,
  Button,
  Form,
  Row,
  Col,
  Input,
  Icon,
  Select,
  DatePicker,
  Divider,
  Modal,
  Popconfirm,
  Tabs,
} from 'antd';
import styles from './SystemList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {setSessionStorage, getSessionStorage, sortTable, searchTable, ApiPostDownloadFile} from '../../utils/utils';

const FormItem = Form.Item;
const {RangePicker} = DatePicker;
const Option = Select.Option;
const TabPane = Tabs.TabPane;
const {TextArea} = Input;
@connect(({sale, loading}) => ({
  loading: loading.models.sale,
  type: sale.type,
  page: sale.page,
  pageSize: sale.pageSize,
  total: sale.total,
  list: sale.list
}))
@Form.create()
export default class SaleList extends PureComponent {

  state = {
    expandForm: false,
    id: 0,
    type: 'TAKE',
    startTime: undefined,
    endTime: undefined,
    order: [
      {
        "direction": "DESC",
        "property": "lastUpdateDate"
      }
    ],
    methodTypeEnum: {
      TAKE: '自提',
      SEND: '派送',
      ELECTRONIC_CODE: '电子券',
      EXPRESS: '快递配送',
      SEND2TAKE: '派送失败转自提'
    }
  };

  fetch = (payload) => {
    const type = getSessionStorage("saleType") || this.props.type;
    this.props.dispatch({
      type: 'sale/fetch',
      payload: {
        columns: [
          {
            "name": 'status',
            "search": type,
            "relation": "EQ",
            "type": "T_STRING"
          },
          {
            "name": 'site.id',
            "search": parse(this.props.location.search.substr(1)).id,
            "relation": "EQ",
            "type": "T_STRING"
          }
        ],
        ...payload,
      },
    });
  };

  componentDidMount() {
    // const today = new Date;
    // const startTime = moment(today).add(-2, 'days').format('YYYY-MM-DD HH:ss:mm');
    // const endTime = moment(today).format('YYYY-MM-DD HH:ss:mm');
    // this.setState({
    //   startTime: moment(today).add(-2, 'days').format('YYYY-MM-DD HH:mm:ss'),
    //   endTime: moment(today).format('YYYY-MM-DD HH:mm:ss')
    // });
    setSessionStorage("saleType", 'FINISH');
    const {page, pageSize} = this.props;
    const type = getSessionStorage("saleType") || this.props.type;
    const {startTime, endTime} = this.state;
    this.fetch({
      page: getSessionStorage("finishListCurrent") * 1 || page,
      pageSize: getSessionStorage("finishListPageSize") * 1 || pageSize,
      startTime: this.state.startTime,
      endTime: this.state.endTime,
      condition: type
    })
  }

  componentWillUnmount() {
    setSessionStorage("saleType", 'FINISH');
    setSessionStorage("finishListPageSize", 30);
    setSessionStorage("finishListCurrent", 1);
    setSessionStorage("extractListPageSize", 30);
    setSessionStorage("extractListCurrent", 1);
    setSessionStorage("receivListPageSize", 30);
    setSessionStorage("receivListCurrent", 1);
    setSessionStorage("deliveryListPageSize", 30);
    setSessionStorage("deliveryListCurrent", 1);
  }

  handleFormReset = () => {
    const {form} = this.props;
    this.setState({
      startTime: undefined,
      endTime: undefined
    });
    form.resetFields();
  };

  handleExport() {
    console.log('点击了导出文件表格按钮');
  }

  handleSizeChange = (current, size) => {
    const saleType = getSessionStorage("saleType") || this.props.type;
    let type = '';
    switch (saleType) {
      case 'FINISH':
        type = 'finish';
        break;
      case 'EXTRACT':
        type = 'extract';
        break;
      case 'RECEIV':
        type = 'receiv';
        break;
      case 'DELIVERY':
        type = 'delivery';
        break;
    }
    setSessionStorage(`${type}ListCurrent`, current);
    setSessionStorage(`${type}ListPageSize`, size);
  };

  handleSearch = e => {
    e.preventDefault();
    const {form} = this.props;
    const type = getSessionStorage("saleType") || this.props.type;

    let str = '';
    switch (type) {
      case 'FINISH':
        str = 'finish';
        break;
      case 'EXTRACT':
        str = 'extract';
        break;
      case 'RECEIV':
        str = 'receiv';
        break;
      case 'DELIVERY':
        str = 'delivery';
        break;
    }

    const {startTime, endTime} = this.state;
    this.fetch({
      condition: type,
      startTime,
      endTime,
      page: 1,
      pageSize: getSessionStorage(`${str}ListPageSize`) * 1 || this.props.pageSize
    })
  };

  handleDateChange = (date, dateStr) => {
    let that = this;
    const type = getSessionStorage("saleType") || this.props.type;

    let str = '';
    switch (type) {
      case 'FINISH':
        str = 'finish';
        break;
      case 'EXTRACT':
        str = 'extract';
        break;
      case 'RECEIV':
        str = 'receiv';
        break;
      case 'DELIVERY':
        str = 'delivery';
        break;
    }

    setTimeout(() => {
      this.setState({
        startTime: dateStr[0],
        endTime: dateStr[1],
      });

      that.fetch({
        type,
        condition: type,
        startTime: that.state.startTime,
        endTime: that.state.endTime,
        page: 1,
        pageSize: getSessionStorage(`${str}ListPageSize`) * 1 || this.props.pageSize
      })
    }, 0)
  };

  handleExportFinish = (e) => {
    e.preventDefault();
    // const type = getSessionStorage("saleType") || this.props.type;
    //API
    // ApiPostDownloadFile('/api/v1/export/siteFinish', {
    ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/siteFinish', {
      order: this.state.order,
      siteId: parse(this.props.location.search.substr(1)).id,
      startTime: this.state.startTime,
      endTime: this.state.endTime,
    });
  };

  handleExportSale = (e) => {
    e.preventDefault();
    // const type = getSessionStorage("saleType") || this.props.type;
    //API
    // ApiPostDownloadFile('/api/v1/export/siteSale', {
    ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/siteSale', {
      order: this.state.order,
      siteId: parse(this.props.location.search.substr(1)).id,
      startTime: this.state.startTime,
      endTime: this.state.endTime,
    });
  };

  toggleForm = () => {
    this.setState({
      expandForm: !this.state.expandForm,
    });
  };

  handleTableChange = (pagination, filters, sorter) => {
    // console.log('tableChange');
    const type = getSessionStorage("saleType") || this.props.type;
    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;

    columns.push({
      "name": "site.id",
      "search": parse(this.props.location.search.substr(1)).id,
      "relation": "EQ",
      "type": "T_STRING"
    });

    columns.push({
      "name": "status",
      "search": type,
      "relation": "EQ",
      "type": "T_STRING"
    });
    let str = '';
    switch (type) {
      case 'FINISH':
        str = 'finish';
        break;
      case 'EXTRACT':
        str = 'extract';
        break;
      case 'RECEIV':
        str = 'receiv';
        break;
      case 'TAKE':
        str = 'take';
      case 'DELIVERY':
        str = 'delivery';
        break;
    }

    setSessionStorage(`${str}ListCurrent`, current);
    setSessionStorage(`${str}ListPageSize`, pageSize);

    const {startTime, endTime} = this.state;
    console.log(str);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order,
      startTime,
      endTime,
      condition: type
    });
  };

  renderForm() {
    return this.state.expandForm ? this.renderAdvancedForm() : this.renderSimpleForm();
  }

  handleTabChange = (k) => {
    setSessionStorage("saleType", k);
    let columns = [];
    columns.push({
      "name": "site.id",
      "search": parse(this.props.location.search.substr(1)).id,
      "relation": "EQ",
      "type": "T_STRING"
    });
    columns.push({
      "name": "status",
      "search": k === 'FINISH_YET' ? 'FINISH' : k,
      "relation": "EQ",
      "type": "T_STRING"
    });
    switch (k) {
      case ('FINISH'):
        this.handleFormReset();
        this.props.dispatch({
          type: 'sale/fetch',
          payload: {
            columns: columns,
            pageSize: getSessionStorage("finishListPageSize") * 1 || this.props.todayPageSize,
            page: getSessionStorage("finishListCurrent") * 1 || this.props.todayCurrent,
            startTime: this.state.startTime,
            endTime: this.state.endTime,
            condition: k
          }
        });
        break;
      case ('EXTRACT'):
        this.props.dispatch({
          type: 'sale/fetch',
          payload: {
            columns: columns,
            pageSize: getSessionStorage("extractListPageSize") * 1 || this.props.orderPageSize,
            page: getSessionStorage("extractListCurrent") * 1 || this.props.orderCurrent,
            startTime: this.state.startTime,
            endTime: this.state.endTime,
            condition: k
          },
        });
        break;
      case ('RECEIV'):
        this.props.dispatch({
          type: 'sale/fetch',
          payload: {
            columns: columns,
            pageSize: getSessionStorage("deliveryListPageSize") * 1 || this.props.dispatchPageSize,
            page: getSessionStorage("deliveryListCurrent") * 1 || this.props.dispatchCurrent,
            startTime: this.state.startTime,
            endTime: this.state.endTime,
            condition: k
          },
        });
        break;
      case ('DELIVERY'):
        this.props.dispatch({
          type: 'sale/fetch',
          payload: {
            columns: columns,
            pageSize: getSessionStorage("deliveryListPageSize") * 1 || this.props.dispatchPageSize,
            page: getSessionStorage("deliveryListCurrent") * 1 || this.props.dispatchCurrent,
            startTime: this.state.startTime,
            endTime: this.state.endTime,
            condition: k
          }
        });
        break;
      case ('TAKE'):
        this.props.dispatch({
          type: 'sale/fetch',
          payload: {
            columns: columns,
            pageSize: getSessionStorage("takeListPageSize") * 1 || this.props.dispatchPageSize,
            page: getSessionStorage("takeListCurrent") * 1 || this.props.dispatchCurrent,
            startTime: this.state.startTime,
            endTime: this.state.endTime,
            condition: k
          }
        });
        break;
      case ('DROP_SHIP'):
        columns.push({
          name: "method",
          relation: "EQ",
          search: "EXPRESS",
          type: "T_STRING"
        });
        this.props.dispatch({
          type: 'sale/fetch',
          payload: {
            columns: columns,
            pageSize: getSessionStorage("expressYetListPageSize") * 1 || this.props.dispatchPageSize,
            page: getSessionStorage("expressYetListCurrent") * 1 || this.props.dispatchCurrent,
            startTime: this.state.startTime,
            endTime: this.state.endTime,
            condition: k
          }
        });
        break;
      case ('FINISH_YET'):
        columns.push({
          name: "method",
          relation: "EQ",
          search: "EXPRESS",
          type: "T_STRING"
        });
        this.props.dispatch({
          type: 'sale/fetch',
          payload: {
            columns: columns,
            pageSize: getSessionStorage("finishYetListPageSize") * 1 || this.props.dispatchPageSize,
            page: getSessionStorage("finishYetListCurrent") * 1 || this.props.dispatchCurrent,
            startTime: this.state.startTime,
            endTime: this.state.endTime,
            condition: k === 'FINISH_YET' && 'FINISH'
          }
        });
        break;
    }
  };

  renderSimpleForm() {
    const {getFieldDecorator} = this.props.form;
    const defaultSelectDate = {
      startDate: moment().startOf('day').subtract(1, 'days'),
      endDate: moment().endOf('day')
    }
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col lg={12} md={12} sm={24}>
            <FormItem label={getSessionStorage('saleType') === 'FINISH' ? '核销时间' : '下单时间'}>
              {getFieldDecorator('date', {
                // initialValue: [getSessionStorage('saleType') !== 'FINISH' ? defaultSelectDate.startDate : '', getSessionStorage('saleType') !== 'FINISH' ? defaultSelectDate.endDate : '']
              })(
                <RangePicker
                  onChange={this.handleDateChange}
                  showTime={{
                    hideDisabledOptions: true,
                    defaultValue: [moment('06:00:00', 'HH:mm:ss'), moment('06:00:00', 'HH:mm:ss')],
                  }}
                  format="YYYY-MM-DD HH:mm:ss"
                  // style={{width: '350px'}}
                />
              )}
            </FormItem>
          </Col>
          <Col md={4} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  render() {
    const {
      loading,
      list,
      page,
      pageSize,
      total
    } = this.props;
    const paginationFinish = {
      pageSize: getSessionStorage("finishListPageSize") * 1 || pageSize,
      current: getSessionStorage("finishListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const paginationExtract = {
      pageSize: getSessionStorage("extractLisPageSize") * 1 || pageSize,
      current: getSessionStorage("extractListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const paginationReceiv = {
      pageSize: getSessionStorage("receivListPageSize") * 1 || pageSize,
      current: getSessionStorage("receivListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const paginationDelivery = {
      pageSize: getSessionStorage("deliveryListPageSize") * 1 || pageSize,
      current: getSessionStorage("deliveryListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    //成功核销列表
    const columns = [
      {
        title: '礼品名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '订单金额',
        dataIndex: 'money',
        sorter: true,
      },
      {
        title: '订单号',
        dataIndex: 'orderNo',
        key: 'orderNo'
      },
      {
        title: '当日流水号',
        dataIndex: 'serialNumber',
        key: 'serialNumber'
      },
      {
        title: '下单时间',
        dataIndex: 'createDate',
        render: (text, record) => (
          moment(record.createDate).format('YYYY-MM-DD HH:mm:ss') || ''
        ),
      },
      {
        title: '核销时间',
        dataIndex: 'finishDate',
        render: (text, record) => (
          moment(record.finishDate).format('YYYY-MM-DD HH:mm:ss') || ''
        ),
      },
      {
        title: '订单类型',
        dataIndex: 'methodType',
        key: 'methodType',
        render: (text, record) => (
          <span>{this.state.methodTypeEnum[record.methodType]}</span>
        ),
      },
      {
        title: '服务员昵称',
        dataIndex: 'customerName',
        key: 'customerName',
      },
    ];
    //自提列表
    const pickColumns = [
      {
        title: '礼品名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '订单金额',
        dataIndex: 'money',
        sorter: true,
      },
      {
        title: '订单号',
        dataIndex: 'orderNo',
        key: 'orderNo'
      },
      {
        title: '当日流水号',
        dataIndex: 'serialNumber',
        key: 'serialNumber'
      },
      {
        title: '下单时间',
        dataIndex: 'createDate',
        render: (text, record) => (
          moment(record.createDate).format('YYYY-MM-DD HH:mm:ss') || ''
        ),
      },
      {
        title: '订单类型',
        dataIndex: 'methodType',
        // key: 'methodType',
        render: (text, record) => (
          <span>{this.state.methodTypeEnum[record.methodType]}</span>
        )
      }
    ];
    //派送中
    const deliveryColumns = [
      {
        title: '礼品名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '订单金额',
        dataIndex: 'money',
        sorter: true,
      },
      {
        title: '订单号',
        dataIndex: 'orderNo',
        key: 'orderNo'
      },
      {
        title: '当日流水号',
        dataIndex: 'serialNumber',
        key: 'serialNumber'
      },
      {
        title: '下单时间',
        dataIndex: 'createDate',
        render: (text, record) => (
          moment(record.createDate).format('YYYY-MM-DD HH:mm:ss') || ''
        ),
      },
      {
        title: '订单类型',
        dataIndex: 'methodType',
        key: 'methodType',
        render: (text, record) => (
          <span>{this.state.methodTypeEnum[record.methodType]}</span>
        ),
      },
      {
        title: '服务员昵称',
        dataIndex: 'customerName',
        key: 'customerName',
      },
    ];

    const verificationColumns = [
      {
        title: '礼品名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '订单金额',
        dataIndex: 'money',
        sorter: true,
      },
      {
        title: '下单时间',
        dataIndex: 'createDate',
        render: (text, record) => (
          moment(record.createDate).format('YYYY-MM-DD HH:mm:ss') || ''
        ),
      },
      {
        title: '核销时间',
        dataIndex: 'time1',
        sorter: true,
      },
      {
        title: '送礼人昵称',
        dataIndex: 'giverName',
        key: 'giverName',
      },
      {
        title: '收礼人昵称',
        dataIndex: 'recipientName',
        key: 'recipientName',
      },
      {
        title: '服务员',
        dataIndex: 'customerName',
        key: 'customerName',
      },
    ];
    //待收礼
    const takeColumns = [
      {
        title: '礼品名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '订单金额',
        dataIndex: 'money',
        sorter: true,
      },
      {
        title: '订单号',
        dataIndex: 'orderNo',
        key: 'orderNo'
      },
      {
        title: '下单时间',
        dataIndex: 'createDate',
        render: (text, record) => (
          moment(record.createDate).format('YYYY-MM-DD HH:mm:ss') || ''
        ),
      }
    ];

    //已发快递列表
    const expressColumns = [
      {
        title: '礼品名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '订单金额',
        dataIndex: 'money',
        sorter: true,
      },
      {
        title: '订单号',
        dataIndex: 'orderNo',
        key: 'orderNo'
      },
      {
        title: '当日流水号',
        dataIndex: 'serialNumber',
        key: 'serialNumber'
      },
      {
        title: '备注',
        dataIndex: 'remark'
      },
      {
        title: '收件人电话',
        dataIndex: 'expressPhone'
      },
      {
        title: '收件人地址',
        dataIndex: 'expressAddress'
      },
      {
        title: '收件人',
        dataIndex: 'expressName'
      }
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Card
            className={styles.listCard}
            bordered={false}
            title="礼品销售列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 32px 40px 32px'}}
          >
            <Button className={styles.btnBt20} icon="download" style={{marginRight: '8px'}}
                    onClick={this.handleExportFinish}>
              导出场所核销成功明细
            </Button>
            <Button className={styles.btnBt20} icon="download" style={{marginRight: '8px'}}
                    onClick={this.handleExportSale}>
              导出场所卖出明细
            </Button>

            <Tabs onChange={this.handleTabChange} defaultActiveKey={getSessionStorage("saleType") || this.props.type}>
              <TabPane tab="成功核销列表" key="FINISH">
                <Table
                  bordered
                  loading={loading}
                  rowKey='id'
                  columns={columns}
                  dataSource={list}
                  pagination={paginationFinish}
                  onChange={this.handleTableChange}
                />
              </TabPane>
              <TabPane tab="待自提列表" key="EXTRACT">
                <Table
                  bordered
                  loading={loading}
                  rowKey='id'
                  columns={pickColumns}
                  dataSource={list}
                  pagination={paginationExtract}
                  onChange={this.handleTableChange}
                />
              </TabPane>
              <TabPane tab="待接单列表" key="RECEIV">
                <Table
                  bordered
                  loading={loading}
                  rowKey='id'
                  columns={pickColumns}
                  dataSource={list}
                  pagination={paginationReceiv}
                  onChange={this.handleTableChange}
                />
              </TabPane>
              <TabPane tab="待收礼列表" key="TAKE">
                <Table
                  bordered
                  loading={loading}
                  rowKey='id'
                  columns={takeColumns}
                  dataSource={list}
                  pagination={paginationReceiv}
                  onChange={this.handleTableChange}
                />
              </TabPane>
              <TabPane tab="派送中列表" key="DELIVERY">
                <Table
                  bordered
                  loading={loading}
                  rowKey='id'
                  columns={deliveryColumns}
                  dataSource={list}
                  pagination={paginationDelivery}
                  onChange={this.handleTableChange}
                />
              </TabPane>

              <TabPane tab="未发快递配送列表" key="DROP_SHIP">
                <Table
                  bordered
                  loading={loading}
                  rowKey='id'
                  columns={expressColumns}
                  dataSource={list}
                  pagination={paginationDelivery}
                  onChange={this.handleTableChange}
                />
              </TabPane>
              <TabPane tab="已发快递配送列表" key="FINISH_YET">
                <Table
                  bordered
                  loading={loading}
                  rowKey='id'
                  columns={expressColumns}
                  dataSource={list}
                  pagination={paginationDelivery}
                  onChange={this.handleTableChange}
                />
              </TabPane>
            </Tabs>
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
