import React, { PureComponent } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import { parse } from 'qs';
import {
  Table,
  Form,
  Card,
  Row,
  Col,
  Radio,
  Input,
  Button,
  Icon,
  Select,
} from 'antd';
import styles from './PayList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import { setSessionStorage, getSessionStorage, sortTable, searchTable, removeSessionStorage } from '../../utils/utils';
const FormItem = Form.Item;
const { Option } = Select;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const { Search } = Input;

@connect(({ partner, loading }) => ({
  list: partner.list,
  loading: loading.models.partner,
  page: partner.scorePage,
  pageSize: partner.scorePageSize,
  total: partner.scoreTotal,
}))
@Form.create()
export default class ScoreList extends PureComponent {

  state = {
    filters: {},
  };

  fetch = (payload) => {
    this.props.dispatch({
      type: 'partner/fetchScore',
      payload: {
        ...payload,
      },
    });
  };

  componentDidMount() {
    const id = parse(this.props.location.search.substr(1)).id;
    const { page, pageSize } = this.props;
    this.fetch({
      page: getSessionStorage("scoreListCurrent") * 1 || page,
      pageSize: getSessionStorage("scoreListPageSize") * 1 || pageSize,
      id,
    });
  }

  componentWillUnmount() {
    removeSessionStorage("scoreListCurrent");
    removeSessionStorage("scoreListPageSize");
  }

  handleFormReset = () => {
    const { form } = this.props;
    form.resetFields();
  };

  renderForm() {
    return this.renderSimpleForm();
  }

  handleSearch = e => {
    e.preventDefault();
    const { form } = this.props;
    form.validateFields(['username'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };
      const columns = searchTable(values);
      if(this.state.filters && this.state.filters.columns){
        this.state.filters.columns.map((item) => {
          columns.push({
            ...item,
          });
        });
      }
      this.fetch({
        columns,
        order: this.state.filters.order,
        page: 1,
        pageSize: getSessionStorage("scoreListPageSize") * 1 || this.props.pageSize,
      });
    });
  };

  handleTableChange = (pagination, filters, sorter) => {
    const { form } = this.props;
    let values = null;
    form.validateFields(['phone'],(err, fieldsValue) => {
      if (err) return;

      values = {
        ...fieldsValue,
      };
    });
    const { current, pageSize } = pagination;
    const res = sortTable(pagination, filters, sorter);
    const { columns, order } = res;
    this.setState({
      filters: {
        columns,
        order,
      }
    });
    if(values){
      Object.keys(values).map((item) => {
        if(values[item]){
          columns.push({
            name: item,
            relation: "LIKE",
            search: values[item],
          })
        }
      });
    }

    setSessionStorage("scoreListCurrent", current);
    setSessionStorage("scoreListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order,
    });
  };

  handleExport() {
    console.log('点击了导出文件表格按钮');
  }

  handleDetail = (id) => {
    window.open(window.location.origin+'#/comsumerProfile'+id)
  };

  render() {
    const {
      list,
      loading,
      total,
      page,
      pageSize,
    } = this.props;

    const pagination = {
      pageSize: getSessionStorage("payListPageSize") * 1 || pageSize,
      current: getSessionStorage("payListPage") * 1 || page,
      total: total,
      showSizeChanger: true,
    };

    const columns = [
      {
        title: '序号',
        dataIndex: 'id',
        render: (text, record, index) => (
          <span>
            { index + 1 + (page-1)*pageSize }
          </span>
        ),
      },
      {
        title: '变更详情',
        dataIndex: 'pay',
        key: 'pay',
      },
      {
        title: '变更时间',
        dataIndex: 'time',
        sorter: true,
        render: (text, record) => (
          record.time && moment(record.time).format('YYYY-MM-DD HH:mm:ss')
        ),
      },
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <Card
            className={styles.listCard}
            bordered={false}
            title="钻石伙伴积分明细列表"
            style={{ marginTop: 24 }}
            bodyStyle={{ padding: '0 32px 40px 32px' }}
          >
            <div className={styles.tableListOperator}>
              <Button icon="download" onClick={this.handleExport}>
                导出表格
              </Button>
            </div>
            <Table
              bordered
              loading={loading}
              rowKey='id'
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
