import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {
  Table,
  Form,
  Card,
  Row,
  Col,
  Radio,
  Input,
  Progress,
  Button,
  Icon,
  Dropdown,
  Menu,
  Avatar,
  Alert,
  message,
  Modal,
  Divider,
  Popconfirm,
  Select,
} from 'antd';
import {
  setSessionStorage,
  getSessionStorage,
  removeSessionStorage,
  sortTable,
  ApiPostDownloadFile,
  searchTable,
} from '../../utils/utils';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {parse} from 'qs';
import styles from './BasicList.less';

const FormItem = Form.Item;
const Option = Select.Option;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const {Search} = Input;
@connect(({site, loading}) => ({
  list: site.list,
  loading: loading.models.site,
  pageSize: site.pageSize,
  page: site.page,
  total: site.total,
}))
@Form.create()
export default class Site extends PureComponent {

  state = {
    modal: false,
    formValues: {},
    id: undefined,
    methodEnum: {
      TAKE: '用户自提',
      SEND: '场内派送',
      EXPRESS: '快递配送',
      ELECTRONIC_CODE: '电子券码'
    }
  };

  fetch = (payload) => {
    // const {id} = parse(this.props.location.search.substr(1));
    // const gatheringName = getSessionStorage('siteListFilterName');
    this.props.dispatch({
      type: 'site/fetch',
      payload: {
        pageSize: getSessionStorage("siteListPageSize") * 1 || this.props.pageSize,
        page: getSessionStorage("siteListCurrent") * 1 || this.props.page,
        ...payload,
      }
    })
  };

  componentDidMount() {
    setSessionStorage('siteListPageSize', 30);
    setSessionStorage('siteListCurrent', 1);
    const gatheringName = getSessionStorage('siteListFilterName');
    if (gatheringName !== undefined && gatheringName !== '' && gatheringName !== null) {
      const payload = {
        columns: [{
          name: "gathering.name",
          relation: "LIKE",
          search: gatheringName,
          type: "T_STRING",
        }]
      };
      this.fetch(payload)
    } else {
      this.fetch()
    }

  }

  componentWillUnmount() {
    removeSessionStorage('siteListCurrent');
    removeSessionStorage('siteListPageSize');
  }

  handleFormReset = () => {
    const {form} = this.props;
    setSessionStorage('siteListFilterName', '');
    form.resetFields();
    this.setState({
      formValues: {},
    });
  };

  handleSearch = e => {
    e.preventDefault();
    const {dispatch, form, pageSize, page} = this.props;

    form.validateFields(['name', 'gathering', 'status', 'type'], (err, fieldsValue) => {
      console.log(fieldsValue);
      if (err) return;

      const values = {
        ...fieldsValue
      };

      let columns = [];
      Object.keys(fieldsValue).forEach((item) => {
        if (item === 'name' && values[item]) {
          columns.push({
            "name": 'name',
            "relation": 'LIKE',
            "type": 'T_STRING',
            "search": fieldsValue[item],
          });
        } else if (item === 'gathering' && values[item]) {
          columns.push({
            "name": 'gathering.name',
            "relation": 'LIKE',
            "type": 'T_STRING',
            "search": fieldsValue[item],
          });
        } else if (item === 'status' && values[item]) {
          columns.push({
            "name": 'status',
            "relation": 'EQ',
            "type": 'T_INT',
            "search": fieldsValue[item],
          });
        } else if (values[item]) {
          columns.push({
            "name": item,
            "relation": 'LIKE',
            "type": 'T_STRING',
            "search": fieldsValue[item],
          })
        }
      });
      setSessionStorage('siteListCurrent', 1);
      sessionStorage.setItem('siteListFilterName', fieldsValue.gathering);
      dispatch({
        type: 'site/fetch',
        payload: {
          // ...values,
          pageNo: 1,
          pageSize: getSessionStorage('siteListPageSize') * 1 || pageSize,
          columns
        }
      })
    })
  };

  toggleForm = () => {
    this.setState({
      expandForm: !this.state.expandForm,
    });
  };

  handleChange = current => {
    setSessionStorage("siteListCurrent", current);
    this.props.dispatch({
      type: 'site/fetchChange',
      payload: {
        pageSize: getSessionStorage("siteListPageSize") * 1 || this.props.pageSize,
        pageNo: current,
      }
    })
  };

  handleSizeChange = (current, size) => {
    setSessionStorage("siteListCurrent", current);
    setSessionStorage("siteListPageSize", size);
    this.props.dispatch({
      type: 'site/fetchChange',
      payload: {
        pageSize: size,
        pageNo: current,
      }
    })
  };

  handleDetail = id => {
    this.props.dispatch({
      type: 'site/redirectDetail',
      payload: {
        id: id,
      },
    });
  };

  handleCreate = () => {
    this.props.dispatch({
      type: 'site/add',
    });
  };

  handleGift = (record) => {
    setSessionStorage('giftListFilterSiteName', record.name);
    this.props.dispatch({
      type: 'site/redirectGift',
      payload: {
        id: record.id,
      }
    });
    // EXPRESS,TAKE,SEND
    let options = [];
    let temp = [];
    temp = this.strToArr(record.method);
    temp.map(item => {
      if (item === 'TAKE') {
        options.push({label: '用户自提', value: item, disabled: false})
      } else if (item === 'SEND') {
        options.push({label: '场内派送', value: item, disabled: false})
      } else if (item === 'EXPRESS') {
        options.push({label: '快递配送', value: item, disabled: false})
      } else {
        options.push({label: '电子券码', value: item, disabled: false})
      }
    });
    setSessionStorage("currentSiteMethods", options);
  };

  //礼物领取方式 字符串转数组
  strToArr(str) {
    return str.split(',')
  }

  handleSale = (id) => {
    this.props.dispatch({
      type: 'site/redirectGiftSale',
      payload: {
        id,
      }
    })
  };

  renderForm() {
    return this.renderSimpleForm();
  }

  renderSimpleForm() {
    const {getFieldDecorator} = this.props.form;
    const gatheringName = getSessionStorage('siteListFilterName');
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col md={5} sm={24}>
            <FormItem label="商户名称">
              {getFieldDecorator('name', {
                // rules: [{len: 11, message: '请输入商家名称'}],
              })(<Input placeholder="请输入商户名称"/>)}
            </FormItem>
          </Col>
          <Col md={5} sm={24}>
            <FormItem label="所属聚点">
              {getFieldDecorator('gathering', {
                initialValue: gatheringName || ''
              })
              (
                <Input placeholder="请输入所属聚点"/>
              )}
            </FormItem>
          </Col>
          {/*<Col md={5} sm={24}>*/}
          {/*<FormItem label="商户类型">*/}
          {/*{getFieldDecorator('type')(*/}
          {/*<Select placeholder='商户类型' style={{width: 200}}>*/}
          {/*<Option value="PLAZA">广场商户</Option>*/}
          {/*<Option value="GATHERING">聚点商户</Option>*/}
          {/*</Select>*/}
          {/*)}*/}
          {/*</FormItem>*/}
          {/*</Col>*/}
          <Col md={5} sm={24}>
            <FormItem label="状态">
              {getFieldDecorator('status')(
                <Select placeholder='商户状态' style={{width: 200}}>
                  <Option value="1">启用</Option>
                  <Option value="0">停用</Option>
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={4} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
              <Button style={{marginLeft: 8}} icon="download" onClick={this.handleExport}>
                导出
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  handlerResetPassword = (record) => {
    const {form} = this.props;
    form.resetFields();
    this.setState({
      modal: true,
      id: record
    });
  };

  handlerResetPasswordCancel = () => {
    this.setState({
      modal: false
    });
  };

  handlerResetPasswordSubmit = () => {
    const {dispatch, form} = this.props;
    const id = this.state.id;
    form.validateFields(['password', 'confirmPassword'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        modal: false
      });
      dispatch({
        type: 'site/resetPassword',
        payload: {
          id,
          ...fieldsValue
        }
      })
    })
  };

  checkPassword = (rule, value, callback) => {
    const form = this.props.form;
    if (value && value !== form.getFieldValue('password')) {
      callback('两次密码输入不一致！');
    } else {
      callback();
    }
  };

  handleTableChange = (pagination, filters, sorter) => {
    const {form} = this.props;
    const {current, pageSize} = pagination;
    // const res = sortTable(pagination, filters, sorter);
    // console.log(res);
    // const {columns, order} = res;
    setSessionStorage("siteListCurrent", current);
    setSessionStorage("siteListPageSize", pageSize);

    form.validateFields(['name', 'gathering', 'status'], (err, fieldsValue) => {
      if (err) return;
      const values = {
        ...fieldsValue
      };
      let columns = [];
      console.log(columns);
      console.log(fieldsValue);
      Object.keys(fieldsValue).forEach((item) => {
        if (item === 'name' && values[item]) {
          columns.push({
            "name": 'name',
            "relation": 'LIKE',
            "type": 'T_STRING',
            "search": fieldsValue[item],
          });
        } else if (item === 'gathering' && values[item]) {
          columns.push({
            "name": 'gathering.name',
            "relation": 'LIKE',
            "type": 'T_STRING',
            "search": fieldsValue[item],
          });
        } else if (item === 'status' && values[item]) {
          columns.push({
            "name": 'status',
            "relation": 'EQ',
            "type": 'T_INT',
            "search": fieldsValue[item],
          });
        } else if (values[item]) {
          columns.push({
            "name": item,
            "relation": 'LIKE',
            "type": 'T_STRING',
            "search": fieldsValue[item],
          })
        }
      });
      console.log(columns);
      this.fetch({
        pageNo: current,
        pageSize,
        columns: columns,
        // order,
      })
    })

  };

  renderResetPasswordModal() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="新密码" {...formItemLayout}>
          {getFieldDecorator('password', {
            rules: [{
              required: true,
              message: '请输入新密码',
            }],
          })(<Input type="passsword" placeholder="请输入新密码" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="再次输入新密码" {...formItemLayout}>
          {getFieldDecorator('confirmPassword', {
            rules: [{
              required: true,
              message: '请输入新密码',
            }, {validator: this.checkPassword},],
          })(<Input type="passsword" placeholder="请输入新密码" style={{width: '100%'}}/>)}
        </FormItem>
      </Form>
    );
  }

  formartMethods = (methodStr) => {
    let arr = methodStr.split(',');
    let result = '';
    arr.map((item, index) => {
      result += this.state.methodEnum[item] + (index + 1 !== arr.length ? ',' : '')
    });
    return result
  };

  handleExport = (e) => {
    e.preventDefault();
    const {form, page, pageSize} = this.props;
    form.validateFields(['name', 'status', 'gathering'], (err, fieldsValue) => {
      if (err) return;

      const values = {
        ...fieldsValue
      };

      let columns = [];
      Object.keys(fieldsValue).forEach((item) => {
        if (item === 'name' && values[item]) {
          columns.push({
            "name": 'name',
            "relation": 'LIKE',
            "type": 'T_STRING',
            "search": fieldsValue[item],
          });
        } else if (item === 'gathering' && values[item]) {
          columns.push({
            "name": 'gathering.name',
            "relation": 'LIKE',
            "type": 'T_STRING',
            "search": fieldsValue[item],
          });
        } else if (item === 'status' && values[item]) {
          columns.push({
            "name": 'status',
            "relation": 'EQ',
            "type": 'T_INT',
            "search": fieldsValue[item],
          });
        }
      });
      //http://192.168.10.111:8082
      // http://test.admin.seemore.club/api
      //API
      // ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/site', {
      // ApiPostDownloadFile('/api/v1/export/site', {
      ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/site', {
        pageNo: page,
        pageSize: getSessionStorage('siteListPageSize') * 1 || pageSize,
        columns
      })
    })
  };


  render() {
    const {list, loading, pageSize, current, total} = this.props;
    const {modal} = this.state;

    const extraContent = (
      <div className={styles.extraContent}>
        <Button icon="plus" type="primary" onClick={this.handleCreate}>
          创建商户
        </Button>
      </div>
    );

    const pagination = {
      pageSize: getSessionStorage('siteListPageSize') * 1 || pageSize,
      current: getSessionStorage('siteListCurrent') * 1 || current,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const columns = [
      {
        title: '序号',
        dataIndex: 'id',
        key: 'id',
        sorter: (a, b) => a.id - b.id,
        width: 85
      },
      {
        title: '商户名称',
        dataIndex: 'name',
        key: 'name',
        // width: 200
      },
      // {
      //   title: '图片',
      //   key: 'pic',
      //   render: (text, record) => (
      //     <img src={record.pic} alt={record.name} style={{ width: '40px', height: '40px' }} />
      //   ),
      // },
      {
        title: '所属聚点',
        dataIndex: 'gatheringName',
        key: 'gatheringName',
      },
      {
        title: '所属省市',
        dataIndex: 'cityName',
        key: 'cityName',
      },
      {
        title: '商户公告',
        dataIndex: 'affiche',
        key: 'affiche',
        width: 150
      },
      {
        title: '商户封面图',
        dataIndex: 'pic',
        key: 'pic',
        render: (text, record) => (
          <img src={record.pic} alt="" style={{width: '40px', height: '40px'}}/>
        )
      },
      {
        title: '商户logo',
        dataIndex: 'logo',
        render: (text, record) => (
          <img src={record.logo} alt="" style={{width: '40px', height: '40px'}}/>
        )
      },
      {
        title: '礼物领取方式',
        dataIndex: 'method',
        // key: 'method',
        render: (text, record) => (
          <span>
            {this.formartMethods(record.method)}
          </span>
        )
      },
      // {
      //   title: '商户类型',
      //   dataIndex: 'type',
      //   render: (text, record) => (
      //     <span>
      //       {record.type === 'PLAZA' ? '广场商户' : '聚点商户'}
      //     </span>
      //   )
      // },
      // {
      //   title: '当前人数',
      //   dataIndex: 'num',
      //   key: 'num',
      // },
      {
        title: '管理员',
        dataIndex: 'userName',
        key: 'userName',
      },
      {
        title: '状态',
        dataIndex: 'status',
        render: (text, record) => (
          <span>
            {record.status ? '启用' : '停用'}
          </span>
        )
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            <a onClick={this.handleDetail.bind(null, record.id)}>查看详情</a>
            <Divider type="vertical"/>
            <a onClick={this.handleGift.bind(null, record)}>查看礼物商品</a>
            <Divider type="vertical"/>
            <a onClick={this.handleSale.bind(null, record.id)}>查看礼品销售</a>
            <Divider type="vertical"/>
            <a onClick={this.handlerResetPassword.bind(null, record.siteAdminId)}>重置密码</a>
          </span>
        )
      }
    ];


    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Modal title="重置密码"
                 visible={modal}
                 onOk={this.handlerResetPasswordSubmit}
                 onCancel={this.handlerResetPasswordCancel}
          >
            {this.renderResetPasswordModal()}
          </Modal>
          <Card
            className={styles.listCard}
            bordered={false}
            title="商户列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 32px 40px 32px'}}
            extra={extraContent}
          >
            <Table
              bordered
              loading={loading}
              rowKey={record => record.id}
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    )
  }
}
