import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {parse} from 'qs';
import {
  Table,
  Form,
  Card,
  Row,
  Col,
  Radio,
  Input,
  // Progress,
  Button,
  // Icon,
  // Dropdown,
  // Menu,
  // Avatar,
  // Alert,
  // message,
  // Modal,
  Divider,
  Popconfirm,
} from 'antd';
import {setSessionStorage, getSessionStorage, removeSessionStorage, sortTable, searchTable} from '../../utils/utils';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';

import styles from './BasicList.less';

const FormItem = Form.Item;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const {Search} = Input;

@connect(({superLike, loading}) => ({
  list: superLike.list,
  loading: loading.models.gift,
  pageSize: superLike.pageSize,
  page: superLike.page,
  total: superLike.total,
}))
@Form.create()
export default class SuperLikeList extends PureComponent {

  state = {
    selectedRowKeys: [],
    methodEnum: {
      TAKE: '用户自提',
      SEND: '场内派送',
      EXPRESS: '快递配送',
      ELECTRONIC_CODE: '电子券码'
    }
  };

  fetch = (payload) => {
    this.props.dispatch({
      type: 'superLike/fetch',
      payload: {
        ...payload
      }
    })
  };

  componentDidMount() {
    this.fetch({
      pageSize: getSessionStorage("superLikeListPageSize") * 1 || this.props.pageSize,
      pageNo: getSessionStorage("superLikeCurrent") * 1 || this.props.page
    });
  }

  componentWillUnmount() {
    removeSessionStorage('superLikeListCurrent');
    removeSessionStorage('superLikeListPageSize');
  }

  handleFormReset = () => {
    const {form} = this.props;
    form.resetFields();
    this.setState({
      formValues: {}
    });
  };

  handleSearch = e => {
    e.preventDefault();
    const {dispatch, form} = this.props;
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      const values = {
        ...fieldsValue
      };
      let columns = [];
      if (values['name']) {
        // columns = searchTable(values);
        columns = [{
          "name": 'souvenir.name',
          "relation": 'LIKE',
          "search": values['name'],
          "type": 'T_STRING'
        }]
      }
      // souvenir.name
      // console.log(columns);
      //wait for fix
      setSessionStorage('superLikeListCurrent',1);
      this.fetch({
        columns,
        pageNo: 1,
        pageSize: getSessionStorage("superLikeListPageSize") * 1 || this.props.pageSize
      });
    });
  };

  toggleForm = () => {
    this.setState({
      expandForm: !this.state.expandForm
    })
  };

  handleChange = current => {
    setSessionStorage("giftListCurrent", current);
    this.props.dispatch({
      type: 'gift/fetch',
      payload: {
        pageSize: getSessionStorage("superLikeListPageSize") * 1 || this.props.pageSize,
        page: current
      },
    });
  };

  handleSizeChange = (current, size) => {
    setSessionStorage("superLikeListCurrent", current);
    setSessionStorage("superLikeListPageSize", size);
    this.props.dispatch({
      type: 'gift/fetch',
      payload: {
        pageSize: size,
        page: current
      },
    });
  };

  handleDetail = id => {
    this.props.dispatch({
      type: 'superLike/redirectDetail',
      payload: {
        id: id,
        siteId: parse(this.props.location.search.substr(1)).id
      },
    });
  };

  handleCreate = () => {
    this.props.dispatch({
      type: 'superLike/add'
      // payload: {
      //   id: parse(this.props.location.search.substr(1)).id
      // },
    });
  };

  renderForm() {
    return this.state.expandForm ? this.renderAdvancedForm() : this.renderSimpleForm();
  }

  renderSimpleForm() {
    const {getFieldDecorator} = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col md={5} sm={24}>
            <FormItem label="礼品名称">
              {getFieldDecorator('name')(<Input placeholder="请输入礼品名称"/>)}
            </FormItem>
          </Col>
          {/*<Col md={5} sm={24}>*/}
          {/*<FormItem label="所属商户">*/}
          {/*{getFieldDecorator('siteName')(<Input placeholder="请输入所属商户"/>)}*/}
          {/*</FormItem>*/}
          {/*</Col>*/}
          {/*<Col md={5} sm={24}>*/}
          {/*<FormItem label="所属推荐聚点">*/}
          {/*{getFieldDecorator('gatheringName')(<Input placeholder="请输入推荐聚点名称"/>)}*/}
          {/*</FormItem>*/}
          {/*</Col>*/}
          <Col md={4} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  onSelectChange = (selectedRowKeys) => {
    this.setState({selectedRowKeys});
  };

  handleDelete = (id) => {
    const {selectedRowKeys} = this.state;
    let ids = [];
    if (selectedRowKeys.length) {
      ids = selectedRowKeys;
    } else {
      ids.push(id);
    }
    this.props.dispatch({
      type: 'superLike/delete',
      payload: {
        ids
        // siteId: parse(this.props.location.search.substr(1)).id,
        // columns: [{
        //   name: 'site.id',
        //   relation: 'EQ',
        //   search: parse(this.props.location.search.substr(1)).id,
        //   type: 'T_STRING'
        // }]
      }
    })
  };

  handleTableChange = (pagination, filters, sorter) => {
    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;
    setSessionStorage("superLikeListCurrent", current);
    setSessionStorage("superLikeListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order,
      siteId: parse(this.props.location.search.substr(1)).id
    })
  };

  formartMethod(str) {
    const methodList = str.split(',');
    let newStr = '';
    methodList.map(item => {
      newStr += this.state.methodEnum[item] + ','
    });
    return newStr
  }

  render() {
    const {
      list,
      loading,
      handleDetail,
      pageSize,
      current,
      handleSizeChange,
      total,
      handleDelete,
    } = this.props;

    const {selectedRowKeys} = this.state;

    const Info = ({title, value, bordered}) => (
      <div className={styles.headerInfo}>
        <span>{title}</span>
        <p>{value}</p>
        {bordered && <em/>}
      </div>
    );

    const extraContent = (
      <div className={styles.extraContent}>
        <Button icon="plus" type="primary" onClick={this.handleCreate}>
          新建礼品
        </Button>
      </div>
    );

    const pagination = {
      pageSize: getSessionStorage('superLikeListPageSize') * 1 || pageSize,
      current: getSessionStorage('superLikeListCurrent') * 1 || current,
      total: total,
      showSizeChanger: true
    };

    const rowSelection = {
      selectedRowKeys,
      onChange: this.onSelectChange
    };

    const columns = [
      {
        title: '礼物id',
        dataIndex: 'souvenirId',
        key: 'souvenirId'
      },
      {
        title: 'VIP折扣',
        dataIndex: 'discount',
        key: 'discount'
      },
      {
        title: 'VIP价格',
        dataIndex: 'money',
        key: 'money'
      },
      {
        title: '礼物名称',
        dataIndex: 'souvenirName',
        key: 'souvenirName'
      },
      {
        title: '礼物原价',
        dataIndex: 'souvenirMoney',
        key: 'souvenirMoney'
        // sorter: true
      },
      {
        title: '礼物领取方式',
        dataIndex: 'souvenirMethod',
        // key: 'souvenirMethod',
        render: (text, record) => (
          <span>{this.formartMethod(record.souvenirMethod)}</span>
        )
      },
      {
        title: '所属商户',
        dataIndex: 'siteName',
        key: 'siteName'
      },
      // {
      //   title: '礼物库存',
      //   dataIndex: 'number',
      //   sorter: true
      // },
      // {
      //   title: '礼物简介',
      //   dataIndex: 'introduce',
      //   key: 'introduce'
      // },
      // {
      //   title: '礼物图片',
      //   dataIndex: 'pic',
      //   render: (text, record) => (
      //     <img src={record.pic} alt={record.name} style={{width: '40px', height: '40px'}}/>
      //   )
      // },
      // {
      //   title: '创建时间',
      //   dataIndex: 'createDate',
      //   sorter: true,
      //   render: (text, record) => (
      //     <span>
      //       {moment(record.createDate).format("YY/MM/DD HH:MM:SS")}
      //     </span>
      //   )
      // },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            <a onClick={this.handleDetail.bind(null, record.id)}>编辑</a>
            <Divider type="vertical"/>
            <Popconfirm placement="top" onConfirm={this.handleDelete.bind(null, record.id)} title='确定要删除吗？' okText="确定"
                        cancelText="取消"><a>删除</a></Popconfirm>
          </span>
        )
      }
    ];


    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Card
            className={styles.listCard}
            bordered={false}
            title="礼品列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 32px 40px 32px'}}
            extra={extraContent}
          >
            <Table
              bordered
              loading={loading}
              rowKey={record => record.id}
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    )
  }
}
