import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {
  Card,
  Row,
  Col,
  Radio,
  Input,
  InputNumber,
  Button,
  Icon,
  Modal,
  Divider,
  Popconfirm,
  Upload,
  Table,
  Form,
  Tabs,
  Select,
  DatePicker
} from 'antd';

import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {
  setSessionStorage,
  getSessionStorage,
  removeSessionStorage,
  sortTable,
  searchTable,
  getLocalStorage,
  ApiPostDownloadFile,
} from '../../utils/utils';

import styles from './SystemList.less';

const FormItem = Form.Item;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const {Search} = Input;
const {TextArea} = Input;
const TabPane = Tabs.TabPane;
const {RangePicker} = DatePicker;

@connect(({svip, loading}) => ({
  loading: loading.models.svip,
  submitting: loading.effects['svip/submit'],
  list: svip.list,
  // label: svip.label,
  pageSize: svip.pageSize,
  page: svip.page,
  total: svip.total,
  all: svip.all,
  detailPageSize: svip.detailPageSize,
  detailPage: svip.detailPage
}))
@Form.create()
export default class SvipList extends PureComponent {

  state = {
    addModal: false,
    editModal: false,
    name: '',
    remark: '',
    id: '',
    formValues: {},
    filters: {},
    order: [
      {
        "direction": "DESC",
        "property": "svipStartTime"
      }
    ],
    integral: ''
  };

  fetch = (payload) => {
    this.props.dispatch({
      type: 'svip/fetch',
      payload: {
        ...payload,
      },
    });
  };

  componentDidMount() {
    const type = getSessionStorage("listType") || 'SINGLE';

    if (type === 'SINGLE') {
      this.fetch({
        page: getSessionStorage("svipListCurrent") * 1 || this.props.page,
        pageSize: getSessionStorage("svipListPageSize") * 1 || this.props.pageSize,
      });
    } else {
      this.props.dispatch({
        type: 'svip/fetchProfile',
        payload: {
          pageSize: getSessionStorage("svipDetailListPageSize") * 1 || this.props.pageSize,
          page: getSessionStorage("svipDetailListCurrent") * 1 || this.props.page
        },
      });
    }

  }

  componentWillUnmount() {
    removeSessionStorage("svipListCurrent");
    removeSessionStorage("svipListPageSize");
    removeSessionStorage("svipDetailListCurrent");
    removeSessionStorage("svipDetailListPageSize");
    removeSessionStorage("listType");
  }

  handleExport = (e) => {
    e.preventDefault();
    const {columns, startTime, endTime} = this.state.filters;
    const {pageSize} = this.props;

    if (getSessionStorage('listType') === 'ALL') {
      //明细列表
      //API
      // ApiPostDownloadFile('/api/v1/export/integralApply', {
      ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/integralApply', {
        columns,
        order: [
          {
            "direction": "DESC",
            "property": "createDate"
          }
        ],
        page: this.props.detailPage,
        pageSize: getSessionStorage('svipDetailListPageSize') * 1 || pageSize,
        startTime,
        endTime
      });
    } else {
      //伙伴列表
      //API
      // ApiPostDownloadFile('/api/v1/export/sviper', {
      ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/sviper', {
        columns,
        order: this.state.order,
        page: getSessionStorage('svipListCurrent') * 1 || this.props.page,
        pageSize: getSessionStorage('svipListPageSize') * 1 || pageSize,
      });
      // const {form} = this.props;
      // form.validateFields(['nickName'], (err, fieldsValue) => {
      //   if (err) return;
      //   this.setState({
      //     formValues: fieldsValue,
      //   });
      //   const values = {
      //     ...fieldsValue,
      //   };
      //   const columns = searchTable(values);
      //   if (this.state.filters && this.state.filters.columns) {
      //     this.state.filters.columns.map((item) => {
      //       columns.push({
      //         ...item,
      //       });
      //     });
      //   }
      //
      // });
    }


  };

  check = (rule, value, callback) => {
    const form = this.props.form;
    if (value && value.indexOf("#") > -1) {
      callback('标签名称不能包含#！');
    } else {
      callback();
    }
  };

  handleEditSubmit = (e) => {
    // alert(32);
    const page = getSessionStorage('svipListCurrent') || this.props.page;
    const pageSize = getSessionStorage('svipListPageSize') || this.props.pageSize;
    e.preventDefault();
    const {form} = this.props;
    form.validateFields(['num', 'remark'], (err, fieldsValue) => {
      if (err) return;

      const values = {
        ...fieldsValue,
      };
      this.setState({
        editModal: false,
      });
      this.handleFormReset();
      this.props.dispatch({
        type: 'svip/addSubmit',
        payload: {
          consumerId: this.state.id,
          ...fieldsValue,
          page,
          pageSize
        },
      });
    });
  };

  handleAddShow = () => {
    this.setState({
      addModal: true,
    });
  };

  handleAddHideModal = () => {
    this.setState({
      addModal: false,
    });
    this.handleFormReset();
  };

  handleEditShow = (record) => {
    this.setState({
      editModal: true,
      id: record.id,
      integral: record.integral
    });
  };

  handleEditHideModal = () => {
    this.setState({
      editModal: false,
    });
    this.handleFormReset();
  };

  handleDelete = (record) => {
    this.props.dispatch({
      type: 'svip/delete',
      payload: {
        id: record.id,
        // page: getSessionStorage("labelListCurrent") || this.props.page,
        // pageSize: getSessionStorage("labelListPageSize") || this.props.pageSize,
      }
    });
  };

  // handleRecovery = (record) => {
  //   this.props.dispatch({
  //     type: 'label/recovery',
  //     payload: {
  //       id: record.id,
  //       "page": getSessionStorage("svipListCurrent") * 1 || this.props.page,
  //       "pageSize": getSessionStorage("svipListPageSize") * 1 || this.props.pageSize,
  //     },
  //   });
  // };

  // handleChange = (current) => {
  //   setSessionStorage("svipListCurrent", current);
  //   this.props.dispatch({
  //     type: 'label/fetchChange',
  //     payload: {
  //       pageSize: getSessionStorage("svipListPageSize") || this.props.pageSize,
  //       current: current,
  //     },
  //   });
  // };

  handleSizeChange = (current, size) => {
    setSessionStorage("svipListCurrent", current);
    setSessionStorage("svipListPageSize", size);
  };

  handleSizeChangeDetailList = (current, size) => {
    setSessionStorage("svipDetailListCurrent", current);
    setSessionStorage("svipDetailListPageSize", size);
  };

  handleFormReset = () => {
    const {form} = this.props;
    form.resetFields();
    this.setState({
      filters: {}
    })
    // removeSessionStorage("svipListCurrent");
    // removeSessionStorage("svipListPageSize");
    // removeSessionStorage("svipDetailListCurrent");
    // removeSessionStorage("svipDetailListPageSize");
  };

  renderEditModal() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="钻石积分" {...formItemLayout}>
          {getFieldDecorator('num', {
            // initialValue: this.state.integral||'',
            rules: [{
              required: true,
              message: '请输入积分数量',
            },
              // {
              //   validator: this.checkNumber.bind(this),
              //   message: '积分格式错误，只能为数字'
              // }
            ],
          })(<InputNumber style={{width: '100%'}} placeholder="请输入积分数量"/>)}
        </FormItem>
        <FormItem label="修改原因" {...formItemLayout}>
          {getFieldDecorator('remark', {
            // initialValue: 123,
            rules: [{
              max: 40,
              message: '修改原因最多40个字符',
            }, {
              required: true,
              message: '请输入修改原因',
            }],
          })(<TextArea placeholder="请填写修改原因" autosize={{minRows: 4}}/>)}
        </FormItem>
        <div>提示：点击手动输入一条积分明细，点击提交后，成为一条记录加入到该钻石伙伴的的钻石积分明细</div>
      </Form>
    );
  }

  renderAddModal() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="标签名称" {...formItemLayout}>
          {getFieldDecorator('addName', {
            rules: [{
              max: 10,
              message: '标签名称最多10个字符',
            }, {
              required: true,
              message: '请输入标签名称',
            },
              {validator: this.check},
            ],
          })(<Input placeholder="请输入标签名称，最多10个字符。"/>)}
        </FormItem>
      </Form>
    );
  }

  renderDelete = (record) => {
    return (
      <Popconfirm placement="leftTop" title='确定要取消身份吗？' onConfirm={this.handleDelete.bind(null, record)} okText="确定"
                  cancelText="取消">
        <a>取消身份</a>
      </Popconfirm>
    );
  };

  // renderRecovery = (record) => {
  //   return (
  //     <Popconfirm placement="leftTop" title='确定要恢复吗？' onConfirm={this.handleRecovery.bind(null, record)} okText="确定" cancelText="取消">
  //       <a >恢复</a>
  //     </Popconfirm>
  //   );
  // };
  handleTabChange = (k) => {
    this.handleFormReset();
    this.setState({
      filters: {}
    });

    setSessionStorage("listType", k);


    if (k !== 'ALL') {
      this.props.dispatch({
        type: 'svip/fetch',
        payload: {
          pageSize: getSessionStorage("svipListPageSize") * 1 || 30,
          page: getSessionStorage("svipListCurrent") * 1 || 1,
        },
      });
    } else {
      this.props.dispatch({
        type: 'svip/fetchProfile',
        payload: {
          // pageSize: getSessionStorage("svipSingleListPageSize") * 1 || this.props.pagePageSize,
          // page: getSessionStorage("svipSingleListCurrent") * 1 || this.props.pageCurrent,
          pageSize: getSessionStorage("svipDetailListPageSize") * 1 || 30,
          page: getSessionStorage("svipDetailListCurrent") * 1 || 1
        },
      });
    }
  };

  handleTableChange = (pagination, filters, sorter) => {
    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;

    if (getSessionStorage('listType') !== 'ALL') {
      setSessionStorage("svipListCurrent", current);
      setSessionStorage("svipListPageSize", pageSize);

      this.fetch({
        page: current,
        pageSize,
        columns: this.state.filters.columns || columns,
        order,
      });
    } else {
      setSessionStorage("svipDetailListCurrent", current);
      setSessionStorage("svipDetailListPageSize", pageSize);
      this.props.dispatch({
        type: 'svip/fetchProfile',
        payload: {
          columns: this.state.filters.columns || columns,
          pageSize: getSessionStorage('svipDetailListPageSize') || 30,
          page: getSessionStorage('svipDetailListCurrent') || 1
        },
      });
    }
  };

  redirectProfile = (record) => {
    window.open(window.location.origin + '#/svip/svipIntegral?id=' + record.id)
  };

  handleDateChange = (date, dateStr) => {
    this.setState({
      filters: {
        startTime: dateStr[0],
        endTime: dateStr[1]
      }
    })
  }

  handleSearch = e => {
    e.preventDefault();
    const {form} = this.props;
    form.validateFields(['searchType', 'searchVal'], (err, fieldsValue) => {
      if (err) return;

      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };

      let columns = [];

      var tagName = getSessionStorage('listType');
      if (tagName === 'ALL') {
        //明细列表
        if (values.searchType === 'NICKNAME') {
          if (values.searchVal) {
            columns.push({
              "name": 'consumer.nickName',
              "relation": 'LIKE',
              "search": values.searchVal,
            });
          }
        } else {
          if (values.searchVal) {
            columns.push({
              "name": 'consumer.account.username',
              "relation": 'LIKE',
              "search": values.searchVal,
            });
          }
        }

        const {startTime, endTime} = this.state.filters;
        this.setState({
          filters: {
            columns,
            startTime,
            endTime
          }
        });

        this.props.dispatch({
          type: 'svip/fetchProfile',
          payload: {
            columns,
            startTime,
            endTime,
            pageSize: getSessionStorage('svipDetailListPageSize') || 30,
            page: 1
          },
        });
      } else {
        //伙伴列表
        if (values.searchVal) {
          if (values.searchType === 'NICKNAME') {
            if (values.searchVal) {
              columns.push({
                "name": 'nickName',
                "relation": 'LIKE',
                "search": values.searchVal,
              });
            }
          } else {
            if (values.searchVal) {
              columns.push({
                "name": 'account.username',
                "relation": 'LIKE',
                "search": values.searchVal,
              });
            }
          }
        }

        this.setState({
          filters: {
            columns,
          }
        });

        this.fetch({
          columns,
          order: this.state.filters.order,
          page: 1,
          pageSize: getSessionStorage("svipListPageSize") * 1 || this.props.pageSize,
        });
      }
    })
  };

  renderForm() {
    return this.renderSimpleForm();
  }

  renderSimpleForm() {
    const {getFieldDecorator} = this.props.form;
    const Option = Select.Option;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col md={3} sm={24}>
            <FormItem>
              {getFieldDecorator('searchType', {
                initialValue: 'NICKNAME'
              })(
                <Select
                  // style={{width: '100px', float: 'left', marginRight: '10px'}}
                  // defaultValue="NICKNAME"
                  onChange={this.handleChange}
                >
                  <Option value="NICKNAME" type='option'>真实昵称</Option>
                  <Option value="PHONE" type='option'>手机号码</Option>
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <FormItem>
              {getFieldDecorator('searchVal')(
                <Input placeholder="请输要查询的内容"/>
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  renderSimpleForm2() {
    const {getFieldDecorator} = this.props.form;
    const Option = Select.Option;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col md={3} sm={24}>
            <FormItem>
              {getFieldDecorator('searchType', {
                initialValue: 'NICKNAME'
              })(
                <Select
                  // style={{width: '100px', float: 'left', marginRight: '10px'}}
                  // defaultValue="NICKNAME"
                  onChange={this.handleChange}
                >
                  <Option value="NICKNAME" type='option'>真实昵称</Option>
                  <Option value="PHONE" type='option'>手机号码</Option>
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <FormItem label="">
              {getFieldDecorator('searchVal')(
                <Input placeholder="请输要查询的内容"/>
              )}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem>
              {getFieldDecorator('date',)(
                <RangePicker
                  onChange={this.handleDateChange}
                  showTime={{
                    hideDisabledOptions: true,
                    defaultValue: [moment('00:00:00', 'HH:mm:ss'), moment('00:00:00', 'HH:mm:ss')],
                  }}
                  format="YYYY-MM-DD HH:mm:ss"
                />
              )}
            </FormItem>
          </Col>
          <Col md={3} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  checkNumber(rule, value, callback) {
    var re = /^(-?\d+)(\.\d+)?$/;
    if (re.test(value)) {
      callback();
    } else {
      callback('积分格式错误');
    }
  };

  render() {
    const {
      loading,
      submitting,
      list,
      total,
      pageSize,
      page,
      detailPage,
      detailPageSize
    } = this.props;
    const {addModal, editModal} = this.state;
    const pagination = {
      pageSize: getSessionStorage("svipListPageSize") * 1 || pageSize,
      current: getSessionStorage("svipListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const svipDetailPagination = {
      pageSize: getSessionStorage("svipDetailListPageSize") * 1 || detailPageSize,
      current: getSessionStorage("svipDetailListCurrent") * 1 || detailPage,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChangeDetailList,
    };


    const columns = [
      {
        title: '序号',
        dataIndex: 'id',
        render: (text, record, index) => (
          index + 1 + (page - 1) * pageSize
        ),
      },
      {
        title: '真实昵称',
        dataIndex: 'nickName',
        key: 'nickName',
      },
      {
        title: '手机号码',
        dataIndex: 'username',
        key: 'username',
      },
      {
        title: '钻石积分',
        dataIndex: 'integral',
        key: 'integral',
      },
      {
        title: '钻石激活码',
        dataIndex: 'code',
        key: 'code',
      },
      {
        title: '分润额度',
        dataIndex: 'profit',
        key: 'profit',
      },
      {
        title: '上一级',
        dataIndex: 'parentPhone',
        key: 'parentPhone',
      },
      // {
      //   title: '渠道一',
      //   dataIndex: 'channel1',
      //   key: 'channel1',
      //   render: (text, record) => (
      //     <span>
      //       {record.channel1 === 'undefined' ? '' : record.channel1}
      //       </span>
      //   ),
      // },
      // {
      //   title: '渠道二',
      //   dataIndex: 'channel2',
      //   key: 'channel2',
      //   render: (text, record) => (
      //     <span>
      //       {record.channel2 === 'undefined' ? '' : record.channel2}
      //       </span>
      //   ),
      // },
      // {
      //   title: '渠道三',
      //   dataIndex: 'channel3',
      //   key: 'channel3',
      //   render: (text, record) => (
      //     <span>
      //       {record.channel3 === 'undefined' ? '' : record.channel3}
      //       </span>
      //   ),
      // },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            <a onClick={this.redirectProfile.bind(null, record)}>明细</a>
            <Divider type="vertical"/>
            <a onClick={this.handleEditShow.bind(null, record)}>修改积分</a>
            <Divider type="vertical"/>
            {record.discard ? this.renderRecovery(record) : this.renderDelete(record)}
          </span>
        ),
      },
    ];

    const allDetailColumns = [
      {
        title: '序号',
        dataIndex: 'id',
        render: (text, record, index) => (
          index + 1 + (page - 1) * pageSize
        ),
      },
      {
        title: '真实昵称',
        dataIndex: 'name',
        key: 'name'
      },
      {
        title: '手机号码',
        dataIndex: 'phone',
        key: 'phone'
      },
      {
        title: '积分说明',
        dataIndex: 'content',
        key: 'content'
      },
      {
        title: '积分数量',
        dataIndex: 'num',
        key: 'num'
      },
      {
        title: '产生时间',
        dataIndex: 'createDate',
        key: 'createDate',
        render: (text, record) => (
          record.createDate && moment(record.createDate).format('YYYY-MM-DD HH:mm:ss')
        ),
      }
    ];

    const uploadProps = {
      action: '/api/upload',
      listType: 'picture',
      name: 'avatar',
    };

    return (
      <PageHeaderLayout>
        {
          getSessionStorage('listType') === 'ALL' ? (
            <div className={styles.tableListForm}>{this.renderSimpleForm2()}</div>) : (
            <div className={styles.tableListForm}>{this.renderSimpleForm()}</div>)
        }
        {/*<div className={styles.tableListForm}>{this.renderForm()}</div>*/}
        <div className={styles.standardList}>
          <Modal
            title="修改积分"
            visible={editModal}
            onOk={this.handleEditSubmit}
            onCancel={this.handleEditHideModal}
            okText="确认"
            cancelText="取消"
            confirmLoading={submitting}
          >
            {this.renderEditModal()}
          </Modal>
          <Card
            className={styles.listCard}
            bordered={false}
            title="钻石伙伴列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 40px 32px'}}
          >
            <div className={styles.tableListOperator}>
              <Button icon="download" onClick={this.handleExport}>
                导出表格
              </Button>
            </div>
            <Tabs onChange={this.handleTabChange} defaultActiveKey={getSessionStorage("listType") || 'SINGLE'}>
              <TabPane tab="钻石伙伴列表" key="SINGLE">
                <Table
                  bordered
                  loading={loading}
                  rowKey='id'
                  columns={columns}
                  dataSource={list}
                  pagination={pagination}
                  onChange={this.handleTableChange}
                />
              </TabPane>
              <TabPane tab="所有钻石伙伴积分明细列表" key="ALL">
                <Table
                  bordered
                  loading={loading}
                  rowKey='id'
                  columns={allDetailColumns}
                  dataSource={list}
                  pagination={svipDetailPagination}
                  onChange={this.handleTableChange}
                />
              </TabPane>
            </Tabs>
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
