import React, { PureComponent } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import {
  Table,
  Card,
  Button,
  Form,
  Row,
  Col,
  Input,
  Icon,
  Select,
  DatePicker,
} from 'antd';
import styles from './SystemList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import { setSessionStorage, getSessionStorage } from '../../utils/utils';
const FormItem = Form.Item;
const { RangePicker } = DatePicker;
const Option = Select.Option;
@connect(({ system, loading }) => ({
  list: system.list,
  total: system.total,
  loading: loading.models.system,
  pageSize: system.pageSize,
}))
@Form.create()
export default class SystemList extends PureComponent {

  state = {
    expandForm: false,
    startTime: null,
    endTime: null,
  }

  componentDidMount() {
    this.props.dispatch({
      type: 'system/fetch',
      payload: {
        count: this.props.pageSize,
        current: 1,
      },
    });
  }

  handleExport() {
    console.log('点击了导出文件表格按钮');
  }

  handleChange = (current) => {
    this.props.dispatch({
      type: 'system/fetchChange',
      payload: {
        count: this.props.pageSize,
        current: current,
      },
    });
  };

  handleSizeChange = (current, size) => {
    this.props.dispatch({
      type: 'system/fetchChange',
      payload: {
        count: size,
        current: current,
      },
    });
  };

  handleSearch = e => {
    e.preventDefault();
    const { dispatch, form, pageSize } = this.props;

    form.validateFields((err, fieldsValue) => {
      if (err) return;

      const values = {
        ...fieldsValue,
        createdAt: {
          startTime: this.state.startTime,
          endTime: this.state.endTime,
        }
      };
      console.log(values)
      dispatch({
        type: 'system/fetch',
        payload: {
          ...values,
          pageSize: pageSize,
          current: 1,
        },
      });
    });
  };

  toggleForm = () => {
    this.setState({
      expandForm: !this.state.expandForm,
    });
  };

  handleDateChange = (date, dateString) => {
    this.setState({
      startTime: dateString[0],
      endTime: dateString[1],
    });
  }

  renderForm() {
    return this.state.expandForm ? this.renderAdvancedForm() : this.renderSimpleForm();
  }
  renderSimpleForm() {
    const { getFieldDecorator } = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
            <FormItem label="操作账号">
              {getFieldDecorator('account')(<Input placeholder="请输入操作用户" />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="操作内容">
              {getFieldDecorator('content')(<Input placeholder="请输入操作内容" />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
                重置
              </Button>
              <a style={{ marginLeft: 8 }} onClick={this.toggleForm}>
                展开 <Icon type="down" />
              </a>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  renderAdvancedForm() {
    const { getFieldDecorator } = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
            <FormItem label="操作账号">
              {getFieldDecorator('account')(<Input placeholder="请输入操作用户" />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="操作内容">
              {getFieldDecorator('content')(<Input placeholder="请输入操作内容" />)}
            </FormItem>
          </Col>
          <Col md={6} sm={24}>
            <Button type="primary" htmlType="submit">
              查询
            </Button>
            <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
              重置
            </Button>
            <a style={{ marginLeft: 8 }} onClick={this.toggleForm}>
              收起 <Icon type="up" />
            </a>
          </Col>
        </Row>
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
            <FormItem label="操作时间">
              {getFieldDecorator('createdAt')(<RangePicker title='请选择操作时间' onChange={this.handleDateChange} />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="是否成功">
              {getFieldDecorator('content')(
                <Select placeholder="请选择操作是否成功" style={{ width: 165 }}>
                  <Option value='操作成功'>操作成功</Option>
                  <Option value='操作失败'>操作失败</Option>
                </Select>
              )}
            </FormItem>
          </Col>
        </Row>
      </Form>
    );
  }

  render() {
    const { list, loading, total, pageSize, } = this.props;

    const pagination = {
      pageSize: pageSize,
      total: total,
      showSizeChanger: true,
      onChange: this.handleChange,
      onShowSizeChange: this.handleSizeChange,
    };

    const columns = [
      {
        title: '操作账号',
        dataIndex: 'id',
        key: 'id',
      },
      {
        title: '操作内容',
        dataIndex: 'codeNum',
        key: 'codeNum',
      },
      {
        title: '操作时间',
        dataIndex: 'createTime',
        key: 'time',
      },
      {
        title: '是否成功',
        dataIndex: 'batch',
        key: 'batch',
      },
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Card
            className={styles.listCard}
            bordered={false}
            title="系统操作日志列表"
            style={{ marginTop: 24 }}
            bodyStyle={{ padding: '0 32px 40px 32px' }}
          >
            <Button className={styles.btnBt20} icon="plus" type="primary" onClick={this.handleExport}>
              导出表格
            </Button>
            <Table
              bordered
              loading={loading}
              rowKey={record => record.id}
              columns={columns}
              dataSource={list}
              pagination={pagination}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
