import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {
  Card,
  Row,
  Col,
  Radio,
  Input,
  Button,
  Icon,
  Modal,
  Divider,
  Popconfirm,
  Upload,
  Table,
  Form,
} from 'antd';

import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {
  setSessionStorage,
  getSessionStorage,
  removeSessionStorage,
  sortTable,
  searchTable,
  getLocalStorage,
  ApiPostDownloadFile,
} from '../../utils/utils';

import styles from './SystemList.less';

const FormItem = Form.Item;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const {Search} = Input;
const {TextArea} = Input;

@connect(({config, loading}) => ({
  loading: loading.models.config,
  submitting: loading.effects['config/submit'],
  list: config.list,
  config: config.config,
  pageSize: config.pageSize,
  page: config.page,
  total: config.total,
  all: config.all,
}))
@Form.create()
export default class SystemConfig extends PureComponent {

  state = {
    editModal: false,
    config: {}
  };

  fetch = (payload) => {
    this.props.dispatch({
      type: 'config/fetch',
      payload: {
        ...payload,
      },
    });
  };

  componentDidMount() {
    this.fetch({
      page: getSessionStorage("sysConfigCurrent") * 1 || this.props.page,
      pageSize: getSessionStorage("sysConfigListPageSize") * 1 || this.props.pageSize,
    });
  }

  componentWillUnmount() {
    removeSessionStorage("sysConfigListCurrent");
    removeSessionStorage("sysConfigListPageSize");
  }

  handleEditSubmit = (e) => {
    e.preventDefault();
    const {form} = this.props;
    form.validateFields(['editValue'], (err, fieldsValue) => {
      if (err) return;

      const values = {
        ...fieldsValue,
      };

      this.setState({
        editModal: false,
      });

      this.handleFormReset();
      // console.log(values);
      this.props.dispatch({
        type: 'config/update',
        payload: {
          id:this.state.config.id,
          name: this.state.config.name,
          value: values.editValue
        }
      })
    });
    // const {form} = this.props;
    // form.validateFields(['editName'], (err, fieldsValue) => {
    //   if (err) return;
    //
    //   const values = {
    //     ...fieldsValue,
    //   };
    //   this.setState({
    //     editModal: false,
    //   });
    //   this.handleFormReset();
    //   this.props.dispatch({
    //     type: 'label/submit',
    //     payload: {
    //       "name": values.editName,
    //       "id": this.state.id,
    //       "page": getSessionStorage("labelListPageSize") * 1 || this.props.page,
    //       "pageSize": getSessionStorage("labelListPageSize") * 1 || this.props.pageSize,
    //     },
    //   });
    // });
  };

  handleEditShow = (record) => {
    this.setState({
      editModal: true,
      config: {...record}
    });
    this.props.dispatch({
      type: 'config/fetchProfile',
      payload: {
        ...record
      }
    });
  };

  handleEditHideModal = () => {
    this.setState({
      editModal: false,
    });
    this.handleFormReset();
  };

  handleChange = (current) => {
    setSessionStorage("sysConfigListCurrent", current);
    this.props.dispatch({
      type: 'config/fetchChange',
      payload: {
        pageSize: getSessionStorage("sysConfigListPageSize") || this.props.pageSize,
        current: current,
      },
    });
  };

  handleSizeChange = (current, size) => {
    setSessionStorage("sysConfigListCurrent", current);
    setSessionStorage("sysConfigListPageSize", size);
    this.props.dispatch({
      type: 'config/fetchChange',
      payload: {
        pageSize: size,
        current: current,
      },
    });
  };

  handleFormReset = () => {
    const {form} = this.props;
    form.resetFields();
  };

  renderEditModal() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="参数值" {...formItemLayout}>
          {getFieldDecorator('editValue', {
            initialValue: this.props.config && this.props.config.value,
            rules: [{
              required: true,
              message: '请输入修改参数',
            }],
          })(<TextArea placeholder="请输入修改参数。" autosize={{minRows: 4}}/>)}
        </FormItem>
      </Form>
    );
  }

  handleTableChange = (pagination, filters, sorter) => {
    const {form} = this.props;
    let values = null;
    form.validateFields(['name'], (err, fieldsValue) => {
      if (err) return;

      values = {
        ...fieldsValue,
      };
    });
    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;
    this.setState({
      filters: {
        columns,
        order,
      }
    });
    if (values) {
      Object.keys(values).map((item) => {
        if (values[item]) {
          columns.push({
            name: item,
            relation: "LIKE",
            search: values[item],
          })
        }
      });
    }

    setSessionStorage("sysConfigListCurrent", current);
    setSessionStorage("sysConfigListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order,
    });
  };

  render() {
    const {
      loading,
      submitting,
      list,
      total,
      pageSize,
      page,
    } = this.props;
    const {addModal, editModal} = this.state;
    const pagination = {
      pageSize: getSessionStorage("sysConfigListPageSize") * 1 || pageSize,
      current: getSessionStorage("sysConfigListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const columns = [
      {
        title: '序号',
        dataIndex: 'id',
        key: 'id'
      },
      {
        title: '参数名',
        dataIndex: 'name',
        key: 'name'
      },
      {
        title:'别名',
        dataIndex:'alias'
      },
      {
        title: '参数值',
        dataIndex: 'value',
        key: 'value',
        width: 500,
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            {record.discard ? '' : <a onClick={this.handleEditShow.bind(null, record)}>修改</a>}
          </span>
        ),
      },
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <Modal
            title="修改参数"
            visible={editModal}
            onOk={this.handleEditSubmit}
            onCancel={this.handleEditHideModal}
            okText="确认"
            cancelText="取消"
            confirmLoading={submitting}
          >
            {this.renderEditModal()}
          </Modal>
          <Card
            className={styles.listCard}
            bordered={false}
            title="全局配置"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 40px 32px'}}
          >
            <Table
              bordered
              loading={loading}
              rowKey='id'
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
