import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {
  Table,
  Card,
  Button,
  Form,
  Row,
  Col,
  Upload,
  Input,
  Modal,
  Select,
  DatePicker,
  InputNumber,
  Icon,
  message,
} from 'antd';
import styles from './SystemList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {
  setSessionStorage,
  getSessionStorage,
  removeSessionStorage,
  sortTable,
  upYunAuthorization,
} from '../../utils/utils';

const FormItem = Form.Item;
const {RangePicker} = DatePicker;
const Option = Select.Option;
const {TextArea} = Input;
@connect(({version, loading}) => ({
  list: version.list,
  total: version.total,
  loading: loading.models.version,
  pageSize: version.pageSize,
  page: version.page,
  version: version.version,
}))
@Form.create()
export default class versionList extends PureComponent {

  state = {
    filters: {},
    modal: false,
    modalVisible: false,
    type: '',
    selectType: '',
    sdk: '',
    id: '',
  };

  componentDidMount() {
    this.fetch({
      page: getSessionStorage("versionListCurrent") * 1 || this.props.page,
      pageSize: getSessionStorage("versionListPageSize") * 1 || this.props.pageSize,
    });
  }

  componentWillUnmount() {
    removeSessionStorage("versionListCurrent");
    removeSessionStorage("versionListPageSize")
  }

  fetch = (payload) => {
    this.props.dispatch({
      type: 'version/fetch',
      payload,
    });
  };

  fetchDetail = (id) => {
    this.setState({
      modalVisible: true,
      id,
    });
    this.props.dispatch({
      type: 'version/fetchVersion',
      payload: {
        id,
      },
    });
  };

  handleFormReset = () => {
    const {form} = this.props;
    form.resetFields();
  }

  handleTableChange = (pagination, filters, sorter) => {
    const {form} = this.props;
    let values = null;
    form.validateFields((err, fieldsValue) => {
      if (err) return;

      values = {
        ...fieldsValue,
      };
    });
    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;
    this.setState({
      filters: {
        columns,
        order,
      }
    });
    if (values) {
      Object.keys(values).map((item) => {
        if (values[item]) {
          columns.push({
            name: item,
            relation: "LIKE",
            search: values[item],
          })
        }
      });
    }

    setSessionStorage("versionListCurrent", current);
    setSessionStorage("versionListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order,
    });
  };

  handleSizeChange = (current, size) => {
    setSessionStorage("versionListCurrent", current);
    setSessionStorage("versionListPageSize", size);
    this.props.dispatch({
      type: 'version/fetch',
      payload: {
        pageSize: size,
        pageNo: current,
      },
    });
  };

  handleCreate = () => {
    this.setState({
      modal: true,
    });
  };

  handleHideModal = () => {
    this.setState({
      modal: false,
      selectType: '',
    });
    this.handleFormReset();
  };

  handleHideEditModal = () => {
    this.setState({
      modalVisible: false,
      selectType: '',
    });
    this.handleFormReset();
  };

  handleAddSubmit = (e) => {
    e.preventDefault();
    const {dispatch, form, pageSize, page} = this.props;
    const {selectType} = this.state;
    let res = ['versionNo', 'versionName', 'appName', 'compulsory', 'content', 'phoneSys'];
    if (selectType === 'IOS') {
      res.push('link');
    }
    form.validateFields(res, (err, fieldsValue) => {
      if (err) return;
      this.setState({
        modal: false,
      });
      this.handleFormReset();
      const values = {
        ...fieldsValue,
      };
      if (selectType === 'IOS') {
        dispatch({
          type: 'version/addSubmit',
          payload: {
            value: {
              ...values,
            },
            pagination: {
              pageSize: getSessionStorage('versionListPageSize') * 1 || pageSize,
              page: getSessionStorage('versionListCurrent') * 1 || page,
            },
          },
        });
      }
      if (selectType === 'ANDROID'||'BAR') {
        dispatch({
          type: 'version/addSubmit',
          payload: {
            value: {
              ...values,
              link: this.state.sdk,
            },
            pagination: {
              pageSize: getSessionStorage('versionListPageSize') * 1 || pageSize,
              page: getSessionStorage('versionListCurrent') * 1 || page,
            },
          },
        });
      }
    });
  };

  handleSelect = (value) => {
    this.setState({
      selectType: value,
    });
  };

  renderModal() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };

    return (
      <Form>
        <FormItem label="版本号" {...formItemLayout}>
          {getFieldDecorator('versionNo', {
            rules: [
              {
                required: true,
                message: '请输入版本号',
              }],
          })(<InputNumber style={{width: '100%'}} placeholder="请输入版本号"/>)}
        </FormItem>
        <FormItem label="版本名称" {...formItemLayout}>
          {getFieldDecorator('versionName', {
            rules: [
              {
                required: true,
                message: '请输入版本名称',
              }],
          })(<Input placeholder="请输入版本名称如1.1.1"/>)}
        </FormItem>
        <FormItem label="APP类型" {...formItemLayout}>
          {getFieldDecorator('phoneSys', {
            rules: [
              {
                required: true,
                message: '请选择APP类型',
              }],
          })(<Select
            onChange={this.handleSelect}
            placeholder="请选择APP类型">
            <Option value='IOS'>IOS</Option>
            <Option value='ANDROID'>ANDROID</Option>
            <Option value='BAR'>BAR</Option>
          </Select>)}
        </FormItem>
        {this.renderSelect("add")}
        <FormItem label="强制更新" {...formItemLayout}>
          {getFieldDecorator('compulsory', {
            rules: [
              {
                required: true,
                message: '请选择是否开启强制更新',
              }],
          })(
            <Select
              placeholder="请选择是否开启强制更新">
              <Option value='false'>否</Option>
              <Option value='true'>是</Option>
            </Select>
          )}
        </FormItem>
        <FormItem label="版本信息" {...formItemLayout}>
          {getFieldDecorator('content', {
            rules: [{
              required: true,
              message: '请输入版本信息',
            },{
              max:200,
              message:'版本信息最多200个字符'
            }],
          })(<TextArea placeholder="请输入版本信息。" autosize={{minRows: 4}}/>)}
        </FormItem>
      </Form>
    );
  }

  renderEditModal() {
    const {getFieldDecorator} = this.props.form;
    const {version} = this.props;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };

    return (
      <Form>
        <FormItem label="版本号" {...formItemLayout}>
          {getFieldDecorator('versionNo1', {
            initialValue: version && version.versionNo,
          })(<InputNumber disabled style={{width: '100%'}} placeholder="请输入版本号"/>)}
        </FormItem>
        <FormItem label="版本号" {...formItemLayout}>
          {getFieldDecorator('versionName1', {
            initialValue: version && version.versionName,
          })(<Input disabled placeholder="请输入版本名称如1.1.1"/>)}
        </FormItem>
        <FormItem label="APP名称" {...formItemLayout}>
          {getFieldDecorator('phoneSys1', {
            initialValue: version && version.phoneSys,
          })(<Select
            disabled
            onChange={this.handleSelect}
            placeholder="请选择APP类型">
            <Option value='IOS'>IOS</Option>
            <Option value='ANDROID'>ANDROID</Option>
            <Option value='BAR'>BAR</Option>
          </Select>)}
        </FormItem>
        <FormItem label="下载链接" {...formItemLayout}>
          {getFieldDecorator('link1', {
            initialValue: version && version.link,
          })(<Input disabled placeholder="请输入下载链接"/>)}
        </FormItem>
        <FormItem label="强制更新" {...formItemLayout}>
          {getFieldDecorator('compulsory1', {
            initialValue: version && version.compulsory ? 'true' : 'false',
          })(
            <Select
              disabled
              placeholder="请选择是否开启强制更新">
              <Option value='false'>否</Option>
              <Option value='true'>是</Option>
            </Select>)}
        </FormItem>
        <FormItem label="版本信息" {...formItemLayout}>
          {getFieldDecorator('content1', {
            initialValue: version && version.content,
          })(<TextArea disabled placeholder="请输入版本信息。" autosize={{minRows: 4}}/>)}
        </FormItem>
      </Form>
    );
  };

  renderSelect() {
    if (this.state.selectType === 'IOS') {
      return this.renderIOS();
    }
    if (this.state.selectType === 'ANDROID'||'BAR') {
      return this.renderSDK();
    }
    return;
  }

  renderSDK() {
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };

    const date = Date.parse(new Date());

    const uploadProps = {
      action: 'http://v0.api.upyun.com/image-seemore',
      listType: 'picture',
      data: {
        'authorization': upYunAuthorization("sdk", date).authorization,
        'policy': upYunAuthorization("sdk", date).policy,
      },
      name: 'file',
      headers: {
        'X-Requested-With': null,
      },
      onChange: (info) => {
        const status = info.file.status;
        if (status === 'done') {
          message.success(`${info.file.name} 文件上传成功.`);
          this.setState({
            sdk: 'http://image.seemore.club' + JSON.parse(event.currentTarget.response).url,
          });
        } else if (status === 'error') {
          message.error(`${info.file.name} 文件上传失败，请重新上传。`);
        }
      },
    };
    return (
      <FormItem
        {...formItemLayout}
        label="上传SDK"
      >
        <Upload {...uploadProps}>
          <Button>
            <Icon type="upload"/> 点击上传
          </Button>
        </Upload>
      </FormItem>
    );
  }


  renderIOS() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };

    return (
      <FormItem
        {...formItemLayout}
        label="IOS下载地址"
      >
        {getFieldDecorator('link', {
          rules: [{
            required: true,
            message: '请输入下载地址',
          }],
        })(<Input placeholder="请输入下载地址"/>)}
      </FormItem>
    );
  }

  render() {
    const {
      list,
      loading,
      total,
      pageSize,
      page,
    } = this.props;

    const {modalVisible, modal} = this.state;

    const extraContent = (
      <div className={styles.extraContent}>
        <Button icon="plus" type="primary" onClick={this.handleCreate}>
          新建版本
        </Button>
      </div>
    );

    const columns = [
      {
        title: '序号',
        dataIndex: 'id',
        render: (text, record, index) => (index + 1 + (page - 1) * pageSize),
      },
      {
        title: '版本号',
        dataIndex: 'versionNo',
        key: 'versionNo',
      },
      {
        title: '版本名称',
        dataIndex: 'versionName',
        key: 'versionName',
      },
      {
        title: '强制更新',
        dataIndex: 'compulsory',
        render: (text, record) => (
          <span>
            {record.compulsory ? '是' : '否'}
          </span>
        ),
      },
      {
        title: 'APP名称',
        dataIndex: 'phoneSys',
        key: 'phoneSys',
      },
      {
        title: '创建时间',
        dataIndex: 'createDate',
        render: (text, record) => (
          <span>
            {moment(record.createDate).format('YYYY-MM-DD HH:mm:ss')}
          </span>
        ),
        sorter: true,
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <a onClick={this.fetchDetail.bind(null, record.id)}>查看详情</a>
        ),
      },
    ];

    const pagination = {
      total,
      showSizeChanger: true,
      pageSize: getSessionStorage("versionListPageSize") * 1 || pageSize,
      current: getSessionStorage("versionListCurrent") * 1 || page,
    };

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <Modal
            title="新建版本"
            visible={modal}
            onOk={this.handleAddSubmit}
            onCancel={this.handleHideModal}
            okText="确认"
            cancelText="取消"
          >
            {this.renderModal()}
          </Modal>
          <Modal
            title="版本详情"
            visible={modalVisible}
            onOk={this.handleHideEditModal}
            onCancel={this.handleHideEditModal}
            footer={null}
          >
            {this.renderEditModal()}
          </Modal>
          <Card
            className={styles.listCard}
            bordered={false}
            title="版本列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 32px 40px 32px'}}
            extra={extraContent}
          >
            <Table
              bordered
              loading={loading}
              rowKey={record => record.id}
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
