import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {
  Table,
  Form,
  Card,
  Row,
  Col,
  Radio,
  Input,
  Button,
  Icon,
  Avatar,
  Modal,
  Divider,
  Popconfirm,
  Select,
  InputNumber,
  DatePicker,
} from 'antd';
import styles from './PayList.less';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {
  setSessionStorage,
  getSessionStorage,
  sortTable,
  searchTable,
  removeSessionStorage,
  ApiPostDownloadFile,
} from '../../utils/utils';

const FormItem = Form.Item;
const {Option} = Select;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const {Search, TextArea} = Input;
const {RangePicker} = DatePicker;
@connect(({vip, loading}) => ({
  list: vip.list,
  loading: loading.models.vip,
  submitting: loading.effects['vip/addSubmit'],
  total: vip.total,
  pageSize: vip.pageSize,
  confirmLoading: vip.confirmLoading,
  page: vip.page,
  vip: vip.vip,
}))
@Form.create()
export default class VIPList extends PureComponent {
  state = {
    modalVisible: false,
    modal: false,
    confirmLoading: false,
    modalCreateCard: false,
    modalActivate: false,
    id: 0,
    filters: {},
    order: [
      {
        "direction": "DESC",
        "property": "createDate"
      }
    ],
    formValues: {},
    start: null,
    end: null
  };

  fetch = (payload) => {
    this.props.dispatch({
      type: 'vip/fetch',
      payload: {
        "order": [
          {
            "direction": "DESC",
            "property": "id"
          }
        ],
        ...payload,
      },
    });
  };

  componentDidMount() {
    this.fetch({
      pageSize: getSessionStorage('vipListPageSize') * 1 || this.props.pageSize,
      page: getSessionStorage('vipListCurrent') * 1 || this.props.page,
    });
  }

  componentWillUnmount() {
    removeSessionStorage("vipListCurrent");
    removeSessionStorage("vipListPageSize")
  }

  handleCreate = () => {
    this.setState({
      modalVisible: true,
    });
  };

  handleCreateCard = () => {
    this.setState({
      modalCreateCard: true,
    });
  };

  handleCreateCardCancel = () => {
    this.setState({
      modalCreateCard: false,
    });
  };

  handleActivate = () => {
    this.setState({
      modalActivate: true,
    });
  };

  handleActivateCancel = () => {
    this.setState({
      modalActivate: false,
    });
  };

  handleUseAtChange = (date, dateString) => {
    this.setState({
      useAt: dateString,
    });
  };

  handleDelete = (record) => {
    this.props.dispatch({
      type: 'vip/delete',
      payload: {
        id: record.id,
        pageSize: getSessionStorage('vipListPageSize') * 1 || this.props.pageSize,
        page: getSessionStorage('vipListCurrent') * 1 || this.props.page,
      },
    });
  };

  handleRemark = (e) => {
    e.preventDefault();
    const {dispatch, form} = this.props;
    form.validateFields(['remark'], (err, fieldsValue) => {
      if (err) return;
      const values = {
        ...fieldsValue,
      };
      this.setState({
        modal: false,
      });
      this.props.dispatch({
        type: 'vip/remarkSubmit',
        payload: {
          id: this.state.id,
          ...values,
          pageSize: getSessionStorage('vipListPageSize') * 1 || this.props.pageSize,
          page: getSessionStorage('vipListCurrent') * 1 || this.props.page,
        },
      });
    });

  };

  handleDetail = record => {
    this.props.dispatch({
      type: 'vip/redirectDetail',
      payload: record,
    });
  };

  handleHideModal = () => {
    this.setState({
      modalVisible: false,
    });
  };

  handleChange = (current) => {
    setSessionStorage('vipListCurrent', current);
    this.props.dispatch({
      type: 'vip/fetchChange',
      payload: {
        pageSize: this.props.pageSize,
        page: current,
      },
    });
  };

  handleSizeChange = (current, size) => {
    setSessionStorage('vipListPageSize', size);
    setSessionStorage('vipListCurrent', current);
    this.props.dispatch({
      type: 'vip/fetchChange',
      payload: {
        pageSize: size,
        page: current,
      },
    });
  };

  handleAddSubmit = (e) => {
    e.preventDefault();
    const {dispatch, form} = this.props;
    form.validateFields(['size'], (err, fieldsValue) => {
      if (err) return;
      const values = {
        ...fieldsValue,
      };
      this.setState({
        modalVisible: false,
      });
      dispatch({
        type: 'vip/addSubmit',
        payload: {
          ...values,
          pageSize: getSessionStorage('vipListPageSize') * 1 || this.props.pageSize,
          page: getSessionStorage('vipListCurrent') * 1 || this.props.page,
        },
      });
    });
  };

  handleActivateSubmit = (e) => {
    e.preventDefault();
    const {dispatch, form} = this.props;
    form.validateFields(['start', 'end', 'dayNum', 'channel', 'discount', 'activationInstructions'], (err, fieldsValue) => {
      if (err) return;
      const values = {
        ...fieldsValue,
      };
      this.setState({
        modalActivate: false,
      })
      dispatch({
        type: 'vip/activateSubmit',
        payload: {
          ...values,
          confirmLoading: this.props.confirmLoading,
          pageSize: getSessionStorage('vipListPageSize') * 1 || this.props.pageSize,
          page: getSessionStorage('vipListCurrent') * 1 || this.props.page,
        },
      });
    });
  };

  handleCreateCardSubmit = (e) => {
    e.preventDefault();
    const {dispatch, form} = this.props;
    form.validateFields(['start', 'end'], (err, fieldsValue) => {
      if (err) return;
      const values = {
        ...fieldsValue,
      };
      this.setState({
        modalCreateCard: false,
      })
      dispatch({
        type: 'vip/createCardSubmit',
        payload: {
          ...values,
          confirmLoading: this.props.confirmLoading,
          pageSize: getSessionStorage('vipListPageSize') * 1 || this.props.pageSize,
          page: getSessionStorage('vipListCurrent') * 1 || this.props.page,
        },
      });
    });
  };

  handleSearch = e => {
    e.preventDefault();
    const {dispatch, form, pageSize} = this.props;
    form.validateFields(['no_start', 'no_end', 'userPhone'], (err, fieldsValue) => {
      if (err) return;

      this.setState({
        formValues: {
          id: fieldsValue.id,
          channel: fieldsValue.userPhone,
        },
      });
      const values = {
        id: fieldsValue.id,
        userPhone: fieldsValue.userPhone,
      };

      //const columns = searchTable(values);
      var columns = [];
      if (values.userPhone) {
        columns = [{
          "name": 'consumer.account.username',
          "relation": 'LIKE',
          "search": values.userPhone,
        }]
      }
      // consumer.account.username


      // console.log(columns);
      // if (this.state.filters && this.state.filters.columns) {
      //   this.state.filters.columns.map((item) => {
      //     columns.push({
      //       ...item,
      //     });
      //   });
      // }
      // console.log(columns);
      this.fetch({
        columns,
        order: this.state.filters.order,
        start: this.state.start,
        end: this.state.end,
        page: 1,
        pageSize: getSessionStorage("vipListPageSize") * 1 || pageSize,
      });
    });
  };
  handleVbindStart = (e) => {
    this.setState({
      start: parseInt(e.target.value)
    })
  }
  handleVbindEnd = (e) => {
    this.setState({
      end: parseInt(e.target.value)
    })
  }

  handleFormReset = () => {
    const {form} = this.props;
    form.resetFields();
  };

  handleShowModal = (record) => {
    const {id} = record;
    this.props.dispatch({
      type: 'vip/queryVip',
      payload: {
        id,
      },
    });
    this.setState({
      modal: true,
      id,
    });
  };

  handleEditRemarkCancel = () => {
    this.setState({
      modal: false,
    });
  };

  handleTableChange = (pagination, filters, sorter) => {
    const {form} = this.props;
    let values = null;
    form.validateFields(['id', 'searchChannel'], (err, fieldsValue) => {
      if (err) return;

      values = {
        id: fieldsValue.id,
        channel: fieldsValue.searchChannel,
      };
    });
    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;
    this.setState({
      filters: {
        columns,
        order,
      }
    });
    if (values) {
      Object.keys(values).map((item) => {
        if (values[item]) {
          columns.push({
            name: item,
            relation: "LIKE",
            search: values[item],
          })
        }
      });
    }

    setSessionStorage("vipListCurrent", current);
    setSessionStorage("vipListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order,
    });
  };

  renderForm() {
    return this.renderSimpleForm();
  }

  renderModal() {
    return this.state.modalVisible ? this.renderModalForm() : '';
  }

  renderCreateCardModal() {
    return this.state.modalCreateCard ? this.renderCreateCardForm() : '';
  }

  renderActivateModal() {
    return this.state.modalCreateCard ? this.renderActivateForm() : '';
  }

  renderCreateCardForm() {
    const {getFieldDecorator} = this.props.form;
    const handleAddSubmit = (e) => {
      e.preventDefault();
      const {dispatch, form} = this.props;
      form.validateFields((err, fieldsValue) => {
        if (err) return;
        const values = {
          ...fieldsValue,
        };
        console.log(values)
        // dispatch({
        //   type: 'vip/addSubmit',
        //   payload: {
        //     ...values,
        //     confirmLoading: this.props.confirmLoading,
        //     pageSize: this.props.pageSize,
        //     current: 1,
        //   },
        // });
      });
    };
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form onSubmit={this.handleCreateCardSubmit}>
        <FormItem label="开始序列号" {...formItemLayout}>
          {getFieldDecorator('start', {
            rules: [{
              required: true,
              message: '请输入开始序列号',
            }],
          })(<InputNumber min={1} placeholder="请输入开始序列号。" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="结束序列号" {...formItemLayout}>
          {getFieldDecorator('end', {
            rules: [{
              required: true,
              message: '请输入结束序列号',
            }],
          })(<InputNumber min={1} placeholder="请输入结束序列号。" style={{width: '100%'}}/>)}
        </FormItem>
      </Form>
    );
  }

  renderActivateForm() {
    const {getFieldDecorator} = this.props.form;
    const handleAddSubmit = (e) => {
      e.preventDefault();
      const {dispatch, form} = this.props;
      form.validateFields((err, fieldsValue) => {
        if (err) return;
        const values = {
          ...fieldsValue,
        };
        // console.log(values)
        // dispatch({
        //   type: 'vip/addSubmit',
        //   payload: {
        //     ...values,
        //     confirmLoading: this.props.confirmLoading,
        //     pageSize: this.props.pageSize,
        //     current: 1,
        //   },
        // });
      });
    };
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form onSubmit={this.handleActivateSubmit}>
        <FormItem label="开始序列号" {...formItemLayout}>
          {getFieldDecorator('start', {
            rules: [{
              required: true,
              message: '请输入开始序列号',
            }],
          })(<InputNumber min={1} placeholder="请输入开始序列号。" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="结束序列号" {...formItemLayout}>
          {getFieldDecorator('end', {
            rules: [{
              required: true,
              message: '请输入结束序列号',
            }],
          })(<InputNumber min={1} placeholder="请输入结束序列号。" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="时长(天)" {...formItemLayout}>
          {getFieldDecorator('dayNum', {
            rules: [{
              required: true,
              message: '请输入时长',
            }],
          })(<InputNumber min={1} placeholder="请输入时长。" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="渠道" {...formItemLayout}>
          {getFieldDecorator('channel', {
            rules: [{
              required: true,
              message: '请输入渠道',
            }],
          })(<Input min={1} placeholder="请输入渠道。" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="折扣" {...formItemLayout}>
          {getFieldDecorator('discount', {
            rules: [{
              required: true,
              message: '请输入折扣',
            }],
          })(<InputNumber min={1} placeholder="请输入折扣。" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="激活说明" {...formItemLayout}>
          {getFieldDecorator('activationInstructions', {
            rules: [{
              required: true,
              message: '请输入激活说明',
            }],
          })(<Input min={1} placeholder="请输入激活说明。" style={{width: '100%'}}/>)}
        </FormItem>
      </Form>
    );
  }


  renderModalForm() {
    const {getFieldDecorator} = this.props.form;
    const handleAddSubmit = (e) => {
      e.preventDefault();
      const {dispatch, form} = this.props;
      form.validateFields((err, fieldsValue) => {
        if (err) return;
        const values = {
          ...fieldsValue,
        };
        dispatch({
          type: 'vip/addSubmit',
          payload: {
            ...values,
            pageSize: this.props.pageSize,
            current: 1,
          },
        });
      });
    };

    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };

    return (
      <Form onSubmit={handleAddSubmit}>
        <FormItem label="生成数量" {...formItemLayout}>
          {getFieldDecorator('size', {
            rules: [{
              required: true,
              message: '请输入需要生成的卡片数量',
            }],
          })(<InputNumber min={1} placeholder="请输入需要生成的卡片数量。" style={{width: '100%'}}/>)}
        </FormItem>
      </Form>
    );
  }

  renderEditModal() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="备注" {...formItemLayout}>
          {getFieldDecorator('remark', {
            initialValue: this.props.vip && this.props.vip.remark,
            rules: [{
              max: 60,
              message: '备注信息最多60个字符',
            }, {
              required: true,
              message: '请输入备注内容',
            }],
          })(<TextArea placeholder="请输入备注内容，最多60个字符。" autosize={{minRows: 4}}/>)}
        </FormItem>
      </Form>
    );
  }

  renderSimpleForm() {
    const {getFieldDecorator} = this.props.form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{md: 8, lg: 24, xl: 48}}>
          <Col md={4} sm={24}>
            <FormItem label="序列号">
              {getFieldDecorator('no_start')(<Input placeholder="请输入开始序列号" onKeyUp={this.handleVbindStart}/>)}
            </FormItem>
          </Col>
          <Col md={4} sm={24}>
            <FormItem label="">
              {getFieldDecorator('no_end')(<Input placeholder="请输结束入序列号" onKeyUp={this.handleVbindEnd}/>)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="手机号">
              {getFieldDecorator('userPhone')(
                <Input placeholder="请输入手机号"/>)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              <Button style={{marginLeft: 8}} onClick={this.handleFormReset}>
                重置
              </Button>
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  renderDetail(record) {
    return (<span>
      {/*<Divider type="vertical" /><a onClick={this.handleDetail.bind(null, record)}>查看详情</a>*/}
    </span>);
  }

  renderDelete(record) {
    return (<Popconfirm placement="top" title='是否作废？' onConfirm={this.handleDelete.bind(null, record)} okText="确定"
                        cancelText="取消"><Divider type="vertical"/><a>作废</a></Popconfirm>);
  }

  handleExport = (e) => {
    e.preventDefault();
    const {form} = this.props;
    form.validateFields(['id', 'searchChannel'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };
      const columns = searchTable(values);
      if (this.state.filters && this.state.filters.columns) {
        this.state.filters.columns.map((item) => {
          columns.push({
            ...item,
          });
        });
      }
      //API
      // ApiPostDownloadFile('/api/v1/export/vip', {
      ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/vip', {
        columns,
        order: this.state.order,
        start: this.state.start,
        end: this.state.end,
        pageNo: 1,
        pageSize: 4,
      });
    });
  };

  render() {
    const {
      list,
      loading,
      pageSize,
      total,
      page,
      submitting,
    } = this.props;
    const {modalVisible, modal, modalCreateCard, modalActivate} = this.state;

    const pagination = {
      pageSize: getSessionStorage('vipListPageSize') * 1 || pageSize,
      current: getSessionStorage('vipListCurrent') * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const columns = [
      {
        title: '序列号',
        dataIndex: 'id',
        key: 'id'
        // sorter: true1,
      },
      {
        title: '充值码',
        dataIndex: 'code',
        key: 'code',
      },
      {
        title: '已制实卡',
        dataIndex: 'entity',
        filters: [
          {
            text: '已制实卡',
            value: true,
          },
          {
            text: '未制实卡',
            value: false,
          },
        ],
        filterMultiple: false,
        render: (text, record) => (
          <span>
            {record.entity ? '已制实卡' : '未制实卡'}
          </span>
        ),
      },
      {
        title: '是否激活',
        dataIndex: 'activation',
        filters: [
          {
            text: '已激活',
            value: true,
          },
          {
            text: '未激活',
            value: false,
          },
        ],
        filterMultiple: false,
        render: (text, record) => (
          <span>
            {record.activation ? '已激活' : '未激活'}
          </span>
        ),
      },
      {
        title: '激活时间',
        dataIndex: 'activationDate',
        sorter: true,
        render: (text, record) => (
          record.activationDate ? moment(record.activationDate).format('YYYY-MM-DD HH:mm:ss') : '未激活'
        ),
      },
      {
        title: '时长(天)',
        dataIndex: 'dayNum',
        sorter: true,
      },
      {
        title: '渠道',
        dataIndex: 'channel',
        key: 'channel',
      },
      // {
      //   title: '渠道二1',
      //   dataIndex: 'channel2',
      //   key: 'channel2',
      // },
      // {
      //   title: '渠道三',
      //   dataIndex: 'channel3',
      //   key: 'channel3',
      // },
      {
        title: '折扣',
        dataIndex: 'discount',
        sorter: true,
      },
      {
        title: '用户手机号',
        dataIndex: 'username',
        key: 'username',
      },
      {
        title: '用户使用时间',
        dataIndex: 'usedDate',
        render: (text, record) => (
          record.usedDate ? moment(record.usedDate).format('YYYY-MM-DD HH:mm:ss') : '未使用'
        ),
      },
      {
        title: '是否作废',
        dataIndex: 'status',
        filters: [
          {
            text: '正常',
            value: 1,
          },
          {
            text: '已作废',
            value: 0,
          },
        ],
        filterMultiple: false,
        render: (text, record) => (
          <span>
            {record.status ? '正常' : '已作废'}
          </span>
        ),
      },
      {
        title: '备注',
        dataIndex: 'remark',
        render: (text, record) => (
          <span>
            {record.remark ? record.remark : record.remark}
          </span>
        ),
      },
      {
        title: '激活说明',
        dataIndex: 'activationInstructions',
        key: 'activationInstructions',
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            <a onClick={this.handleShowModal.bind(null, record)}>备注</a>
            {record.status !== 1 ? '' : this.renderDelete(record)}
            {record.username ? this.renderDetail(record) : ''}
          </span>
        ),
      },
    ];

    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <div className={styles.tableListForm}>{this.renderForm()}</div>
          <Modal
            title="生成VIP卡"
            visible={modalVisible}
            onOk={this.handleAddSubmit}
            onCancel={this.handleHideModal}
            okText="确认"
            cancelText="取消"
            confirmLoading={submitting}
          >
            {this.renderModal()}
          </Modal>
          <Modal title="备注"
                 visible={modal}
                 onOk={this.handleRemark}
                 onCancel={this.handleEditRemarkCancel}
          >
            {this.renderEditModal()}
          </Modal>
          <Modal title="制实卡"
                 visible={modalCreateCard}
                 onOk={this.handleCreateCardSubmit}
                 onCancel={this.handleCreateCardCancel}
          >
            {this.renderCreateCardModal()}
          </Modal>
          <Modal title="激活"
                 visible={modalActivate}
                 onOk={this.handleActivateSubmit}
                 onCancel={this.handleActivateCancel}
          >
            {this.renderActivateForm()}
          </Modal>
          <Card
            className={styles.listCard}
            bordered={false}
            title="已生成的VIP充值码列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 32px 40px 32px'}}
          >
            <div className={styles.tableListOperator}>
              <Button icon="download" onClick={this.handleExport}>
                导出表格
              </Button>
              <Button icon="plus" type="primary" onClick={this.handleCreate}>
                批量生成VIP充值码
              </Button>
              <Button icon="tag-o" onClick={this.handleCreateCard}>
                制实卡
              </Button>
              <Button icon="bulb" type="danger" onClick={this.handleActivate}>
                激活
              </Button>
            </div>
            <Table
              bordered
              loading={loading}
              rowKey='id'
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
