import React, {PureComponent} from 'react';
import moment from 'moment';
import {connect} from 'dva';
import {
  Card,
  Row,
  Col,
  Radio,
  Input,
  InputNumber,
  Button,
  Icon,
  Modal,
  Divider,
  Popconfirm,
  Upload,
  Table,
  Select,
  Form,
} from 'antd';

import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {
  setSessionStorage,
  getSessionStorage,
  removeSessionStorage,
  sortTable,
  searchTable,
  getLocalStorage,
  ApiPostDownloadFile,
} from '../../utils/utils';

import styles from './SystemList.less';

const FormItem = Form.Item;
const RadioButton = Radio.Button;
const RadioGroup = Radio.Group;
const {Search} = Input;
const {TextArea} = Input;

@connect(({vip, loading}) => ({
  list: vip.list,
  loading: loading.models.vip,
  submitting: loading.effects['vip/rechargeList'],
  total: vip.total,
  pageSize: vip.pageSize,
  confirmLoading: vip.confirmLoading,
  page: vip.page,
  vip: vip.vip,
  recharge: vip.recharge,
  id: null,
  type: 0
}))
@Form.create()
export default class RechargeList extends PureComponent {

  state = {
    addModal: false,
    editModal: false,
    name: '',
    remark: '',
    id: '',
    formValues: {},
    filters: {},
    integral: ''
  };

  fetch = (payload) => {
    this.props.dispatch({
      type: 'vip/rechargeList',
      payload: {
        ...payload,
      },
    });
  };
  redirectProfile = (record) => {
    this.props.dispatch({
      type: 'vip/redirectProfile',
      payload: {
        id: record.id,
      }
    });
  }
  handleStatus = (record) => {
    const {dispatch} = this.props;
    dispatch({
      type: 'vip/vipRechargeStatus',
      payload: {
        id: record.id,
        page: getSessionStorage('vipRechargeListCurrent') || 1,
        pageSize: getSessionStorage("vipRechargeListPageSize") || 30
      },
    });
  }

  componentDidMount() {
    this.fetch({
      page: 1,
      pageSize: 30
    });
  }

  componentWillUnmount() {
    removeSessionStorage("vipRechargeListCurrent");
    removeSessionStorage("vipRechargeListPageSize");
  }

  // =============新增模态框 start================
  handleAddShow = () => {
    this.setState({
      addModal: true,
      // id: record.id,
    });
    // this.props.dispatch({
    //   type: 'vip/rechargeDetail',
    //   payload: {
    //     id: record.id,
    //   }
    // });
  };

  renderAddModal() {
    // console.log('renderAddModal');
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    const Option = Select.Option;
    return (
      <Form>
        <FormItem label="VIP时长名称" {...formItemLayout}>
          {getFieldDecorator('name', {
            rules: [{
              required: true,
              message: '请输入VIP时长名称',
            }],
          })(<Input placeholder="请输入VIP时长名称"/>)}
        </FormItem>
        <FormItem label="时长（天）" {...formItemLayout}>
          {getFieldDecorator('num', {
            rules: [{
              required: true,
              message: '请输入时长',
            }],
          })(<InputNumber style={{width: '100%'}} placeholder="请输入时长" autosize={{minRows: 4}}/>)}
        </FormItem>
        <FormItem label="价格（心钻）" {...formItemLayout}>
          {getFieldDecorator('money', {
            rules: [{
              required: true,
              message: '请输入价格（心钻）',
            }],
          })(<InputNumber style={{width: '100%'}} placeholder="请输入价格（心钻）" autosize={{minRows: 4}}/>)}
        </FormItem>
        <FormItem label="日均价" {...formItemLayout}>
          {getFieldDecorator('price', {
            rules: [{
              required: true,
              message: '请输日均价',
            }],
          })(<InputNumber style={{width: '100%'}} placeholder="请输日均价" autosize={{minRows: 4}}/>)}
        </FormItem>
        <FormItem
          {...formItemLayout}
          label="平台"
        >
          {getFieldDecorator('type', {})(
            <Select
            >
              <Option value={0} type='option'>ios</Option>
              <Option value={1} type='option'>Android-Web</Option>
            </Select>
          )}
        </FormItem>
        <FormItem label="苹果内购ID" {...formItemLayout}>
          {getFieldDecorator('appleBuyId', {})(<Input/>)}
        </FormItem>
      </Form>
    );
  }

  handleAddHideModal = () => {
    this.setState({
      addModal: false,
    });
    this.handleFormReset();
  };

  handleAddSubmit = (e) => {
    e.preventDefault();
    const {form} = this.props;
    console.log(this.props);
    form.validateFields(['name', 'num', 'money', 'price', 'appleBuyId', 'type'], (err, fieldsValue) => {
      if (err) return;
      // const values = {
      //   ...fieldsValue,
      // };
      this.setState({
        addModal: false,
      });
      this.handleFormReset();
      this.props.dispatch({
        type: 'vip/addRecharge',
        payload: {
          ...fieldsValue,
        },
      });
    })
  };


  // =============新增模态框 end================
  // =============修改模态框 start================
  handleEditShow = (record) => {
    // console.log(record);
    this.setState({
      editModal: true,
      id: record.id,
    });
    this.props.dispatch({
      type: 'vip/rechargeDetail',
      payload: {
        id: record.id,
      }
    });
  };

  handleEditHideModal = () => {
    this.setState({
      editModal: false,
    });
    this.handleFormReset();
  };

  handleEditSubmit = (e) => {
    e.preventDefault();
    const {version} = this.props.recharge
    const {form, page, pageSize} = this.props;
    form.validateFields(['name', 'num', 'money', 'price', 'appleBuyId', 'type'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        editModal: false,
      });
      this.handleFormReset();

      this.props.dispatch({
        type: 'vip/editRecharge',
        payload: {
          id: this.state.id,
          status: this.props.recharge.status,
          version,
          ...fieldsValue,
          page: getSessionStorage('vipRechargeListCurrent') * 1 || page,
          pageSize: getSessionStorage('vipRechargeListPageSize') * 1 || pageSize
        },
      });
    })
  };

  renderEditModal() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    const Option = Select.Option;
    return (
      <Form>
        <FormItem label="VIP时长名称" {...formItemLayout}>
          {getFieldDecorator('name', {
            initialValue: this.props.recharge && this.props.recharge.name,
            rules: [{
              required: true,
              message: '请输入VIP时长名称',
            }, {
              max: 10,
              message: 'VIP时长名称最多10个字符'
            }]
          })(<Input placeholder="请输入积分数量"/>)}
        </FormItem>
        <FormItem label="时长（天）" {...formItemLayout}>
          {getFieldDecorator('num', {
            initialValue: this.props.recharge && this.props.recharge.num,
            rules: [{
              required: true,
              message: '请输入时长',
            }]
          })(<InputNumber style={{width: '100%'}} placeholder="请输入时长" autosize={{minRows: 4}}/>)}
        </FormItem>
        <FormItem label="价格（心钻）" {...formItemLayout}>
          {getFieldDecorator('money', {
            initialValue: this.props.recharge && this.props.recharge.money,
            rules: [{
              required: true,
              message: '请输入价格（心钻）',
            }]
          })(<InputNumber style={{width: '100%'}} placeholder="请输入价格（心钻）" autosize={{minRows: 4}}/>)}
        </FormItem>
        <FormItem label="日均价" {...formItemLayout}>
          {getFieldDecorator('price', {
            initialValue: this.props.recharge && this.props.recharge.price,
            rules: [{
              required: true,
              message: '请输日均价',
            }],
          })(<InputNumber style={{width: '100%'}} placeholder="请输日均价" autosize={{minRows: 4}}/>)}
        </FormItem>
        <FormItem
          {...formItemLayout}
          label="平台"
        >
          {getFieldDecorator('type', {
            initialValue: this.props.recharge && this.props.recharge.type,
          })(
            <Select
              // style={{width: '100px', float: 'left', marginRight: '10px'}}
              // defaultValue={this.props.recharge && this.props.recharge.type}
              // onChange={this.handleChange}
            >
              <Option value={0} type='option'>ios</Option>
              <Option value={1} type='option'>Android-Web</Option>
            </Select>
          )}
        </FormItem>
        <FormItem label="苹果内购ID" {...formItemLayout}>
          {getFieldDecorator('appleBuyId', {
            initialValue: this.props.recharge && this.props.recharge.appleBuyId,
          })(<Input/>)}
        </FormItem>
      </Form>
    );
  }

  // =============修改模态框 end================
  handleFormReset = () => {
    const {form} = this.props;
    form.resetFields();
  };
  handleTableChange = (pagination, filters, sorter) => {
    console.log(pagination, filters, sorter);
    const {current, pageSize} = pagination;

    setSessionStorage("vipRechargeListCurrent", current);
    setSessionStorage("vipRechargeListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
    });
  }
  handleSizeChange = (current, size) => {
    setSessionStorage("vipRechargeListCurrent", current);
    setSessionStorage("vipRechargeListPageSize", size);
  };

  // checkNumber(rule, value, callback) {
  //   // console.log(value);
  //   var re = /^(-?\d+)(\.\d+)?$/;
  //   if (re.test(value)) {
  //     callback();
  //   }else {
  //     callback('格式错误');
  //   }
  // };


  render() {
    const {
      loading,
      submitting,
      list,
      total,
      pageSize,
      page,
      recharge,
    } = this.props;
    // console.log('render()')
    // console.log({list});
    // console.log({recharge});
    // this.setState({
    //   status
    // })

    const extraContent = (
      <div className={styles.extraContent}>
        <Button icon="plus" type="primary" onClick={this.handleAddShow}>
          添加VIP时长
        </Button>
      </div>
    );

    const {addModal, editModal} = this.state;
    const pagination = {
      pageSize: getSessionStorage("vipRechargeListPageSize") * 1 || pageSize,
      current: getSessionStorage("vipRechargeListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };

    const columns = [
      {
        title: '序号',
        dataIndex: 'id',
        render: (text, record, index) => (
          index + 1 + (page - 1) * pageSize
        ),
      },
      {
        title: 'VIP时长名称',
        dataIndex: 'name',
        // key: 'name',
      },
      {
        title: '时长（天）',
        dataIndex: 'num',
        // key: 'num',
      },
      {
        title: '价格',
        dataIndex: 'money',
        // key: 'integral',
      },
      {
        title: '日均价',
        dataIndex: 'price',
        // key: 'code',
      },
      {
        title: '平台',
        dataIndex: 'type',
        render: (text, record) => (
          <span>{record.type === 0 ? 'ios' : 'Android-Web'}</span>
        ),
      },
      {
        title: '购买次数',
        dataIndex: 'channel2',
        key: 'channel2'
      },
      {
        title: '苹果内购项目ID',
        dataIndex: 'appleBuyId',
        key: 'appleBuyId'
      },
      // {
      //   title: '添加时间',
      //   dataIndex: 'channel3',
      //   key: 'channel3'
      // },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            <a onClick={this.handleEditShow.bind(null, record)}>修改</a>
            <Divider type="vertical"/>
            <a onClick={this.handleStatus.bind(null, record)}>{record.status ? '禁用' : '启用'}</a>
            <a>{record.status}</a>
            {/*<Divider type="vertical"/>*/}
            {/*{record.discard ? this.renderRecovery(record) : this.renderDelete(record)}*/}
          </span>
        ),
      },
    ];


    return (
      <PageHeaderLayout>
        <div className={styles.standardList}>
          <Modal
            title="修改VIP积分项目"
            visible={editModal}
            onOk={this.handleEditSubmit}
            onCancel={this.handleEditHideModal}
            okText="确认"
            cancelText="取消"
            confirmLoading={submitting}
          >
            {this.renderEditModal()}
          </Modal>
          <Modal
            title="新增VIP积分项目"
            visible={addModal}
            onOk={this.handleAddSubmit}
            onCancel={this.handleAddHideModal}
            okText="确认"
            cancelText="取消"
            confirmLoading={submitting}
          >
            {this.renderAddModal()}
          </Modal>
          <Card
            className={styles.listCard}
            bordered={false}
            title="VIP时长列表"
            style={{marginTop: 24}}
            bodyStyle={{padding: '0 40px 32px'}}
            extra={extraContent}
          >
            <div className={styles.tableListOperator}>
              {/*<Button icon="download" onClick={this.handleExport}>*/}
              {/*导出表格*/}
              {/*</Button>*/}
            </div>
            <Table
              bordered
              loading={loading}
              rowKey='id'
              columns={columns}
              dataSource={list}
              pagination={pagination}
              onChange={this.handleTableChange}
            />
          </Card>
        </div>
      </PageHeaderLayout>
    );
  }
}
