import React, {Component} from 'react';
import Debounce from 'lodash-decorators/debounce';
import Bind from 'lodash-decorators/bind';
import {connect} from 'dva';
import {parse} from 'qs';
import {Base64} from 'js-base64';
import {
  Button,
  Icon,
  Card,
  Form,
  Input,
  Switch,
  Upload,
  Row,
  Col,
  Select,
  Cascader,
  Tabs,
  Table,
  Divider,
  Modal,
  InputNumber,
  message,
} from 'antd';
import Address from 'components/Map';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import moment from 'moment';
import {getCity} from '../../utils/getCity';
import {getSessionStorage, searchTable, setSessionStorage, sortTable, upYunAuthorization} from '../../utils/utils';
import styles from '../List/BasicList.less';
import Lightbox from 'react-image-lightbox';
import 'react-image-lightbox/style.css';

const FormItem = Form.Item;
const {TextArea} = Input;
const Option = Select.Option;
const TabPane = Tabs.TabPane;
const getWindowWidth = () => window.innerWidth || document.documentElement.clientWidth;
@connect(({accumulation, site, loading}) => ({
  accumulationMsg: accumulation.accumulationMsg,
  loading: loading.models.accumulation,
  loadingSite: loading.effects['site/fetchSite'],
  siteCurrent: accumulation.siteCurrent,
  sitePageSize: accumulation.sitePageSize,
  siteTotal: accumulation.siteTotal,
  siteList: accumulation.siteList,
  city: accumulation.city,
  type: accumulation.type,
  submitting: loading.effects['accumulation/editSubmit'],
}))
@Form.create()
export default class AccumulationEdit extends Component {

  state = {
    stepDirection: 'horizontal',
    pointIn: '',
    pointOut: '',
    activeKey: '1',
    city: '',
    change: true,//提交按钮判断1
    filters: null,
    modal: false,
    id: 0,
    pic: '',
    //私语开关
    whisperSwitch: {
      change: false,
      value: false,
    },
    adoreSwitch: {
      change: false,
      value: false,
    },
    siteAdminId: 0,
    isOpen: false,
  };

  componentDidMount() {
    const {id} = parse(this.props.location.search.substr(1));
    const {dispatch, type} = this.props;
    const types = getSessionStorage("accumulationType") || type;
    switch (types) {
      case '1':
        dispatch({
          type: 'accumulation/fetchDetail',
          payload: {
            id,
          }
        });
        break;
      case '2':
        dispatch({
          type: 'accumulation/fetchSite',
          payload: {
            columns: [{
              name: "gathering.id",
              search: id,
              relation: 'EQ',
            }],
            page: 1,
            pageSize: 30,
          }
        });
        break;
    }

    this.setStepDirection();
    window.addEventListener('resize', this.setStepDirection);
  }

  fetch = (payload) => {
    dispatch({
      type: 'accumulation/fetchSite',
      payload: {
        ...payload,
      }
    });
  };

  componentWillUnmount() {
    setSessionStorage("accumulationType", "1");
    window.removeEventListener('resize', this.setStepDirection);
    this.setStepDirection.cancel();
  }

  onOperationTabChange = key => {
    this.setState({operationkey: key});
  };

  @Bind()
  @Debounce(200)
  setStepDirection() {
    const {stepDirection} = this.state;
    const w = getWindowWidth();
    if (stepDirection !== 'vertical' && w <= 576) {
      this.setState({
        stepDirection: 'vertical',
      });
    } else if (stepDirection !== 'horizontal' && w > 576) {
      this.setState({
        stepDirection: 'horizontal',
      });
    }
  }

  //聚点开启/关闭
  handleAccLock = () => {
    this.props.dispatch({
      type: 'accumulation/lock',
      payload: {
        id: parse(this.props.location.search.substr(1)).id
      },
    })
  };

  swiperChange = () => {
    this.setState({
      whisperSwitch: {
        change: !this.state.whisperSwitch.change,
        value: !this.props.accumulationMsg.whisperSwitch,
      }
    });
  };

  likeChange = () => {
    this.setState({
      adoreSwitch: {
        change: !this.state.adoreSwitch.change,
        value: !this.props.accumulationMsg.adoreSwitch,
      }
    });
  };

  handleSubmit = e => {
    e.preventDefault();
    const {dispatch, form, accumulationMsg} = this.props;
    this.setState({
      change: true
    })
    form.validateFields(['name', 'introduce', 'affiche', 'coordinates', 'regionId', 'dummy', 'quitCoordinates', 'whisperSwitch', 'adoreSwitch'], (err, fieldsValue) => {
      if (err) return;
      const {point} = this.state;
      const values = {
        ...fieldsValue,
      };
      let coordinates = [];
      JSON.parse(values.coordinates).map((item) => {
        coordinates.push({
          lng: item.lng,
          lat: item.lat,
          type: 0,
        })
      });
      let quitCoordinates = [];
      JSON.parse(values.quitCoordinates).map((item) => {
        quitCoordinates.push({
          lng: item.lng,
          lat: item.lat,
          type: 1,
        })
      });
      dispatch({
        type: 'accumulation/editSubmit',
        payload: {
          id: parse(this.props.location.search.substr(1)).id,
          name: values.name,
          introduce: values.introduce,
          affiche: values.affiche,
          coordinates,
          quitCoordinates,
          pic: this.state.pic ? this.state.pic : accumulationMsg && accumulationMsg.pic,
          cityName: this.state.city ? this.state.city.toString() : accumulationMsg && accumulationMsg.cityName,
          dummy: values.dummy,
          regionId: values.regionId[values.regionId.length - 1],
          whisperSwitch: this.state.whisperSwitch.change ? this.state.whisperSwitch.value : this.props.accumulationMsg.whisperSwitch,
          adoreSwitch: this.state.adoreSwitch.change ? this.state.adoreSwitch.value : this.props.accumulationMsg.adoreSwitch,
        },
      });
    });
  };

  handlePointIn = (e) => {
    console.log(e)
    let point = JSON.stringify(e);
    this.setState({
      pointIn: point,
    });
  };
  handlePointOut = (e) => {
    let point = JSON.stringify(e);
    this.setState({
      pointOut: point,
    });
  };

  handleTabChange = (k) => {
    setSessionStorage("accumulationType", k);
    if (k === '2') {
      this.props.dispatch({
        type: 'accumulation/fetchSite',
        payload: {
          columns: [{
            name: "gathering.id",
            search: parse(this.props.location.search.substr(1)).id,
            relation: 'EQ',
          }],
          page: 1,
          pageSize: 30,
        }
      });
    }
  };

  handleCreate = () => {
    this.props.dispatch({
      type: 'site/add',
      payload: {
        id: parse(this.props.location.search.substr(1)).id,
      }
    });
  };

  handleSite = (id) => {
    this.props.dispatch({
      type: 'accumulation/redirectSite',
      payload: {
        id,
      }
    });
  };

  handleGift = (id) => {
    this.props.dispatch({
      type: 'site/redirectGift',
      payload: {
        id,
      }
    });
  };

  handleSale = (id) => {
    this.props.dispatch({
      type: 'site/redirectGiftSale',
      payload: {
        id,
      }
    });
  };

  handleCityChange = (value, selectedOptions) => {
    let city = [];
    selectedOptions.map((item) => {
      city.push(item.label);
    });
    this.setState({
      city,
    });
  };

  handleTableChange = (pagination, filters, sorter) => {
    const {form} = this.props;
    let values = null;
    form.validateFields(['siteName'], (err, fieldsValue) => {
      if (err) return;

      values = {
        ...fieldsValue,
      };
    });
    const {current, pageSize} = pagination;
    const res = sortTable(pagination, filters, sorter);
    const {columns, order} = res;
    this.setState({
      filters: {
        columns,
        order,
      }
    });
    Object.keys(values).map((item) => {
      if (values[item]) {
        columns.push({
          name: item,
          relation: "LIKE",
          search: values[item],
        })
      }
    });

    setSessionStorage("accumulationListCurrent", current);
    setSessionStorage("accumulationListPageSize", pageSize);
    this.fetch({
      page: current,
      pageSize,
      columns,
      order,
    });
  };

  handleLock = (id) => {
    this.props.dispatch({
      type: 'site/lock',
      payload: {
        id,
      },
    });
  };

  handleSearch = e => {
    e.preventDefault();
    const {form} = this.props;
    form.validateFields(['siteName'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        formValues: fieldsValue,
      });
      const values = {
        ...fieldsValue,
      };
      const columns = searchTable(values);
      if (this.state.filters && this.state.filters.columns) {
        this.state.filters.columns.map((item) => {
          columns.push({
            ...item,
          });
        });
      }
      this.fetch({
        columns,
        order: this.state.filters.order,
        page: 1,
        pageSize: getSessionStorage("accumulationSiteListPageSize") * 1 || this.props.pageSize,
      });
    });
  };

  handleOnChange = () => {
    this.setState({
      change: false,
    }, () => {
      this.setState({
        change: false,
      });
    });
  };

  handlerResetPassword = (id) => {
    this.setState({
      modal: true,
      siteAdminId: id,
    });
  };

  handlerResetPasswordCancel = (record) => {
    this.setState({
      modal: false,
    });
  };

  handlerResetPasswordSubmit = () => {
    const {dispatch, form} = this.props;
    form.validateFields(['password', 'confirmPassword'], (err, fieldsValue) => {
      if (err) return;
      this.setState({
        modal: false,
      });
      dispatch({
        type: 'site/resetPassword',
        payload: {
          id: this.state.siteAdminId,
          ...fieldsValue,
        },
      });
    });
  };


  checkPassword = (rule, value, callback) => {
    const form = this.props.form;
    if (value && value !== form.getFieldValue('password')) {
      callback('两次密码输入不一致！');
    } else {
      callback();
    }
  }

  renderResetPasswordModal() {
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    return (
      <Form>
        <FormItem label="新密码" {...formItemLayout}>
          {getFieldDecorator('password', {
            rules: [{
              required: true,
              message: '请输入新密码',
            }],
          })(<Input type="passsword" placeholder="请输入新密码" style={{width: '100%'}}/>)}
        </FormItem>
        <FormItem label="再次输入新密码" {...formItemLayout}>
          {getFieldDecorator('confirmPassword', {
            rules: [{
              required: true,
              message: '请输入新密码',
            }, {validator: this.checkPassword},],
          })(<Input type="passsword" placeholder="请输入新密码" style={{width: '100%'}}/>)}
        </FormItem>
      </Form>
    );
  }

  fetchImg = (pic) => {
    let res = [];
    res.push(pic);
    return res;
  };

  handleOpen = () => {
    this.setState({
      isOpen: true,
    });
  };

  handleClose = () => {
    this.setState({
      isOpen: false,
    });
  };

  render() {
    const {
      loading,
      add,
      accumulationMsg,
      siteCurrent,
      sitePageSize,
      siteTotal,
      siteList,
      loadingSite,
      submitting,
    } = this.props;
    // console.log({loading})
    const {getFieldDecorator} = this.props.form;
    const {modal, pic, change, isOpen} = this.state;
    const images = this.fetchImg(accumulationMsg && accumulationMsg.pic);

    const extraContent = (
      <div className={styles.extraContent}>
        <Button icon="plus" type="primary" onClick={this.handleCreate}>
          新建场所
        </Button>
      </div>
    );

    const formItemLayout = {
      labelCol: {
        xs: {span: 8},
        sm: {span: 4},
      },
      wrapperCol: {
        xs: {span: 16},
        sm: {span: 12},
      },
    };
    const tailFormItemLayout = {
      wrapperCol: {
        xs: {
          span: 16,
          offset: 8,
        },
        sm: {
          span: 20,
          offset: 4,
        },
      },
    };
    const date = Date.parse(new Date());
    const uploadProps = {
      action: 'http://v0.api.upyun.com/image-seemore',
      listType: 'picture',
      data: {
        'authorization': upYunAuthorization("accumulation", date).authorization,
        'policy': upYunAuthorization("accumulation", date).policy,
      },
      name: 'file',
      headers: {
        'X-Requested-With': null,
      },
      disabled: change,
      onChange: (info) => {
        const status = info.file.status;
        if (status === 'done') {
          message.success(`${info.file.name} 文件上传成功.`);
          this.setState({
            pic: 'http://image.seemore.club' + JSON.parse(event.currentTarget.response).url,
          });
        } else if (status === 'error') {
          message.error(`${info.file.name} 文件上传失败，请重新上传。`);
        }
      },
    };

    const paginationSite = {
      pageSize: getSessionStorage("accumulationSiteListPageSize") * 1 || this.props.sitePageSize,
      current: getSessionStorage("accumulationSiteListCurrent") * 1 || this.props.siteCurrent,
      total: siteTotal,
      showSizeChanger: true,
      onShowSizeChange: this.handleSiteSizeChange,
    };

    const siteColumns = [
      {
        title: '序号',
        dataIndex: 'id',
        key: 'id',
      },
      {
        title: '场所名称',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '场所管理员ID',
        dataIndex: 'siteAdminId',
        key: 'siteAdminId',
      },
      {
        title: '场所图片',
        dataIndex: 'pic',
        render: (text, record) => (
          <span>
          <img src={record.pic ? record.pic : ''} alt="场所图片" width='180px' height='180px'/>
          </span>
        ),
      },
      {
        title: '创建时间',
        dataIndex: 'createDate',
        render: (text, record) => (
          <span>
            {moment(record.createDate).format('YYYY-MM-DD HH:mm:ss')}
          </span>
        ),
        sorter: true,
      },
      {
        title: '操作',
        key: 'action',
        render: (text, record) => (
          <span>
            <a onClick={this.handleSite.bind(null, record.id)}>查看详情</a>
            <Divider type="vertical"/>
            <a onClick={this.handleGift.bind(null, record.id)}>查看礼物商品</a>
            <Divider type="vertical"/>
            <a onClick={this.handleSale.bind(null, record.id)}>查看礼物销售</a>
            <Divider type="vertical"/>
            <a onClick={this.handleLock.bind(null, record.id)}>
              {record.status ? '关闭场所' : '恢复场所'}
            </a>
            <Divider type="vertical"/>
            <a onClick={this.handlerResetPassword.bind(null, record.siteAdminId)}>重置管理员密码</a>
          </span>
        ),
      },
    ];

    return (
      <PageHeaderLayout
      >
        <Modal title="重置密码"
               visible={modal}
               onOk={this.handlerResetPasswordSubmit}
               onCancel={this.handlerResetPasswordCancel}
        >
          {this.renderResetPasswordModal()}
        </Modal>
        <Card title={accumulationMsg && accumulationMsg.name} style={{marginBottom: 24, marginTop: 24}} bordered={false}
              extra={extraContent}>
          <Tabs onChange={this.handleTabChange} defaultActiveKey={getSessionStorage("accumulationType") || '1'}>
            <TabPane tab="基本信息" key="1" loading={loading}>
              <Form onSubmit={this.handleSubmit}>
                <FormItem
                  {...formItemLayout}
                  label="聚点名称"
                >
                  {getFieldDecorator('name', {
                    initialValue: accumulationMsg && accumulationMsg.name,
                    rules: [{
                      required: true, message: '请填写聚点名称',
                    }, {
                      max: 20, message: '聚点名称最多20个字符',
                    }],
                  })(
                    <Input disabled={change} placeholder="请填写聚点名称"/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="创建时间"
                >
                  {getFieldDecorator('createDate', {
                    initialValue: accumulationMsg && moment(accumulationMsg.createDate).format('YYYY-MM-DD HH:mm:ss'),
                  })(
                    <Input disabled/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="聚点图片"
                >
                  {
                    accumulationMsg && accumulationMsg.pic ?
                      <a onClick={this.handleOpen}><img style={{maxWidth: '100%'}}
                                                        src={accumulationMsg && accumulationMsg.pic}
                                                        alt="聚点封面"/></a> : ''
                  }
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="更换聚点图片"
                >
                  <Upload {...uploadProps}>
                    <Button disabled={change}>
                      <Icon type="upload"/> 点击上传
                    </Button>
                    &nbsp;&nbsp;&nbsp;&nbsp;尺寸要求1200px*767px
                  </Upload>
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="聚点介绍"
                >
                  {getFieldDecorator('introduce', {
                    initialValue: accumulationMsg && accumulationMsg.introduce,
                    rules: [{
                      required: true, message: '请填写聚点描述',
                    }, {
                      max: 40, message: '最多输入40个字符',
                    }],
                  })(
                    <TextArea disabled={change} placeholder="请填写聚点描述" autosize={{minRows: 4}}/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="聚点公告"
                >
                  {getFieldDecorator('affiche', {
                    initialValue: accumulationMsg && accumulationMsg.affiche,
                    rules: [{
                      // required: true, message: '请填写聚点公告',
                    },
                      // {
                      //   max: 40, message: '最多输入40个字符',
                      // }
                    ],
                  })(
                    <TextArea disabled={change} placeholder="请填写聚点公告" autosize={{minRows: 4}}/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="当前人数"
                >
                  {getFieldDecorator('currentHeadcount', {
                    initialValue: accumulationMsg && accumulationMsg.currentHeadcount,
                  })(
                    <InputNumber style={{width: '100%'}} disabled placeholder="请填写当前人数"/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="上一周期真实配对成功数"
                >
                  {getFieldDecorator('matching', {
                    initialValue: accumulationMsg && accumulationMsg.matching,
                  })(
                    <InputNumber style={{width: '100%'}} disabled placeholder="请填写昨日配对成功数"/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="配对成功数虚增值"
                >
                  {getFieldDecorator('dummy', {
                    initialValue: accumulationMsg && accumulationMsg.dummy,
                    rules: [{
                      required: true, message: '请填写配对成功数虚增值',
                    }],
                  })(
                    <InputNumber style={{width: '100%'}} disabled={change} placeholder="请填写配对成功数虚增值"/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="不限私语次数开关"
                >
                  {getFieldDecorator('whisperSwitch')(
                    <Switch disabled={change} onChange={this.swiperChange} checkedChildren="开启" unCheckedChildren="关闭"
                            checked={this.state.whisperSwitch.change ? this.state.whisperSwitch.value : accumulationMsg && accumulationMsg.whisperSwitch}/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="不限喜欢次数开关"
                >
                  {getFieldDecorator('adoreSwitch')(
                    <Switch disabled={change} onChange={this.likeChange} checkedChildren="开启" unCheckedChildren="关闭"
                            checked={this.state.adoreSwitch.change ? this.state.adoreSwitch.value : accumulationMsg && accumulationMsg.adoreSwitch}/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="聚点所在省市"
                >
                  {getFieldDecorator('regionId', {
                    initialValue: this.state.city ? this.state.city : accumulationMsg && accumulationMsg.city,
                    rules: [{
                      required: true, message: '请选择聚点所在省市',
                    }],
                  })(
                    <Cascader disabled={change} onChange={this.handleCityChange} options={getCity()}
                              placeholder="请选择聚点所在地"/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="进入聚点地理围栏"
                >
                  {getFieldDecorator('coordinates', {
                    initialValue: this.state.pointIn ? this.state.pointIn : accumulationMsg && JSON.stringify(accumulationMsg.coordinates),
                    rules: [{
                      required: true, message: '请在地图上选择聚点范围',
                    }],
                  })(
                    <Input disabled={true}/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="离开聚点地理围栏"
                >
                  {getFieldDecorator('quitCoordinates', {
                    initialValue: this.state.pointOut ? this.state.pointOut : accumulationMsg && JSON.stringify(accumulationMsg.quitCoordinates),
                    rules: [{
                      required: true, message: '请在地图上选择聚点范围',
                    }],
                  })(
                    <Input disabled={true}/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="选择聚点范围"
                >
                  <Address
                    btn={true}
                    key={Math.random()}
                    change={change}
                    place={this.state.city ? this.state.city : (accumulationMsg && accumulationMsg.cityName && accumulationMsg.cityName.split(","))}
                    prevPointIn={this.state.pointIn ? this.state.pointIn : accumulationMsg && JSON.stringify(accumulationMsg.coordinates)}
                    prevPointOut={this.state.pointOut ? this.state.pointOut : accumulationMsg && JSON.stringify(accumulationMsg.quitCoordinates)}
                    handlePointIn={this.handlePointIn.bind(this)}
                    handlePointOut={this.handlePointOut.bind(this)}
                  >

                  </Address>
                  <p>请在地图上选择聚点范围，完成后双击鼠标确定。红色为离开聚点范围，绿色为进去聚点范围</p>
                </FormItem>
                <FormItem {...tailFormItemLayout}>
                  <Button disabled={change} loading={submitting} type="primary" htmlType="submit">提交</Button>
                  <Button disabled={!change} type="primary" onClick={this.handleOnChange}
                          style={{marginLeft: 8}}>开启修改</Button>
                  {accumulationMsg && accumulationMsg.status ?
                    <Button onClick={this.handleAccLock} style={{marginLeft: 8}}>关闭聚点</Button> :
                    <Button onClick={this.handleAccLock} style={{marginLeft: 8}}>开启聚点</Button>}
                </FormItem>
              </Form>
            </TabPane>
            {/*<TabPane tab="聚点场所" key="2">*/}
              {/*<Table*/}
                {/*bordered*/}
                {/*loading={loadingSite}*/}
                {/*rowKey='id'*/}
                {/*columns={siteColumns}*/}
                {/*dataSource={siteList}*/}
                {/*pagination={paginationSite}*/}
                {/*onChange={this.handleTableChange}*/}
              {/*/>*/}
            {/*</TabPane>*/}
          </Tabs>
        </Card>
        {isOpen && (
          <Lightbox
            mainSrc={images[0]}
            onCloseRequest={this.handleClose}
          />
        )}
      </PageHeaderLayout>
    );
  }
}
