import React, {Component} from 'react';
import Debounce from 'lodash-decorators/debounce';
import Bind from 'lodash-decorators/bind';
import {connect} from 'dva';
import {
  Button,
  Icon,
  Card,
  Form,
  Input,
  Select,
  Upload,
  Cascader,
  InputNumber,
  message,
} from 'antd';
import Address from 'components/Map';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {getCity} from '../../utils/getCity';
import {setSessionStorage, upYunAuthorization} from '../../utils/utils';

const FormItem = Form.Item;
const {TextArea} = Input;
const Option = Select.Option;
const getWindowWidth = () => window.innerWidth || document.documentElement.clientWidth;
@connect(({accumulation, loading}) => ({
  accumulationMsg: accumulation.accumulationMsg,
  loading: loading.effects['accumulation/fetchCity'],
  city: accumulation.city,
  submitting: loading.effects['accumulation/addSubmit'],
}))
@Form.create()
export default class AccumulationAdd extends Component {

  state = {
    stepDirection: 'horizontal',
    pointIn: '',
    pointOut: '',
    city: [],
    pic: '',
  };

  fetchCity = (payload) => {
    this.props.dispatch({
      type: 'accumulation/fetchCity',
      payload: {
        ...payload,
      },
    });
  };

  componentDidMount() {
    //新建场所成功，跳转回列表处理
    setSessionStorage("accumulationType", "2");
    this.setStepDirection();
    window.addEventListener('resize', this.setStepDirection);
  }

  componentWillUnmount() {
    window.removeEventListener('resize', this.setStepDirection);
    this.setStepDirection.cancel();
  }

  onOperationTabChange = key => {
    this.setState({operationkey: key});
  };

  @Bind()
  @Debounce(200)
  setStepDirection() {
    const {stepDirection} = this.state;
    const w = getWindowWidth();
    if (stepDirection !== 'vertical' && w <= 576) {
      this.setState({
        stepDirection: 'vertical',
      });
    } else if (stepDirection !== 'horizontal' && w > 576) {
      this.setState({
        stepDirection: 'horizontal',
      });
    }
  }

  handleSubmit = e => {
    e.preventDefault();
    const {dispatch, form} = this.props;

    form.validateFields(['name', 'introduce', 'affiche', 'coordinates', 'regionId', 'dummy', 'quitCoordinates'], (err, fieldsValue) => {
      if (err) return;
      const {like, swiper, point, startTime, endTime} = this.state;
      const values = {
        ...fieldsValue,
        like,
        swiper,
        range: point,
      };
      let coordinates = [];
      JSON.parse(values.coordinates).map((item) => {
        coordinates.push({
          lng: item.lng,
          lat: item.lat,
          type: 0,
        })
      });
      let quitCoordinates = [];
      JSON.parse(values.quitCoordinates).map((item) => {
        quitCoordinates.push({
          lng: item.lng,
          lat: item.lat,
          type: 1,
        })
      });
      dispatch({
        type: 'accumulation/addSubmit',
        payload: {
          name: values.name,
          introduce: values.introduce,
          coordinates,
          quitCoordinates,
          pic: this.state.pic,
          affiche:values.affiche,
          cityName: this.state.city.toString(),
          dummy: values.dummy,
          regionId: values.regionId[values.regionId.length - 1],
        },
      });
    });
  };

  handlePointIn = (e) => {
    let point = JSON.stringify(e);
    this.setState({
      pointIn: point,
    });
  };
  handlePointOut = (e) => {
    let point = JSON.stringify(e);
    this.setState({
      pointOut: point,
    });
  };

  handleCityChange = (value, selectedOptions) => {
    let city = [];
    selectedOptions.map((item) => {
      city.push(item.label);
    });
    this.setState({
      city,
    });
  };

  render() {
    const {loading, city, submitting} = this.props;
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 8},
        sm: {span: 4},
      },
      wrapperCol: {
        xs: {span: 16},
        sm: {span: 12},
      },
    };
    const tailFormItemLayout = {
      wrapperCol: {
        xs: {
          span: 16,
          offset: 8,
        },
        sm: {
          span: 20,
          offset: 4,
        },
      },
    };
    const date = Date.parse(new Date());
    const uploadProps = {
      action: 'http://v0.api.upyun.com/image-seemore',
      listType: 'picture',
      data: {
        'authorization': upYunAuthorization("accumulation", date).authorization,
        'policy': upYunAuthorization("accumulation", date).policy,
      },
      name: 'file',
      headers: {
        'X-Requested-With': null,
      },
      onChange: (info) => {
        const status = info.file.status;
        if (status === 'done') {
          message.success(`${info.file.name} 文件上传成功.`);
          this.setState({
            pic: 'http://image.seemore.club' + JSON.parse(event.currentTarget.response).url,
          });
        } else if (status === 'error') {
          message.error(`${info.file.name} 文件上传失败，请重新上传。`);
        }
      },
    };

    return (
      <PageHeaderLayout
      >
        <Card title="聚点信息" style={{marginBottom: 24}} bordered={false}>
          <Form onSubmit={this.handleSubmit}>
            <FormItem
              {...formItemLayout}
              label="聚点名称"
            >
              {getFieldDecorator('name', {
                rules: [{
                  required: true, message: '请填写聚点名称',
                }, {
                  max: 20, message: '聚点名称最多20个字符',
                }],
              })(
                <Input placeholder="请填写聚点名称"/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="配对成功数虚增值"
            >
              {getFieldDecorator('dummy', {
                initialValue: 0,
                rules: [{
                  required: true, message: '请填写配对成功数虚增值',
                }],
              })(
                <InputNumber style={{width: '100%'}} placeholder="请填写配对成功数虚增值"/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="聚点介绍"
            >
              {getFieldDecorator('introduce', {
                rules: [{
                  required: true, message: '请填写聚点介绍',
                },
                  {
                    max: 40, message: '最多输入40个字符',
                  }
                ],
              })(
                <TextArea placeholder="请填写聚点介绍" autosize={{minRows: 4}}/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="聚点公告"
            >
              {getFieldDecorator('affiche', {
                rules: [{
                  // required: true, message: '请填写聚点公告',
                },
                  // {
                  //   max: 40, message: '最多输入40个字符',
                  // }
                ],
              })(
                <TextArea placeholder="请填写聚点公告" autosize={{minRows: 4}}/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="聚点图片"
            >
              {getFieldDecorator('pic', {
                initialValue: this.state.pic,
                rules: [{
                  required: true, message: '请上传聚点图片',
                }],
              })(
                <Input disabled placeholder="请上传聚点图片"/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="上传聚点图片"
            >
              <Upload {...uploadProps}>
                <Button style={{width: 120}}>
                  <Icon type="upload"/> 点击上传
                </Button>
              </Upload>
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="聚点所在省市"
            >
              {getFieldDecorator('regionId', {
                rules: [{
                  required: true, message: '请选择聚点所在省市',
                }],
              })(
                <Cascader onChange={this.handleCityChange} options={getCity()} placeholder="请选择聚点所在省市"/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="进入聚点地理围栏"
            >
              {getFieldDecorator('coordinates', {
                initialValue: this.state.pointIn,
                rules: [{
                  required: true, message: '请在地图上选择聚点范围',
                }],
              })(
                <Input disabled={true}/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="离开聚点地理围栏"
            >
              {getFieldDecorator('quitCoordinates', {
                initialValue: this.state.pointOut,
                rules: [{
                  required: true, message: '请在地图上选择聚点范围',
                }],
              })(
                <Input disabled={true}/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="选择聚点范围"
            >
              <Address
                key={Math.random()}
                btn={true}
                place={this.state.city}
                prevPointIn={this.state.pointIn ? this.state.pointIn : true}
                prevPointOut={this.state.pointOut ? this.state.pointOut : true}
                handlePointIn={this.handlePointIn.bind(this)}
                handlePointOut={this.handlePointOut.bind(this)}
              >
              </Address>
              <p>请在地图上选择聚点范围，完成后双击鼠标确定。红色为离开聚点范围，绿色为进去聚点范围。</p>
            </FormItem>
            <FormItem {...tailFormItemLayout}>
              <Button loading={submitting} type="primary" htmlType="submit">提交</Button>
            </FormItem>
          </Form>
        </Card>
      </PageHeaderLayout>
    );
  }
}
