import React, { Component } from 'react';
import { connect } from 'dva';
import { Link } from 'dva/router';
import { Form, Input, Button, Row, Col, Checkbox, Card, Select } from 'antd';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import { parse } from 'qs';
const FormItem = Form.Item;
const Option = Select.Option;
const CheckboxGroup = Checkbox.Group;
@connect(({ loading, administrator }) => ({
  submitting: loading.effects['administrator/editSubmit'],
  loading: loading.models.administrator,
  roleList: administrator.roleList,
  user: administrator.user,
}))
@Form.create()
export default class AdministratorAdd extends Component {
  state = {
    formValues: '',
  };

  componentDidMount() {
    const { id } = parse(this.props.location.search.substr(1));
    const { dispatch } = this.props;
    dispatch({
      type: 'administrator/fetchAll',
    });
    dispatch({
      type: 'administrator/fetchProfile',
      payload: {
        id,
      },
    });
  }

  handleSubmit = (e) => {
    const { id } = parse(this.props.location.search.substr(1));
    e.preventDefault();
    this.props.form.validateFields((err, values) => {
      if (!err) {
        let list = [];
        values.roleList.map((item) => {
          list.push({
            id: item,
          })
        });
        const { name, userName, password, email } = values;
        this.props.dispatch({
          type: 'administrator/submit',
          payload: {
            name,
            userName,
            password,
            email,
            ids: list,
            id,
          },
        });
      }
    });
  };

  render() {
    const { submitting, user, loading, roleList } = this.props;
    const { getFieldDecorator } = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
    };
    return (
      <PageHeaderLayout>
        <Card title='管理员详情' loading={loading}>
          <Form onSubmit={this.handleSubmit}>
            <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
              <Col md={12} offset={4} sm={24}>
                <FormItem
                  {...formItemLayout}
                  label="管理员昵称"
                >
                  {getFieldDecorator('name', {
                    initialValue: user && user.name,
                    rules: [{
                      required: true, message: '管理员昵称不能为空'
                    }],
                  })(
                    <Input />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="管理员邮箱"
                >
                  {getFieldDecorator('email', {
                    initialValue: user && user.email,
                    rules: [{
                      required: true, message: '管理员邮箱不能为空'
                    }],
                  })(
                    <Input />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="管理员角色"
                >
                  {getFieldDecorator('roleList', {
                    initialValue: user && user.roleList,
                    rules: [{
                      required: true, message: '管理员角色不能为空'
                    }],
                  })(
                    <CheckboxGroup options={roleList} />
                  )}
                </FormItem>
                <FormItem
                  wrapperCol={{
                    xs: { span: 24, offset: 0 },
                    sm: { span: 16, offset: 8 },
                  }}
                >
                  <Button loading={submitting} type="primary" htmlType="submit">提交</Button>
                </FormItem>
              </Col>
            </Row>
          </Form>
        </Card>
      </PageHeaderLayout>
    );
  }
}
