import React, { Component } from 'react';
import { connect } from 'dva';
import { Link } from 'dva/router';
import { Form, Input, Button, Row, Col, Checkbox, Card, Select, TreeSelect } from 'antd';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
const FormItem = Form.Item;
const Option = Select.Option;
const CheckboxGroup = Checkbox.Group;
const { TextArea } = Input;
@connect(({ loading, authority }) => ({
  submitting: loading.effects['authority/addSubmit'],
  loading: loading.models.permission,
  pageList: authority.pageList,
  funcList: authority.funcList,
}))
@Form.create()
export default class AuthorityAdd extends Component {
  state = {
    formValues: '',
  };

  componentDidMount() {
    const { dispatch } = this.props;
    dispatch({
      type: 'authority/fetchFuncAll',
      payload: {
        type: 'METHOD',
      },
    });
    dispatch({
      type: 'authority/fetchPageAll',
      payload: {
        type: 'PAGE',
      },
    });
  }

  handleSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFields((err, values) => {
      if (!err) {
        let list = [];
        values.funcList.map((item) => {
          list.push({
            id: item,
          });
        });
        values.pageList.map((item) => {
          list.push({
            id: parseInt(item),
          });
        });
        this.props.dispatch({
          type: 'authority/addSubmit',
          payload: {
            code: '2',
            sysPermissions: list,
            name: values.name,
            description: values.description,
          },
        });
      }
    });
  };

  render() {
    const { submitting, loading, funcList, pageList } = this.props;
    const { getFieldDecorator } = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
    };

    return (
      <PageHeaderLayout>
        <Card title='新增权限' loading={loading}>
          <Form onSubmit={this.handleSubmit}>
            <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
              <Col md={12} offset={4} sm={24}>
                <FormItem
                  {...formItemLayout}
                  label="权限名称"
                >
                  {getFieldDecorator('name', {
                    rules: [{
                      required: true, message: '权限名称不能为空'
                    }],
                  })(
                    <Input placeholder="请输入权限名称" />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="权限描述"
                >
                  {getFieldDecorator('description', {
                    rules: [{
                      required: true, message: '权限描述不能为空'
                    }],
                  })(
                    <TextArea placeholder="请输入权限描述" autosize={{ minRows: 4}} />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="权限页面资源"
                >
                  {getFieldDecorator('pageList', {
                    rules: [{
                      required: true, message: '权限页面资源不能为空'
                    }],
                  })(
                    <TreeSelect
                      treeData={pageList}
                      showCheckedStrategy={TreeSelect.SHOW_PARENT}
                      treeCheckable={true}
                      searchPlaceholder="请选择页面资源"
                    />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="权限方法资源"
                >
                  {getFieldDecorator('funcList', {
                    rules: [{
                      required: true, message: '权限方法资源不能为空'
                    }],
                  })(
                    <CheckboxGroup options={funcList} />
                  )}
                </FormItem>
                <FormItem
                  wrapperCol={{
                    xs: { span: 24, offset: 0 },
                    sm: { span: 16, offset: 8 },
                  }}
                >
                  <Button loading={submitting} type="primary" htmlType="submit">提交</Button>
                </FormItem>
              </Col>
            </Row>
          </Form>
        </Card>
      </PageHeaderLayout>
    );
  }
}
