import React, {Component} from 'react';
import {connect} from 'dva';
import moment from 'moment';
import {Link} from 'dva/router';
import {
  Form,
  Table,
  Input,
  Button,
  Upload,
  Icon,
  Row,
  Col,
  Avatar,
  Card,
  Select,
  InputNumber,
  Tabs,
  List,
  Cascader,
} from 'antd';
import {parse} from 'qs';
import Address from 'components/Map';
import {getCity} from '../../utils/getCity';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {setSessionStorage, getSessionStorage, sortTable} from '../../utils/utils';
import Lightbox from 'react-image-lightbox';
import 'react-image-lightbox/style.css';
import styles from './CardList.less';
import bitmap from '../../assets/bitmap.png'

const FormItem = Form.Item;
const Option = Select.Option;
const TabPane = Tabs.TabPane;
@connect(({loading, comsumer}) => ({
  submitting: loading.effects['comsumer/submit'],
  user: comsumer.user,
  userData: comsumer.userData,
  photoList: comsumer.photoList,
  loading: loading.effects['comsumer/fetchProfile'],
  suspending: loading.effects['comsumer/suspend'],
  photoPageSize: comsumer.photoPageSize,
  photoTotal: comsumer.photoTotal,
  photoCurrent: comsumer.photoCurrent,
  tagsList: comsumer.tagsList,
  sysVocationIdList: comsumer.sysVocationIdList,
  payPage: comsumer.payPage,
  payPageSize: comsumer.payPageSize,
  payTotal: comsumer.payTotal,
  payList: comsumer.payList,
  list: comsumer.list,
}))
@Form.create()
export default class Comsumer extends Component {
  state = {
    formValues: '',
    photoIndex: 0,
    isOpen: false,
    pointAt: null,
    // city: ['北京市','北京市','东城区'],
    city: [],
  };

  componentDidMount() {
    const {id} = parse(this.props.location.search.substr(1));
    const {dispatch} = this.props;
    dispatch({
      type: 'comsumer/fetchProfile',
      payload: {
        id,
      }
    });
    dispatch({
      type: 'comsumer/fetchTags',
      payload: {},
    });
    dispatch({
      type: 'comsumer/fetchSysVocationId',
      payload: {},
    });
  }

  handleBasicSubmit = (e) => {
    const {id} = parse(this.props.location.search.substr(1));
    e.preventDefault();
    const {dispatch, form, pageSize, tagsList} = this.props;
    form.validateFields([
      'nickName',
      'sex',
      'tags',
      'site',
      'pointAt',
      'sysVocationId',
    ], (err, values) => {
      if (!err) {
        const {nickName, sex, site, sysVocationId, tags, pointAt} = values;
        let tagsListOption = [];
        if (tags && tags.length) {
          tags.map((item) => {
            tagsList.map((item1) => {
              if (item === item1.key) {
                tagsListOption.push({
                  id: item,
                  name: item1.value,
                })
              }
            });
          });
        }
        ;
        dispatch({
          type: 'comsumer/submit',
          payload: {
            nickName,
            pointAt: pointAt.toString(),
            sex: sex === '男' ? 1 : 0,
            site,
            sysVocationId,
            tags: tagsListOption,
            id,
          },
        });
      }
    });
  };

  handlePointAt = (e) => {
    const point = JSON.stringify(e);
    this.setState({
      pointAt: point,
    }, () => {
      this.setState({
        pointAt: point,
      });
    });
  };
  handleAddress = (e) => {
    // console.log('handleAddress');
    // console.log(this.state.city);
    this.setState({
      city: e
    });
    // console.log('---2---')
    // console.log(this.state.city);
  }

  handleCityChange = (value, selectedOptions) => {
    let city = [];
    selectedOptions.map((item) => {
      city.push(item.label);
    });
    this.setState({
      city,
    });
  };

  handleDataSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFields([
      'vipGrade',
      'vipTime',
      'svip',
      'astro',
      'phone',
      'tags',
    ], (err, values) => {
      if (!err) {
        this.props.dispatch({
          type: 'comsumer/submit',
          payload: {
            ...values,
          },
        });
      }
    });
  };

  handleSuspend = (e) => {
    e.preventDefault();
    this.props.dispatch({
      type: 'comsumer/suspend',
      payload: {
        id: this.props.user && this.props.user.id,
      },
    });
  };

  handleTabChange = (k) => {
    // console.log('tabChange');
    const {dispatch} = this.props;
    const {id} = parse(this.props.location.search.substr(1));
    if (k === '4') {
      dispatch({
        type: 'comsumer/fetchPhotoList',
        payload: {
          id,
        },
      });
    }
    if (k === '3') {
      // console.log(this.props.payPageSize);
      // setSessionStorage('comsumerPayListPage', this.props.payPage);
      // setSessionStorage('comsumerPayListPageSize', this.props.payPageSize);
      dispatch({
        type: 'comsumer/fetchPayList',
        payload: {
          "columns": [
            {
              "name": "orderRecord.consumerA.id",
              "relation": "EQ",
              "search": id,
            },
            // {
            //   "name": "reveal",
            //   "relation": "EQ",
            //   "search": 1,
            // }
          ],
          page: getSessionStorage("comsumerPayListPage") || this.props.payPage,
          pageSize: getSessionStorage("comsumerPayListPageSize") || this.props.payPageSize,
        },
      });
      // console.log(this.props.payPage);
    }
    if (k === '2') {
      //数据统计
      dispatch({
        type: 'comsumer/fetchData',
        payload: {
          id,
        },
      });
    }
    if (k === '1') {
      // console.log(1);
      dispatch({
        type: 'comsumer/fetchProfile',
        payload: {
          id,
        }
      });
      dispatch({
        type: 'comsumer/fetchTags',
        payload: {},
      });
      dispatch({
        type: 'comsumer/fetchSysVocationId',
        payload: {},
      });
    }
  };

  handlePass = (record) => {
    // console.log(1);
    this.props.dispatch({
      type: 'comsumer/ablumPass',
      payload: {
        id: record.id,
        uid: parse(this.props.location.search.substr(1))
      }
    })
  };

  handleDelete = (record) => {
    this.props.dispatch({
      type: 'comsumer/refuse',
      payload: {
        id: record.id,
        uid: parse(this.props.location.search.substr(1))
      }
    });
    // this.props.dispatch({
    //   type: 'comsumer/fetchPhotoList',
    //   payload: {
    //     id: 32161,
    //   },
    // });
  };

  handleLightBox = (record) => {
    let id = 0;
    this.props.user.albums.map((item, index) => {
      if (item.id === record.id) {
        id = index;
      }
    });
    this.setState({
      isOpen: true,
      photoIndex: id,
    });
  };

  fetchImg = (arr = []) => {
    let res = [];
    arr.map(item => {
      res.push(item.pic);
    });
    return res;
  };

  handleClose = () => {
    this.setState({
      isOpen: false,
    });
  };

  handleSizeChange = (current, size) => {
    setSessionStorage("comsumerPayListCurrent", current);
    setSessionStorage("comsumerPayListPageSize", size);
    this.props.dispatch({
      type: 'comsumer/fetch',
      payload: {
        pageSize: size,
        page: current,
      },
    });
  };

  handleTableChange = (pagination, filters, sorter) => {
    const {form} = this.props;
    let values = null;

    const {current, pageSize} = pagination;

    setSessionStorage("comsumerPayListCurrent", current);
    setSessionStorage("comsumerPayListPageSize", pageSize);

    const columns = [{
      name: "orderRecord.consumerA.id",
      relation: "EQ",
      search: parse(this.props.location.search.substr(1)).id,
      type: "T_STRING"
    }]
    this.fetch({
      page: current,
      pageSize,
      columns,
    });
  };

  fetch = (payload) => {
    this.props.dispatch({
      type: 'comsumer/fetchPayList',
      payload,
    });
  };
  //校验
  // checkAccount(rule, value, callback) {
  //   var re = /^[0-9]*$/;
  //
  //   if (value.length==11 || re.test(value)) {
  //     callback();
  //   } else {
  //     callback('XXXXXX');
  //   }
  // };

  render() {
    const {
      submitting,
      user,
      userData,
      suspending,
      loading,
      sysVocationIdList,
      tagsList,
      payList,
      payPageSize,
      payPage,
      payTotal,
      // list,
      photoList
    } = this.props;
    // console.log('render');
    // console.log({photoList});
    // console.log({userData});
    const {getFieldDecorator} = this.props.form;
    // console.log({getFieldDecorator});

    const {photoIndex, isOpen} = this.state;

    // handleAddress
    // this.handleAddress('30,30');
    // const city = ['北京市','北京市','东城区'];
    // console.log('city');
    // console.log(this.state.city);
    // this.setState({
    //   city:['北京市','北京市','东城区']
    // })
    // console.log(this.state.city);


    // console.log(user);
    // console.log(this.state.photoIndex);
    // console.log(this.state.city);
    // console.log(this.state.city);
    // this.state.city = user.city;
    // console.log(this.state.city);
    const imagesList = this.fetchImg(user && user.albums || []);

    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    const columns = [
      {
        title: '序号',
        dataIndex: 'id',
        render: (text, record, index) => (
          <span>
            {index + (payPage - 1) * payPageSize + 1}
          </span>
        ),
      },
      {
        title: '时间',
        dataIndex: 'time',
        render: (text, record) => (
          <span>
            {record.time && moment(record.time).format('YYYY-MM-DD HH:mm:ss')}
          </span>
        ),
      },
      {
        title: '描述',
        dataIndex: 'title',
        key: 'title',
      },
    ];
    const pagination = {
      pageSize: getSessionStorage("comsumerPayListPageSize") * 1 || payPageSize,
      current: getSessionStorage("comsumerPayListCurrent") * 1 || payPage,
      total: payTotal,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };


    const tagsListOptions = Array.isArray(tagsList) && tagsList.length ? tagsList.map(d => <Option value={d.key}
                                                                                                   key={d.key}>{d.value}</Option>) : [];
    const sysVocationIdListOptions = Array.isArray(sysVocationIdList) && sysVocationIdList.length ? sysVocationIdList.map(d =>
      <Option value={d.key} key={d.key}>{d.value}</Option>) : [];

    return (
      <PageHeaderLayout>
        <Card title='用户详细资料' extra={user && !user.lock ?
          <Button loading={suspending} type="primary" onClick={this.handleSuspend}>禁用</Button> :
          <Button loading={suspending} type="primary" onClick={this.handleSuspend}>解禁</Button>}>
          <Tabs onChange={this.handleTabChange}>
            <TabPane tab="基本资料" key="1" loading={loading}>
              <Form onSubmit={this.handleBasicSubmit}>
                <Row gutter={{md: 8, lg: 24, xl: 48}}>
                  <Col md={12} offset={4} sm={24}>
                    <FormItem
                      {...formItemLayout}
                      label="真实头像"
                    >
                      <Row gutter={{md: 8, lg: 24, xl: 48}}>
                        <Col md={16} offset={0} sm={24}>
                          <img alt="真实头像" src={user && user.photo} style={{width: '180px', height: '180px'}}/>
                        </Col>
                      </Row>
                    </FormItem>
                    {/*<FormItem*/}
                      {/*{...formItemLayout}*/}
                      {/*label="匿名头像"*/}
                    {/*>*/}
                      {/*<Row gutter={{md: 8, lg: 24, xl: 48}}>*/}
                        {/*<Col md={24} offset={0} sm={24}>*/}
                          {/*<img alt="匿名头像" src={user && user.defaultPhoto || ''} style={{maxWidth: '100%'}}/>*/}
                        {/*</Col>*/}
                      {/*</Row>*/}
                    {/*</FormItem>*/}
                    <FormItem
                      {...formItemLayout}
                      label="用户ID"
                    >
                      {getFieldDecorator('id', {
                        initialValue: user && user.id,
                      })(
                        <Input disabled/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="真实昵称"
                    >
                      {getFieldDecorator('nickName', {
                        initialValue: user && user.nickName,
                        rules: [{
                          required: true, message: '请填写真实昵称',
                        },
                          {
                            max:10,message:'最大10个字符'
                            // validator:this.checkAccount.bind(this)
                          }
                        ],
                      })(
                        <Input/>
                      )}
                    </FormItem>
                    {/*<FormItem*/}
                      {/*{...formItemLayout}*/}
                      {/*label="匿名昵称"*/}
                    {/*>*/}
                      {/*{getFieldDecorator('defaultNickName', {*/}
                        {/*initialValue: user && user.defaultNickName,*/}
                      {/*})(*/}
                        {/*<Input disabled/>*/}
                      {/*)}*/}
                    {/*</FormItem>*/}
                    <FormItem
                      {...formItemLayout}
                      label="手机号码"
                    >
                      {getFieldDecorator('phone', {
                        initialValue: user && user.phone,
                      })(
                        <Input disabled/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="性别"
                    >
                      {getFieldDecorator('sex', {
                        initialValue: user && user.sex,
                      })(
                        <Select>
                          <Option value="男">男</Option>
                          <Option value="女">女</Option>
                        </Select>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="星座"
                    >
                      {getFieldDecorator('astro', {
                        initialValue: user && user.astro,
                      })(
                        <Input disabled/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="生肖"
                    >
                      {getFieldDecorator('zodiac', {
                        initialValue: user && user.zodiac,
                      })(
                        <Input disabled/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="手机系统"
                    >
                      {getFieldDecorator('phoneSysVersion', {
                        initialValue: user && user.phoneSysVersion,
                      })(
                        <Input disabled/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="APP版本"
                    >
                      {getFieldDecorator('appVersion', {
                        initialValue: user && user.appVersion,
                      })(
                        <Input disabled/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="行业"
                    >
                      {getFieldDecorator('sysVocationId', {
                        initialValue: user && user.sysVocationId,
                      })(
                        <Select
                          style={{width: '100%'}}
                          placeholder="请选择用户行业"
                        >
                          {sysVocationIdListOptions}
                        </Select>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="当前/最后位置"
                    >
                      {getFieldDecorator('pointAt', {
                        initialValue: this.state.pointAt !== null ? JSON.stringify(this.state.pointAt) : user && JSON.stringify('{\"lng\":' + user.longitude + ',\"lat\":' + user.latitude + '}'),
                        //"{\"lng\":104.050819,\"lat\":30.705532}" longitude
                        //"{\"lng\":104.06203,\"lat\":30.715716}"
                        // initialValue: this.state.pointAt !== null ? JSON.stringify(this.state.pointAt) : JSON.stringify("{'lng':"+user && user.longitude+",'lat':"+user && user.latitude+"}"),
                      })(
                        <Input placeholder="请选择最后位置"/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="选择位置所在地"
                    >
                      {getFieldDecorator('regionId', {
                        initialValue: this.state.city,
                        // initialValue: ['1北京市','北京市','东城区'],
                        rules: [{
                          required: true,
                          message: '请选择聚点所在地',
                        }],
                      })(
                        <Cascader showSearch={true} onChange={this.handleCityChange} options={getCity()}
                                  placeholder="请选择位置所在地"/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="选择当前/最后位置"
                    >
                      <Address
                        key={Math.random()}
                        place={this.state.city}
                        prevPointAt={this.state.pointAt ? this.state.pointAt : user && JSON.stringify(user.site)}
                        handlePointAt={this.handlePointAt.bind(this)}
                        handleAddress={this.handleAddress.bind(this)}
                      >

                      </Address>
                      <p>请在地图上单击鼠标右键选取选择用户最后位置。</p>
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="注册时间"
                    >
                      {getFieldDecorator('createDate', {
                        initialValue: user && moment(user.createDate).format('YYYY-MM-DD HH:mm:ss'),
                      })(
                        <Input disabled/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="最后登录时间"
                    >
                      {getFieldDecorator('lastSigned', {
                        initialValue: user && (user.lastSigned === null ? '' : moment(user.lastSigned).format('YYYY-MM-DD HH:mm:ss')),
                      })(
                        <Input disabled/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="标签"
                    >
                      {getFieldDecorator('tags', {
                        initialValue: (user && user.tags !== null) ? user.tags : [],
                        rules: [{
                          required: true,
                          message: '至少选择一个标签',
                        }],
                      })(
                        <Select
                          mode="multiple"
                          style={{width: '100%'}}
                          placeholder="请选择用户标签"
                        >
                          {tagsListOptions}
                        </Select>
                      )}
                    </FormItem>
                    <FormItem
                      wrapperCol={{
                        xs: {span: 24, offset: 0},
                        sm: {span: 16, offset: 8},
                      }}
                    >
                      <Button loading={submitting} type="primary" htmlType="submit">确定修改</Button>
                    </FormItem>
                  </Col>
                </Row>
              </Form>
            </TabPane>
            <TabPane tab="数据统计" key="2">
              <Row gutter={{md: 8, lg: 24, xl: 48}}>
                <Col md={12} offset={4} sm={24}>
                  <form onSubmit={this.handleDataSubmit}>
                    <FormItem
                      {...formItemLayout}
                      label="vip"
                    >
                      {getFieldDecorator('vipGrade', {
                        initialValue: userData && userData.vipGrade === 1 ? '是' : '否',
                      })(
                        <Select disabled>
                          <Option value="是">是</Option>
                          <Option value="否">否</Option>
                        </Select>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="VIP到期时间"
                    >
                      {getFieldDecorator('vipExpirationTime', {
                        initialValue: userData && userData.vipExpirationTime,
                      })(
                        <Input disabled/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="钻石会员"
                    >
                      {getFieldDecorator('svip', {
                        initialValue: userData && userData.svip ? '是' : '否',
                      })(
                        <Select disabled>
                          <Option value="是">是</Option>
                          <Option value="否">否</Option>
                        </Select>
                      )}
                    </FormItem>

                    <FormItem
                      {...formItemLayout}
                      label="钻石伙伴积分"
                    >
                      {getFieldDecorator('integral', {
                        initialValue: userData && userData.integral,
                      })(
                        <InputNumber disabled style={{width: '100%'}}/>
                      )}
                    </FormItem>

                    <FormItem
                      {...formItemLayout}
                      label="当前配对人数"
                    >
                      {getFieldDecorator('friendNum', {
                        initialValue: userData && userData.friendNum,
                      })(
                        <InputNumber disabled style={{width: '100%'}}/>
                      )}
                    </FormItem>

                    <FormItem
                      {...formItemLayout}
                      label="我收到的"
                    >
                      {getFieldDecorator('newReceive ', {
                        initialValue: userData && userData.newReceive,
                      })(
                        <InputNumber disabled style={{width: '100%'}}/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="我送出的"
                    >
                      {getFieldDecorator('newSend', {
                        initialValue: userData && userData.newSend,
                      })(
                        <InputNumber disabled style={{width: '100%'}}/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="历史礼物-我收到的"
                    >
                      {getFieldDecorator('oldReceive', {
                        initialValue: userData && userData.oldReceive,
                      })(
                        <InputNumber disabled style={{width: '100%'}}/>
                      )}
                    </FormItem>
                    <FormItem
                      {...formItemLayout}
                      label="历史礼物-我送出的"
                    >
                      {getFieldDecorator('oldSend', {
                        initialValue: userData && userData.oldSend,
                      })(
                        <InputNumber disabled style={{width: '100%'}}/>
                      )}
                    </FormItem>
                  </form>
                </Col>
              </Row>
            </TabPane>
            <TabPane tab="消费记录" key="3">
              <Table
                bordered
                loading={loading}
                rowKey='id'
                columns={columns}
                dataSource={payList}
                pagination={pagination}
                onChange={this.handleTableChange}
              />
            </TabPane>
            <TabPane tab="相册照片" key="4">
              <List
                rowKey="id"
                loading={loading}
                grid={{gutter: 24, lg: 4, md: 3, sm: 2, xs: 2}}
                dataSource={photoList}
                renderItem={(item, index) =>
                  (
                    <List.Item key={item.id}>
                      <Card hoverable className={styles.card}
                            disabled
                            actions={item.status === 0 ? [<a onClick={this.handlePass.bind(null, item)}>通过</a>,
                              <a onClick={this.handleDelete.bind(null, item, index)}>不通过</a>] : [<a
                              disabled="disabled">通过</a>, <a disabled="disabled">不通过</a>]}>
                        <Card.Meta
                          avatar={<img alt='用户照片' onClick={this.handleLightBox.bind(null, item, index)}
                                       className={styles.cardAvatar}
                                       src={item.status === -1 ? 'http://image.seemore.club/98defd6ee70dfb1dea416cecdf391f58/1538100075000.png' : item.pic}/>}
                        />
                      </Card>
                    </List.Item>
                  )
                }
              />
            </TabPane>
          </Tabs>
        </Card>
        {isOpen && (
          <Lightbox
            mainSrc={imagesList[photoIndex] || []}
            onCloseRequest={this.handleClose}
          />
        )}
      </PageHeaderLayout>
    );
  }
}
