import React, {Component} from 'react';
import {connect} from 'dva';
import {Link} from 'dva/router';
import {
  Form,
  Input,
  Button,
  Row,
  Col,
  Checkbox,
  Card,
  Select,
  InputNumber,
  Upload,
  Icon,
  message,
  Modal,
  Tree
} from 'antd';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {parse} from 'qs';
import {getSessionStorage, upYunAuthorization} from '../../utils/utils';
import {getCity} from "../../utils/getCity";

const FormItem = Form.Item;
const Option = Select.Option;
const CheckboxGroup = Checkbox.Group;
const {TextArea} = Input;
const {TreeNode} = Tree;
@connect(({loading, gift}) => ({
  submitting: loading.effects['gift/editSubmit'],
  gift: gift.gift,
  sites: gift.sites,
  accumulations: gift.accumulations
}))
@Form.create()
export default class Gift extends Component {

  state = {
    // formValues: '',
    // pics: [],
    //'TAKE', 'SEND', 'EXPRESS', 'ELECTRONIC_CODE'
    // options: [
    //   {label: '用户自提', value: 'TAKE', disabled: false},
    //   {label: '场内派送', value: 'SEND', disabled: false},
    //   {label: '快递配送', value: 'EXPRESS', disabled: false},
    //   {label: '电子券码', value: 'ELECTRONIC_CODE', disabled: false}
    // ],
    checkMethod: undefined,
    previewVisible: false,
    previewImage: '',
    codeShow: false,
    provinceList: getCity(),
    selectedItems: undefined,
    // method: [],
    checkedKeys: undefined,
    fileList: undefined,
    methodList: undefined,
    methodEnum: {
      TAKE: '用户自提',
      SEND: '场内派送',
      EXPRESS: '快递配送',
      ELECTRONIC_CODE: '电子券码'
    },
    cityShow: false,
    selectSiteId: null,
    checkAll: undefined,
    isEditMethod: false
  };

  componentDidMount() {
    const {id} = parse(this.props.location.search.substr(1));
    this.props.dispatch({
      type: 'gift/fetchDetail',
      payload: {
        id
      }
    });
    this.getSiteList();
    this.getAccumulations()
  }

  //提交修改
  handleSubmit = (e) => {
    const {id} = parse(this.props.location.search.substr(1));
    e.preventDefault();
    const {gift} = this.props;
    const {fileList, provinceList, selectedItems, checkedKeys, checkAll, checkMethod} = this.state;

    //Param:pics 礼物图片
    var pics = [];
    if (JSON.stringify(fileList) !== '[]') {
      var pic = {};

      if (fileList) {
        fileList.map((item, index) => {
          pic = {
            link: item.url || 'http://image.seemore.club' + item.response.url,
            num: index + 1,
            id: typeof item.name === 'number' && item.name % 1 === 0 ? item.name : null
          };
          pics.push(pic)
        });
      } else {
        pics = gift.pics
      }
    } else {
      pics = gift.pics
    }

    // Param:Gathering 推荐聚点
    var gatherings = [];

    if (selectedItems) {
      if (JSON.stringify(selectedItems) !== '[]') {
        gatherings = this.formartGatheringNamesToIds(selectedItems ? selectedItems : this.props.gift.gatherings);
      } else {
        gatherings = this.formartGatheringNamesToIds(selectedItems)
      }
    } else {
      gatherings = gift.gatherings;
    }
    // if (JSON.stringify(selectedItems) !== '[]') {
    //   gatherings = this.formartGatheringNamesToIds(selectedItems ? selectedItems : this.props.gift.gatherings);
    //   // console.log(gatherings);
    // } else {
    //   gatherings = gift.gatherings;
    // }

    //Param:Regions 配送地区
    var regions = [];
    if (checkAll) {
      regions = [{regionId: 99999}]
    } else {
      if (checkedKeys) {
        checkedKeys.map(item => {
          let id = null;
          if (gift.regions.length) {
            gift.regions.map(g => {
              if (g.regionId === parseInt(item)) {
                // console.log('===');
                id = g.id
              }
            });
            regions.push({
              regionId: item,
              id
            })
          } else {
            regions = null
          }
        });
        // console.log(checkedKeys);
        for (let i = 0; i < provinceList.length; i++) {
          for (let j = 0; j < regions.length; j++) {
            if (parseInt(regions[j].regionId) === provinceList[i].value) {
              regions.splice(j, 1);
            }
          }
        }
      } else {
        // regions = undefined
        if (checkedKeys===undefined){
          regions = this.props.gift.regions
        } else {
          regions = undefined
        }
      }
    }
    // console.log(regions);

    this.props.form.validateFields((err, values) => {
      if (!err) {
        this.props.dispatch({
          type: 'gift/editSubmit',
          payload: {
            ...values,
            id,
            method: this.acTiveArrStringFun(values.method),
            pics,
            gatherings,
            regions
          }
        })
      }
    })
  };

  //礼物图片-预览
  handlePreview = (file) => {
    this.setState({
      previewImage: file.url || file.thumbUrl,
      previewVisible: true,
    });
  };

  handleCancel = () => this.setState({previewVisible: false});
  //图片数据格式化
  formartPicsToFileList = (pics) => {
    var list = [];
    var pic = {};
    pics.map(item => {
      pic = {
        uid: item.id,
        name: item.id,
        status: 'done',
        url: item.link,
      };
      list.push(pic);
    });
    return list
  };
  //聚点数据格式化Ids转Names
  formartIdsToNames = (ids) => {
    console.log(ids)
    const gatheringList = this.props.accumulations;
    let names = [];
    ids.map(i => {
      gatheringList.map(g => {
        if (i.gatheringId === g.id) {
          names.push(g.name)
        }
      })
    });
    return names
  };

  //聚点数据格式化Names转Ids
  formartGatheringNamesToIds(gList) {
    console.log(gList)
    const {accumulations, gift} = this.props;
    var gatherings = [];
    var gathering = {};
    const gatheringList = accumulations.filter(o => gList.includes(o.name));
    gatheringList.map((g, index) => {
      let gIndex = undefined;
      // console.log('index:' + index);
      gift.gatherings.map((gf, g_index) => {
        if (g.id === gf.gatheringId) {
          gIndex = g_index
        }
      });
      gathering = {
        gatheringId: g.id,
        id: gIndex !== undefined ? gift.gatherings[gIndex].id : null
      };
      gatherings.push(gathering)
    });

    return gatherings;
  }

  //方法数据格式化
  formartMethod(str) {
    if (str.indexOf(',') >= 0) {
      return str.split(',')
    } else {
      let arr = [];
      arr.push(str);
      return arr
    }
  }

  //地区id格式化
  formartRegionParentId(ids) {
    const {provinceList} = this.state;
    for (let i = 0; i < ids.length; i++) {
      for (let j = 0; j < provinceList.length; j++) {
        if (parseInt(ids[i]) === provinceList[j].value) {
          ids.splice(i, 1);
        }
      }
    }
    var objList = [];
    ids.map(item => {
      objList.push({regionId: item})
    });
    return objList
  }

  //数组转字符串
  acTiveArrStringFun(obj) {
    const arr = [];
    if (obj != null && obj.length !== 0) {
      for (let i = 0; i < obj.length; i++) {
        arr.push(obj[i]);
      }
    }
    return arr.toString();
  }

  //获取商户列表
  getSiteList() {
    this.props.dispatch({
      type: 'gift/fetchSites',
      payload: {
        page: 1,
        pageSize: 99999
      }
    })
  }

  //获取聚点列表
  getAccumulations() {
    this.props.dispatch({
      type: 'gift/fetchAccumulations',
      payload: {
        page: 1,
        pageSize: 99999
      }
    })
  }

  //聚点下拉列表改变
  handleSelectedChange = selectedItems => {
    // console.log('GatheringChange');
    // console.log('-----------');
    // console.log(selectedItems);
    // console.log('-----------');
    var gatherings = [];
    this.props.accumulations.map(g => {
      selectedItems.map(item => {
        if (g.name === item) {
          gatherings.push({gatheringId: g.id})
        }
      })
    });
    this.setState({selectedItems});
  };
  //配送方式改变
  handleMethodChange = (checkMethod) => {
    this.setState({
      isEditMethod: true
    });
    if (checkMethod.indexOf('ELECTRONIC_CODE') >= 0) {
      this.setState({
        codeShow: true,
        cityShow: true,
        checkAll: false,
        checkedKeys: [],
        checkMethod
      })
    } else if (checkMethod.indexOf('EXPRESS') >= 0) {
      this.setState({
        cityShow: true,
        checkAll: false,
        checkedKeys: [],
        checkMethod
      })
    } else {
      this.setState({
        cityShow: false,
        codeShow: false,
        checkAll: false,
        checkMethod
      })
    }
  };
  //商户改变
  handleSiteChange = (e) => {
    const curSite = this.props.sites.filter(s => s.id === e);
    const temp = this.formartMethod(curSite[0].method);
    var methodList = [];
    if (Array.isArray(temp)) {
      methodList = temp
    } else {
      methodList.push(temp);
    }
    this.setState({
      methodList,
      checkMethod: [],
      checkedKeys: [],
      selectSiteId: e
    })
  };

  onCheck = (checkedKeys, info) => {
    this.setState({checkedKeys})
  };
  //全选
  checkAll = (e) => {
    // console.log(e);
    // const {checkAll} = this.state;
    // if (checkAll === undefined) {
    //   this.setState({
    //     checkAll: !e.target.checked,
    //     checkedKeys: []
    //   })
    // } else {
    //   this.setState({
    //     checkAll: !this.state.checkAll,
    //     checkedKeys: []
    //   })
    // }

    // console.log(e);
    this.setState({
      checkAll: e.target.checked,
      checkedKeys: []
    })
  };

  render() {
    const {submitting, loading, gift, sites, accumulations} = this.props;
    const {previewVisible, previewImage, provinceList, checkMethod, methodList, selectedItems, fileList, isEditMethod} = this.state;

    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8}
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16}
      }
    };
    const {getFieldDecorator} = this.props.form;
    //礼物图片-上传
    const date = Date.parse(new Date());
    const uploadProps = {
      // action: 'http://v0.api.upyun.com/seemore-web1',
      action: 'http://v0.api.upyun.com/image-seemore',
      listType: 'picture-card',
      data: {
        'authorization': upYunAuthorization("gift", date).authorization,
        'policy': upYunAuthorization("gift", date).policy,
      },
      name: 'file',
      headers: {
        'X-Requested-With': null,
      },
      // defaultFileList: this.props.gift ? this.props.gift.pics : [],
      onChange: (info) => {
        const status = info.file.status;
        if (status === 'done') {
          message.success(`${info.file.name} 文件上传成功.`);
        } else if (status === 'error') {
          message.error(`${info.file.name} 文件上传失败，请重新上传。`);
        }
        this.setState({fileList: info.fileList})
      }
    };
    const uploadButton = (
      <div>
        <Icon type="plus"/>
        <div className="ant-upload-text">Upload</div>
      </div>
    );

    //礼物图片-数据
    var files = [];
    if (this.state.fileList === undefined) {
      files = gift ? this.formartPicsToFileList(gift.pics) : [];
    } else {
      files = fileList
    }
    //礼物图片-预览

    //所属商户Option
    const sitesOptions = Array.isArray(sites) && sites.length ? sites.map(d =>
      <Option value={d.id} key={d.id}>{d.name}</Option>) : [];

    //推荐场所选中项
    var items = []
    if (selectedItems === undefined) {
      items = gift && this.formartIdsToNames(gift.gatherings);
    } else {
      items = selectedItems
    }

    var filteredOptions = [];
    var isCode = false;
    if (gift) {
      filteredOptions = accumulations.filter(o => !items.includes(o.name))
      // var isCode = false;//领取方式是否是电子券类型，如果是要禁用所有编辑功能
      // isCode = true
      // console.log(gift.method);
      if (gift.method === 'ELECTRONIC_CODE') {
        isCode = true
      }
    }

    let option = {};
    let options = [];
    let cityShow = undefined;
    let r_checkMethod = [];
    if (gift) {
      //选中项
      if (checkMethod === undefined) {
        r_checkMethod = this.formartMethod(gift.method)
      } else if (JSON.stringify(checkMethod) === '[]') {
        r_checkMethod = []
      } else {
        r_checkMethod = checkMethod
      }
      //可选项
      if (methodList === undefined) {
        if (JSON.stringify(sites) !== '[]') {
          let curSite = this.props.sites.filter(s => s.id === gift.siteId);
          let temp = this.formartMethod(curSite[0].method);
          if (Array.isArray(temp)) {
            this.formartMethod(curSite[0].method).map(m => {
              option = {
                label: this.state.methodEnum[m],
                value: m,
                disabled: false
              };
              options.push(option)
            });
          } else {
            options.push(temp);
          }
        }
      } else {
        methodList.map(m => {
          option = {
            label: this.state.methodEnum[m],
            value: m
          };
          options.push(option)
        })
      }

      //------根据源数据禁用其他checkbox
      var codeShow = this.state.codeShow;

      if (r_checkMethod.indexOf('ELECTRONIC_CODE') >= 0) {
        options.map(item => {
          item.disabled = true;
          if (item.value === 'ELECTRONIC_CODE') {
            item.disabled = false;
            codeShow = true;
          }
        })
      } else if (r_checkMethod.indexOf('EXPRESS') >= 0) {
        options.map(item => {
          item.disabled = true;
          if (item.value === 'EXPRESS') {
            item.disabled = false;
            codeShow = false;
          }
        })
      } else if (r_checkMethod.indexOf('TAKE') >= 0 || r_checkMethod.indexOf('SEND') >= 0) {
        options.map(item => {
          item.disabled = true;
          if (item.value === 'TAKE' || item.value === 'SEND') {
            item.disabled = false;
            codeShow = false;
          }
        });
      } else {
        options.map(item => {
          item.disabled = false;
        })
      }
      //------

      //直接显示快递配送或者电子券码的配送城市层
      if (checkMethod) {
        if (JSON.stringify(checkMethod) === '[]') {
          cityShow = false
        } else {
          let flag = false;
          checkMethod.map(m => {
            if (['EXPRESS', 'ELECTRONIC_CODE'].indexOf(m) >= 0) {
              flag = true
            }
          });
          if (flag)
            cityShow = true
        }
      } else {
        const prop_method = this.formartMethod(gift.method);
        let flag = false;
        prop_method.map(m => {
          if (['EXPRESS', 'ELECTRONIC_CODE'].indexOf(m) >= 0) {
            flag = true
          }
        });
        if (flag) {
          cityShow = true
        }
      }
    }

    //省市树
    const treeNode = provinceList.map(p =>
      <TreeNode title={p.label} key={p.value}>
        {p.children.map(c =>
          (
            <TreeNode title={c.label} key={c.value}/>
          )
        )}
      </TreeNode>
    );

    const regions = [];
    // let cityListShow = false;
    var checkAll = this.state.checkAll;
    if (gift) {
      if (checkAll === undefined) {
        if (gift.regions) {
          if (gift.regions[0].regionId === 99999) {
            checkAll = true
          } else {
            gift.regions.map(r => {
              regions.push(r.regionId + '');
              checkAll = false
            });
          }
        }
      } else {
        console.log(checkAll);
      }
    }

    return (
      <PageHeaderLayout>
        <Card title='礼品详情' loading={loading}>
          <Form onSubmit={this.handleSubmit}>
            <Row gutter={{md: 8, lg: 24, xl: 48}}>
              <Col md={12} offset={4} sm={24}>
                <FormItem
                  {...formItemLayout}
                  label="礼物图片"
                >
                  {/*{getFieldDecorator('name', {*/}
                    {/*initialValue: gift && gift.name,*/}
                    {/*rules: [{*/}
                      {/*required: true, message: '礼品名称不能为空'*/}
                    {/*}, {*/}
                      {/*max: 40, message: '最多输入40个字符'*/}
                    {/*}]*/}
                  {/*})(*/}
                    {/*<Input placeholder="请输入礼品名称" disabled={isCode}/>*/}
                  {/*)}*/}
                  <Upload {...uploadProps}
                          fileList={fileList ? fileList : files}
                          onPreview={this.handlePreview}
                          disabled={isCode}
                  >
                    {fileList && fileList.length >= 10 ? null : uploadButton}
                  </Upload>
                  <Modal visible={previewVisible} footer={null} onCancel={this.handleCancel}>
                    <img alt="example" style={{width: '100%'}} src={previewImage}/>
                  </Modal>
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="礼品名称"
                >
                  {getFieldDecorator('name', {
                    initialValue: gift && gift.name,
                    rules: [{
                      required: true, message: '礼品名称不能为空'
                    }, {
                      max: 40, message: '最多输入40个字符'
                    }]
                  })(
                    <Input placeholder="请输入礼品名称" disabled={isCode}/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="礼物简介"
                >
                  {getFieldDecorator('introduce', {
                    initialValue: gift && gift.introduce,
                    rules: [{
                      required: true, message: '礼物名称不能为空',
                    },
                      {
                        max: 40, message: '礼物介绍最多40个字符',
                      }
                    ],
                  })(
                    <TextArea placeholder="请输入礼物介绍" autosize={{minRows: 2}} disabled={isCode}/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="所属商户"
                >
                  {getFieldDecorator('siteId', {
                    initialValue: gift && gift.siteId,
                    rules: [{
                      required: true, message: '所属商户不能为空'
                    }]
                  })(
                    <Select
                      style={{width: '100%'}}
                      placeholder="请选择所属商户"
                      onChange={this.handleSiteChange}
                      disabled={isCode}
                    >
                      {sitesOptions}
                    </Select>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="所属推荐聚点"
                >
                  <Select
                    mode="multiple"
                    placeholder="请选择所属推荐聚点"
                    value={selectedItems ? selectedItems : items}
                    onChange={this.handleSelectedChange}
                    style={{width: '100%'}}
                    disabled={isCode}
                  >
                    {filteredOptions.map(item => (
                      <Select.Option key={item} value={item.name}>
                        {item.name}
                      </Select.Option>
                    ))}
                  </Select>
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="礼品单价"
                >
                  {getFieldDecorator('money', {
                    initialValue: gift && gift.money,
                    rules: [{
                      required: true, message: '礼品单价不能为空'
                    }]
                  })(
                    <InputNumber style={{width: '100%'}} placeholder="请输入礼品单价" disabled={isCode}/>
                  )}
                </FormItem>
                {
                  !codeShow&&<FormItem
                    {...formItemLayout}
                    label="礼品库存"
                  >
                    {getFieldDecorator('number', {
                      initialValue: gift && gift.number,
                      rules: [{
                        required: true, message: '礼品库存不能为空'
                      }]
                    })(
                      <InputNumber style={{width: '100%'}} placeholder="请输入礼品库存" disabled={isCode}/>
                    )}
                  </FormItem>
                }
                <FormItem
                  {...formItemLayout}
                  label="礼物领取方式"
                >
                  {getFieldDecorator('method', {
                    initialValue: r_checkMethod,
                    rules: [{
                      required: true, message: '礼物领取方式不能为空'
                    }]
                  })(
                    <CheckboxGroup
                      // value={this.state.checkMethod === undefined ? JSON.stringify(this.state.checkMethod)==='[]'? gift && this.formartMethod(gift.method) : JSON.stringify(this.state.checkMethod === '[]') ? [] : this.state.checkMethod :[]}
                      options={options}
                      onChange={this.handleMethodChange}
                      disabled={isCode}/>
                  )}
                </FormItem>
                {
                  codeShow && <FormItem
                    {...formItemLayout}
                    label="电子券码"
                  >
                    {getFieldDecorator('codes', {
                      initialValue: this.props.gift && this.props.gift.codes,
                      rules: [{
                        required: true, message: '电子券码不能为空'
                      }]
                    })(
                      <TextArea placeholder="请输入电子券码" autosize={{minRows: 2}} disabled={!isEditMethod}/>
                    )}
                  </FormItem>
                }
                {
                  cityShow && <FormItem
                    {...formItemLayout}
                    label="礼物到达城市"
                    //1 style={{display: cityShow ? 'block' : this.state.cityShow ? 'block' : 'none'}}
                  >
                    <Checkbox disabled={isCode} onChange={this.checkAll}
                              checked={this.state.checkAll === undefined ? checkAll : this.state.checkAll}>全国</Checkbox>
                    {
                      !checkAll && <Tree
                        checkable
                        checkedKeys={this.state.checkedKeys ? this.state.checkedKeys : regions}
                        defaultExpandAll={false}
                        onSelect={this.onSelect}
                        onCheck={this.onCheck}
                        disabled={isCode}
                      >
                        {treeNode}
                      </Tree>
                    }
                  </FormItem>
                }
                <FormItem
                  wrapperCol={{
                    xs: {span: 24, offset: 0},
                    sm: {span: 16, offset: 8},
                  }}
                >
                  <Button loading={submitting} type="primary" htmlType="submit" disabled={isCode}>提交</Button>
                </FormItem>
              </Col>
            </Row>
          </Form>
        </Card>
      </PageHeaderLayout>
    )
  }
}
