import React, {Component} from 'react';
import {connect} from 'dva';
import {Link} from 'dva/router';
import {parse} from 'qs';
import {
  Form,
  Input,
  Button,
  Row,
  Col,
  Checkbox,
  Card,
  Select,
  InputNumber,
  Upload,
  Icon,
  message,
  Modal
} from 'antd';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {getSessionStorage, upYunAuthorization} from '../../utils/utils';
import styles from './GiftAdd.less';
import {getCity} from '../../utils/getCity';
import {Tree} from 'antd';

const {TreeNode} = Tree;
const FormItem = Form.Item;
const Option = Select.Option;
const CheckboxGroup = Checkbox.Group;

const {TextArea} = Input;
@connect(({loading, gift}) => ({
  submitting: loading.effects['gift/addSubmit'],
  sites: gift.sites,
  accumulations: gift.accumulations
}))
@Form.create()
export default class Gift extends Component {
  state = {
    formValues: '',
    pics: [],
    // options: JSON.parse(getSessionStorage('currentSiteMethods')),
    methodList: undefined,
    checkMethod: undefined,
    isShow: false,
    //礼物图片list
    previewVisible: false,
    previewImage: '',
    fileList: [],
    selectedItems: [],
    gatherings: [],//gathering
    // codeTextShow:false
    cityShow: false,
    checkedKeys: [],
    indeterminate: true,
    checkAll: false,
    storeShow: true,
    checkedList: [],
    provinceList: getCity(),
    methodEnum: {
      TAKE: '用户自提',
      SEND: '场内派送',
      EXPRESS: '快递配送',
      ELECTRONIC_CODE: '电子券码'
    },
  };

  componentDidMount() {
    this.getSiteList();
    this.getAccumulations();
  }

  getSiteList() {
    this.props.dispatch({
      type: 'gift/fetchSites',
      payload: {
        page: 1,
        pageSize: 99999
      }
    })
  }

  getAccumulations() {
    this.props.dispatch({
      type: 'gift/fetchAccumulations',
      payload: {
        page: 1,
        pageSize: 99999
      }
    })
  }

  handleSelectedChange = selectedItems => {
    var gatherings = [];
    this.props.accumulations.map(g => {
      selectedItems.map(item => {
        if (g.name === item) {
          gatherings.push({gatheringId: g.id})
        }
      })
    });
    this.setState({selectedItems, gatherings});
  };
  handleSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFields(['name', 'introduce', 'siteId', 'money', 'number', this.state.isShow ? 'codes' : ''], (err, values) => {
      if (!err) {
        var regions = [];
        if (this.state.checkAll) {
          regions = [{regionId: 99999}]
        } else {
          this.state.checkedKeys.map(item => {
            regions.push({regionId: item})
          });

          for (let i = 0; i < this.state.provinceList.length; i++) {
            for (let j = 0; j < regions.length; j++) {
              if (parseInt(regions[j].regionId) === this.state.provinceList[i].value) {
                regions.splice(j, 1);

              }
            }
          }
        }
        this.props.dispatch({
          type: 'gift/addSubmit',
          payload: {
            ...values,
            pics: this.formartSubmitPics(this.state.fileList),
            method: this.acTiveArrStringFun(this.state.checkMethod),
            gatherings: this.state.gatherings,
            regions
          }
        })
      }
    })
  };

  //商家礼物发送方式

  onChange = (e) => {
    const {methodList} = this.state;
    var cityShow = this.state.cityShow;
    var isShow = this.state.isShow;
    var storeShow = this.state.storeShow;
    if (e.indexOf('ELECTRONIC_CODE') >= 0) {
      methodList.map(item => {
        item.disabled = true;
        if (item.value === 'ELECTRONIC_CODE') {
          item.disabled = false;
          cityShow = true;
          isShow = true;
          storeShow = false;
        }
      })
    } else if (e.indexOf('EXPRESS') >= 0) {
      methodList.map(item => {
        item.disabled = true;
        if (item.value === 'EXPRESS') {
          item.disabled = false;
          cityShow = true;
          isShow = false;
          storeShow = true;
        }
      })
    } else if (e.indexOf('TAKE') >= 0 || e.indexOf('SEND') >= 0) {
      methodList.map(item => {
        item.disabled = true;
        if (item.value === 'TAKE' || item.value === 'SEND') {
          item.disabled = false;
          cityShow = false;
          isShow = false;
          storeShow = true;
        }
      });
    } else {
      methodList.map(item => {
        item.disabled = false;
        cityShow = false;
        isShow = false;
        storeShow = true;
      })
    }
    this.setState({checkMethod: e, cityShow, isShow, storeShow})
  };

  formartSubmitPics(fileList) {
    console.log(fileList);
    let pic = null;
    let pics = [];
    if (fileList) {
      fileList.map((item, index) => {
        pic = {
          link: 'http://image.seemore.club' + item.response.url,
          num: index + 1
        };
        pics.push(pic);
      })
    }
    return pics
  }

  closeCodeCheckBox(index) {
    let opt = this.state.options;
    opt.map(item => {
      item.disabled = false
    });
    opt[index].disabled = true;
    this.setState({
      options: [...opt]
    })
  }

  acTiveArrStringFun(obj) {
    const arr = [];
    if (obj != null && obj.length !== 0) {
      for (let i = 0; i < obj.length; i++) {
        arr.push(obj[i]);
      }
    }
    return arr.toString();
  }

  //商户改变
  handleSiteChange = (e) => {
    const curSite = this.props.sites.filter(s => s.id === e);
    // console.log(curSite);
    const temp = this.formartMethod(curSite[0].method);
    var methodList = [];
    if (Array.isArray(temp)) {
      methodList = temp
    } else {
      methodList.push(temp);
    }
    var options = [];
    var option = {};
    methodList.map(m => {
      option = {
        label: this.state.methodEnum[m],
        value: m,
        disabled: false
      };
      options.push(option)
    });
    this.setState({
      methodList: options,
      checkMethod: [],
    })

  };

  formartMethod(str) {
    if (str.indexOf(',') >= 0) {
      return str.split(',')
    } else {
      let arr = [];
      arr.push(str);
      return arr
    }
  }

  //礼物图片start
  handleCancel = () => this.setState({previewVisible: false})

  handlePreview = (file) => {
    this.setState({
      previewImage: file.url || file.thumbUrl,
      previewVisible: true,
    });
  };

  //礼物图片end

  onSelect = (selectedKeys, info) => {
    console.log('selected', selectedKeys, info);
  };

  onCheck = (checkedKeys, info) => {
    this.setState({checkedKeys})
  };

  checkAll = () => {
    this.setState({
      checkAll: !this.state.checkAll,
    })
  };

  render() {
    const {submitting, loading, sites, accumulations} = this.props;
    const siteId = parse(this.props.location.search.substr(1)).siteId;
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8}
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16}
      }
    };
    const date = Date.parse(new Date());
    const uploadProps = {
      // action: 'http://v0.api.upyun.com/seemore-web1',
      action: 'http://v0.api.upyun.com/image-seemore',
      listType: 'picture-card',
      data: {
        'authorization': upYunAuthorization("gift", date).authorization,
        'policy': upYunAuthorization("gift", date).policy,
      },
      name: 'file',
      headers: {
        'X-Requested-With': null,
      },
      // defaultFileList: this.props.gift ? this.props.gift.pics : [],
      onChange: (info) => {
        const status = info.file.status;
        if (status === 'done') {
          message.success(`${info.file.name} 文件上传成功.`);
        } else if (status === 'error') {
          message.error(`${info.file.name} 文件上传失败，请重新上传。`);
        }
        this.setState({fileList: info.fileList})
      }
    };

    const sitesOptions = Array.isArray(sites) && sites.length ? sites.map(d =>
      <Option value={d.id} key={d.id}>{d.name}</Option>) : [];

    const {selectedItems} = this.state;
    const filteredOptions = accumulations.filter(o => !selectedItems.includes(o.name));
    const {previewVisible, previewImage, pics, checkAll, fileList} = this.state;
    const uploadButton = (
      <div>
        <Icon type="plus"/>
        <div className="ant-upload-text">Upload</div>
      </div>
    );
    const provinceList = getCity();

    const treeNode = provinceList.map(p =>
      <TreeNode title={p.label} key={p.value}>
        {p.children.map(c =>
          (
            <TreeNode title={c.label} key={c.value}/>
          )
        )}
      </TreeNode>
    );

    return (
      <PageHeaderLayout>
        <Card title='新建礼物' loading={loading}>
          <Form onSubmit={this.handleSubmit}>
            <Row gutter={{md: 8, lg: 24, xl: 48}}>
              <Col md={12} offset={4} sm={24}>
                <FormItem
                  {...formItemLayout}
                  label="礼物图片"
                >
                  {getFieldDecorator('pics', {
                    rules: [{
                      required: true, message: '礼物名称不能为空',
                    }]
                  })(
                    <Upload {...uploadProps}
                            fileList={fileList}
                            onPreview={this.handlePreview}
                    >
                      {fileList && fileList.length >= 10 ? null : uploadButton}
                    </Upload>
                  )}
                  {/*<Upload {...uploadProps}*/}
                          {/*fileList={fileList}*/}
                          {/*onPreview={this.handlePreview}*/}
                  {/*>*/}
                    {/*{fileList && fileList.length >= 10 ? null : uploadButton}*/}
                  {/*</Upload>*/}
                  <Modal visible={previewVisible} footer={null} onCancel={this.handleCancel}>
                    <img alt="example" style={{width: '100%'}} src={previewImage}/>
                  </Modal>
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="礼物名称"
                >
                  {getFieldDecorator('name', {
                    rules: [{
                      required: true, message: '礼物名称不能为空',
                    }, {
                      max: 40, message: '最多输入40个字符'
                    }],
                  })(
                    <Input placeholder="请输入礼物名称"/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="礼物简介"
                >
                  {getFieldDecorator('introduce', {
                    rules: [{
                      required: true, message: '礼物名称不能为空',
                    },
                      {
                        max: 40, message: '礼物介绍最多40个字符',
                      }
                    ],
                  })(
                    <TextArea placeholder="请输入礼物介绍" autosize={{minRows: 2}}/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="所属商户"
                >
                  {getFieldDecorator('siteId', {
                    // initialValue: sitesOptions && siteId || "",
                    rules: [{
                      required: true, message: '所属商户不能为空'
                    }]
                  })(
                    <Select
                      allowClear={true}
                      style={{width: '100%'}}
                      placeholder="请选择所属商户"
                      onChange={this.handleSiteChange}
                    >
                      {sitesOptions}
                    </Select>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="所属推荐聚点"
                >
                  <Select
                    mode="multiple"
                    placeholder="请选择所属推荐聚点"
                    value={selectedItems}
                    onChange={this.handleSelectedChange}
                    style={{width: '100%'}}
                  >
                    {filteredOptions.map(item => (
                      <Select.Option key={item} value={item.name}>
                        {item.name}
                      </Select.Option>
                    ))}
                  </Select>
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="礼物单价"
                >
                  {getFieldDecorator('money', {
                    rules: [{
                      required: true, message: '礼物单价不能为空'
                    }]
                  })(
                    <InputNumber style={{width: '100%'}} placeholder="请输入礼物单价"/>
                  )}
                </FormItem>
                {
                  this.state.storeShow ? <FormItem
                    {...formItemLayout}
                    label="礼物库存"
                  >
                    {getFieldDecorator('number', {
                      rules: [{
                        required: true, message: '礼物库存不能为空'
                      }]
                    })(
                      <InputNumber style={{width: '100%'}} placeholder="请输入礼物库存"/>
                    )}
                  </FormItem> : ''
                }
                {
                  this.state.methodList && <FormItem
                    {...formItemLayout}
                    label="礼物领取方式"
                  >
                    {getFieldDecorator('method', {
                      // initialValue: r_checkMethod,
                      rules: [{
                        required: true, message: '礼物领取方式不能为空'
                      }]
                    })(
                      <CheckboxGroup options={this.state.methodList} onChange={this.onChange}/>
                    )}
                  </FormItem>
                }
                <FormItem
                  {...formItemLayout}
                  label="电子券码"
                  style={{display: this.state.isShow ? 'block' : 'none'}}
                >
                  {getFieldDecorator('codes', {
                    rules: [{
                      required: true, message: '电子券码不能为空'
                    }]
                  })(
                    <TextArea placeholder="请输入电子券码" autosize={{minRows: 2}}/>
                  )}
                </FormItem>
                {
                  this.state.cityShow && <FormItem
                    {...formItemLayout}
                    label="礼物到达城市"
                  >
                    {/*<Button type="primary" htmlType="button"*/}
                    {/*onClick={this.checkAll}>{this.state.checkAll ? '非全国' : '全国'}</Button>*/}

                    <Checkbox onChange={this.checkAll}
                              checked={checkAll}>全国</Checkbox>

                    {!this.state.checkAll && <Tree
                      checkable
                      checkedKeys={this.state.checkedKeys}
                      defaultExpandAll={false}
                      onSelect={this.onSelect}
                      onCheck={this.onCheck}
                    >
                      {treeNode}
                    </Tree>}
                  </FormItem>
                }
                <FormItem
                  wrapperCol={{
                    xs: {span: 24, offset: 0},
                    sm: {span: 16, offset: 8},
                  }}
                >
                  <Button loading={submitting} type="primary" htmlType="submit">提交</Button>
                </FormItem>
              </Col>
            </Row>
          </Form>
        </Card>
      </PageHeaderLayout>
    )
  }
}
