import React, { Component } from 'react';
import { connect } from 'dva';
import { Link } from 'dva/router';
import { Form, Input, Button, Row, Col, Checkbox, Card, Select } from 'antd';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import { parse } from 'qs';
const FormItem = Form.Item;
const Option = Select.Option;
const CheckboxGroup = Checkbox.Group;
@connect(({ loading, role }) => ({
  submitting: loading.effects['role/submit'],
  loading: loading.effects['role/fetchRole'],
  role: role.role,
  authorityList: role.authorityList,
}))
@Form.create()
export default class Comsumer extends Component {
  state = {
    formValues: '',
  };

  componentDidMount() {
    const { dispatch } = this.props;
    const { id } = parse(this.props.location.search.substr(1));
    dispatch({
      type: 'role/fetchAll',
      payload: {},
    });
    dispatch({
      type: 'role/fetchProfile',
      payload: {
        id,
      },
    });
  }

  handleChange = (checkedValues) => {
    console.log('checked = ', checkedValues);
  }

  handleSubmit = (e) => {
    const { id } = parse(this.props.location.search.substr(1));
    e.preventDefault();
    this.props.form.validateFields((err, values) => {
      if (!err) {
        let list = [];
        values.authorities.map((item) => {
          list.push({
            id: item,
          });
        });
        this.props.dispatch({
          type: 'role/submit',
          payload: {
            ...values,
            code: '2',
            id,
            authorities: list,
          },
        });
      }
    });
  };

  render() {
    const { submitting, role, loading, authorityList } = this.props;
    const { getFieldDecorator } = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
    };
    return (
      <PageHeaderLayout>
        <Card title='角色详情'>
          <Form onSubmit={this.handleSubmit} >
            <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
              <Col md={12} offset={4} sm={24}>
                <FormItem
                  {...formItemLayout}
                  label="角色名称"
                >
                  {getFieldDecorator('name', {
                    rules: [{
                      required: true, message: '角色名称不能为空'
                    }],
                    initialValue: role && role.name,
                  })(
                    <Input />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="角色描述"
                >
                  {getFieldDecorator('description', {
                    rules: [{
                      required: true, message: '角色描述不能为空'
                    }],
                    initialValue: role && role.description,
                  })(
                    <Input />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="角色权限"
                >
                  {getFieldDecorator('authorities', {
                    initialValue: role && role.authorityList,
                    rules: [{
                      required: true, message: '角色权限不能为空'
                    }],
                  })(
                    <CheckboxGroup options={authorityList} />
                  )}
                </FormItem>
                <FormItem
                  wrapperCol={{
                    xs: { span: 24, offset: 0 },
                    sm: { span: 16, offset: 8 },
                  }}
                >
                  <Button loading={submitting} type="primary" htmlType="submit">提交</Button>
                </FormItem>
              </Col>
            </Row>
          </Form>
        </Card>
      </PageHeaderLayout>
    );
  }
}
