import React, { Component } from 'react';
import { connect } from 'dva';
import { Link } from 'dva/router';
import { Form, Input, Button, Row, Col, Checkbox, Card, Select } from 'antd';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
const FormItem = Form.Item;
const Option = Select.Option;
const CheckboxGroup = Checkbox.Group;
@connect(({ loading, role }) => ({
  submitting: loading.effects['role/submit'],
  loading: loading.models.role,
  authorityList: role.authorityList,
}))
@Form.create()
export default class RoleAdd extends Component {
  state = {
    formValues: '',
  };

  componentDidMount() {
    this.props.dispatch({
      type: 'role/fetchAll',
    });
  }

  handleSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFields((err, values) => {
      if (!err) {
        let list = [];
        values.authorities.map((item) => {
          list.push({
            id: item,
            code: '2',
          });
        })
        this.props.dispatch({
          type: 'role/submit',
          payload: {
            ...values,
            code: '2',
            authorities: list,
          },
        });
      }
    });
  };

  render() {
    const { submitting, user, loading, handleChange, authorityList } = this.props;
    const { getFieldDecorator } = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
    };
    return (
      <PageHeaderLayout>
        <Card title='新建角色' loading={loading}>
          <Form onSubmit={this.handleSubmit}>
            <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
              <Col md={12} offset={4} sm={24}>
                <FormItem
                  {...formItemLayout}
                  label="角色名称"
                >
                  {getFieldDecorator('name', {
                    rules: [{
                      required: true, message: '角色名称不能为空'
                    }],
                  })(
                    <Input placeholder="请输入角色名称" />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="角色描述"
                >
                  {getFieldDecorator('description', {
                    rules: [{
                      required: true, message: '角色描述不能为空'
                    }],
                  })(
                    <Input placeholder="请输入角色描述" />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="选择权限"
                >
                  {getFieldDecorator('authorities', {
                    rules: [{
                      required: true, message: '权限不能为空'
                    }],
                  })(
                    <CheckboxGroup options={authorityList} />
                  )}
                </FormItem>
                <FormItem
                  wrapperCol={{
                    xs: { span: 24, offset: 0 },
                    sm: { span: 16, offset: 8 },
                  }}
                >
                  <Button loading={submitting} type="primary" htmlType="submit">提交</Button>
                </FormItem>
              </Col>
            </Row>
          </Form>
        </Card>
      </PageHeaderLayout>
    );
  }
}
