import React, {Component} from 'react';
import Debounce from 'lodash-decorators/debounce';
import Bind from 'lodash-decorators/bind';
import {connect} from 'dva';
import {parse} from 'qs';
import {
  Button,
  Card,
  Form,
  Input,
  Upload,
  Select,
  Icon,
  message,
  Checkbox,
  Cascader
} from 'antd';
import Address from 'components/Map';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import moment from 'moment';
import {getSessionStorage, setSessionStorage, upYunAuthorization} from '../../utils/utils';
import {getCity} from "../../utils/getCity";

const FormItem = Form.Item;
const {TextArea} = Input;
const Option = Select.Option;
const CheckboxGroup = Checkbox.Group;
const getWindowWidth = () => window.innerWidth || document.documentElement.clientWidth;
@connect(({site, loading}) => ({
  submitting: loading.effects['site/addSubmit'],
  gatheringList: site.gatheringList
}))
@Form.create()
export default class SiteAdd extends Component {

  state = {
    stepDirection: 'horizontal',
    pic: '',
    logo: '',
    subAcc: false,
    options: [
      {
        label: '用户自提',
        value: 'TAKE',
        disabled: false
      },
      {
        label: '场内派送',
        value: 'SEND',
        disabled: false
      },
      {
        label: '快递配送',
        value: 'EXPRESS',
        disabled: false
      },
      {
        label: '电子券码',
        value: 'ELECTRONIC_CODE',
        disabled: false
      }
    ],
    checkMethod: undefined,
    cityId: undefined,
    city: undefined,//['四川省', '成都市', '青羊区'],
    marker: undefined
  };

  componentDidMount() {
    this.setStepDirection();
    this.getAccumulationList();
    window.addEventListener('resize', this.setStepDirection);
  }

  componentWillUnmount() {
    window.removeEventListener('resize', this.setStepDirection);
    this.setStepDirection.cancel();
  }

  onOperationTabChange = key => {
    this.setState({operationkey: key});
  };

  @Bind()
  @Debounce(200)
  setStepDirection() {
    const {stepDirection} = this.state;
    const w = getWindowWidth();
    if (stepDirection !== 'vertical' && w <= 576) {
      this.setState({
        stepDirection: 'vertical',
      });
    } else if (stepDirection !== 'horizontal' && w > 576) {
      this.setState({
        stepDirection: 'horizontal',
      });
    }
  }

  getAccumulationList() {
    this.props.dispatch({
      type: 'site/fetchAllGatheringList',
      payload: {
        page: 1,
        pageSize: 9999
      }
    })
  }

  handleSubmit = e => {
    e.preventDefault();
    const {dispatch, form} = this.props;
    setSessionStorage('accumulationType', 2);
    form.validateFields(['name', 'introduce', 'affiche', 'userName', 'passWord', 'seemoreMsg', 'type', 'email', 'gatheringId','pic','logo','method'], (err, fieldsValue) => {
      if (err) return;
      const values = {
        ...fieldsValue,
      };
      dispatch({
        type: 'site/addSubmit',
        payload: {
          ...values,
          // gatheringId: parse(this.props.location.search.substr(1)).gatheringId,
          pic: this.state.pic,
          logo:this.state.logo,
          method: this.acTiveArrStringFun(this.state.checkMethod),
          cityId: this.state.cityId,
          latitude: this.state.marker.lat,
          longitude: this.state.marker.lng
        }
      })
    })
  };

  //商家类型选择
  handleChange = (e) => {
    // console.log(e)
    if (e === 'GATHERING') {
      this.setState({
        subAcc: true
      })
    } else {
      this.setState({
        subAcc: false
      })
    }
  };

  //商家礼物发送方式
  onChange = (e) => {
    // let opt = this.state.options
    // //电子券在选项中的下标
    // let codeIndex = -1
    // opt.map((item, index) => {
    //   if (item.value === 'ELECTRONIC_CODE') {
    //     // console.log(index)
    //     codeIndex = index;
    //     return
    //   }
    // });
    //
    // if (codeIndex !== -1) {
    //   //有电子券选项
    //   if (e.includes('ELECTRONIC_CODE')) {
    //     //选了电子券
    //     opt.map(item => {
    //       item.disabled = true
    //     });
    //     opt[codeIndex].disabled = false
    //     this.setState({
    //       isShow: true
    //     })
    //   } else if (e.includes('TAKE') || e.includes('SEND') || e.includes('EXPRESS')) {
    //     //没选电子券
    //     opt.map(item => {
    //       item.disabled = false
    //     });
    //     opt[codeIndex].disabled = true
    //     this.setState({
    //       isShow: false
    //     })
    //   } else {
    //     //什么都没选
    //     opt.map(item => {
    //       item.disabled = false
    //     });
    //     this.setState({
    //       isShow: false
    //     })
    //   }
    //   this.setState({
    //     options: [...opt]
    //   })
    // }
    this.setState({
      checkMethod: e
    })

    // this.setState({
    //   checkMethod: this.acTiveArrStringFun(e)
    // })
  };

  //获取cityId
  // handleCityChange = (e) => {
  //   console.log(e);
  //   this.setState({
  //     cityId: e[1]
  //   })
  // };

  handleCityChange = (value, selectedOptions) => {
    let city = [];
    selectedOptions.map((item) => {
      city.push(item.label)
    });
    this.setState({
      city,
      cityId: value[1]
    })
  };

  acTiveArrStringFun(obj) {
    const arr = [];
    if (obj != null && obj.length !== 0) {
      for (let i = 0; i < obj.length; i++) {
        arr.push(obj[i])
      }
    }
    return arr.toString()
  }

  handlePointIn = (e) => {
    let point = JSON.stringify(e);
    this.setState({
      pointIn: point
    })
  };
  handlePointOut = (e) => {
    let point = JSON.stringify(e);
    this.setState({
      pointOut: point
    })
  };
  handleMarker = (e) => {
    this.setState({
      marker: e
    })
  };

  onPicChange(str, info) {
    const status = info.file.status;
    if (status === 'done') {
      message.success(`${info.file.name} 文件上传成功.`);
      if (str === 'pic') {
        this.setState({
          pic: 'http://image.seemore.club' + JSON.parse(event.currentTarget.response).url
        })
      } else {
        this.setState({
          logo: 'http://image.seemore.club' + JSON.parse(event.currentTarget.response).url
        })
      }
    } else if (status === 'error') {
      message.error(`${info.file.name} 文件上传失败，请重新上传。`)
    }
  };

  render() {
    const {submitting, gatheringList} = this.props;
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 8},
        sm: {span: 4},
      },
      wrapperCol: {
        xs: {span: 16},
        sm: {span: 12},
      },
    };
    const tailFormItemLayout = {
      wrapperCol: {
        xs: {
          span: 16,
          offset: 8,
        },
        sm: {
          span: 20,
          offset: 4,
        },
      },
    };
    const date = Date.parse(new Date());
    const uploadProps = {
      action: 'http://v0.api.upyun.com/image-seemore',
      listType: 'picture',
      data: {
        'authorization': upYunAuthorization("site", date).authorization,
        'policy': upYunAuthorization("site", date).policy,
      },
      name: 'file',
      headers: {
        'X-Requested-With': null,
      },
      // onChange: (info) => {
      //   console.log(info);
      //   console.log(this);
      //   const status = info.file.status;
      //   if (status === 'done') {
      //     message.success(`${info.file.name} 文件上传成功.`);
      //     this.setState({
      //       pic: 'http://image.seemore.club' + JSON.parse(event.currentTarget.response).url
      //     })
      //   } else if (status === 'error') {
      //     message.error(`${info.file.name} 文件上传失败，请重新上传。`)
      //   }
      // }
    };
    //商家列表
    const Option = Select.Option;
    let siteList = [];
    for (let i = 0; i < gatheringList.length; i++) {
      siteList.push(<Option key={gatheringList[i].id} value={gatheringList[i].id}>{gatheringList[i].name}</Option>);
    }

    return (
      <PageHeaderLayout>
        <Card title="商户名称" style={{marginBottom: 24}} bordered={false}>
          <Form onSubmit={this.handleSubmit}>
            <FormItem
              {...formItemLayout}
              label="商户封面图"
            >
              {getFieldDecorator('pic', {
                initialValue: this.state.pic,
                rules: [{
                  required: true, message: '请上传商户封面图',
                }],
              })(
                <Input disabled placeholder="请上传商户封面图"/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="上传商户封面图"
            >
              <Upload id='pic' {...uploadProps} onChange={this.onPicChange.bind(this, 'pic')}>
                <Button>
                  <Icon type="upload"/> upload
                </Button>
                &nbsp;&nbsp;&nbsp;&nbsp;尺寸要求180px*180px
              </Upload>
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="商户logo"
            >
              {getFieldDecorator('logo', {
                initialValue: this.state.logo,
                rules: [{
                  required: true, message: '请上传商户logo',
                }],
              })(
                <Input disabled placeholder="请上传商户logo"/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="上传商户logo"
            >
              <Upload {...uploadProps} onChange={this.onPicChange.bind(this, 'logo')}>
                <Button>
                  <Icon type="upload"/> upload
                </Button>
                &nbsp;&nbsp;&nbsp;&nbsp;尺寸要求180px*180px
              </Upload>
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="商户名称"
            >
              {getFieldDecorator('name', {
                rules: [{
                  required: true, message: '请输入商户名称',
                }, {
                  max: 10, message: '最多输入10个字符',
                },],
              })(
                <Input placeholder="请输入商户名称"/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="商户介绍"
            >
              {getFieldDecorator('introduce', {
                rules: [{
                  required: true, message: '请输入商户介绍',
                }, {
                  max: 40, message: '最多输入40个字符',
                },],
              })(
                <TextArea placeholder="请输入商户介绍，最多40个字符" autosize={{minRows: 4}}/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="商户公告"
            >
              {getFieldDecorator('affiche', {
                // rules: [{
                //   // required: true, message: '请输入商家公告',
                // },
                //   // {
                //   //   max: 40, message: '最多输入40个字符',
                //   // }
                // ]
              })(
                <TextArea placeholder="请输入商户公告" autosize={{minRows: 4}}/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="所属聚点"

            >
              {getFieldDecorator('gatheringId', {
                // initialValue: user && user.sex,
              })(
                <Select>
                  {siteList}
                </Select>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="所属省市"
            >
              {getFieldDecorator('cityId', {
                // rules: [{
                //   required: true, message: '请选择商户所在省市',
                // }],
              })(
                <Cascader showSearch={true} onChange={this.handleCityChange} options={getCity()}
                          placeholder="请选择商户所在省市"/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="选择商户位置"
            >
              <div>请在地图上选择聚点范围，右键单击鼠标确定。</div>
              <Address
                btn={false}
                key={Math.random()}
                place={['四川省', '成都市', '青羊区']}
                prevPointIn={this.state.pointIn ? this.state.pointIn : true}
                prevPointOut={this.state.pointOut ? this.state.pointOut : true}
                prevMarker={this.state.marker ? this.state.marker : false}
                handlePointIn={this.handlePointIn.bind(this)}
                handlePointOut={this.handlePointOut.bind(this)}
                handleMarker={this.handleMarker.bind(this)}
              >
              </Address>
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="商户管理员账号"
            >
              {getFieldDecorator('userName', {
                rules: [{
                  required: true, message: '请输入商户管理员账号',
                }],
              })(
                <Input placeholder="请输入商户管理员账号"/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="商户管理员密码"
            >
              {getFieldDecorator('passWord', {
                rules: [{
                  required: true, message: '请输入商户管理员密码'
                }]
              })(
                <Input type="password" placeholder="请输入商户管理员密码"/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="商户流水接收邮箱"
            >
              {getFieldDecorator('email', {
                rules: [{
                  required: true, message: '请输入商家流水接收邮箱'
                }]
              })(
                <Input placeholder="请输入商户流水接收邮箱"/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="礼物领取方式"
            >
              {getFieldDecorator('method', {
                rules:[{
                  required: true, message: '请选择礼物领取方式'
                }]
              })(
                <CheckboxGroup options={this.state.options} onChange={this.onChange}/>
              )}
            </FormItem>
            <FormItem
              {...formItemLayout}
              label="礼物兑换处说明"
            >
              {getFieldDecorator('seemoreMsg', {
                initialValue: '本店私慕礼物兑换处位置位于用户寄存包窗口，营业时间至凌晨2点',
                rules: [{
                  required: true, message: '请输入商户介绍',
                }, {
                  max: 40, message: '最多输入40个字符',
                },],
              })(
                <TextArea placeholder="请输入私慕礼物兑换处位置及营业时间说明，最多40个字符" autosize={{minRows: 4}}/>
              )}
            </FormItem>
            <FormItem {...tailFormItemLayout}>
              <Button loading={submitting} type="primary" htmlType="submit">提交</Button>
            </FormItem>
            {/*<FormItem*/}
            {/*{...formItemLayout}*/}
            {/*label="商户类型"*/}
            {/*>*/}
            {/*{getFieldDecorator('type', {*/}
            {/*// initialValue: user && user.sex,*/}
            {/*})(*/}
            {/*<Select onChange={this.handleChange}>*/}
            {/*<Option value="PLAZA">广场商户</Option>*/}
            {/*<Option value="GATHERING">聚点商户</Option>*/}
            {/*</Select>*/}
            {/*)}*/}
            {/*</FormItem>*/}
          </Form>
        </Card>
      </PageHeaderLayout>
    )
  }
}
