import React, {Component} from 'react';
import {connect} from 'dva';
import {Link} from 'dva/router';
import {
  Form,
  Input,
  Button,
  Row,
  Col,
  Checkbox,
  Card,
  Select,
  InputNumber,
  Upload,
  Icon,
  message,
} from 'antd';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {parse} from 'qs';
import {getSessionStorage, upYunAuthorization} from '../../utils/utils';

const FormItem = Form.Item;
const Option = Select.Option;
const CheckboxGroup = Checkbox.Group;
const {TextArea} = Input;
@connect(({loading, superLike}) => ({
  submitting: loading.effects['superLike/editSubmit'],
  superLike: superLike.superLike,
}))
@Form.create()
export default class SuperLike extends Component {

  state = {
    formValues: '',
    // pic: '',
    // options: JSON.parse(getSessionStorage('currentSiteMethods')),
    // checkMethod: undefined
    disabled:true
  };

  componentDidMount() {
    const {id} = parse(this.props.location.search.substr(1));
    this.props.dispatch({
      type: 'superLike/fetchDetail',
      payload: {
        id
      }
    })
  }

  handleSubmit = (e) => {
    e.preventDefault();
    if (!this.state.disabled){
      // const {id} = parse(this.props.location.search.substr(1));
      const {superLike} = this.props;
      this.props.form.validateFields((err, values) => {
        if (!err) {
          this.props.dispatch({
            type: 'superLike/editSubmit',
            payload: {
              id:superLike.id,
              ...values
            }
          })
        }
      })
    }
    this.setState({
      disabled:!this.state.disabled
    })
  };

  formatMethod(str) {
    return str.split(',');

    // let opt = this.state.options;
    // if (arr.includes('ELECTRONIC_CODE')) {
    //   opt[0].disabled = true;
    //   opt[1].disabled = true;
    //   opt[2].disabled = true;
    //   opt[3].disabled = false
    //
    // } else if (arr.includes('TAKE') || arr.includes('SEND') || arr.includes('EXPRESS')) {
    //   opt[0].disabled = false;
    //   opt[1].disabled = false;
    //   opt[2].disabled = false;
    //   opt[3].disabled = true
    // } else {
    //   opt.map(item => {
    //     item.disabled = false
    //   })
    // }
  }

  render() {
    const {submitting, loading, superLike} = this.props;
    const {getFieldDecorator} = this.props.form;
    const {disabled} = this.state;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8}
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16}
      },
    };
    const date = Date.parse(new Date());
    const uploadProps = {
      // action: 'http://v0.api.upyun.com/seemore-web1',
      action: 'http://v0.api.upyun.com/image-seemore',
      listType: 'picture',
      data: {
        'authorization': upYunAuthorization("gift", date).authorization,
        'policy': upYunAuthorization("gift", date).policy,
      },
      name: 'file',
      headers: {
        'X-Requested-With': null,
      },
      onChange: (info) => {
        const status = info.file.status;
        if (status === 'done') {
          message.success(`${info.file.name} 文件上传成功.`);
          this.setState({
            pic: 'http://image.seemore.club' + JSON.parse(event.currentTarget.response).url,
          });
        } else if (status === 'error') {
          message.error(`${info.file.name} 文件上传失败，请重新上传。`);
        }
      },
    };

    return (
      <PageHeaderLayout>
        <Card title='礼品详情' loading={loading}>
          <Form onSubmit={this.handleSubmit}>
            <Row gutter={{md: 8, lg: 24, xl: 48}}>
              <Col md={12} offset={4} sm={24}>
                <FormItem
                  {...formItemLayout}
                  label="礼品id"
                >
                  {getFieldDecorator('souvenirId', {
                    initialValue: superLike && superLike.souvenirId,
                    // rules: [{
                    //   required: true, message: '礼品单价不能为空'
                    // }]
                  })(
                    <InputNumber style={{width: '100%'}} placeholder="请输入礼品id" disabled={disabled}/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="VIP折扣"
                >
                  {getFieldDecorator('discount', {
                    initialValue: superLike && superLike.discount,
                    // rules: [{
                    //   required: true, message: '礼品单价不能为空'
                    // }]
                  })(
                    <InputNumber style={{width: '100%'}} placeholder="请输入VIP折扣" disabled={disabled}/>
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="序号"
                >
                  {getFieldDecorator('num', {
                    initialValue: superLike && superLike.num,
                    // rules: [{
                    //   required: true, message: '礼品单价不能为空'
                    // }]
                  })(
                    <InputNumber style={{width: '100%'}} placeholder="请输入序号" disabled={disabled}/>
                  )}
                </FormItem>
                <FormItem
                  wrapperCol={{
                    xs: {span: 24, offset: 0},
                    sm: {span: 16, offset: 8},
                  }}
                >
                  <Button loading={submitting} type="primary" htmlType="submit">{disabled?'开启修改':'保存'}</Button>
                </FormItem>
              </Col>
            </Row>
          </Form>
        </Card>
      </PageHeaderLayout>
    )
  }
}
