import React, {Component} from 'react';
import {connect} from 'dva';
import moment from 'moment';
import {Link} from 'dva/router';
import {
  Form,
  Table,
  Input,
  Button,
  Upload,
  Icon,
  Row,
  Col,
  Avatar,
  Card,
  Select,
  InputNumber,
  Tabs,
  List,
  Cascader,
} from 'antd';
import {parse} from 'qs';
import Address from 'components/Map';
import {getCity} from '../../utils/getCity';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import {setSessionStorage, getSessionStorage, sortTable, ApiPostDownloadFile, searchTable} from '../../utils/utils';
import Lightbox from 'react-image-lightbox';
import 'react-image-lightbox/style.css';
import styles from './CardList.less';

const FormItem = Form.Item;
const Option = Select.Option;
const TabPane = Tabs.TabPane;
@connect(({loading, svip}) => ({
  loading: loading.models.svip,
  submitting: loading.effects['svip/fetchProfile'],
  list: svip.list,
  label: svip.label,
  pageSize: svip.pageSize,
  page: svip.page,
  total: svip.total,
  all: svip.all,
}))
@Form.create()
export default class SvipIntegral extends Component {
  state = {
    formValues: '',
    photoIndex: 0,
    isOpen: false,
    pointAt: null,
    city: [],
    filters: {},
    order:{}
  };

  fetch = (payload) => {
    this.props.dispatch({
      type: 'svip/fetchProfile',
      payload: {
        ...payload,
      },
    });
  };

  componentDidMount() {
    const {id} = parse(this.props.location.search.substr(1));
    const {dispatch, page, pageSize} = this.props;
    const columns = [{
      name: 'consumer.id',
      relation: "EQ",
      search: id,
      type: "T_STRING"
    }];

    this.setState({
      filters: {
        columns,
      }
    });

    this.fetch({
      columns,
      page: getSessionStorage('scoreListCurrent') * 1 || page,
      pageSize: getSessionStorage('scoreListPageSize') * 1 || pageSize
    })
  }

  handleBasicSubmit = (e) => {
    const {id} = parse(this.props.location.search.substr(1));
    e.preventDefault();
    const {dispatch, form, pageSize, tagsList} = this.props;
    form.validateFields([
      'nickName',
      'sex',
      'tags',
      'site',
      'sysVocationId',
    ], (err, values) => {
      if (!err) {
        const {nickName, sex, site, sysVocationId, tags} = values;
        let tagsListOption = [];
        if (tags && tags.length) {
          tags.map((item) => {
            tagsList.map((item1) => {
              if (item === item1.key) {
                tagsListOption.push({
                  id: item,
                  name: item1.value,
                })
              }
            });
          });
        }
        ;
        dispatch({
          type: 'comsumer/submit',
          payload: {
            nickName,
            sex: sex === '男' ? 1 : 0,
            site,
            sysVocationId,
            tags: tagsListOption,
            id,
          },
        });
      }
    });
  };

  handlePointAt = (e) => {
    const point = JSON.stringify(e);
    this.setState({
      pointAt: point,
    }, () => {
      this.setState({
        pointAt: point,
      });
    });
  };

  handleCityChange = (value, selectedOptions) => {
    let city = [];
    selectedOptions.map((item) => {
      city.push(item.label);
    });
    this.setState({
      city,
    });
  };

  handleDataSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFields([
      'vipGrade',
      'vipTime',
      'svip',
      'astro',
      'phone',
      'tags',
    ], (err, values) => {
      if (!err) {
        this.props.dispatch({
          type: 'comsumer/submit',
          payload: {
            ...values,
          },
        });
      }
    });
  };

  handleSuspend = (e) => {
    e.preventDefault();
    this.props.dispatch({
      type: 'comsumer/suspend',
      payload: {
        id: this.props.user && this.props.user.id,
      },
    });
  };

  handleTabChange = (k) => {
    const {dispatch} = this.props;
    const {id} = parse(this.props.location.search.substr(1));
    if (k === '4') {
      dispatch({
        type: 'comsumer/fetchPhotoList',
        payload: {
          id,
        },
      });
    }
    if (k === '3') {
      dispatch({
        type: 'comsumer/fetchPayList',
        payload: {
          "columns": [
            {
              "name": "orderRecord.consumerA.id",
              "relation": "EQ",
              "search": id,
            }
          ],
          page: getSessionStorage("comsumerPayListPage") || this.props.payPage,
          pageSize: getSessionStorage("comsumerPayListPageSize") || this.props.payPage,
        },
      });
    }
    if (k === '2') {
      dispatch({
        type: 'comsumer/fetchData',
        payload: {
          id,
        },
      });
    }
    if (k === '1') {
      dispatch({
        type: 'comsumer/fetchProfile',
        payload: {
          id,
        }
      });
      dispatch({
        type: 'comsumer/fetchTags',
        payload: {},
      });
      dispatch({
        type: 'comsumer/fetchSysVocationId',
        payload: {},
      });
    }
  };

  handleExport = (e) => {
    e.preventDefault();

    const {page, pageSize} = this.props;
    const {columns} = this.state.filters;
    //API
    // ApiPostDownloadFile('/api/v1/export/integral', {
    ApiPostDownloadFile('http://test.admin.seemore.club/api/v1/export/integral', {
      columns,
      order: this.state.filters.order,
      page: getSessionStorage('scoreListCurrent') * 1 || page,
      pageSize: getSessionStorage('scoreListPageSize') * 1 || pageSize,
    });
  };

  handleSizeChange = (current, size) => {
    setSessionStorage("scoreListCurrent", current);
    setSessionStorage("scoreListPageSize", size);
  };

  handleTableChange = (pagination, filters, sorter) => {
    const {current, pageSize} = pagination;

    setSessionStorage("scoreListCurrent", current);
    setSessionStorage("scoreListPageSize", pageSize);

    this.fetch({
      columns: this.state.filters.columns,
      page: current,
      pageSize,
      // order:this.state.
    })
  };

  render() {
    const {
      list,
      loading,
      total,
      page,
      pageSize
    } = this.props;
    const pagination = {
      pageSize: getSessionStorage("scoreListPageSize") * 1 || pageSize,
      current: getSessionStorage("scoreListCurrent") * 1 || page,
      total: total,
      showSizeChanger: true,
      onShowSizeChange: this.handleSizeChange,
    };
    const {getFieldDecorator} = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: {span: 24},
        sm: {span: 8},
      },
      wrapperCol: {
        xs: {span: 24},
        sm: {span: 16},
      },
    };
    const columns = [
      {
        title: '序号',
        dataIndex: 'id',
        render: (text, record, index) => (
          index + 1 + (page - 1) * pageSize
        ),
      },
      {
        title: '说明',
        dataIndex: 'content',
        key: 'content'
      },
      {
        title: '积分数量',
        dataIndex: 'num',
        key: 'num'
      },
      {
        title: '产生时间',
        dataIndex: 'createDate',
        key: 'createDate',
        render: (text, record) => (
          record.createDate && moment(record.createDate).format('YYYY-MM-DD HH:mm:ss')
        ),
      }
    ];


    return (
      <PageHeaderLayout>
        <Card title='积分详情' className={styles.listCard}>
          <div className={styles.tableListOperator}>
            <Button style={{marginBottom: '16px'}} icon="download" onClick={this.handleExport}>
              导出表格
            </Button>
          </div>
          <Table
            bordered
            loading={loading}
            rowKey='id'
            columns={columns}
            dataSource={list}
            pagination={pagination}
            onChange={this.handleTableChange}
          />
        </Card>
      </PageHeaderLayout>
    );
  }
}
