import React, { Component } from 'react';
import { connect } from 'dva';
import { Link } from 'dva/router';
import { Form, Input, Button, Row, Col, Card, } from 'antd';
import Login from 'components/Login';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
const { Tab, UserName, Password, Mobile, Captcha, Submit } = Login;
const FormItem = Form.Item;
@connect(({ loading, user, personal }) => ({
  submitting: loading.effects['personal/editPassword'],
}))
@Form.create()
export default class EditPassword extends Component {
  state = {
    formValues: '',
  };

  handleSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFields((err, values) => {
      if (!err) {
        this.props.dispatch({
          type: 'personal/editPassword',
          payload: {
            ...values,
            id: parseInt(this.props.match.params.id),
          },
        });
      }
    });
  };

  checkPassword = (rule, value, callback) => {
    const form = this.props.form;
    if (value && value !== form.getFieldValue('password')) {
        callback('两次密码输入不一致！');
    } else {
        callback();
    }
  };

  render() {
    const { submitting, error, help, checkPassword } = this.props;
    const { getFieldDecorator } = this.props.form;
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
    };
    return (
      <PageHeaderLayout>
        <Card
          bordered={true}
          title="修改密码"
          style={{ marginTop: 24 }}
          bodyStyle={{ padding: '32px 40px' }}
        >
          <Form onSubmit={this.handleSubmit}>
            <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
              <Col md={12} offset={4} sm={24}>
                <FormItem
                  {...formItemLayout}
                  label="当前密码"
                >
                  {getFieldDecorator('oldPassword', {
                    rules: [
                      { required: true, message: '请输入当前密码' },
                    ],
                  })(
                    <Input type='password' placeholder='请输入当前密码' />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="新密码"
                >
                  {getFieldDecorator('password', {
                    rules: [
                      { required: true, message: '请输入新密码' },
                    ],
                  })(
                    <Input type='password' placeholder='请输入新密码' />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="再次输入新密码"
                >
                  {getFieldDecorator('confirmPassword', {
                    rules: [
                      { required: true, message: '请再次输入新密码' },
                      { validator: this.checkPassword },
                    ],
                  })(
                    <Input type='password' placeholder='请再次输入新密码' />
                  )}
                </FormItem>
                <FormItem
                  wrapperCol={{
                    xs: { span: 24, offset: 0 },
                    sm: { span: 16, offset: 8 },
                  }}
                >
                  <Button loading={submitting} type="primary" htmlType="submit">确定修改</Button>
                </FormItem>
              </Col>
            </Row>
          </Form>
        </Card>
      </PageHeaderLayout>
    );
  }
}
