import React, {Component} from 'react';
import {connect} from 'dva';
import {Link} from 'dva/router';
import {Checkbox, Alert, Icon} from 'antd';
import Login from 'components/Login';
import styles from './Login.less';
import {Base64} from 'js-base64';

const {Tab, UserName, Password, Mobile, Captcha, Submit} = Login;

import fetch from 'dva/fetch';

@connect(({login, loading}) => ({
  login,
  m: login.m,
  submitting: loading.effects['login/login'],
}))
export default class LoginPage extends Component {

  componentDidMount() {
    const userName = window.localStorage.getItem("userName") && Base64.decode(window.localStorage.getItem("userName"));
    const password = window.localStorage.getItem("userName") && Base64.decode(window.localStorage.getItem("userName"));
    if (this.state.autoLogin && userName && password) {
      this.props.dispatch({
        type: 'login/login',
        payload: {
          userName: userName,
          password: password,
        },
      });
    }
  }

  state = {
    type: 'account',
    autoLogin: false,
  };

  onTabChange = type => {
    this.setState({type});
  };

  handleSubmit = (err, values) => {
    const {type} = this.state;
    if (!err) {
      this.props.dispatch({
        type: 'login/login',
        payload: {
          ...values,
        },
      });
    }
  };

  changeAutoLogin = e => {
    this.setState({
      autoLogin: e.target.checked,
    });
  };

  renderMessage = content => {
    return <Alert style={{marginBottom: 24}} message={content} type="error" showIcon/>;
  };

  render() {
    const {login, submitting, m} = this.props;
    const {type} = this.state;
    return (
      <div className={styles.main}>
        <Login defaultActiveKey={type} onTabChange={this.onTabChange} onSubmit={this.handleSubmit}>
          <Tab key="account" tab="欢迎使用私幕Lite后台">
            {m === '错误的凭证,坏的凭证' &&
            !login.submitting &&
            this.renderMessage('用户名或密码错误')}
            <UserName name="username" placeholder="请输入用户名"/>
            <Password name="password" placeholder="请输入密码"/>
          </Tab>
          <Submit loading={submitting}>登录</Submit>
        </Login>
      </div>
    );
  }
}
