import React, { Component } from 'react';
import { connect } from 'dva';
import { Link } from 'dva/router';
import { Form, Input, Button, Upload, Icon, Row, Col, Avatar, Card } from 'antd';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
const FormItem = Form.Item;
@connect(({ loading, user }) => ({
  submitting: loading.effects['personal/submit'],
  loading: loading.models.user,
  currentUser: user.currentUser,
}))
@Form.create()
export default class Personal extends Component {
  state = {
    formValues: '',
  };


  handleSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFields(['name', 'email'], (err, values) => {
      if (!err) {
        this.props.dispatch({
          type: 'personal/submit',
          payload: {
            ...values,
            id: this.props.currentUser.id,
          },
        });
      }
    });
  };

  render() {
    const { submitting, currentUser, loading, handleSubmit } = this.props;
    const { getFieldDecorator } = this.props.form;
    const uploadProps = {
      action: '/api/upload',
      listType: 'picture',
      name: 'avatar',
    };
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
    };
    return (
      <PageHeaderLayout>
        <Card
          bordered={true}
          loading={loading}
          title="个人中心"
          style={{ marginTop: 24 }}
          bodyStyle={{ padding: '32px 40px' }}
        >
          <Form onSubmit={this.handleSubmit}>
            <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
              <Col md={12} offset={4} sm={24}>
                <FormItem
                  {...formItemLayout}
                  label="昵称"
                >
                  {getFieldDecorator('name', {
                    rules: [{
                      required: true, message: '请填您的昵称',
                    }],
                    initialValue: currentUser.name,
                  })(
                    <Input />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="账号"
                >
                  {getFieldDecorator('userName', {
                    rules: [{
                      required: true, message: '请填写您的账号',
                    }],
                    initialValue: currentUser.userName,
                  })(
                    <Input />
                  )}
                </FormItem>
                <FormItem
                  {...formItemLayout}
                  label="邮箱"
                >
                  {getFieldDecorator('email', {
                    rules: [{
                      required: true, message: '请填写邮箱',
                    }],
                    initialValue: currentUser.email,
                  })(
                    <Input placeholder='请填写邮箱' />
                  )}
                </FormItem>
                <FormItem
                  wrapperCol={{
                    xs: { span: 24, offset: 0 },
                    sm: { span: 16, offset: 8 },
                  }}
                >
                  <Button loading={submitting} type="primary" htmlType="submit">提交</Button>
                </FormItem>
              </Col>
            </Row>
          </Form>
        </Card>
      </PageHeaderLayout>
    );
  }
}
