import fetch from 'dva/fetch';
import {notification, message} from 'antd';
import {routerRedux} from 'dva/router';
import store from '../index';
import {getLocalStorage} from './utils';
// import fetchJsonp from 'fetch-jsonp';

const codeMessage = {
  200: '服务器成功返回请求的数据。',
  201: '新建或修改数据成功。',
  202: '一个请求已经进入后台排队（异步任务）。',
  204: '删除数据成功。',
  400: '发出的请求有错误，服务器没有进行新建或修改数据的操作。',
  401: '用户没有权限（令牌、用户名、密码错误）。',
  403: '用户得到授权，但是访问是被禁止的。',
  404: '发出的请求针对的是不存在的记录，服务器没有进行操作。',
  406: '请求的格式不可得。',
  410: '请求的资源被永久删除，且不会再得到的。',
  422: '当创建一个对象时，发生一个验证错误。',
  500: '服务器发生错误，请检查服务器。',
  502: '网关错误。',
  503: '服务不可用，服务器暂时过载或维护。',
  504: '网关超时。',
};

function checkStatus(response) {
  // console.log('checkStatus');
  // console.log(response);
  if (response.status >= 200 && response.status < 300) {
    return response;
  }
  const errortext = codeMessage[response.status] || response.statusText;
  // notification.error({
  //   message: `请求错误 ${response.status}: ${response.url}`,
  //   description: errortext,
  // });
  const error = new Error(errortext);
  error.name = response.status;
  error.response = response;
  // console.log('error');
  // console.log(error);
  throw error;
}

/**
 * Requests a URL, returning a promise.
 *
 * @param  {string} url       The URL we want to request
 * @param  {object} [options] The options we want to pass to "fetch"
 * @return {object}           An object containing either "data" or "err"
 */
export default function request(url, options) {
  // console.log(options);
  const defaultOptions = {
    credentials: 'include',
    // mode:'cors',
    // timeout: 100000,
  };
  const authorization = getLocalStorage('authorization') || '';
  const newOptions = {...defaultOptions, ...options};
  // console.log(newOptions);
  if (newOptions.method === 'POST' || newOptions.method === 'PUT' || newOptions.method === 'DELETE') {
    // console.log(authorization);
    if (url.indexOf('login') > -1) {
      if (!(newOptions.body instanceof FormData)) {
        // console.log(1);
        newOptions.headers = {
          Accept: 'application/json',
          'Content-Type': 'application/json; charset=UTF-8',
          ...newOptions.headers,
        };
        newOptions.body = JSON.stringify(newOptions.body);
      } else {
        // console.log(2);
        // newOptions.body is FormData
        newOptions.headers = {
          Accept: 'application/json',
          'Content-Type': 'application/json; charset=UTF-8',
          ...newOptions.headers,
        };
      }
    } else {
      if (!(newOptions.body instanceof FormData)) {
        // console.log(3);
        // console.log(authorization);
        newOptions.headers = {
          Accept: 'application/json',
          'Content-Type': 'application/json; charset=UTF-8',
          ...newOptions.headers,
          Authorization: authorization,
        };
        newOptions.body = JSON.stringify(newOptions.body);
      } else {
        // console.log(4);
        // console.log('123'+authorization);
        // newOptions.body is FormData
        newOptions.headers = {
          Accept: 'application/json',
          'Content-Type': 'application/json; charset=UTF-8',
          ...newOptions.headers,
          Authorization: authorization,
        };
      }
    }
  } else {
    // console.log('----'+authorization);
    // console.log(5);
    // console.log(authorization);
    newOptions.headers = {
      Accept: 'application/json',
      'Content-type': 'application/json; charset=UTF-8',
      Authorization: authorization,
    };
    // newOptions.headers = {
    //   Accept: 'application/json',
    //   'Content-Type': 'application/json; charset=utf-8',
    //   Authorization: authorization
    // };
  }
  // console.log('---fetch---');
  // console.log(url);
  // console.log(newOptions);
  return fetch(url, newOptions
    // {
    //   method: 'POST',
    //   mode: 'cors',
    //   credentials: 'include',
    //   headers: {
    //     Accept: 'application/json',
    //     'Content-Type': 'application/json; charset=utf-8',
    //     Authorization: authorization,
    //   }
    // }
  )
    .then(checkStatus)
    .then(response => {
      // console.log(6);
      // console.log(response);
      return response.json();
    })
    .then(res => {
      // console.log(7);
      // console.log(res);
      const {dispatch} = store;
      if (res.c === 9000) {
        dispatch({
          type: 'login/logout',
        });
        if (authorization) {
          message.error("权限过期，请重新登录");
        }
        return;
      }
      return res;
    })
    .catch(e => {
      // console.log(e);
      const status = e.name;
      // if (status === 403) {
      //   dispatch(routerRedux.push('/exception/403'));
      //   return;
      // }
      // if (status <= 504 && status >= 500) {
      //   message.error("对不起，您没有权限执行该操作");
      // }
      return;
      // if (status >= 404 && status < 422) {
      //   dispatch(routerRedux.push('/exception/404'));
      // }
    });
}
